/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              EXTENDED MODAL LOGICS ROUTINES            * */
/* *                                                        * */
/* *  $Module:   EML                                        * */ 
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.2 $                                        * */
/* $State: Exp $                                            * */
/* $Date: 2007/07/05 13:28:10 $                             * */
/* $Author: weidenb $                                       * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Renate Schmidt                             * */
/* *             School of Computer Science                 * */
/* *             University of Manchester                   * */
/* *             Oxford Rd, Manchester M13 9PL, UK          * */
/* *             Email: Renate.Schmidt@manchester.ac.uk     * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/
/* *              Modifications for Axiomatic Translation   * */
/* *              K.J.Smith @ 2007/8 john@KJSmith.net       * */


/* $RCSfile: eml.h,v $ */

#ifndef _EMLDFG_
#define _EMLDFG_

/**************************************************************/
/* Includes                                                   */
/**************************************************************/

#include "term.h"
#include "list.h"
#include "hasharray.h"

/**************************************************************/
/* Global Variables and Constants (Only seen by macros)       */
/**************************************************************/

extern SYMBOL  eml_APPLYF;
extern SYMBOL  eml_BOX;
extern SYMBOL  eml_COMP;
extern SYMBOL  eml_CONV;
extern SYMBOL  eml_DIA;
extern SYMBOL  eml_DIV;
extern SYMBOL  eml_DOMAIN;
extern SYMBOL  eml_DOMRESTR;
extern SYMBOL  eml_ID;
extern SYMBOL  eml_RANGE;
extern SYMBOL  eml_RANRESTR;
extern SYMBOL  eml_SUM;
extern SYMBOL  eml_TEST;

extern SYMBOL  eml_AXIOM_D; /* kjs */
extern SYMBOL  eml_AXIOM_B; /* kjs */ 
extern SYMBOL  eml_AXIOM_T; /* kjs */
extern SYMBOL  eml_AXIOM_4; /* kjs */
extern SYMBOL  eml_AXIOM_5; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1; /* kjs */

extern SYMBOL  eml_AXIOM_4K2; /* kjs */
extern SYMBOL  eml_AXIOM_4K3; /* kjs */
extern SYMBOL  eml_AXIOM_5K2; /* kjs */
extern SYMBOL  eml_AXIOM_5K3; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK11; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK12; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK21; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK22; /* kjs */

extern SYMBOL  eml_AXIOM_4K2c; /* kjs */
extern SYMBOL  eml_AXIOM_4K3c; /* kjs */
extern SYMBOL  eml_AXIOM_5K2c; /* kjs */
extern SYMBOL  eml_AXIOM_5K3c; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK11c; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK12c; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK21c; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK22c; /* kjs */

extern SYMBOL  eml_AXIOM_4K2o; /* kjs */
extern SYMBOL  eml_AXIOM_4K3o; /* kjs */
extern SYMBOL  eml_AXIOM_5K2o; /* kjs */
extern SYMBOL  eml_AXIOM_5K3o; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK11o; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK12o; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK21o; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1KK22o; /* kjs */

extern SYMBOL  eml_AXIOM_Dc; /* kjs */
extern SYMBOL  eml_AXIOM_Bc; /* kjs */ 
extern SYMBOL  eml_AXIOM_Tc; /* kjs */
extern SYMBOL  eml_AXIOM_4c; /* kjs */
extern SYMBOL  eml_AXIOM_5c; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1c; /* kjs */

extern SYMBOL  eml_AXIOM_Do; /* kjs */
extern SYMBOL  eml_AXIOM_Bo; /* kjs */ 
extern SYMBOL  eml_AXIOM_To; /* kjs */
extern SYMBOL  eml_AXIOM_4o; /* kjs */
extern SYMBOL  eml_AXIOM_5o; /* kjs */
extern SYMBOL  eml_AXIOM_ALT1o; /* kjs */

extern SYMBOL  eml_SLF; /* kjs */
extern SYMBOL  eml_AXIOMSLF; /* kjs */
extern SYMBOL  eml_NOAXIOM; /* kjs */

void eml_SetAxiomFlagValue(char*, char*); /* kjs */
void eml_SetAxiomFlagValue2(char*, int); /* kjs */
void eml_SetAxiomFlagValueBi(char*, char*, char*); /* kjs */

typedef enum { eml_PROP,
               eml_REL,
	       eml_NDE,
               eml_NARYPROP,
	       eml_NARYNDE,
	       eml_SEMIFNDE, 
               eml_VARSORT,
               eml_AXIOM,   /* kjs */
               eml_AXIOMREL  /* kjs */
} eml_SYMBOLTYPE;

extern LIST   *eml_PROPINDEXTOFOSYMBOL;
extern SYMBOL eml_SEMIFNDESYMBOLS[symbol__MAXSIGNATURE];            
/* Records which nde symbols have been created, for the semi-functional
 * translation */

#define eml__MAXMODALDEPTH 100
#define eml__MAXNOAXIOMSYMBOL 4096 /* kjs */

extern SYMBOL eml_NARYSYMBOLS[symbol__MAXSIGNATURE][eml__MAXMODALDEPTH];    
/* Records which symbols of the n-ary signature have been created */
int eml_GetPrecedenceMode();

/**************************************************************/
/* Access to the first-order symbols.                         */
/**************************************************************/

static __inline__ SYMBOL eml_Box(void)
{
  return eml_BOX;
}

static __inline__ SYMBOL eml_Dia(void)
{
  return eml_DIA;
}

static __inline__ SYMBOL eml_Domain(void)
{
  return eml_DOMAIN;
}

static __inline__ SYMBOL eml_Range(void)
{
  return eml_RANGE;
}

static __inline__ SYMBOL eml_Comp(void)
{
  return eml_COMP;
}

static __inline__ SYMBOL eml_Sum(void)
{
  return eml_SUM;
}

static __inline__ SYMBOL eml_Conv(void)
{
  return eml_CONV;
}

static __inline__ SYMBOL eml_Test(void)
{
  return eml_TEST;
}

static __inline__ SYMBOL eml_Id(void)
{
  return eml_ID;
}

static __inline__ SYMBOL eml_Div(void)
{
  return eml_DIV;
}

static __inline__ SYMBOL eml_DomRestr(void)
{
  return eml_DOMRESTR;
}

static __inline__ SYMBOL eml_RanRestr(void)
{
  return eml_RANRESTR;
}

static __inline__ SYMBOL eml_ApplyFunct(void)
{
  return eml_APPLYF;
}

/**************************************************************/
/* Symbol identification and access                           */
/**************************************************************/

static __inline__ BOOL eml_IsId(TERM S)
{
  return symbol_Equal(eml_ID,term_TopSymbol(S));
}

static __inline__ BOOL eml_IsDiv(TERM S)
{
  return symbol_Equal(eml_DIV,term_TopSymbol(S));
}

static __inline__ BOOL eml_IsNotSymbol(SYMBOL S)
{
  return symbol_Equal(fol_Not(), S);
}

static __inline__ BOOL eml_IsImpliesSymbol(SYMBOL S)
{
  return symbol_Equal(fol_Implies(), S);
}

static __inline__ BOOL eml_IsImpliedSymbol(SYMBOL S)
{
  return symbol_Equal(fol_Implied(), S);
}

static __inline__ BOOL eml_IsEquivSymbol(SYMBOL S)
{
  return symbol_Equal(fol_Equiv(), S);
}

static __inline__ BOOL eml_IsDiaSymbol(SYMBOL S)
{
  return (symbol_Equal(eml_DIA,S));
}

static __inline__ BOOL eml_IsBoxSymbol(SYMBOL S)
{
  return (symbol_Equal(eml_BOX,S));
}

static __inline__ BOOL eml_IsModalOpSymbol(SYMBOL S)
{
  return (symbol_Equal(eml_BOX,S) || symbol_Equal(eml_DIA,S));
}

static __inline__ BOOL eml_IsRelPropSymbol(SYMBOL S)
{
  return eml_IsModalOpSymbol(S);
}

static __inline__ BOOL eml_IsModalLiteral(TERM T)
/* unused */
{
  return fol_IsLiteral(T) || eml_IsModalOpSymbol(term_TopSymbol(T)) ||
      (symbol_Equal(term_TopSymbol(T),fol_Not()) && 
       eml_IsModalOpSymbol(term_TopSymbol(term_FirstArgument(T))));
}


static __inline__ BOOL eml_IsPropJunctor(SYMBOL S)
{
  return symbol_Equal(S, fol_AND) || 
      symbol_Equal(S, fol_OR) || 
      symbol_Equal(S, fol_NOT) || 
      symbol_Equal(S, fol_IMPLIES) ||
      symbol_Equal(S, fol_IMPLIED) ||
      symbol_Equal(S, fol_EQUIV);
}

static __inline__ BOOL eml_IsDesignatedPropSymbol(SYMBOL S)
{
  return symbol_Equal(S, fol_TRUE) || 
      symbol_Equal(S, fol_FALSE) || 
      symbol_Equal(S, eml_ID) || 
      symbol_Equal(S, eml_DIV);
}

static __inline__ BOOL eml_IsNullaryPredicate(SYMBOL S)
{
  return symbol_IsPredicate(S) && !eml_IsDesignatedPropSymbol(S) &&
	  (symbol_Arity(S) == 0);
}

static __inline__ BOOL eml_IsNaryJunctor(SYMBOL S)
{
  return symbol_Equal(S, fol_AND) || 
      symbol_Equal(S, fol_OR) || 
      symbol_Equal(S, eml_COMP) || 
      symbol_Equal(S, eml_SUM);
}

static __inline__ BOOL eml_IsRelationalJunctor(SYMBOL S)
{
  return eml_IsPropJunctor(S) ||
      symbol_Equal(S, eml_COMP) || 
      symbol_Equal(S, eml_CONV) ||
      symbol_Equal(S, eml_SUM) ||
      symbol_Equal(S, eml_DOMRESTR) ||
      symbol_Equal(S, eml_RANRESTR) ||
      symbol_Equal(S, eml_TEST);
}

static __inline__ BOOL eml_IsModalJunctor(SYMBOL S)
{
  return eml_IsModalOpSymbol(S) || eml_IsPropJunctor(S);
}

static __inline__ BOOL eml_IsPredefinedPred(SYMBOL S)
{
  return symbol_Equal(S, eml_DIV) || symbol_Equal(S, eml_ID);
}

static __inline__ TERM eml_Atom(TERM Lit)
{
  if (term_TopSymbol(Lit) == fol_NOT)
    return term_FirstArgument(Lit);
  else
    return Lit;
}

static __inline__ SYMBOL eml_GetDualSymbol(SYMBOL symbol)
{
  SYMBOL dual;

  dual = symbol;

  if (symbol_Equal(symbol,fol_True()))
    dual = fol_False();
  else if (symbol_Equal(symbol,fol_False()))
    dual = fol_True();
  else if (symbol_Equal(symbol,fol_Or()))
    dual = fol_And();
  else if (symbol_Equal(symbol,fol_And()))
    dual =  fol_Or();
  else if (symbol_Equal(symbol,fol_Exist()))
    dual = fol_All();
  else if (symbol_Equal(symbol,fol_All()))
    dual = fol_Exist();
  else if (symbol_Equal(symbol,eml_Dia()))
    dual = eml_Box();
  else if (symbol_Equal(symbol,eml_Box()))
    dual = eml_Dia();
  else if (symbol_Equal(symbol,eml_Id()))
    dual = eml_Div();
  else if (symbol_Equal(symbol,eml_Div()))
    dual = eml_Id();
  else if (symbol_Equal(symbol,eml_Comp()))
    dual = eml_Sum();
  else if (symbol_Equal(symbol,eml_Sum()))
    dual = eml_Comp();

  return dual;
}

/**************************************************************/
/* Propositional/first order symbol associations              */
/**************************************************************/

static __inline__ BOOL eml_VarSortType(eml_SYMBOLTYPE SymbolType)
{
  return SymbolType == eml_VARSORT;
}

static __inline__ BOOL eml_NaryType(eml_SYMBOLTYPE SymbolType)
{
  return SymbolType == eml_NARYPROP || SymbolType == eml_NARYNDE;
}

static __inline__ BOOL eml_SemiFuncNdeType(eml_SYMBOLTYPE SymbolType)
{
  return SymbolType == eml_SEMIFNDE;
}

static __inline__ BOOL eml_RelType(eml_SYMBOLTYPE SymbolType)
{
  return SymbolType == eml_REL;
}

static __inline__ void eml_SetPropNarySymbolAssocList(SYMBOL PropSymbol, 
		int Arity, SYMBOL FoSymbol)
{
  eml_NARYSYMBOLS[symbol_Index(PropSymbol)][Arity-1] = FoSymbol;
}

static __inline__ void eml_SetPropSemiFNdeSymbolAssocList(SYMBOL PropSymbol, 
		int Arity, SYMBOL FoSymbol)
{
  eml_SEMIFNDESYMBOLS[symbol_Index(PropSymbol)] = FoSymbol;
}

static __inline__ void eml_SetPropFoSymbolAssocList(SYMBOL PropSymbol, LIST FoSymbols)
{
  eml_PROPINDEXTOFOSYMBOL[symbol_Index(PropSymbol)] =  FoSymbols;
}

static __inline__ SYMBOL eml_FoQuantAssocWithPropSymbol(SYMBOL PropSymbol)
{
  LIST symbolList;
  symbolList = eml_PROPINDEXTOFOSYMBOL[symbol_Index(PropSymbol)];
  if (list_Empty(symbolList))
    return symbol__NULL;
  else
    return (SYMBOL) list_First(symbolList);
}

static __inline__ SYMBOL eml_FoJunctorAssocWithPropSymbol(SYMBOL PropSymbol)
{
  LIST symbolList;
  symbolList = eml_PROPINDEXTOFOSYMBOL[symbol_Index(PropSymbol)];
  if (list_Empty(symbolList) || list_Empty(list_Cdr(symbolList)))
    return symbol__NULL;
  else
  return (SYMBOL) list_Second(symbolList);
}

/**************************************************************/
/* Functions                                                  */
/**************************************************************/

void eml_Init(PRECEDENCE);
void eml_Free(void);
void eml_TranslateToFolMain(LIST*, LIST*, BOOL, FLAGSTORE, PRECEDENCE);
BOOL eml_FormulaContainsEMLTheorySymbol(TERM);

/* kjs */
static __inline__ BOOL eml_IsNullSymbol(SYMBOL S)
{
	return symbol_Equal(symbol_Null(), S); /* symbol__NULL */
}

static __inline__ BOOL eml_IsOrSymbol(SYMBOL S)
{
	return symbol_Equal(fol_Or(), S);
}

static __inline__ BOOL eml_IsAndSymbol(SYMBOL S)
{
	return symbol_Equal(fol_And(), S);
}

static __inline__ BOOL eml_IsFalseSymbol(SYMBOL S)
{
	return symbol_Equal(fol_False(), S);
}
static __inline__ BOOL eml_IsTrueSymbol(SYMBOL S)
{
	return symbol_Equal(fol_True(), S);
}

static __inline__ BOOL eml_IsFalseTerm(TERM T)
{
	return symbol_Equal(fol_False(), term_TopSymbol(T));
}
static __inline__ BOOL eml_IsTrueTerm(TERM T)
{
	return symbol_Equal(fol_True(), term_TopSymbol(T));
}

static __inline__ SYMBOL eml_Axiom_D(void) {  return eml_AXIOM_D; }
static __inline__ SYMBOL eml_Axiom_B(void) {  return eml_AXIOM_B; }
static __inline__ SYMBOL eml_Axiom_T(void) {  return eml_AXIOM_T; }
static __inline__ SYMBOL eml_Axiom_4(void) {  return eml_AXIOM_4; }
static __inline__ SYMBOL eml_Axiom_5(void) {  return eml_AXIOM_5; }
static __inline__ SYMBOL eml_Axiom_ALT1(void) {  return eml_AXIOM_ALT1; }

static __inline__ SYMBOL eml_Axiom_4K2(void) {  return eml_AXIOM_4K2; }
static __inline__ SYMBOL eml_Axiom_4K3(void) {  return eml_AXIOM_4K3; }
static __inline__ SYMBOL eml_Axiom_5K2(void) {  return eml_AXIOM_5K2; }
static __inline__ SYMBOL eml_Axiom_5K3(void) {  return eml_AXIOM_5K3; }
static __inline__ SYMBOL eml_Axiom_ALT1KK11(void) {  return eml_AXIOM_ALT1KK11; }
static __inline__ SYMBOL eml_Axiom_ALT1KK12(void) {  return eml_AXIOM_ALT1KK12; }
static __inline__ SYMBOL eml_Axiom_ALT1KK21(void) {  return eml_AXIOM_ALT1KK21; }
static __inline__ SYMBOL eml_Axiom_ALT1KK22(void) {  return eml_AXIOM_ALT1KK22; }

static __inline__ SYMBOL eml_Axiom_4K2c(void) {  return eml_AXIOM_4K2c; }
static __inline__ SYMBOL eml_Axiom_4K3c(void) {  return eml_AXIOM_4K3c; }
static __inline__ SYMBOL eml_Axiom_5K2c(void) {  return eml_AXIOM_5K2c; }
static __inline__ SYMBOL eml_Axiom_5K3c(void) {  return eml_AXIOM_5K3c; }
static __inline__ SYMBOL eml_Axiom_ALT1KK11c(void) {  return eml_AXIOM_ALT1KK11c; }
static __inline__ SYMBOL eml_Axiom_ALT1KK12c(void) {  return eml_AXIOM_ALT1KK12c; }
static __inline__ SYMBOL eml_Axiom_ALT1KK21c(void) {  return eml_AXIOM_ALT1KK21c; }
static __inline__ SYMBOL eml_Axiom_ALT1KK22c(void) {  return eml_AXIOM_ALT1KK22c; }

static __inline__ SYMBOL eml_Axiom_4K2o(void) {  return eml_AXIOM_4K2o; }
static __inline__ SYMBOL eml_Axiom_4K3o(void) {  return eml_AXIOM_4K3o; }
static __inline__ SYMBOL eml_Axiom_5K2o(void) {  return eml_AXIOM_5K2o; }
static __inline__ SYMBOL eml_Axiom_5K3o(void) {  return eml_AXIOM_5K3o; }
static __inline__ SYMBOL eml_Axiom_ALT1KK11o(void) {  return eml_AXIOM_ALT1KK11o; }
static __inline__ SYMBOL eml_Axiom_ALT1KK12o(void) {  return eml_AXIOM_ALT1KK12o; }
static __inline__ SYMBOL eml_Axiom_ALT1KK21o(void) {  return eml_AXIOM_ALT1KK21o; }
static __inline__ SYMBOL eml_Axiom_ALT1KK22o(void) {  return eml_AXIOM_ALT1KK22o; }

static __inline__ SYMBOL eml_Axiom_Dc(void) {  return eml_AXIOM_Dc; }
static __inline__ SYMBOL eml_Axiom_Bc(void) {  return eml_AXIOM_Bc; }
static __inline__ SYMBOL eml_Axiom_Tc(void) {  return eml_AXIOM_Tc; }
static __inline__ SYMBOL eml_Axiom_4c(void) {  return eml_AXIOM_4c; }
static __inline__ SYMBOL eml_Axiom_5c(void) {  return eml_AXIOM_5c; }
static __inline__ SYMBOL eml_Axiom_ALT1c(void) {  return eml_AXIOM_ALT1c; }

static __inline__ SYMBOL eml_Axiom_Do(void) {  return eml_AXIOM_Do; }
static __inline__ SYMBOL eml_Axiom_Bo(void) {  return eml_AXIOM_Bo; }
static __inline__ SYMBOL eml_Axiom_To(void) {  return eml_AXIOM_To; }
static __inline__ SYMBOL eml_Axiom_4o(void) {  return eml_AXIOM_4o; }
static __inline__ SYMBOL eml_Axiom_5o(void) {  return eml_AXIOM_5o; }
static __inline__ SYMBOL eml_Axiom_ALT1o(void) {  return eml_AXIOM_ALT1o; }

static __inline__ SYMBOL eml_Slf(void) {  return eml_SLF; }
static __inline__ SYMBOL eml_AxiomSlf(void) {  return eml_AXIOMSLF; }
static __inline__ SYMBOL eml_NoAxiom(void) {  return eml_NOAXIOM; }

static __inline__ BOOL eml_IsAxiomTypeSymbol(SYMBOL S) /* kjs */
{
  return (     symbol_Equal(eml_AXIOM_D,S) || symbol_Equal(eml_AXIOM_B,S)
			|| symbol_Equal(eml_AXIOM_T,S) || symbol_Equal(eml_AXIOM_4,S)
			|| symbol_Equal(eml_AXIOM_5,S) || symbol_Equal(eml_AXIOM_ALT1,S)
			
			|| symbol_Equal(eml_AXIOM_Dc,S) || symbol_Equal(eml_AXIOM_Bc,S)
			|| symbol_Equal(eml_AXIOM_Tc,S) || symbol_Equal(eml_AXIOM_4c,S)
			|| symbol_Equal(eml_AXIOM_5c,S) || symbol_Equal(eml_AXIOM_ALT1c,S)
			
			|| symbol_Equal(eml_AXIOM_Do,S) || symbol_Equal(eml_AXIOM_Bo,S)
			|| symbol_Equal(eml_AXIOM_To,S) || symbol_Equal(eml_AXIOM_4o,S)
			|| symbol_Equal(eml_AXIOM_5o,S) || symbol_Equal(eml_AXIOM_ALT1o,S)
			
			|| symbol_Equal(eml_AXIOM_4K2,S) || symbol_Equal(eml_AXIOM_4K3,S) 
			|| symbol_Equal(eml_AXIOM_5K2,S) || symbol_Equal(eml_AXIOM_5K3,S) 
			|| symbol_Equal(eml_AXIOM_ALT1KK11,S) || symbol_Equal(eml_AXIOM_ALT1KK12,S)
            || symbol_Equal(eml_AXIOM_ALT1KK21,S) || symbol_Equal(eml_AXIOM_ALT1KK22,S)
			
            || symbol_Equal(eml_AXIOM_4K2c,S) || symbol_Equal(eml_AXIOM_4K3c,S) 
            || symbol_Equal(eml_AXIOM_5K2c,S) || symbol_Equal(eml_AXIOM_5K3c,S) 
            || symbol_Equal(eml_AXIOM_ALT1KK11c,S) || symbol_Equal(eml_AXIOM_ALT1KK12c,S)
            || symbol_Equal(eml_AXIOM_ALT1KK21c,S) || symbol_Equal(eml_AXIOM_ALT1KK22c,S)

            || symbol_Equal(eml_AXIOM_4K2o,S) || symbol_Equal(eml_AXIOM_4K3o,S) 
            || symbol_Equal(eml_AXIOM_5K2o,S) || symbol_Equal(eml_AXIOM_5K3o,S) 
            || symbol_Equal(eml_AXIOM_ALT1KK11o,S) || symbol_Equal(eml_AXIOM_ALT1KK12o,S)
            || symbol_Equal(eml_AXIOM_ALT1KK21o,S) || symbol_Equal(eml_AXIOM_ALT1KK22o,S)
			);
}

static __inline__ BOOL eml_IsNOAXIOM_Symbol(SYMBOL S) {  return (symbol_Equal(eml_NOAXIOM,S)); }
static __inline__ BOOL eml_IsSLF_Symbol(SYMBOL S) {  return (symbol_Equal(eml_SLF,S)); }
static __inline__ BOOL eml_IsAxiomSLF_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOMSLF,S)); }

static __inline__ BOOL eml_IsAxiom_D_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_D,S)); }
static __inline__ BOOL eml_IsAxiom_B_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_B,S)); }
static __inline__ BOOL eml_IsAxiom_T_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_T,S)); }
static __inline__ BOOL eml_IsAxiom_4_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_4,S)); }
static __inline__ BOOL eml_IsAxiom_5_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_5,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1,S)); }

static __inline__ BOOL eml_IsAxiom_Dc_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_Dc,S)); }
static __inline__ BOOL eml_IsAxiom_Bc_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_Bc,S)); }
static __inline__ BOOL eml_IsAxiom_Tc_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_Tc,S)); }
static __inline__ BOOL eml_IsAxiom_4c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_4c,S)); }
static __inline__ BOOL eml_IsAxiom_5c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_5c,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1c,S)); }

static __inline__ BOOL eml_IsAxiom_Do_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_Do,S)); }
static __inline__ BOOL eml_IsAxiom_Bo_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_Bo,S)); }
static __inline__ BOOL eml_IsAxiom_To_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_To,S)); }
static __inline__ BOOL eml_IsAxiom_4o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_4o,S)); }
static __inline__ BOOL eml_IsAxiom_5o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_5o,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1o,S)); }

static __inline__ BOOL eml_IsAxiom_4K2_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_4K2,S)); }
static __inline__ BOOL eml_IsAxiom_4K3_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_4K3,S)); }
static __inline__ BOOL eml_IsAxiom_5K2_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_5K2,S)); }
static __inline__ BOOL eml_IsAxiom_5K3_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_5K3,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK11_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK11,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK12_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK12,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK21_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK21,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK22_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK22,S)); }

static __inline__ BOOL eml_IsAxiom_4K2c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_4K2c,S)); }
static __inline__ BOOL eml_IsAxiom_4K3c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_4K3c,S)); }
static __inline__ BOOL eml_IsAxiom_5K2c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_5K2c,S)); }
static __inline__ BOOL eml_IsAxiom_5K3c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_5K3c,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK11c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK11c,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK12c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK12c,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK21c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK21c,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK22c_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK22c,S)); }

static __inline__ BOOL eml_IsAxiom_4K2o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_4K2o,S)); }
static __inline__ BOOL eml_IsAxiom_4K3o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_4K3o,S)); }
static __inline__ BOOL eml_IsAxiom_5K2o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_5K2o,S)); }
static __inline__ BOOL eml_IsAxiom_5K3o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_5K3o,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK11o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK11o,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK12o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK12o,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK21o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK21o,S)); }
static __inline__ BOOL eml_IsAxiom_ALT1KK22o_Symbol(SYMBOL S) {  return (symbol_Equal(eml_AXIOM_ALT1KK22o,S)); }

static __inline__ void eml_Flush(void) {
	fflush(stderr); 
	fflush(stdout);	
}

static __inline__ TERM emlterm_ThirdArgument(TERM T)
{
	return (TERM) list_Third(T->args);
}
static __inline__ TERM emlterm_FourthArgument(TERM T)
{
	return (TERM) list_Fourth(T->args);
}
static __inline__ TERM emlterm_FifthArgument(TERM T)
{
	return (TERM) list_Fifth(T->args);
}

static __inline__ BOOL eml_TestFalse(TERM Term)
{
	if (eml_IsFalseSymbol(term_TopSymbol(Term))) {
		return TRUE;
	} else if(!term_IsComplex(Term)) { 
		return FALSE;
	} else if (symbol_IsPredicate(term_TopSymbol(Term))) { 
		return FALSE;
	} else if ( eml_IsNotSymbol(term_TopSymbol(Term))
		&&	eml_IsFalseSymbol(term_TopSymbol(term_FirstArgument(Term)))) {
		return TRUE;
	} else {
		return FALSE;
	}
}
/* kjs */

#endif
