/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *       CLASS COPYDFG2DFGOUTPUTLISTENER                  * */
/* *                                                        * */
/* *  $Module:   COPYDFG2DFGOUTPUTLISTENER                  * */ 
/* *                                                        * */
/* *  Copyright (C) 1999, 2001, 2002 MPI fuer Informatik    * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.1.1.1 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2006/02/20 10:28:30 $                             * */
/* $Author: topic $                                         * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include <qmessagebox.h>

#include "CopyOutputListener.h"
#include "SaveFileListener.h"
#include "SPASSDialogs.h"

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/
/**********************************************************
  INPUT:   SPASSFiles, a tab widget, an editor, the status
           bar, an action, an output widget and a save
           file listener.
  RETURNS: None.
  EFFECT:  Creates a new instance of this class.
***********************************************************/
CopyOutputListener::CopyOutputListener(SPASSFiles *f,
				       SPASSSplitter *splitter,
				       SPASSStatusBar *status,
				       QAction* action,
				       SaveFileListener * savelistener)
  : FileListener(f, splitter, status)
{
  saver = savelistener;

  connect(action, SIGNAL(activated()),
	  this, SLOT(listen()));
}

/**************************************************************/
/*                          Slots                             */
/**************************************************************/
/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  handles the copy output event.
           Copies the output into the editor.
***********************************************************/
void CopyOutputListener::listen(void)
{
  int answer=QMessageBox::Yes;

  if (splitterWidget->getInput()->isModified()) {
    answer=SPASSDialogs::showWarningToSave(files);
      
    if (files->input->fileinfo->isWritable() && (answer==QMessageBox::Yes)) {
      saver->listen();
    }
  }

  if (answer != QMessageBox::Cancel) {
    QString filename = splitterWidget->getOutput()->getTemporaryFileName(); 
    handleFileOpen(filename);
    statusbar->showFileName(filename);
  }
}




