/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              CLASS HELPLISTENER                        * */
/* *                                                        * */
/* *  $Module:   HELPLISTENER                               * */ 
/* *                                                        * */
/* *  Copyright (C) 2001, 2002 MPI fuer Informatik          * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.1.1.1 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2006/02/20 10:28:30 $                             * */
/* $Author: topic $                                         * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include <QDir>
#include <QFile>
#include <QTextDocument>
#include <QUrl>

#include "HelpListener.h"
#include "SPASSFiles.h"

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/
/**********************************************************
  INPUT:   An action, and a help file source.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
HelpListener::HelpListener(QAction * action, const QString & src)
  : Listener(),
    path("."),
    browser()
{
  QStringList source_dirs ;
  QString html_dir = QDir::convertSeparators(QDir::cleanPath(HELP_PREFIX HTML_DIR));
  source_dirs << html_dir;
  browser.setSearchPaths(source_dirs);

  /* Create the browser with the given source file. */
  source = src;

  QFile file(source);

  if (file.open(QFile::ReadOnly | QFile::Text)) {
    browser.setHtml(file.readAll());
    browser.resize(QSize(600,600));
    file.close();
  }

  /* Connect the action to this listener. */
  connect(action, SIGNAL(activated()),
	  this, SLOT(listen()));
}

/**************************************************************/
/*                          Slots                             */
/**************************************************************/
/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  handles the help event.
           Shows the help browser.
***********************************************************/
void HelpListener::listen(void)
{
  browser.show();
}
