/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *       CLASS NEWFILELISTENER                            * */
/* *                                                        * */
/* *  $Module:   NEWFILELISTENER                            * */ 
/* *                                                        * */
/* *  Copyright (C) 2001, 2002 MPI fuer Informatik          * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.1.1.1 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2006/02/20 10:28:30 $                             * */
/* $Author: topic $                                         * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include <qmessagebox.h>

#include "NewFileListener.h"
#include "SaveFileListener.h"

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/
/**********************************************************
  INPUT:   SPASS files, a tab widget, an editor, a status
           bar, an action, an output widget, and a save
	   file listener.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
NewFileListener::NewFileListener(SPASSFiles *files,
				 SPASSSplitter *splitter,
				 SPASSStatusBar *status,
				 QAction *action,
				 SaveFileListener *saveListener)
  : FileListener(files, splitter, status)
{
  saver = saveListener;

  /* Connect the action with this listener. */
  connect(action, SIGNAL(activated()),
	  this, SLOT(listen()));
}


/**************************************************************/
/*                          Slots                             */
/**************************************************************/

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  handles the File New event.
           Opens a new empty file in the editor.
***********************************************************/
void NewFileListener::listen(void)
{
  int answer;

  answer = handleModifiedInput();

  if (answer != QMessageBox::Cancel) {
    if (files->input->file != NULL) {
      delete files->input->file; // delete closes it if its open automatically
      files->input->file = new QFile(SPASSFiles::Input::DEFAULT);
      Q_CHECK_PTR(files->input->file);

      delete files->input->fileinfo;
      files->input->fileinfo = new QFileInfo(SPASSFiles::Input::DEFAULT);
      Q_CHECK_PTR(files->input->fileinfo);
    }

    splitterWidget->getInput()->clear();
    statusbar->showFileName(QString(SPASSFiles::Input::DEFAULT));

    splitterWidget->getOutput()->clear();
  }
}



