/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              CLASS PDFHELPLISTENER                     * */
/* *                                                        * */
/* *  $Module:   PDFHELPLISTENER                            * */ 
/* *                                                        * */
/* *  Copyright (C) 2001, 2002 MPI fuer Informatik          * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.1.1.1 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2006/02/20 10:28:30 $                             * */
/* $Author: topic $                                         * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include <iostream>
#include <QtDebug>
#include <qinputdialog.h>

#include "KillApplicationListener.h"
#include "PDFHelpListener.h"

QString PDFHelpListener::reader = "";

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/
/**********************************************************
  INPUT:   An action, and a help file source.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
PDFHelpListener::PDFHelpListener(QAction * action, const QString & src)
  : Listener(),
    reader_process(this, "pdf reader process")
{
  /* Create a process that will run the reader with the given source file. */
  source = src;

#if defined(Q_WS_MAC)
  reader = "/usr/bin/open";
#elif defined(Q_OS_WIN32)
  reader = "cmd /c start";
#else

  unsigned int i;

  /* Number of reader programs known to SPASS */
  const unsigned int NUM_READERS = 6;

  /* Reader name is platform dependant, and there
     are a couple of programs able to display PDF ...
     so we use a little hack to find out which
     is installed.
  */

  char * pdf_readers [NUM_READERS] = {
    /* Since Microsoft Operating Systems don't have useful environment variable
     * settings, we have to search blidly in the file system to find the Acrobat
     * reader binary. Using the MSDOS filename for directory entries should work
     * for all languages where the program files folder starts with progra*
     */
    "C:\\Program Files\\Adobe\\Acrobat 5.0\\Reader\\AcroRd32.exe",
    "C:\\Progra~1\\Adobe\\Acrobat 5.0\\Reader\\AcroRd32.exe",
    "C:\\Progra~2\\Adobe\\Acrobat 5.0\\Reader\\AcroRd32.exe",
    "acroread",
    "xpdf",
    "gv"
  };

  for (i = 0; i < NUM_READERS; ++i) {
    reader_process.clearArguments();
    reader_process.addArgument(pdf_readers[i]);
 
    if (reader_process.start()) {
      KillApplicationListener::killProcess(&reader_process);
      reader = pdf_readers[i];
      reader_process.addArgument(source);
      break;
    }
  }

#endif

  // XXX else there is no reader we know installed.

  /* Connect the action to this listener. */
  connect(action, SIGNAL(activated()),
	  this, SLOT(listen()));
}

/**************************************************************/
/*                      Deconstructors                        */
/**************************************************************/
/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Deletes this object. It kills the associated 
           process. 
***********************************************************/
PDFHelpListener::~PDFHelpListener(void)
{
  KillApplicationListener::killProcess(&reader_process);
}

/**************************************************************/
/*                          Methods                           */
/**************************************************************/
/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Sets arguments of reader process.
***********************************************************/
void PDFHelpListener::setArguments(void) {
	reader_process.clearArguments();
	reader_process.addArgument(reader);
	reader_process.addArgument(source);
}

/**************************************************************/
/*                          Slots                             */
/**************************************************************/
/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  handles the help event.
           Starts the PDF reader with the given file.
***********************************************************/
void PDFHelpListener::listen(void)
{
	if (reader.isEmpty()) {
		reader = QInputDialog::getText(
			"No PDF Reader found", 
			"No PDF reader was found on your system.\n"
			"If you have one installed, please specify the full path to the executable"
			);
	}

	setArguments();

	reader_process.start();
}
