/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              CLASS SPASSABOUTBOX                       * */
/* *                                                        * */
/* *  $Module:   SPASSABOUTBOX                              * */
/* *                                                        * */
/* *  Copyright (C) 1999, 2001, 2002, 2003                  * */
/* *  MPI fuer Informatik                                   * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.2 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2007/07/16 10:36:18 $                             * */
/* $Author: topic $                                      * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include <QPixmap>
#include <QKeyEvent>

#include "SPASSAboutBox.h"
#include "SPASSActions.h"
#include "SPASSImages.h"

/**************************************************************/
/*                        Constants                           */
/**************************************************************/

const QString SPASSAboutBox::TEXT(
    "SPASSGUI\n"
    "Version 3.0\n\n"
    "Authors :\n"
    "\tChristoph Weidenbach, Bijan Afshordel, Uwe Brahm,\n"
    "\tThomas Hillenbrand, Enno Keen, Christian Theobalt, Dalibor Topic\n\n"
    "November 2005\n\n"
    "Copyright (C) 1999, 2001, 2002, 2003, 2005, 2007"
    "Max-Planck-Institut fr Informatik\n\n"
    "for recent developments see http://www.spass-prover.org\n\n"
    "\n\nSPASSGUI comes with ABSOLUTELY NO WARRANTY; for details type `"
#if defined(Q_WS_MAC)
    "Apple+W"
#else
    "Ctrl+W"
#endif
    "'.\n"
    "This is free software, and you are welcome to redistribute it\n"
    "under certain conditions; type `"
#if defined(Q_WS_MAC)
    "Apple+L"
#else
    "Ctrl+L"
#endif
    "' for details."
    );

/***************************************************************
		                 Constructors
****************************************************************/

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  creates a SPASSAboutBox widget.
***********************************************************/

SPASSAboutBox::SPASSAboutBox(void)
  :	QDialog(),
	pic(this),
	label(TEXT, this),
	ok("Ok", this),
	layout(this, 10,7)
{
  // Dialog settings
  setCaption ("About SPASS");
  setFixedSize(minimumSize());

  QPixmap picture = QPixmap::fromImage(qembed_findImage("fish-icon"));
  setIcon (picture);
  pic.setPixmap(picture);

  connect( &ok, SIGNAL(clicked()), SLOT(accept()) );

  ok.setFocusPolicy(Qt::StrongFocus);

  layout.addWidget(&pic, 0, Qt::AlignCenter);
  layout.addWidget(&label);
  layout.addWidget(&ok, 0, Qt::AlignCenter);

  layout.activate();
}

/**********************************************************
  INPUT:   A key event.
  RETURNS: None.
  EFFECT:  Calls accept() if the user has pressed the
           return key.
***********************************************************/
void SPASSAboutBox::keyPressEvent(QKeyEvent* ke)
{
  if ((ke->key()) == Qt::Key_Return) {
    accept();
  }
}
