/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              CLASS SPASSACTIONS                        * */
/* *                                                        * */
/* *  $Module:   SPASSACTIONS                               * */ 
/* *                                                        * */
/* *  Copyright (C) 1999, 2001, 2002, 2005                  * */
/* *    MPI fuer Informatik                                 * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.2 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2007/01/25 16:17:13 $                             * */
/* $Author: topic $                                      * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include <QIcon>
#include <QKeySequence>
#include <QPixmap>
#include <QActionGroup>

#include "SPASSActions.h"
#include "SPASSImages.h"

/**************************************************************/
/*                        Constants                           */
/**************************************************************/

const QString SPASSActions::Edit::COPY_ICON("editcopy");
const QString SPASSActions::Edit::COPY_MENU_TEXT("&Copy");
const QString SPASSActions::Edit::COPY_KEY_SEQUENCE("Ctrl+C");

const QString SPASSActions::Edit::COPYOUTPUT_ICON("1leftarrow");
const QString SPASSActions::Edit::COPYOUTPUT_MENU_TEXT("Copy &output to editor");

const QString SPASSActions::Edit::CUT_ICON("editcut");
const QString SPASSActions::Edit::CUT_MENU_TEXT("Cu&t");
const QString SPASSActions::Edit::CUT_KEY_SEQUENCE("Ctrl+X");

const QString SPASSActions::Edit::PASTE_ICON("editpaste");
const QString SPASSActions::Edit::PASTE_MENU_TEXT("&Paste");
const QString SPASSActions::Edit::PASTE_KEY_SEQUENCE("Ctrl+V");

const QString SPASSActions::File::EXIT_ICON("exit");
const QString SPASSActions::File::EXIT_MENU_TEXT("E&xit application");

const QString SPASSActions::File::NEWFILE_ICON("filenew");
const QString SPASSActions::File::NEWFILE_MENU_TEXT("&New file");
const QString SPASSActions::File::NEWFILE_KEY_SEQUENCE("Ctrl+N");

const QString SPASSActions::File::OPEN_ICON("fileopen");
const QString SPASSActions::File::OPEN_MENU_TEXT("&Open file");
const QString SPASSActions::File::OPEN_KEY_SEQUENCE("Ctrl+O");

const QString SPASSActions::File::SAVE_ICON("filesave");
const QString SPASSActions::File::SAVE_MENU_TEXT("&Save file");
const QString SPASSActions::File::SAVE_KEY_SEQUENCE("Ctrl+S");

const QString SPASSActions::File::SAVE_AS_MENU_TEXT("Save &as another file");

const QString SPASSActions::Help::ABOUT_MENU_TEXT("&About SPASS");

const QString SPASSActions::Help::DFG2DFG_MENU_TEXT("DFG2DFG &Options");

const QString SPASSActions::Help::FAQ_MENU_TEXT("SPASS &FAQ");

const QString SPASSActions::Help::HANDBOOK_MENU_TEXT("SPASS &Handbook");

const QString SPASSActions::Help::SPASS_MENU_TEXT("SPASS O&ptions");

const QString SPASSActions::Help::SPASS_SYNTAX_MENU_TEXT("SPASS Input &Syntax");

const QString SPASSActions::Help::LICENSE_MENU_TEXT("&License");
const QString SPASSActions::Help::LICENSE_KEY_SEQUENCE("Ctrl+L");

const QString SPASSActions::Help::WARRANTY_MENU_TEXT("No &Warranty");
const QString SPASSActions::Help::WARRANTY_KEY_SEQUENCE("Ctrl+W");

const QString SPASSActions::Preferences::FONT_ICON("fonts");
const QString SPASSActions::Preferences::FONT_MENU_TEXT("&Font");

const QString SPASSActions::Tools::ABORT_ICON("stop");
const QString SPASSActions::Tools::ABORT_MENU_TEXT("A&bort running SPASS");
const QString SPASSActions::Tools::ABORT_KEY_SEQUENCE("Ctrl+B");

const QString SPASSActions::Tools::RUN_ICON("run");
const QString SPASSActions::Tools::RUN_MENU_TEXT("Run &SPASS");
const QString SPASSActions::Tools::RUN_KEY_SEQUENCE("Ctrl+R");

const QString SPASSActions::Tools::DFG2ASCII_ICON("misc");
const QString SPASSActions::Tools::DFG2ASCII_MENU_TEXT("Run DFG2&ASCII");
const QString SPASSActions::Tools::DFG2ASCII_KEY_SEQUENCE("Ctrl+A");

const QString SPASSActions::Tools::DFG2DFG_ICON("filter");
const QString SPASSActions::Tools::DFG2DFG_MENU_TEXT("Run &DFG2DFG");
const QString SPASSActions::Tools::DFG2DFG_KEY_SEQUENCE("Ctrl+D");

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/
/**********************************************************
  INPUT:   A parent widget, a name, and a boolean flag.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSActions::File::File(QObject * parent) 
  : QActionGroup (parent)
{
  newfile = new QAction(QIcon(QPixmap(qembed_findImage(NEWFILE_ICON))),
			NEWFILE_MENU_TEXT,
			this);
  Q_CHECK_PTR(newfile);
  newfile->setShortcut(QKeySequence(NEWFILE_KEY_SEQUENCE));

  open = new QAction(QIcon(QPixmap(qembed_findImage(OPEN_ICON))),
		     OPEN_MENU_TEXT,
		     this);
  Q_CHECK_PTR(open);
  open->setShortcut(QKeySequence(OPEN_KEY_SEQUENCE));

  save = new QAction(QIcon(QPixmap(qembed_findImage(SAVE_ICON))),
		     SAVE_MENU_TEXT,
		     this);
  Q_CHECK_PTR(save);
  save->setShortcut(QKeySequence(SAVE_KEY_SEQUENCE));

  saveAs = new QAction(SAVE_AS_MENU_TEXT,
		       this);
  Q_CHECK_PTR(saveAs);

  exit = new QAction(QIcon(QPixmap(qembed_findImage(EXIT_ICON))),
		     EXIT_MENU_TEXT,
		     this);
  Q_CHECK_PTR(exit);
}

/**********************************************************
  INPUT:   A parent widget, a name, and a boolean flag.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSActions::Edit::Edit(QObject * parent) 
  : QActionGroup (parent) 
{
  copy  = new QAction(QIcon(QPixmap(qembed_findImage(COPY_ICON))),
		      COPY_MENU_TEXT,
		      this);
  Q_CHECK_PTR(copy);
  copy->setShortcut(QKeySequence(COPY_KEY_SEQUENCE));

  cut   = new QAction(QIcon(QPixmap(qembed_findImage(CUT_ICON))),
		      CUT_MENU_TEXT,
		      this);
  Q_CHECK_PTR(cut);
  cut->setShortcut(QKeySequence(CUT_KEY_SEQUENCE));

  paste = new QAction(QIcon(QPixmap(qembed_findImage(PASTE_ICON))),
		      PASTE_MENU_TEXT,
		      this);
  Q_CHECK_PTR(paste);
  paste->setShortcut(QKeySequence(PASTE_KEY_SEQUENCE));

  copyOutput = new QAction(QIcon(QPixmap(qembed_findImage(COPYOUTPUT_ICON))),
			   COPYOUTPUT_MENU_TEXT,
			   this);
  Q_CHECK_PTR(copyOutput);
}

/**********************************************************
  INPUT:   A parent widget, a name, and a boolean flag.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSActions::Tools::Tools(QObject * parent) 
  : QActionGroup (parent) 
{
  spass = new QAction(QIcon(QPixmap(qembed_findImage(RUN_ICON))),
		      RUN_MENU_TEXT,
		      this);
  Q_CHECK_PTR(spass);
  spass->setShortcut(QKeySequence(RUN_KEY_SEQUENCE));

  dfg2Ascii = new QAction(QIcon(QPixmap(qembed_findImage(DFG2ASCII_ICON))),
			  DFG2ASCII_MENU_TEXT,
			  this);
  Q_CHECK_PTR(dfg2Ascii);
  dfg2Ascii->setShortcut(QKeySequence(DFG2ASCII_KEY_SEQUENCE));

  dfg2Dfg = new QAction(QIcon(QPixmap(qembed_findImage(DFG2DFG_ICON))),
			DFG2DFG_MENU_TEXT,
			this);
  Q_CHECK_PTR(dfg2Dfg);
  dfg2Dfg->setShortcut(QKeySequence(DFG2DFG_KEY_SEQUENCE));

  abort = new QAction(QIcon(QPixmap(qembed_findImage(ABORT_ICON))),
		      ABORT_MENU_TEXT,
		      this);
  Q_CHECK_PTR(abort);
  abort->setShortcut(QKeySequence(ABORT_KEY_SEQUENCE));
}

/**********************************************************
  INPUT:   A parent widget, a name, and a boolean flag.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSActions::Preferences::Preferences(QObject * parent) 
  : QActionGroup (parent) 
{
  font = new QAction(QIcon(QPixmap(qembed_findImage(FONT_ICON))),
		     FONT_MENU_TEXT,
		     this);
  Q_CHECK_PTR(font);
}

/**********************************************************
  INPUT:   A parent widget, a name, and a boolean flag.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSActions::Help::Help(QObject * parent) 
  : QActionGroup (parent) 
{
  about = new QAction(ABOUT_MENU_TEXT,
		      this);
  Q_CHECK_PTR(about);

  license = new QAction(LICENSE_MENU_TEXT,
			this);
  Q_CHECK_PTR(license);
  license->setShortcut(QKeySequence(LICENSE_KEY_SEQUENCE));

  warranty = new QAction(WARRANTY_MENU_TEXT,
			 this);
  Q_CHECK_PTR(warranty);
  warranty->setShortcut(QKeySequence(WARRANTY_KEY_SEQUENCE));

  dfg2dfg = new QAction(DFG2DFG_MENU_TEXT,
			this);
  Q_CHECK_PTR(dfg2dfg);

  spass = new QAction(SPASS_MENU_TEXT,
		      this);
  Q_CHECK_PTR(spass);

  spass_syntax = new QAction(SPASS_SYNTAX_MENU_TEXT,
			     this);
  Q_CHECK_PTR(spass_syntax);

  handbook = new QAction(HANDBOOK_MENU_TEXT,
			 this);
  Q_CHECK_PTR(handbook);

  faq = new QAction(FAQ_MENU_TEXT,
		    this);
  Q_CHECK_PTR(faq);
}

/**********************************************************
  INPUT:   A parent widget, a name, and a boolean flag.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSActions::SPASSActions(QObject * parent)
{
  file        = new File(parent);
  Q_CHECK_PTR(file);

  edit        = new Edit(parent);
  Q_CHECK_PTR(edit);

  tools       = new Tools(parent);
  Q_CHECK_PTR(tools);

  preferences = new Preferences(parent);
  Q_CHECK_PTR(preferences);

  help        = new Help(parent);
  Q_CHECK_PTR(help);
}

/**************************************************************/
/*                        Destructor                          */
/**************************************************************/
/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Deletes an instance of this class.
***********************************************************/
SPASSActions::File::~File(void) {
  delete exit;
  delete saveAs;
  delete save;
  delete open;
  delete newfile;
}

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Deletes an instance of this class.
***********************************************************/
SPASSActions::Edit::~Edit(void) {
  delete copy;
  delete copyOutput;
  delete cut;
  delete paste;
}

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Deletes an instance of this class.
***********************************************************/
SPASSActions::Tools::~Tools(void) {
  delete abort;
  delete spass;
  delete dfg2Ascii;
  delete dfg2Dfg;
}

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Deletes an instance of this class.
***********************************************************/
SPASSActions::Preferences::~Preferences(void) {
  delete font;
}

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Deletes an instance of this class.
***********************************************************/
SPASSActions::Help::~Help(void) {
  delete faq;
  delete handbook;
  delete spass_syntax;
  delete dfg2dfg;
  delete spass;
  delete warranty;
  delete license;
  delete about;
}

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Deletes an instance of this class.
***********************************************************/
SPASSActions::~SPASSActions(void) {
  delete file;
  delete edit;
  delete tools;
  delete preferences;
  delete help;
}
