/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              CLASS SPASSACTIONS                        * */
/* *                                                        * */
/* *  $Module:   SPASSACTIONS                               * */ 
/* *                                                        * */
/* *  Copyright (C) 1999, 2001, 2002, 2005                  * */
/* *    MPI fuer Informatik                                 * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.2 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2007/01/25 16:17:13 $                             * */
/* $Author: topic $                                      * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

#ifndef _SPASSACTIONS_
#define _SPASSACTIONS_

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include <QAction>
#include <QObject>
#include <QString>
#include <QActionGroup>

/* This class holds all actions. */

/* Actions are grouped into ActionGroups, according to the menus in which they appear.
   Each action has a few associated Strings, like ACTIONNAME_TEXT.

   * ACTIONNAME_ICON
     denotes the name of the icon resource for that action.

   * ACTIONNAME_MENU_TEXT
     denotes the text used in the menu, including the menu shortcut key, preceded by '&'.

   * ACTIONNAME_KEY_SEQUENCE
     denotes the key sequence used to invoke that action (CTRL+Key). The key sequences
     follow Microsoft's guidelines.
*/

class SPASSActions {
  class File : public QActionGroup {
  public:
    File(QObject * parent);
    ~File(void);

    QAction* newfile;
    QAction* open;
    QAction* save;
    QAction* saveAs;
    QAction* exit;
 
  private:
    static const QString EXIT_ICON;
    static const QString EXIT_MENU_TEXT;

    static const QString NEWFILE_ICON;
    static const QString NEWFILE_MENU_TEXT;
    static const QString NEWFILE_KEY_SEQUENCE;

    static const QString OPEN_ICON;
    static const QString OPEN_MENU_TEXT;
    static const QString OPEN_KEY_SEQUENCE;

    static const QString SAVE_ICON;
    static const QString SAVE_MENU_TEXT;
    static const QString SAVE_KEY_SEQUENCE;

    static const QString SAVE_AS_MENU_TEXT;
  };

  class Edit : public QActionGroup {
  public:
    Edit(QObject * parent);
    ~Edit(void);

    QAction* copy;
    QAction* copyOutput;
    QAction* cut;
    QAction* paste;

  private:
    static const QString      COPY_ICON;
    static const QString      COPY_MENU_TEXT;
    static const QString      COPY_KEY_SEQUENCE;

    static const QString      COPYOUTPUT_ICON;
    static const QString      COPYOUTPUT_MENU_TEXT;

    static const QString      CUT_ICON;
    static const QString      CUT_MENU_TEXT;
    static const QString      CUT_KEY_SEQUENCE;

    static const QString      PASTE_ICON;
    static const QString      PASTE_MENU_TEXT;
    static const QString      PASTE_KEY_SEQUENCE;
  };

  class Tools : public QActionGroup {
  public:
    Tools(QObject * parent);
    ~Tools(void);

    QAction* spass;
    QAction* dfg2Ascii;
    QAction* dfg2Dfg;
    QAction* abort;

  private:
    static const QString RUN_ICON;
    static const QString RUN_MENU_TEXT;
    static const QString RUN_KEY_SEQUENCE;

    static const QString DFG2ASCII_ICON;
    static const QString DFG2ASCII_MENU_TEXT;
    static const QString DFG2ASCII_KEY_SEQUENCE;

    static const QString DFG2DFG_ICON;
    static const QString DFG2DFG_MENU_TEXT;
    static const QString DFG2DFG_KEY_SEQUENCE;

    static const QString ABORT_ICON;
    static const QString ABORT_MENU_TEXT;    
    static const QString ABORT_KEY_SEQUENCE;
  };

  class Preferences : public QActionGroup {
  public:
    Preferences(QObject * parent);
    ~Preferences(void);

    QAction* font;

  private:
    static const QString FONT_ICON;
    static const QString FONT_MENU_TEXT;
  };

  class Help : public QActionGroup {
  public:
    Help(QObject * parent);
    ~Help(void);

    QAction* about;
    QAction* dfg2dfg;
    QAction* faq;
    QAction* handbook;
    QAction* license;
    QAction* spass;
    QAction* spass_syntax;
    QAction* warranty;

  private:
    static const QString ABOUT_MENU_TEXT;

    static const QString DFG2DFG_MENU_TEXT;

    static const QString FAQ_MENU_TEXT;

    static const QString HANDBOOK_MENU_TEXT;

    static const QString SPASS_MENU_TEXT;    

    static const QString SPASS_SYNTAX_MENU_TEXT;

    static const QString LICENSE_MENU_TEXT;
    static const QString LICENSE_KEY_SEQUENCE;

    static const QString WARRANTY_MENU_TEXT;
    static const QString WARRANTY_KEY_SEQUENCE;
  };

 public:
  SPASSActions(QObject * parent);
  ~SPASSActions(void);

  File*        file;
  Edit*        edit;
  Tools*       tools;
  Preferences* preferences;
  Help*        help;
};

#endif /* _SPASSACTIONS_ */


