/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              CLASS SPASSDESKTOPMAINWIDGET              * */
/* *                                                        * */
/* *  $Module:   SPASSDESKTOPMAINWIDGET                     * */ 
/* *                                                        * */
/* *  Copyright (C) 1999, 2001, 2002 MPI fuer Informatik    * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.2 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2007/01/25 16:17:13 $                             * */
/* $Author: topic $                                      * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include "SPASSDesktopWidget.h"
#include "SPASSDesktopMainWidget.h"
#include "SPASSPreferences.h"

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/
/**********************************************************
  INPUT:   SPASS actions, SPASS applications, SPASS files,
           SPASS status bar, a parent widget, a name and widget
           flags.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSDesktopMainWidget::SPASSDesktopMainWidget (SPASSActions* actions,
						SPASSApplications* apps,
						SPASSFiles* files,
						SPASSStatusBar* status,
						QWidget* parent,
						const char* name,
						Qt::WFlags f)
  : Q3VBox(parent, name, f),
    splitter(actions, status, this, "input/output splitter"),
    tooloptions(this, "tool options"),
    dfg2asciiRunner(apps->dfg2asciiProcess, apps->DFG2ASCII, NULL,
		    &splitter, status, actions->tools->dfg2Ascii),
    dfg2dfgRunner(apps->dfg2dfgProcess, apps->DFG2DFG, &tooloptions.edit,
		  &splitter, status, actions->tools->dfg2Dfg),
    spassRunner(apps->spassProcess, apps->SPASS,  &tooloptions.edit,
		&splitter, status, actions->tools->spass),
    spassKiller(apps->spassProcess, actions->tools->abort),
    saver(files, &splitter, status, actions->file->save),
    saveAsFileListener(files, &splitter, status, actions->file->saveAs),
    newFileListener(files, &splitter, status, actions->file->newfile, getSaveFileListener()),
    openFileListener(files, &splitter, status, actions->file->open, getSaveFileListener()),
    copyOutputListener(files, &splitter, status, actions->edit->copyOutput, getSaveFileListener()),
    aboutListener(actions->help->about),
    spassHelpListener(actions->help->spass, SPASSFiles::Help::SPASS),
    dfg2dfgHelpListener(actions->help->dfg2dfg, SPASSFiles::Help::DFG2DFG),
    spass_syntaxHelpListener(actions->help->spass_syntax, SPASSFiles::Help::SPASS_SYNTAX),
    handbookHelpListener(actions->help->handbook, SPASSFiles::Help::HANDBOOK),
    faqHelpListener(actions->help->faq, SPASSFiles::Help::FAQ),
    licenseHelpListener(actions->help->license, SPASSFiles::Help::LICENSE),
    warrantyHelpListener(actions->help->warranty, SPASSFiles::Help::WARRANTY)
{
}

/**************************************************************/
/*                          Public methods                    */
/**************************************************************/
/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  returns the save file listener.
***********************************************************/
SaveFileListener* SPASSDesktopMainWidget::getSaveFileListener(void) 
{
  return &saver;
}
