/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              CLASS SPASSDESKTOPWIDGET                  * */
/* *                                                        * */
/* *  $Module:   SPASSDESKTOPWIDGET                         * */
/* *                                                        * */
/* *  Copyright (C) 1999, 2001, 2002 MPI fuer Informatik    * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.1.1.1 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2006/02/20 10:28:31 $                             * */
/* $Author: topic $                                         * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/
#include <qmenubar.h>
#include <qmessagebox.h>
//Added by qt3to4:
#include <QPixmap>
#include <Q3PopupMenu>

#include "AboutListener.h"
#include "SPASSDesktopWidget.h"
#include "SPASSDialogs.h"
#include "SPASSImages.h"

/**************************************************************/
/*                        Constants                           */
/**************************************************************/

const QString SPASSDesktopWidget::CAPTION("SPASSGUI");

const QString SPASSDesktopWidget::ICONPIC("fish-icon");

const QString SPASSDesktopWidget::MENUENTRY_FILE("&File");
const QString SPASSDesktopWidget::MENUENTRY_EDIT("&Edit");
const QString SPASSDesktopWidget::MENUENTRY_RUNMENU("&Tools");
const QString SPASSDesktopWidget::MENUENTRY_OPTIONS("&Settings");
const QString SPASSDesktopWidget::MENUENTRY_HELP("&Help");

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/
/**********************************************************
  INPUT:   A parent widget and a name.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSDesktopWidget::SPASSDesktopWidget (QWidget* parent, const char *name)
  : QMainWindow(parent,name,Qt::WStyle_NormalBorder)
{
  actions = new SPASSActions(this);
  Q_CHECK_PTR(actions);

  prefs = new SPASSPreferences(actions->preferences->font, this, "preferences");
  Q_CHECK_PTR(prefs);

  exiter = new ExitListener(actions->file->exit);
  Q_CHECK_PTR(exiter);

  files = new SPASSFiles();
  Q_CHECK_PTR(files);

  applications = new SPASSApplications();
  Q_CHECK_PTR(applications);

  //create a status bar
  statusbar=new SPASSStatusBar(this,"statusbar");
  Q_CHECK_PTR(statusbar);

  setCaption(CAPTION);

  iconpic = QPixmap (qembed_findImage(ICONPIC));
  setIcon (iconpic);

  dirpath = QDir::currentDirPath();

  inputfilechanged = FALSE;

  mainWidget = new SPASSDesktopMainWidget(actions, applications, files, statusbar, this, "main widget");
  Q_CHECK_PTR(mainWidget);

  setCentralWidget(mainWidget);

  statusbar->showFileName(files->input->file->name());

  //******************* the toolbar definition *********************

  toolbar = new QToolBar ("Toolbar",this);
  Q_CHECK_PTR(toolbar);

  /* Add actions in file action group manually, since
     actions without associated icons show up as blank
     buttons in the toolbar.

     Add spass action group to the toolbar.
  */

  actions->file->exit->addTo(toolbar);
  toolbar->addSeparator();

  actions->file->newfile->addTo(toolbar);
  actions->file->open->addTo(toolbar);
  actions->file->save->addTo(toolbar);
  toolbar->addSeparator();

  actions->edit->addTo(toolbar);
  toolbar->addSeparator();

  actions->tools->addTo(toolbar);
  toolbar->addSeparator();

  actions->preferences->font->addTo(toolbar);

  addToolBar(Qt::TopToolBarArea, toolbar);

  //****************** the menu definition *************************
  file = new Q3PopupMenu (this, "file");
  Q_CHECK_PTR(file);

  edit=new Q3PopupMenu (this, "edit");
  Q_CHECK_PTR(edit);

  options=new Q3PopupMenu (this, "options");
  Q_CHECK_PTR(options);

  runmenu=new Q3PopupMenu (this, "spass");
  Q_CHECK_PTR(runmenu);

  helpmenu=new Q3PopupMenu (this, "help");
  Q_CHECK_PTR(helpmenu);

  QMenuBar * menubar = menuBar();

  menubar->insertItem(MENUENTRY_FILE, file);
  menubar->insertItem(MENUENTRY_EDIT, edit);
  menubar->insertItem(MENUENTRY_RUNMENU, runmenu);
  menubar->insertItem(MENUENTRY_OPTIONS, options);
  menubar->insertItem(MENUENTRY_HELP, helpmenu);

  actions->file->addTo(file);
  actions->edit->addTo(edit);
  actions->tools->addTo(runmenu);
  actions->preferences->addTo(options);
  actions->help->addTo(helpmenu);

  //***************** end of menu definition ***************************

  showMaximized();
}

SPASSPreferences* SPASSDesktopWidget::prefs = NULL;

/**************************************************************/
/*                        Destructor                          */
/**************************************************************/
/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Deletes an instance of this class.
***********************************************************/
SPASSDesktopWidget::~SPASSDesktopWidget ()
{
  //IMPORTANT : CANCEL is the same as NO here, not as in the other cases !!!!
  if (inputfilechanged) {
    if ((files->input->fileinfo != NULL)
	&& (files->input->fileinfo->isWritable())
	&& (SPASSDialogs::showWarningToSave(files)==QMessageBox::Yes)) {
      mainWidget->getSaveFileListener()->listen();
    }
  }

  delete statusbar;
  delete toolbar;
  delete mainWidget;
  delete applications;
  delete files;
  delete actions;
  delete prefs;
  delete exiter;
}

/**************************************************************/
/*                          Slots                             */
/**************************************************************/

/**************************************************************/
/*                        public methods                      */
/**************************************************************/

/**********************************************************
  INPUT:   None.
  RETURNS: Current preferences.
  EFFECT:  This method provides access to the current
           preferences object. This is only useful to
	   connect slots to signals emmitted by
	   preferences.
***********************************************************/
SPASSPreferences* SPASSDesktopWidget::getPreferences(void)
{
  return prefs;
}

