/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              CLASS SPASSDIALOGS                        * */
/* *                                                        * */
/* *  $Module:   SPASSDIALOGS                               * */ 
/* *                                                        * */
/* *  Copyright (C) 1999, 2001, 2002 MPI fuer Informatik    * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.1.1.1 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2006/02/20 10:28:31 $                             * */
/* $Author: topic $                                      * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/


/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include <qmessagebox.h>
#include <qpixmap.h>

#include "SPASSDesktopWidget.h"
#include "SPASSDialogs.h"
#include "SPASSImages.h"

/**************************************************************/
/*                        public methods                     */
/**************************************************************/

/**********************************************************
  INPUT:   SPASS files.
  RETURNS: The value of showConfirmation.
  EFFECT:  shows a messagebox which asks the user whether
           the current input file should be saved.
***********************************************************/
int SPASSDialogs::showWarningToSave(SPASSFiles *files)
{
  return showConfirmation("Do you want to save the changes in "
			  + QString(files->input->file->name())
			  + " ?");
}

/**********************************************************
  INPUT:   a message.
  RETURNS: QMessageBox::Yes, QMessageBox::No or
           QMessageBox::Cancel, depending on user's
           selection.
  EFFECT:  shows a confirmation message in a messagebox.
***********************************************************/
int SPASSDialogs::showConfirmation(QString message)
{
  QMessageBox mbox("Confirmation", message, QMessageBox::Warning, QMessageBox::Yes,
		   QMessageBox::No, QMessageBox::Cancel, NULL);
  mbox.setIconPixmap(QPixmap (qembed_findImage(SPASSDesktopWidget::ICONPIC)));
  return mbox.exec();
}


/**********************************************************
  INPUT:   a message.
  RETURNS: QMessageBox::Ok or QMessageBox::Cancel,
           depending on user's selection.
  EFFECT:  shows an error message in a messagebox.
***********************************************************/
int SPASSDialogs::showErrorMessage(QString message)
{
  QMessageBox mbox("Error", message, QMessageBox::Warning, QMessageBox::Ok,
		   QMessageBox::Cancel, QMessageBox::NoButton);
  mbox.setIconPixmap(QPixmap (qembed_findImage(SPASSDesktopWidget::ICONPIC)));
  return mbox.exec();
}







