/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              CLASS SPASSFILES                          * */
/* *                                                        * */
/* *  $Module:   SPASSFILES                                 * */ 
/* *                                                        * */
/* *  Copyright (C) 1999, 2001, 2002 MPI fuer Informatik    * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.2 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2007/01/25 16:17:13 $                             * */
/* $Author: topic $                                      * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include <qdir.h>

#include "SPASSFiles.h"

/**************************************************************/
/*                        Constants                           */
/**************************************************************/

const QString SPASSFiles::Help::DFG2DFG(QDir::convertSeparators(QDir::cleanPath(HELP_PREFIX HTML_DIR "script_5.html")));
const QString SPASSFiles::Help::FAQ(QDir::convertSeparators(QDir::cleanPath(HELP_PREFIX HTML_DIR "script_7.html")));
const QString SPASSFiles::Help::HANDBOOK(QDir::convertSeparators(QDir::cleanPath(HELP_PREFIX PDF_DIR "handbook-spass.pdf")));
const QString SPASSFiles::Help::LICENSE(QDir::convertSeparators(QDir::cleanPath(HELP_PREFIX HTML_DIR "COPYING.html")));
const QString SPASSFiles::Help::SPASS(QDir::convertSeparators(QDir::cleanPath(HELP_PREFIX HTML_DIR "script_1.html")));
const QString SPASSFiles::Help::SPASS_SYNTAX(QDir::convertSeparators(QDir::cleanPath(HELP_PREFIX PDF_DIR "spass-input-syntax.pdf")));
const QString SPASSFiles::Help::WARRANTY(QDir::convertSeparators(QDir::cleanPath(HELP_PREFIX HTML_DIR "WARRANTY.html")));

const QString SPASSFiles::Input::DEFAULT("noname.dfg");

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/
/**********************************************************
  INPUT:   A file name.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSFiles::Input::Input(const QString & filename) {
  file = new QFile(filename);
  Q_CHECK_PTR(file);

  fileinfo = new QFileInfo(*file);
  Q_CHECK_PTR(fileinfo);
}

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSFiles::SPASSFiles(void) {
  input  = new Input();
}

/**************************************************************/
/*                        Destructors                         */
/**************************************************************/
/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Deletes an instance of this class.
***********************************************************/
SPASSFiles::Input::~Input(void) {
  delete file;

  if (fileinfo != NULL) {
    delete fileinfo;
  }
}

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Deletes an instance of this class.
***********************************************************/
SPASSFiles::~SPASSFiles(void) {
  delete input;
}

