/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              CLASS SPASSSPLITTER                       * */
/* *                                                        * */
/* *  $Module:   SPASSSPLITTER                              * */ 
/* *                                                        * */
/* *  Copyright (C) 2002 MPI fuer Informatik                * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.1.1.1 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2006/02/20 10:28:31 $                             * */
/* $Author: topic $                                         * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/
/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include "SPASSSplitter.h"

/**************************************************************/
/*                         CONSTANTS                          */
/**************************************************************/

const QString SPASSSplitter::EDITOR_LABEL("Editor");
const QString SPASSSplitter::OUTPUT_LABEL("Output");

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/
/**********************************************************
  INPUT:   SPASS actions, a spass status bar, a parent
           widget and a name.
  RETURNS: None.
  EFFECT:  Creates an instance of this class.
***********************************************************/
SPASSSplitter::SPASSSplitter (SPASSActions * actions, SPASSStatusBar * status, QWidget * parent, const char * name)
    : QSplitter(Qt::Horizontal, parent, name),
      left(this, "left"),
      right(this, "right"),
      editor_label(EDITOR_LABEL, &left, "editor label"),
      output_label(OUTPUT_LABEL, &right, "output label"),
      input(false, &left, "input"),
      output(true, &right, "output")
{
  /* Connect actions and slots. */
  connect(getInput(), SIGNAL(cursorPositionChanged(int, int)), status, SLOT(showCursorPosition(int, int)));
  connect(actions->edit->copy, SIGNAL(activated()), getInput(), SLOT(copy()));
  connect(actions->edit->cut, SIGNAL(activated()), getInput(), SLOT(cut()));
  connect(actions->edit->paste, SIGNAL(activated()), getInput(), SLOT(paste()));
}

/**************************************************************/
/*                          Public methods                    */
/**************************************************************/
/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  returns the editor.
***********************************************************/
SPASSTextEdit* SPASSSplitter::getInput(void)
{
  return &input;
}

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  returns the editor.
***********************************************************/
SPASSTextEdit* SPASSSplitter::getOutput(void)
{
  return &output;
}

