/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *       CLASS SAVEASFILELISTENER                         * */
/* *                                                        * */
/* *  $Module:   SAVEASFILELISTENER                         * */ 
/* *                                                        * */
/* *  Copyright (C) 2001, 2002 MPI fuer Informatik          * */
/* *                                                        * */
/* *  This program is free software; you can redistribute   * */
/* *  it and/or modify it under the terms of the GNU        * */
/* *  General Public License as published by the Free       * */
/* *  Software Foundation; either version 2 of the License, * */
/* *  or (at your option) any later version.                * */
/* *                                                        * */
/* *  This program is distributed in the hope that it will  * */
/* *  be useful, but WITHOUT ANY WARRANTY; without even     * */
/* *  the implied warranty of MERCHANTABILITY or FITNESS    * */
/* *  FOR A PARTICULAR PURPOSE.  See the GNU General Public * */
/* *  License for more details.                             * */
/* *                                                        * */
/* *  You should have received a copy of the GNU General    * */
/* *  Public License along with this program; if not, write * */
/* *  to the Free Software Foundation, Inc., 59 Temple      * */
/* *  Place, Suite 330, Boston, MA  02111-1307  USA         * */
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.1.1.1 $                                         * */
/* $State: Exp $                                            * */
/* $Date: 2006/02/20 10:28:31 $                             * */
/* $Author: topic $                                         * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Christoph Weidenbach                       * */
/* *             MPI fuer Informatik                        * */
/* *             Im Stadtwald                               * */
/* *             66123 Saarbruecken                         * */
/* *             Email: weidenb@mpi-inf.mpg.de               * */
/* *             Germany                                    * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

/**************************************************************/
/*                         INCLUDES                           */
/**************************************************************/

#include <qmessagebox.h>

#include <QFileDialog>

#include "SaveFileListener.h"
#include "SaveAsFileListener.h"
#include "SPASSdefines.h"
#include "SPASSDialogs.h"

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/
const QString SaveAsFileListener::DIALOG_TITLE("Save as file");

/**************************************************************/
/*                        Constructors                        */
/**************************************************************/

/**********************************************************
  INPUT:   A pointer to SPASS files, a pointer to a SPASS
           splitter, a pointer to the status bar, a pointer
           to an action.
  RETURNS: None.
  EFFECT:  Constructs an instance of this class. Disconnects
           the parent class' from the action, before
           connecting own listen slot to action's activated
           signal.
***********************************************************/
SaveAsFileListener::SaveAsFileListener(SPASSFiles *f, SPASSSplitter *splitter, SPASSStatusBar *status, QAction * action)
  : SaveFileListener(f, splitter, status, action)
{
  /* Disconnect parent class event listener
   * from action before connecting yourself.
   */
  disconnect(action, SIGNAL(activated()),
	     (SaveFileListener *) this, SLOT(listen()));

  connect(action, SIGNAL(activated()),
	  this, SLOT(listen()));
}

/**************************************************************/
/*                          Slots                             */
/**************************************************************/

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  handles the File SaveAs event.
           Saves a file in the editor under a different name.
***********************************************************/
void SaveAsFileListener::listen(void)
{
  SaveFileListener::save(getSaveFileName());
}

/**************************************************************/
/*                          public methods                    */
/**************************************************************/

/**********************************************************
  INPUT:   None.
  RETURNS: None.
  EFFECT:  Keeps asking the user for a filename for saving,
           until she either picks a good one, or gives up.
***********************************************************/
QString SaveAsFileListener::getSaveFileName(void)
{
  QString filename;

  /* keep asking for a file name until the user either picks
   * a good one, or gives up.
   */
  while (true) {
    /* Ask the user for filename to save under */
    filename = FileListener::getFileName(DIALOG_TITLE,
					 QFileDialog::AnyFile);

    /* If it is empty, the user gives up. */
    if (filename.isEmpty()) {
      break;
    }

    /* If a file with the name exists already, ask for permission
       to overwrite it.
    */
    if (QFile::exists(filename)) {
      int overwrite = SPASSDialogs::showErrorMessage(ERR_FILE_EXISTS_OVERWRITE);
      
      if (overwrite == QMessageBox::Ok) {
	break;
      }
      else {
	continue;
      }
    }

    QFile provisional(filename);
    
    /* If the file can not be opened for writing, show an error
       message and retry.
    */
    if (!provisional.open(QIODevice::WriteOnly)) {
      SPASSDialogs::showErrorMessage(ERR_NO_WRITE_PERMISSION);
      continue;
    }
    else {
      break;
    }
  }

  return filename;
}
