/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *              EXTENDED MODAL LOGICS ROUTINES            * */
/* *                                                        * */
/* *  $Module:   EML                                        * */ 
/* *                                                        * */
/* *                                                        * */
/* $Revision: 1.3 $                                        * */
/* $State: Exp $                                            * */
/* $Date: 2007/07/05 13:28:09 $                             * */
/* $Author: weidenb $                                       * */
/* *                                                        * */
/* *             Contact:                                   * */
/* *             Renate Schmidt                             * */
/* *             School of Computer Science                 * */
/* *             University of Manchester                   * */
/* *             Oxford Rd, Manchester M13 9PL, UK          * */
/* *             Email: Renate.Schmidt@manchester.ac.uk     * */
/* *                                                        * */
/* *              Modifications for Axiomatic Translation   * */
/* *              @K.J.Smith 2007/8 john@KJSmith.net       * */
/* ********************************************************** */
/**************************************************************/


/* $RCSfile: eml.c,v $ */

#include "cnf.h"
#include "eml.h"
#include "foldfg.h"
#include "flags.h"

SYMBOL  eml_APPLYF;
SYMBOL  eml_BOX;
SYMBOL  eml_COMP;
SYMBOL  eml_CONV;
SYMBOL  eml_DIA;
SYMBOL  eml_DIV;
SYMBOL  eml_DOMAIN;
SYMBOL  eml_DOMRESTR;
SYMBOL  eml_ID;
SYMBOL  eml_RANGE;
SYMBOL  eml_RANRESTR;
SYMBOL  eml_SUM;
SYMBOL  eml_TEST;

LIST    eml_SYMBOLS;                    /* eml junctor symbols */

LIST   *eml_PROPINDEXTOFOSYMBOL;       /* list of FO symbols associated with 
                                           eml prop/junctor symbols */
SYMBOL  eml_SEMIFNDESYMBOLS[symbol__MAXSIGNATURE];            
                                        /* nde symbols associated with diamonds */
SYMBOL  eml_NARYSYMBOLS[symbol__MAXSIGNATURE][eml__MAXMODALDEPTH];    
                                        /* FO symbols with particular
                                         * arity associated with p's */

static const char* eml_PREDNAMEPREFIX[9] = { "SkQ", "SkR", "SkNde" , "SkQ", "SkNde", "SkS", "", "Q", "R" }; /* kjs */

SYMBOL eml_AXIOM_D, eml_AXIOM_B, eml_AXIOM_T, eml_AXIOM_4, eml_AXIOM_5, eml_AXIOM_ALT1; /* kjs */
SYMBOL eml_AXIOM_Dc, eml_AXIOM_Bc, eml_AXIOM_Tc, eml_AXIOM_4c, eml_AXIOM_5c, eml_AXIOM_ALT1c; /* kjs */
SYMBOL eml_AXIOM_Do, eml_AXIOM_Bo, eml_AXIOM_To, eml_AXIOM_4o, eml_AXIOM_5o, eml_AXIOM_ALT1o; /* kjs */
SYMBOL eml_AXIOM_4K2, eml_AXIOM_4K3, eml_AXIOM_5K2, eml_AXIOM_5K3;
SYMBOL eml_AXIOM_ALT1KK11, eml_AXIOM_ALT1KK12, eml_AXIOM_ALT1KK21, eml_AXIOM_ALT1KK22; /* kjs */
SYMBOL eml_AXIOM_4K2c, eml_AXIOM_4K3c, eml_AXIOM_5K2c, eml_AXIOM_5K3c;
SYMBOL eml_AXIOM_ALT1KK11c, eml_AXIOM_ALT1KK12c, eml_AXIOM_ALT1KK21c, eml_AXIOM_ALT1KK22c; /* kjs */
SYMBOL eml_AXIOM_4K2o, eml_AXIOM_4K3o, eml_AXIOM_5K2o, eml_AXIOM_5K3o;
SYMBOL eml_AXIOM_ALT1KK11o, eml_AXIOM_ALT1KK12o, eml_AXIOM_ALT1KK21o, eml_AXIOM_ALT1KK22o; /* kjs */
SYMBOL eml_SLF, eml_AXIOMSLF, eml_NOAXIOM;

static const char* eml_RELPROPERTYLABELS[6] = { "", "serial",
       "reflexive" , "symmetric", "transitive", "euclidean" };

typedef enum {
	eml_ON = 1 , eml_OFF = 0, eml_FULL = 2, eml_ALL, eml_COMPLEX
} EML_CONTROL; /* kjs */
const int InternalMode = 1;
const int ExternalMode = 0;

typedef struct {
	EML_CONTROL DoNotUseAxiomBComposition;
	EML_CONTROL DoNotUseAxiomDComposition;
	EML_CONTROL DoNotUseAxiomAlt1Composition;
	EML_CONTROL DoNotUseAxiom4Composition;
	EML_CONTROL DoNotUseAxiom5Composition;
	EML_CONTROL DoNotUseAxiom4KComposition;
	EML_CONTROL DoNotUseAxiom5KComposition;
	EML_CONTROL DoNotUseAxiomAlt1KKComposition;
	EML_CONTROL IgnoreLogicFlagWarnings;
	EML_CONTROL IncludeNegativeDefs;
	EML_CONTROL ExcludeOptionalPositiveShortcuts;
	EML_CONTROL NeverUsePositiveShortcuts;
	EML_CONTROL DoNotSortTermNames;
	EML_CONTROL DoNotUseComposition; 
	EML_CONTROL AlwaysUseSubstitutedSymbolNames;
	EML_CONTROL DoNotUsePrintStatements;
	EML_CONTROL DoNotUseSetPrecedence;
	/* Not available from options - flag set by software */
	EML_CONTROL UsingInlineAxiomfeatures;
	EML_CONTROL UsingSetFlagAxiomfeatures;
} AXIOMHIDDENOPTION; /* kjs */
static AXIOMHIDDENOPTION HiddenOpt; /* kjs */

LIST AlreadyDEFinedList;

typedef enum { NONE, K, FOUR, FIVE, T, D, B, ALT1, FOURK, FIVEK, ALT1KK, AXIOM_NONE,
			   SR, G, DEN, TR, M, W, CR, CR2, CR3, BK, H, DBBB
	} AXIOMTYPE; /* kjs */

typedef enum { /* translation types */
	AXIOMATIC_TR, AXIOMATIC_TR_COMP, CLASSICAL_TR
} AXIOMMODE; /* kjs */
typedef struct {
	AXIOMTYPE AxiomType;
	AXIOMMODE Mode;
	int Parameter1;
	int Parameter2;
	int Index; /* */
	SYMBOL Modality;
	SYMBOL Modality2;
} AXIOM; /* kjs - defines parameters of an axiom */
#define MAXDEFINEDAXIOMS 100
static AXIOM AxiomComposition[MAXDEFINEDAXIOMS]; /* kjs - defines order in which axioms are applied */
static int AxiomCompositionIndex = 1; /* points to next available slot */

typedef struct {
	SYMBOL Symbol;
	char *Name;
	TERM Term;
	eml_SYMBOLTYPE Type;
	LIST NegBox;
	int AccessCount;
} AXIOMSYMBOL; /* kjs */
static AXIOMSYMBOL eml_AxiomSymbolList[eml__MAXNOAXIOMSYMBOL]; /* kjs */
static int eml_INDEXAXIOMSYMBOL = 0; /* kjs */

#define eml_SIZEAXIOMVARSTORE 100
SYMBOL eml_AxiomVarStore[eml_SIZEAXIOMVARSTORE]; /* [0]=VarX, [1]=VarY, [2]=VarZ... variable store */
typedef enum { VARX, VARY, VARZ, VARU, VARV, VARW, VARG, VARD, VARE, VAR9, VAR10, VAR11, VAR12 } AXIOMVAR; /* kjs */

typedef struct {
	TERM Term;   /* original term */
	LIST SuperDef; /* list of the rest */
	LIST BoxDef;   /* list of Box pointers */
	LIST SubDef;   /* list of pointers to predicates */
	LIST XtraBoxDef; /* incremented as axioms are processed */
	LIST CompositionList; /* */
} AXIOMDEFLIST; /* kjs */

static SYMBOL eml_R[MAXDEFINEDAXIOMS]; /* kjs */
static int eml_INDEX_R = 0; /* kjs - points to next avialable slot */

typedef struct {
	char *R;
	char *S;
	char *Axiom; 
} AXIOMFLAG; /* kjs */
static AXIOMFLAG eml_AXIOMFLAG[MAXDEFINEDAXIOMS]; /* kjs */
static int eml_INDEX_FLAG = 0; /* kjs - points to next avialable slot */
#define eml_AllowedCount 69 
static const char* eml_AllowedSetFlags[eml_AllowedCount] = { 
		"None", "T",  "D",  "B",  "4",  "5",  "ALT1",
		"To", "Do", "Bo", "4o", "5o", "ALT1o",
		"Tc", "Dc", "Bc", "4c", "5c", "ALT1c",
		"4K2",  "4K3",  "5K2",  "5K3",  "ALT1KK11",  "ALT1KK12",  "ALT1KK21",  "ALT1KK22",
		"4K2o", "4K3o", "5K2o", "5K3o", "ALT1KK11o", "ALT1KK12o", "ALT1KK21o", "ALT1KK22o",
		"4K2c", "4K3c", "5K2c", "5K3c", "ALT1KK11c", "ALT1KK12c", "ALT1KK21c", "ALT1KK22c",
		"SRo", "Go", "DENo", "TRo", "Mo", "Wo", "SR", "G", "DEN", "TR", "M", "W", "DBBB", "DBBBo",
		"CRo", "CR2o", "B2o", "B3o", "CR", "CR2", "B2", "B3", "H", "Ho", "CR3", "CR3o", 
};

static TERM  eml_RemoveTrivialAtomsAndOps(TERM);
static TERM  eml_RemoveTrivialOperator(TERM Term);

static TERM  eml_EmbedInRelCalculusProp(TERM);
static TERM  eml_EmbedInRelCalculusRel(TERM);

static TERM  eml_RelationalTranslationProp(TERM, SYMBOL, FLAGSTORE, PRECEDENCE);
static TERM  eml_RelationalTranslationRel(TERM, SYMBOL, SYMBOL, FLAGSTORE, PRECEDENCE);

static TERM  eml_FunctTranslProp(TERM, TERM, FLAGSTORE, PRECEDENCE);
static TERM  eml_FunctTranslRel(TERM, TERM, FLAGSTORE, PRECEDENCE);
static TERM  eml_FunctTranslItoNaryPredProp(TERM, LIST, char*, int, FLAGSTORE, PRECEDENCE);
static TERM  eml_FunctTranslItoNaryPredRel(TERM, LIST, char*, int, FLAGSTORE, PRECEDENCE);

static TERM  eml_SemiFunctTranslProp(TERM, TERM, int, FLAGSTORE, PRECEDENCE);
static TERM  eml_SemiFunctTranslRelBox(TERM, TERM, TERM, FLAGSTORE, PRECEDENCE);
static TERM  eml_SemiFunctTranslRelDia(TERM, TERM, FLAGSTORE, PRECEDENCE);

static TERM eml_RelFunctTranslProp(TERM, SYMBOL, char*, FLAGSTORE, PRECEDENCE);
static TERM eml_RelFunctTranslRel(TERM, SYMBOL, SYMBOL, char*, FLAGSTORE, PRECEDENCE);

/* kjs */
static TERM eml_AxiomaticTranslationRel (TERM, SYMBOL, SYMBOL, FLAGSTORE, PRECEDENCE);
static TERM eml_AxiomaticTranslation (TERM, SYMBOL, SYMBOL, FLAGSTORE, PRECEDENCE);
static TERM eml_EliminateDiamond (TERM, BOOL *);
static TERM eml_EliminateNotNot (TERM, BOOL *);
static TERM eml_AxiomaticStd (TERM);
static void eml_TermName(TERM, char *);
static void eml_SymbolNameHelper (SYMBOL, char *);
static void eml_GetDEFUnits(AXIOMDEFLIST *);
static void eml_GetDEFUnitsHelper(TERM, AXIOMDEFLIST *);
static LIST eml_DEF (TERM, SYMBOL, SYMBOL, BOOL, FLAGSTORE, PRECEDENCE);
static SYMBOL eml_CreateAxiomSymbol(TERM, eml_SYMBOLTYPE, int, int, PRECEDENCE);
static TERM eml_BuildExistentialTerm(AXIOMDEFLIST *, SYMBOL, FLAGSTORE, PRECEDENCE);
static LIST eml_ProcessAxiomaticDefList (AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static TERM eml_Axiomatic (TERM, FLAGSTORE, PRECEDENCE);
static TERM eml_RelationalTranslation(TERM, FLAGSTORE, PRECEDENCE);
static TERM eml_EliminateBiImplication(TERM, BOOL *);
static TERM eml_EliminateImplies(TERM, BOOL *);
static TERM eml_EliminateImplied(TERM, BOOL *);
static TERM eml_EliminateOr(TERM, BOOL *);
static TERM eml_EliminateTrue(TERM, BOOL *);
static TERM eml_EliminateModals (TERM, BOOL *);
static TERM eml_Negate(TERM);
static TERM eml_NegateElimNotNot(TERM);
static void eml_SetAxiomSymbol(char *, SYMBOL *, TERM, eml_SYMBOLTYPE);
static SYMBOL eml_GetAxiomSymbol(const char *);
static TERM eml_ProcessLogicT(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessLogicD(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessLogic4(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessLogic5(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessLogicB(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessLogicAlt1(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessLogic5K(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessLogic4K(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessLogicAlt1KK(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static LIST eml_ProcessAxiomLogic (AXIOM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessSLF(TERM, TERM *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessAXSLF(TERM, TERM *, FLAGSTORE, PRECEDENCE);
static TERM eml_ProcessExempt(TERM, TERM *);
static void eml_Print(const char *);
static void eml_PrintD(const char *, const int);
static void eml_PrintDT(const char *, const int, const TERM);
static void eml_PrintT(const char *, const TERM);
static void eml_PrintS(const char *, const SYMBOL);
static void eml_PrintDS(const char *, const int, const SYMBOL);
static void eml_Error(const char *);
static void eml_ErrorD(const char *, const int);
static void eml_ErrorC(const char *, const char *);
static LIST eml_ProcessLogic (AXIOM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE, 
		TERM (*)(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE));
static LIST eml_SimpleDEF (TERM, SYMBOL, SYMBOL, BOOL, FLAGSTORE, PRECEDENCE);
static int eml_TermLength(const TERM);
static void eml_TermLengthHelper(const TERM, int *);
static void eml_AxiomDEFListInit (TERM, AXIOMDEFLIST *);
static LIST eml_AxiomDEFListConc (AXIOMDEFLIST *, EML_CONTROL);
static void eml_AnalyzeEmlAxiomTranslationFlags(FLAGSTORE);
static BOOL eml_TermEqual(const TERM, const TERM);
static BOOL eml_ListContains (const LIST *, TERM);
static void eml_OptTermName(TERM, char *);
static TERM eml_TermNameSort(TERM);
static LIST eml_SortTermList(LIST);
static BOOL eml_TermNameTest (POINTER, POINTER);
/*static BOOL eml_TermCompareByArity (POINTER, POINTER);*/
static void eml_AxiomOptionsInit(FLAGSTORE);
static void eml_Int2String(int, char *);
static void eml_SetPrecedence(PRECEDENCE, const TERM);
static TERM eml_ComposeAxioms(TERM);
static BOOL eml_SetPositiveShortcut();
static void eml_AxiomInit(FLAGSTORE, PRECEDENCE);
static void eml_AxiomCleanUp();
static SYMBOL eml_GetVar(int);
static TERM eml_ProcessClassicalLogic (AXIOM, FLAGSTORE, PRECEDENCE);
static void eml_UpdateCompositionAxiomLogic(AXIOM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static void eml_PrintAxiomComposition();
static void eml_PrintSymbolTable();
static LIST eml_AxiomLogicControl(AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE);
static BOOL eml_AreAxiomsDefined ();
static AXIOM eml_GetAxiom (int);
static BOOL eml_BuildAxiom(AXIOMTYPE, AXIOMMODE, int, int);
static BOOL eml_BuildAxiomR(AXIOMTYPE, AXIOMMODE, int, int, SYMBOL);
static BOOL eml_BuildAxiomAt(int, AXIOMTYPE, AXIOMMODE, int, int);
static TERM eml_ProcessPreviousComposition(AXIOM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE, int);
static void eml_UpdateCompositionList(TERM, AXIOMDEFLIST *); 
static TERM eml_QuantifyTerm(SYMBOL, TERM, LIST);
static void eml_Count_Modalitys(TERM);
static void eml_AnalyzeSetAxiom(FLAGSTORE);
static void eml_DefineNewDefs(TERM, AXIOMDEFLIST *, LIST *,	FLAGSTORE, PRECEDENCE,BOOL); 
static LIST eml_ListAddTerm(TERM, LIST);
static LIST eml_ListAddList(LIST, LIST);
static BOOL eml_BuildAxiomRS(AXIOMTYPE, AXIOMMODE, int, int, SYMBOL, SYMBOL);
/* kjs */

/**************************************************************/
/* ********************************************************** */
/* *                                                        * */
/* *  FUNCTIONS                                             * */
/* *                                                        * */
/* ********************************************************** */
/**************************************************************/

void eml_Init(PRECEDENCE Precedence)
/**************************************************************
  INPUT:   None.
  RETURNS: None.
  USAGE:   extern public.
  SUMMARY: Initializes the Eml Module.
  EFFECTS: All additional extended modal logic symbols are created.  
           (The first-order symbols are created in fol_Init.)
	   And, creates an array for the list of
	   propositional/first-order symbol pairs as well as Eml logical
	   symbols/first-order logical symbol lists.
  CAUTION: MUST BE CALLED BEFORE ANY OTHER eml-FUNCTION.
***************************************************************/
{ 
  int i;
  eml_SLF = symbol_CreateJunctor("slf", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_NOAXIOM = symbol_CreateJunctor("NoAxiom", 1, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOMSLF = symbol_CreateJunctor("axslf", 2, symbol_STATLEX, Precedence); /* kjs */
  
  eml_AXIOM_D = symbol_CreateJunctor("axD", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_B = symbol_CreateJunctor("axB", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_T = symbol_CreateJunctor("axT", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_4 = symbol_CreateJunctor("ax4", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_5 = symbol_CreateJunctor("ax5", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1 = symbol_CreateJunctor("axALT1", 2, symbol_STATLEX, Precedence); /* kjs */ 
  /* this adds the term for name - for printing, etc */
  eml_AXIOM_4K2 = symbol_CreateJunctor("ax4K2", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_4K3 = symbol_CreateJunctor("ax4K3", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_5K2 = symbol_CreateJunctor("ax5K2", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_5K3 = symbol_CreateJunctor("ax5K3", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1KK11 = symbol_CreateJunctor("axALT1KK11", 2, symbol_STATLEX, Precedence); /* kjs */ 
  eml_AXIOM_ALT1KK12 = symbol_CreateJunctor("axALT1KK12", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1KK21 = symbol_CreateJunctor("axALT1KK21", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1KK22 = symbol_CreateJunctor("axALT1KK22", 2, symbol_STATLEX, Precedence); /* kjs */
   
  eml_AXIOM_4K2c = symbol_CreateJunctor("ax4K2c", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_4K3c = symbol_CreateJunctor("ax4K3c", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_5K2c = symbol_CreateJunctor("ax5K2c", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_5K3c = symbol_CreateJunctor("ax5K3c", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1KK11c = symbol_CreateJunctor("axALT1KK11c", 2, symbol_STATLEX, Precedence); /* kjs */ 
  eml_AXIOM_ALT1KK12c = symbol_CreateJunctor("axALT1KK12c", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1KK21c = symbol_CreateJunctor("axALT1KK21c", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1KK22c = symbol_CreateJunctor("axALT1KK22c", 2, symbol_STATLEX, Precedence); /* kjs */
    
  eml_AXIOM_4K2o = symbol_CreateJunctor("ax4K2o", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_4K3o = symbol_CreateJunctor("ax4K3o", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_5K2o = symbol_CreateJunctor("ax5K2o", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_5K3o = symbol_CreateJunctor("ax5K3o", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1KK11o = symbol_CreateJunctor("axALT1KK11o", 2, symbol_STATLEX, Precedence); /* kjs */ 
  eml_AXIOM_ALT1KK12o = symbol_CreateJunctor("axALT1KK12o", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1KK21o = symbol_CreateJunctor("axALT1KK21o", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1KK22o = symbol_CreateJunctor("axALT1KK22o", 2, symbol_STATLEX, Precedence); /* kjs */
      
  eml_AXIOM_Dc = symbol_CreateJunctor("axDc", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_Bc = symbol_CreateJunctor("axBc", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_Tc = symbol_CreateJunctor("axTc", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_4c = symbol_CreateJunctor("ax4c", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_5c = symbol_CreateJunctor("ax5c", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1c = symbol_CreateJunctor("axALT1c", 2, symbol_STATLEX, Precedence); /* kjs */ 
   
  eml_AXIOM_Do = symbol_CreateJunctor("axDo", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_Bo = symbol_CreateJunctor("axBo", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_To = symbol_CreateJunctor("axTo", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_4o = symbol_CreateJunctor("ax4o", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_5o = symbol_CreateJunctor("ax5o", 2, symbol_STATLEX, Precedence); /* kjs */
  eml_AXIOM_ALT1o = symbol_CreateJunctor("axALT1o", 2, symbol_STATLEX, Precedence); /* kjs */ 

  eml_BOX	= symbol_CreateJunctor("box", 2, symbol_STATLEX, Precedence);
  eml_COMP	= symbol_CreateJunctor("comp", 2, symbol_STATLEX, Precedence);
  eml_CONV	= symbol_CreateJunctor("conv", 1, symbol_STATLEX, Precedence);
  eml_DIA	= symbol_CreateJunctor("dia", 2, symbol_STATLEX, Precedence);
  eml_DIV	= symbol_CreatePredicate("div", 0, symbol_STATLEX, Precedence);
  eml_DOMAIN	= symbol_CreateJunctor("domain", 1, symbol_STATLEX, Precedence);
  eml_DOMRESTR	= symbol_CreateJunctor("domrestr", 2, symbol_STATLEX, Precedence);
  eml_ID	= symbol_CreatePredicate("id", 0, symbol_STATLEX, Precedence);
  eml_RANGE	= symbol_CreateJunctor("range", 1, symbol_STATLEX, Precedence);
  eml_RANRESTR	= symbol_CreateJunctor("ranrestr", 2, symbol_STATLEX, Precedence);
  eml_SUM	= symbol_CreateJunctor("sum", 2, symbol_STATLEX, Precedence);
  eml_TEST	= symbol_CreateJunctor("test", 1, symbol_STATLEX, Precedence);
  symbol_AddProperty(eml_DIV, PREDEFINED);
  symbol_AddProperty(eml_ID, PREDEFINED);
  
  eml_SYMBOLS =
	  list_Cons((POINTER)eml_BOX, list_Cons((POINTER)eml_COMP,
			  list_Cons((POINTER)eml_CONV, list_Cons((POINTER)eml_DIA,
					  list_Cons((POINTER)eml_DIV, list_Cons((POINTER)eml_DOMAIN, 
							  list_Cons((POINTER)eml_DOMRESTR, list_Cons((POINTER)eml_ID, 
									  list_Cons((POINTER)eml_RANGE, list_Cons((POINTER)eml_RANRESTR,
											  list_Cons((POINTER)eml_SUM, 
													list_Cons((POINTER)eml_SLF, /*kjs*/
													list_Cons((POINTER)eml_AXIOMSLF, /*kjs*/
													list_Cons((POINTER)eml_NOAXIOM, /* kjs */
													
													list_Cons((POINTER)eml_AXIOM_D, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_B, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_T, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_4, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_5, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1, /*kjs*/
															  
													list_Cons((POINTER)eml_AXIOM_4K2, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_4K3, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_5K2, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_5K3, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK11, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK21, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK12, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK22, /*kjs*/
															
													list_Cons((POINTER)eml_AXIOM_4K2c, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_4K3c, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_5K2c, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_5K3c, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK11c, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK21c, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK12c, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK22c, /*kjs*/
															
													list_Cons((POINTER)eml_AXIOM_4K2o, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_4K3o, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_5K2o, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_5K3o, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK11o, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK21o, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK12o, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1KK22o, /*kjs*/
																	
													list_Cons((POINTER)eml_AXIOM_Dc, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_Bc, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_Tc, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_4c, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_5c, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1c, /*kjs*/
															  															  
													list_Cons((POINTER)eml_AXIOM_Do, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_Bo, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_To, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_4o, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_5o, /*kjs*/
													list_Cons((POINTER)eml_AXIOM_ALT1o, /*kjs*/
													
					list_List((POINTER)eml_TEST))))))))))))))))))))))))))))))))))))))))))))))))))))))))
	  );

  eml_PROPINDEXTOFOSYMBOL = (LIST*)memory_Malloc(sizeof(LIST) * symbol__MAXSIGNATURE);
  for (i=0;i< symbol__MAXSIGNATURE;i++)
    eml_PROPINDEXTOFOSYMBOL[i] = list_Nil();

  eml_SetPropFoSymbolAssocList(eml_Dia(),
		list_Cons((POINTER)fol_Exist(), list_List((POINTER)fol_And())));
  eml_SetPropFoSymbolAssocList(eml_Box(), 
		list_Cons((POINTER)fol_All(), list_List((POINTER)fol_Implies())));
  eml_SetPropFoSymbolAssocList(eml_Comp(), 
		list_Cons((POINTER)fol_Exist(), list_List((POINTER)fol_And())));
  eml_SetPropFoSymbolAssocList(eml_Sum(), 
		list_Cons((POINTER)fol_All(), list_List((POINTER)fol_Or())));
  eml_SetPropFoSymbolAssocList(eml_Domain(), 
		list_List((POINTER)fol_Exist()));
  eml_SetPropFoSymbolAssocList(eml_Range(), 
		list_List((POINTER)fol_Exist()));
  eml_SetPropFoSymbolAssocList(eml_Id(), 
		list_List((POINTER)fol_Equality()));
  

}

BOOL eml_FormulaContainsEMLTheorySymbol(TERM Formula)
/**************************************************************
  INPUT:   A term or a formula
  RETURNS: TRUE iff <Formula> contains an EML theory symbol.
  USAGE:   extern public.
***************************************************************/
{ 
  SYMBOL Top;
  LIST   Scan;
  
  Top = term_TopSymbol(Formula);

  if (symbol_IsPredicate(Top)) {
    if (symbol_Equal(eml_DIV,Top) || symbol_Equal(eml_ID,Top))
      return TRUE;
    else
      return FALSE;
  }
  if (symbol_IsFunction(Top) || symbol_IsVariable(Top))
    return FALSE;

  if (symbol_Equal(Top, eml_BOX) || symbol_Equal(Top, eml_COMP) || symbol_Equal(Top, eml_CONV) || 
      symbol_Equal(Top, eml_SUM) || symbol_Equal(Top, eml_DIV) || symbol_Equal(Top, eml_DOMAIN) ||
      symbol_Equal(Top, eml_DOMRESTR) || symbol_Equal(Top, eml_RANGE) || symbol_Equal(Top, eml_RANRESTR) ||
      symbol_Equal(Top, eml_TEST))
    return TRUE;
  
  if (fol_IsQuantifier(Top))
    Scan = list_Cdr(term_ArgumentList(Formula));
  else
    Scan = term_ArgumentList(Formula);

  while (!list_Empty(Scan)) {
    if (eml_FormulaContainsEMLTheorySymbol((TERM)list_First(Scan)))
      return TRUE;
    Scan = list_Cdr(Scan);
  }

  return FALSE;
  
}

void eml_InitFunctTransl(FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   None.
  RETURNS: None.
  USAGE:   static intern.
  SUMMARY: Initializes the routines for the functional translation of
           basic (serial) modal logics ito n-ary predicates.
  EFFECTS: Additonal flags are set.
  CAUTION: Prerequisite for the functional translation ito n-ary predicates
           routines.
***************************************************************/
{ 
	/* printf("\nDoing eml_InitFunctTransl()\n"); */

  /* Dynamic memory allocation of eml_NARYSYMBOLS??
   * This does not work:
  eml_NARYSYMBOLS = (SYMBOL **)memory_Malloc(sizeof(SYMBOL) * symbol__MAXSIGNATURE *
		  symbol__MAXSIGNATURE);
		  */
  if ( (flag_GetFlagValue(Flags, flag_EMLTR) == flag_EMLTRSEMIFUNC) || 
       !flag_GetFlagValue(Flags, flag_EMLFNARY)) {
    eml_APPLYF	= symbol_CreateFunction("app", 2, symbol_STATLEX, Precedence);
    /*     fol_SYMBOLS = list_Cons((POINTER)eml_APPLYF, fol_SYMBOLS);*/
  }

}


void eml_Free(void)
/**************************************************************
  INPUT:   None.
  RETURNS: void.
  EFFECT:  The eml related memory used by the eml module is freed.
***************************************************************/
{
  int i;

  list_Delete(eml_SYMBOLS);

  for (i=0;i< symbol__MAXSIGNATURE;i++)
    list_Delete(eml_PROPINDEXTOFOSYMBOL[i]);

  memory_Free(eml_PROPINDEXTOFOSYMBOL, sizeof(LIST) * symbol__MAXSIGNATURE);

  /* list_Delete(eml_NARYSYMBOLS); ?? */
  
  eml_AxiomCleanUp(); /* kjs */
}

LIST eml_NullaryPredList()
/**************************************************************
  INPUT:   None.
  RETURNS: The list of nullary predicate symbols in the signature
  USAGE:   not used.
  EFFECTS: Creates a table for the list of
           propositional/first-order symbol pairs.
***************************************************************/
{
  LIST   nullaryPredList;
  int 	 i;

  if (!symbol_SignatureExists()) {
    fprintf(stderr,"\n\t eml_NullaryPredList(): no signature!?\n");
    misc_Error();
  }

  nullaryPredList = list_Nil();
  for(i = 1; i < symbol_ACTINDEX; i++)
    if (!symbol_IsFreed(i) &&
	eml_IsNullaryPredicate(symbol_GetSigSymbol(i)))
      nullaryPredList =
	      list_Cons((POINTER)(symbol_GetSigSymbol(i)),
			      nullaryPredList);

#ifdef DEBUG
  printf("\n nullaryPredList: ");
    for (Scan=nullaryPredList; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
      symbol_Print((SYMBOL)list_Car(Scan));
      printf(" ");
    }
  printf("\n");
#endif
  
  return nullaryPredList;
}

static SYMBOL eml_GetFoSymbolAssocWithPropSymbol(SYMBOL
		PropSymbol, NAT Arity, eml_SYMBOLTYPE SymbolType)
/**************************************************************
  INPUT:   a (propositional) symbol, the arity of the corresponding
           predicate symbol, the symbol type.
  RETURNS: The corresponding first-order symbol.
  EFFECTS: None.
***************************************************************/
{
  /* printf("\n  PropSymbol = "); */
  /* symbol_Print(PropSymbol); */
  if (eml_NaryType(SymbolType)) {
    /* Retrieve symbol with given arity */
    SYMBOL symbol;
    /* printf("\n  eml_NaryType"); */
    symbol = eml_NARYSYMBOLS[symbol_Index(PropSymbol)][Arity-1];
    if (symbol_IsSymbol(symbol))
      return symbol;
  }
  else if (eml_SemiFuncNdeType(SymbolType)) {
    /* Retrieve nde symbol for semi-functional translation */
    SYMBOL symbol;
    /* printf("\n  eml_SemiFuncNdeType"); */
    symbol = eml_SEMIFNDESYMBOLS[symbol_Index(PropSymbol)];
    if (symbol_IsSymbol(symbol))
      return symbol;
  }
  else if (eml_VarSortType(SymbolType)) {
    /* Reuse propositional symbol as predicate symbol to indicate the
     * sort */
    /* printf("\n  eml_VarSortType"); */
    return PropSymbol;  /* Struture sharing!
			 * Alternatively, set up another array called
			 * eml_PROPINDEXTOSORTSYMBOL, say */
  } 
  else {
    /* Retrieve predicate symbol: P_p for p, and R_r for r */
    LIST symbolList;
    /* printf("\n  not eml_NaryType and not eml_VarSortType"); */
    symbolList = eml_PROPINDEXTOFOSYMBOL[symbol_Index(PropSymbol)];
    if (!list_Empty(symbolList))
      return (SYMBOL) list_First(symbolList);
  }

    /* printf("\n  not eml_NaryType and not eml_VarSortType and symbolList is empty"); */
  return symbol__NULL;
}


SYMBOL eml_CreateFoSymbol(SYMBOL PropSymbol, eml_SYMBOLTYPE SymbolType,
		int Arity, int Status, PRECEDENCE Precedence)
/*******************************************************
  INPUT:   A symbol (which MUST be a propositonal symbol/nullary
	   predicate symbol), a symbol type (of the fo symbol to be
	   created), the arity of the new symbol, The status of the new
	   symbol.
  RETURNS: A first-order symbol corresponding to PropSymbol.
********************************************************/
{
  SYMBOL foSymbol;
  char   newName[symbol__SYMBOLMAXLEN];
  
  if (eml_NaryType(SymbolType)) {
    /* Note: if SymbolType is n-ary then any propositional symbol can
     * be associated with more than one n-ary predicate symbol, for
     * that reason no user defined FoSymbols will be considered */
    sprintf(newName,"%s%d%s", eml_PREDNAMEPREFIX[SymbolType], Arity,
	    symbol_Name(PropSymbol));
    foSymbol = symbol_CreatePredicate(newName, Arity, Status, Precedence);
    eml_SetPropNarySymbolAssocList(PropSymbol, Arity, foSymbol);
  }
  else if (eml_SemiFuncNdeType(SymbolType)) {
    /* NOTE: For the moment no user defined FoSymbols will be
     * considered.  This restriction is provisional */
    sprintf(newName,"%s%s", eml_PREDNAMEPREFIX[eml_NDE], 
	    symbol_Name(PropSymbol));
    foSymbol = symbol_CreatePredicate(newName, Arity, Status, Precedence);
    eml_SetPropSemiFNdeSymbolAssocList(PropSymbol, Arity, foSymbol);
  }
  else {
    sprintf(newName,"%s%s", eml_PREDNAMEPREFIX[SymbolType],
	    symbol_Name(PropSymbol));
    foSymbol = symbol_CreatePredicate(newName, Arity, Status, Precedence);
    eml_SetPropFoSymbolAssocList(PropSymbol,list_List((POINTER)foSymbol));
  }
  
  return foSymbol;
}

TERM eml_CreateQuantifier(TERM Term, SYMBOL Quantifier, LIST VarList,
		LIST Arguments)
/*******************************************************
  INPUT:   A term (dummy, not used), symbol (which MUST be a fol
	   quantifier), a list of variables that will be bound, and
           a list of arguments.
  RETURNS: A new quantified term.
********************************************************/
{                                                                  
  return term_Create(Quantifier,                                             
		     list_Cons(term_Create(fol_Varlist(), VarList),   
			       Arguments));  
}

static TERM  eml_RplacWithQuantifier(TERM Term, SYMBOL Quantifier, 
		LIST VarList, LIST Arguments)
/**************************************************************
  INPUT:   A formula, a symbol (quantifier), two list of terms.
  RETURNS: A quantifier replacement.
  EFFECT:  Note, a term node is created for the variable list.
  CAUTION: The term in destructively changed.
***************************************************************/
{
  term_RplacTop(Term,Quantifier);
  term_RplacArgumentList(Term, 
	list_Cons(term_Create(fol_Varlist(), VarList), Arguments));

  return Term;
}

static TERM eml_BuildSortQuantifierFor(TERM Term, SYMBOL ModalTop,
		SYMBOL RelSubTop, SYMBOL Var, BOOL WithSort,
		LIST Arguments, POINTER (*BuildFunction)(), 
		PRECEDENCE Precedence)
/*******************************************************
  INPUT:   A term (which MUST be a modal term, i.e. dia(..) or box (...)),
	   a single variable, a Boolean value indicating whether sorts or
	   required, and a list of arguments.
  RETURNS: A quantified term, possibly restricted by the appropriate sort.
  CAUTION: The term is potentially destructively changed (depends on the
           BuildFunction).
********************************************************/
{                                                                  
#ifdef DEBUG                                                          
  if (!eml_IsModalOpSymbol(ModalTop)) {
    printf("\n\nIllegal input in eml_BuildSortQuantifierFor\n");
    misc_Error();
  }
#endif                                                             
                                                                   
  if (WithSort) {
    eml_SYMBOLTYPE symbolType;
    SYMBOL foSymbol;
#ifdef DEBUG                                                          
    if (!eml_IsNullaryPredicate(RelSubTop)) {
      printf("\n\nIllegal relational argument of modal operator, in eml_BuildSortQuantifierFor\n");
      misc_Error();
    }
#endif                                                             

    symbolType = eml_VARSORT;
    foSymbol   = eml_GetFoSymbolAssocWithPropSymbol(RelSubTop, 1, symbolType);
    if (foSymbol == symbol__NULL) {
      foSymbol = eml_CreateFoSymbol(RelSubTop, symbolType, 1, symbol_STATLEX, Precedence);
      /* Inheritance of precedence? */
      /* symbol_SetOrdering(Precedence, foSymbol,symbol_Ordering(Precedence, PropSymbol)); */
    }
    return BuildFunction(Term, eml_FoQuantAssocWithPropSymbol(ModalTop), 
		list_List(term_Create(Var,list_Nil())),   
		list_List(term_Create(eml_FoJunctorAssocWithPropSymbol(ModalTop),
		  list_Cons(term_Create(foSymbol,list_List(term_Create(Var,list_Nil()))), Arguments))));
    /* exists x S(x) /\ ... 
     * forall x S(x) -> ... */
  }
  else {
    return BuildFunction(Term, eml_FoQuantAssocWithPropSymbol(ModalTop),
		list_List(term_Create(Var,list_Nil())), Arguments);
    /* exists x ... 
     * forall x ... */
  }
}

static TERM  eml_RplacWithDesignatedPropAtom(TERM Term, SYMBOL RplacSymbol)
/**************************************************************
  INPUT:   A formula and a symbol.
  RETURNS: A replacement without arguments, e.g. true, false, id, etc.
  CAUTION: The term in destructively changed.
***************************************************************/
{
  term_RplacTop(Term,RplacSymbol);
  list_DeleteWithElement(term_ArgumentList(Term),(void (*)())term_Delete);
  term_RplacArgumentList(Term,list_Nil());

  return Term;
}

static TERM  eml_RplacWithOpAndArgs(TERM Term, SYMBOL RplacSymbol, 
		LIST Arguments)
/**************************************************************
  INPUT:   A formula, a symbol and a list of terms.
  RETURNS: A replacement with argument list.
  CAUTION: The term in destructively changed.
***************************************************************/
{
  term_RplacTop(Term,RplacSymbol);
  term_RplacArgumentList(Term,Arguments);

  return Term;
}

static TERM  eml_RemoveTrivialOperator(TERM Term)
/**************************************************************
  INPUT:   A formula.
  RETURNS: The formula after
           removal of "or", "and", "comp" and "sum" with only one argument
  CAUTION: The term in destrucively changed.
***************************************************************/
{
  if (eml_IsNaryJunctor(term_TopSymbol(Term)) &&
      list_Empty(list_Cdr(term_ArgumentList(Term)))) {
    TERM helpTerm = term_FirstArgument(Term);
    list_Delete(term_ArgumentList(Term));
    Term = eml_RplacWithOpAndArgs(Term, term_TopSymbol(helpTerm), term_ArgumentList(helpTerm));
    term_Free(helpTerm);
  }

  return Term;
}

static TERM  eml_RemoveTrivialAtomsAndOps(TERM Term)
/**************************************************************
  INPUT:   A formula.
  RETURNS: The formula after applying
           or(true,...) -> true,      and(true,phi) -> phi
           or(false,phi) -> phi,      and(false,...) -> false
                 etc plus
           dia(alpha,false) -> false, box(alpha,true) -> true
           dia(false,phi) -> false,   box(false,phi) -> true
  CAUTION: The term in destructively changed.
***************************************************************/
{
  SYMBOL Top, Subtop, RelSubtop;
  LIST   Scan;
  TERM   Subterm, RelSubterm;
  BOOL   Update;

  if (!term_IsComplex(Term))
    return Term;

  Top    = term_TopSymbol(Term);
  Update = FALSE;

  /* Term = and(...) */
  if (symbol_Equal(Top,fol_And())) {
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
      Subterm = eml_RemoveTrivialAtomsAndOps(list_Car(Scan));
      Subtop = term_TopSymbol(Subterm);
      if (symbol_Equal(Subtop,fol_True()))
        Update = TRUE;
      else if (symbol_Equal(Subtop,fol_False())) {
        /* and(..., false, ...) -> false */ 
        return eml_RplacWithDesignatedPropAtom(Term,fol_False());
      }
    }
    if (Update) {
      /* and(..., true, ..., true, ...) -> and(..., ..., ...) */ 
      term_RplacArgumentList(Term,list_DeleteElementIfFree(term_ArgumentList(Term),(BOOL (*)())fol_IsTrue,(void (*)())term_Delete));
      if (list_Empty(term_ArgumentList(Term))) {
        term_RplacTop(Term,fol_True());
        return Term;
      }
    }
    return eml_RemoveTrivialOperator(Term); /* and(phi) -> phi */
  }
  /* Term = or(...) */
  else if (symbol_Equal(Top,fol_Or())) {
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
      Subterm = eml_RemoveTrivialAtomsAndOps(list_Car(Scan));
      Subtop = term_TopSymbol(Subterm);
      if (symbol_Equal(Subtop,fol_False()))
        Update = TRUE;
      else if (symbol_Equal(Subtop,fol_True())) {
        /* or(..., true, ...) -> true */ 
        return eml_RplacWithDesignatedPropAtom(Term,fol_True());
      }
    }
    if (Update) {
      term_RplacArgumentList(Term,list_DeleteElementIfFree(term_ArgumentList(Term),(BOOL (*)())fol_IsFalse,(void (*)())term_Delete));
      if (list_Empty(term_ArgumentList(Term))) {
        term_RplacTop(Term,fol_False());
        return Term;
      }
    }
    return eml_RemoveTrivialOperator(Term); /* or(phi) -> phi */
  }
  /* Term = not(...) */
  else if (symbol_Equal(Top,fol_Not())) {
    Subterm = eml_RemoveTrivialAtomsAndOps(term_FirstArgument(Term));
    Subtop = term_TopSymbol(Subterm);
    if (eml_IsDesignatedPropSymbol(Subtop)) {
      /* not(false) -> true,  not(true) -> false,  not(div) -> id,  not(id) -> div */
      return eml_RplacWithDesignatedPropAtom(Term,eml_GetDualSymbol(Subtop));
    }
  }
  /* Term = forall(...)  or  Term = exists(...) */
  else if (fol_IsQuantifier(Top)) {
    Subterm = eml_RemoveTrivialAtomsAndOps(term_SecondArgument(Term));
    Subtop = term_TopSymbol(Subterm);
    if (symbol_Equal(Subtop,fol_True())) {
      /* forall ... true -> true,  exists ... true -> true */
      return eml_RplacWithDesignatedPropAtom(Term,fol_True());
    }
    else if (symbol_Equal(Subtop,fol_False())) {
      /* forall ... false -> false,  exists ... false -> false */
      return eml_RplacWithDesignatedPropAtom(Term,fol_False());
    }
  }
  /* Term = dia(...) or Term = box(...) */
  else if (eml_IsModalOpSymbol(Top)) {
    RelSubterm = eml_RemoveTrivialAtomsAndOps(term_FirstArgument(Term));
    RelSubtop = term_TopSymbol(RelSubterm);
    Subterm    = eml_RemoveTrivialAtomsAndOps(term_SecondArgument(Term));
    Subtop    = term_TopSymbol(Subterm);
    if (symbol_Equal(Top,eml_Dia()) && 
         (symbol_Equal(Subtop,fol_False()) || symbol_Equal(RelSubtop,fol_False()))) {
      /* dia(alpha,false) -> false,  dia(false,phi) -> false */
      return eml_RplacWithDesignatedPropAtom(Term,fol_False());
    }
    else if (symbol_Equal(Top,eml_Box()) && 
       (symbol_Equal(Subtop,fol_True()) || symbol_Equal(RelSubtop,fol_False()))) {
      /* box(alpha,true) -> true,  box(true,phi) -> true */
      return eml_RplacWithDesignatedPropAtom(Term,fol_True());
    }
    else if (symbol_Equal(RelSubtop, eml_Id())) {
      /* dia(id,phi) -> phi,  box(id,phi) -> phi */
      term_Delete(RelSubterm);
      list_Delete(term_ArgumentList(Term));
      Term = eml_RplacWithOpAndArgs(Term, Subtop, term_ArgumentList(Subterm));
      term_Free(Subterm);
      return Term;
    }
  }
  /* Term = domain(...) or Term = range(...) */
  else if (symbol_Equal(Top,eml_Domain()) || symbol_Equal(Top,eml_Range())) {
    RelSubterm = eml_RemoveTrivialAtomsAndOps(term_FirstArgument(Term));
    RelSubtop = term_TopSymbol(RelSubterm);
    if (symbol_Equal(RelSubtop,fol_False())) {
      /* domain(false) -> false,  range(false) -> false */
      return eml_RplacWithDesignatedPropAtom(Term,fol_False());
    }
    else if (symbol_Equal(RelSubtop, eml_Id())) {
      /* domain(id) -> true,  range(id) -> true */
      return eml_RplacWithDesignatedPropAtom(Term,fol_True());
    }
  }
  /* Term = implies(...) */
  else if (symbol_Equal(Top,fol_Implies())) {
    Subterm = eml_RemoveTrivialAtomsAndOps(term_FirstArgument(Term));
    Subtop = term_TopSymbol(Subterm);
    if (symbol_Equal(Subtop,fol_False())) {
      /* implies(false,phi) -> true */
      return eml_RplacWithDesignatedPropAtom(Term,fol_True());
    }
    else if (symbol_Equal(Subtop,fol_True())) {
      /* implies(true,phi) -> phi */
      term_Delete(Subterm);
      Subterm = term_SecondArgument(Term);
      list_Delete(term_ArgumentList(Term));
      Term = eml_RplacWithOpAndArgs(Term,term_TopSymbol(Subterm),term_ArgumentList(Subterm));
      term_Free(Subterm);
      return eml_RemoveTrivialAtomsAndOps(Term);
    }
    Subterm = eml_RemoveTrivialAtomsAndOps(term_SecondArgument(Term));
    Subtop = term_TopSymbol(Subterm);
    if (symbol_Equal(Subtop,fol_True())) {
      /* implies(phi,true) -> true */
      return eml_RplacWithDesignatedPropAtom(Term,fol_True());
    }
    else if (symbol_Equal(Subtop,fol_False()))  {
      /* implies(phi,false) -> not(phi) */
      Term = eml_RplacWithOpAndArgs(Term, fol_Not(),
		      list_DeleteElementIfFree(term_ArgumentList(Term),
			  (BOOL (*)())fol_IsFalse, (void (*)())term_Delete));
      return eml_RemoveTrivialAtomsAndOps(Term);
    }
  }
  /* Term = implied(...) */
  else if (symbol_Equal(Top,fol_Implied())) {
    Subterm = eml_RemoveTrivialAtomsAndOps(term_SecondArgument(Term));
    Subtop = term_TopSymbol(Subterm);
    if (symbol_Equal(Subtop,fol_False())) {
      /* implied(phi,false) -> true */
      return eml_RplacWithDesignatedPropAtom(Term,fol_True());
    }
    else if (symbol_Equal(Subtop,fol_True())) {
      /* implied(phi,true) -> phi */
      term_Delete(Subterm);
      Subterm = term_FirstArgument(Term);
      list_Delete(term_ArgumentList(Term));
      Term = eml_RplacWithOpAndArgs(Term,term_TopSymbol(Subterm),term_ArgumentList(Subterm));
      term_Free(Subterm);
      return eml_RemoveTrivialAtomsAndOps(Term);
    }
    Subterm = eml_RemoveTrivialAtomsAndOps(term_FirstArgument(Term));
    Subtop = term_TopSymbol(Subterm);
    if (symbol_Equal(Subtop,fol_True()))
      /* implied(true,phi) -> true */
      return eml_RplacWithDesignatedPropAtom(Term,fol_True());
    else if (symbol_Equal(Subtop,fol_False())) {
      /* implied(false,phi) -> not(phi) */
      Term = eml_RplacWithOpAndArgs(Term, fol_Not(),
		      list_DeleteElementIfFree(term_ArgumentList(Term),
			  (BOOL (*)())fol_IsFalse, (void (*)())term_Delete));
      return eml_RemoveTrivialAtomsAndOps(Term);
    }
  }
  /* Term = equiv(...) */
  else if (symbol_Equal(Top,fol_Equiv())) {
    Subterm = eml_RemoveTrivialAtomsAndOps(term_FirstArgument(Term));
    Subtop = term_TopSymbol(Subterm);
    if (symbol_Equal(Subtop,fol_False())) {
      /* equiv(false,phi) -> not(phi) */
      Term = eml_RplacWithOpAndArgs(Term, fol_Not(),
		      list_DeleteElementIfFree(term_ArgumentList(Term),
			  (BOOL (*)())fol_IsFalse, (void (*)())term_Delete));
      return eml_RemoveTrivialAtomsAndOps(Term);
    }
    else if (symbol_Equal(Subtop,fol_True())) {
      /* equiv(true,phi) -> phi */
      term_Delete(Subterm);
      Subterm = term_SecondArgument(Term);
      list_Delete(term_ArgumentList(Term));
      Term = eml_RplacWithOpAndArgs(Term, term_TopSymbol(Subterm),
		      term_ArgumentList(Subterm));
      term_Free(Subterm);
      return eml_RemoveTrivialAtomsAndOps(Term);
    }
    Subterm = eml_RemoveTrivialAtomsAndOps(term_SecondArgument(Term));
    Subtop = term_TopSymbol(Subterm);
    if (symbol_Equal(Subtop,fol_False())) {
      /* equiv(phi,false) -> not(phi) */
      Term = eml_RplacWithOpAndArgs(Term, fol_Not(),
		list_DeleteElementIfFree(term_ArgumentList(Term),
		    (BOOL (*)())fol_IsFalse, (void (*)())term_Delete));
      return eml_RemoveTrivialAtomsAndOps(Term);
    }
    else if (symbol_Equal(Subtop,fol_True())) {
      /* equiv(phi,true) -> phi */
      term_Delete(Subterm);
      Subterm = term_FirstArgument(Term);
      list_Delete(term_ArgumentList(Term));
      Term = eml_RplacWithOpAndArgs(Term, term_TopSymbol(Subterm),
		term_ArgumentList(Subterm));
      term_Free(Subterm);
    }
  }
  /* Term = comp(...) */
  else if (symbol_Equal(Top,eml_Comp())) {
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
      Subterm = eml_RemoveTrivialAtomsAndOps(list_Car(Scan));
      Subtop = term_TopSymbol(Subterm);
      if (symbol_Equal(Subtop,eml_Id()))
        Update = TRUE;
      else if (symbol_Equal(Subtop,fol_False())) {
	/* comp(..., false, ...) -> false */
        return eml_RplacWithDesignatedPropAtom(Term,fol_False());
      }
    }
    if (Update) {
      /* comp(..., id, ..., id, ...) -> comp(..., ..., ...) */
      term_RplacArgumentList(Term,
	      list_DeleteElementIfFree(term_ArgumentList(Term),
		  (BOOL (*)())eml_IsId, (void (*)())term_Delete));
      if (list_Empty(term_ArgumentList(Term))) {
        term_RplacTop(Term,eml_Id());
        return Term;
      }
    }
    return eml_RemoveTrivialOperator(Term); /* comp(alpha) -> alpha */
  }
  /* Term = sum(...) */
  else if (symbol_Equal(Top,eml_Sum())) {
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
      Subterm = eml_RemoveTrivialAtomsAndOps(list_Car(Scan));
      Subtop = term_TopSymbol(Subterm);
      if (symbol_Equal(Subtop,eml_Div()))
        Update = TRUE;
      else if (symbol_Equal(Subtop,fol_True())) {
	/* sum(..., true, ...) -> true */
        return eml_RplacWithDesignatedPropAtom(Term,fol_True());
      }
    }
    if (Update) {
      /* sum(..., div, ..., div, ...) -> sum(..., ..., ...) */
      term_RplacArgumentList(Term,
	      list_DeleteElementIfFree(term_ArgumentList(Term),
		  (BOOL (*)())eml_IsDiv, (void (*)())term_Delete));
      if (list_Empty(term_ArgumentList(Term))) {
        term_RplacTop(Term,eml_Div());
        return Term;
      }
    }
    return eml_RemoveTrivialOperator(Term); /* sum(alpha) -> alpha */
  } 
  /* Term = test(...) */
  else if (symbol_Equal(Top,eml_Test())) {
    Subterm = eml_RemoveTrivialAtomsAndOps(term_FirstArgument(Term));
    Subtop = term_TopSymbol(Subterm);
    if (symbol_Equal(Subtop,fol_False())) {
      /* test(false) -> false */
      return eml_RplacWithDesignatedPropAtom(Term,fol_False());
    }
    else if (symbol_Equal(Subtop, fol_True())) {
      /* test(true) -> id  */
      return eml_RplacWithDesignatedPropAtom(Term,eml_Id());
    }
  }
  /* Term = conv(...) */
  else if (symbol_Equal(Top,eml_Conv())) {
    RelSubterm = eml_RemoveTrivialAtomsAndOps(term_FirstArgument(Term));
    RelSubtop = term_TopSymbol(RelSubterm);
    if (symbol_Equal(RelSubtop,fol_True()) ||
		symbol_Equal(RelSubtop,fol_False()) ||
		symbol_Equal(RelSubtop,eml_Id()) ||
		symbol_Equal(RelSubtop,eml_Div())) {
      /* conv(false) -> false,  conv(true) -> true,  conv(id) -> id,  conv(div) -> div */
      return eml_RplacWithDesignatedPropAtom(Term,RelSubtop);
    }
    else if (symbol_Equal(RelSubtop,eml_Test())) {
      /* conv(test(...)) -> test(...)  */
      list_Delete(term_ArgumentList(Term));
      Term = eml_RplacWithOpAndArgs(Term, RelSubtop, term_ArgumentList(RelSubterm));
      term_Free(RelSubterm);
      return Term;
    }
  }
  /* Term = domrestr(...) or Term = ranrestr(...) */
  else if (symbol_Equal(Top,eml_DomRestr()) || symbol_Equal(Top,eml_RanRestr())) {
    RelSubterm = eml_RemoveTrivialAtomsAndOps(term_FirstArgument(Term));
    RelSubtop  = term_TopSymbol(RelSubterm);
    Subterm    = eml_RemoveTrivialAtomsAndOps(term_SecondArgument(Term));
    Subtop     = term_TopSymbol(Subterm);
    if (symbol_Equal(RelSubtop,fol_False()) || symbol_Equal(Subtop,fol_False())) {
      /* domrestr(false,...), domrestr(...,false) -> false,  
       * ranrestr(false,...), ranrestr(...,false) -> false */
      return eml_RplacWithDesignatedPropAtom(Term,fol_False());
    }
    else if (symbol_Equal(Subtop, fol_True())) {
      /* domrestr(alpha,true) -> alpha,  ranrestr(alpha,true) -> alpha */
      term_Delete(Subterm);
      list_Delete(term_ArgumentList(Term));
      Term = eml_RplacWithOpAndArgs(Term, RelSubtop, term_ArgumentList(RelSubterm));
      term_Free(RelSubterm);
      return Term;
    }
  }

  return Term;
}

static TERM eml_CreateModalTerm(SYMBOL ModOp, LIST RelTermList, TERM PropTerm)
/**************************************************************
  INPUT:   A symbol (either box or dia), a list of relational terms, 
           a list with one propositional term.
  RETURNS: A nested box(..., box(..., box(..., ....)))
           or dia(..., dia(..., dia(..., ....))) term
***************************************************************/
{
  if (list_Empty(RelTermList)) {
    return PropTerm;
  }
  else {
    return term_Create(ModOp,
             list_Cons(list_Car(RelTermList),
	       list_List(eml_CreateModalTerm(ModOp, list_Cdr(RelTermList), PropTerm))));
  }
}

static TERM eml_EliminateComp(TERM Term)
/**************************************************************
  INPUT:   A Term.
  RETURNS: eliminates comp if possible by replacing, e.g. 
           box(comp(..., ...., ....), ....) with 
	   box(..., box(..., box(..., ....))).
  CAUTION: The Term is destructively changed.
***************************************************************/
{
  SYMBOL Top;
  TERM   RelSubterm;

  Top    = term_TopSymbol(Term);

  /* box(comp(..., ...., ....), ....) -> box(..., box(..., box(..., ....)))
     dia(comp(..., ...., ....), ....) -> dia(..., dia(..., dia(..., ....))) */ 
  if (eml_IsModalOpSymbol(Top)) {
    RelSubterm = term_FirstArgument(Term);
    if (symbol_Equal(term_TopSymbol(RelSubterm),eml_Comp())) {
      LIST ArgsList;
      ArgsList = list_Cons(list_Car(term_ArgumentList(RelSubterm)),
	         list_List(eml_CreateModalTerm(Top, 
	           list_Cdr(term_ArgumentList(RelSubterm)), 
		     eml_EliminateComp(term_SecondArgument(Term)))));
      list_Delete(term_ArgumentList(RelSubterm));
      term_Free(RelSubterm);
      list_Delete(term_ArgumentList(Term));
      Term = eml_RplacWithOpAndArgs(Term, Top, ArgsList);
    }
  } else if (!symbol_IsPredicate(Top)) {
    LIST   Scan;
    for (Scan=term_ArgumentList(Term);!list_Empty(Scan);Scan=list_Cdr(Scan))
      eml_EliminateComp(list_Car(Scan));
  }

    return Term;
}

static TERM eml_MakeOneAndOrCompSum(TERM Term)
/**************************************************************
  INPUT:   A Term.
  RETURNS: Takes all arguments of an and together.
  CAUTION: The Term is destructively changed.
***************************************************************/
{
  SYMBOL Top;
  LIST   Scan;
  TERM   Subterm;

  Top    = term_TopSymbol(Term);

  /* and(..., and( ..., ...)) -> and(..., ..., ...) */ 
  if (symbol_Equal(Top,fol_And())) {
    Scan = term_ArgumentList(Term);
    while (!list_Empty(Scan)) {
      Subterm = (TERM)list_Car(Scan);
      eml_MakeOneAndOrCompSum(Subterm);
      if (symbol_Equal(term_TopSymbol(Subterm),fol_And())) {
	Scan = list_Cdr(Scan);
	term_RplacArgumentList(Term,
	  list_Nconc(term_ArgumentList(Subterm),list_PointerDeleteElement(term_ArgumentList(Term),Subterm)));
	term_Free(Subterm);
      }
      else
	Scan = list_Cdr(Scan);
    }

  /* or(..., or( ..., ...)) -> or(..., ..., ...) */ 
  } else if (symbol_Equal(Top,fol_Or())) {
    Scan = term_ArgumentList(Term);
    while (!list_Empty(Scan)) {
      Subterm = (TERM)list_Car(Scan);
      eml_MakeOneAndOrCompSum(Subterm);
      if (symbol_Equal(term_TopSymbol(Subterm),fol_Or())) {
	Scan = list_Cdr(Scan);
	term_RplacArgumentList(Term,
	  list_Nconc(term_ArgumentList(Subterm),list_PointerDeleteElement(term_ArgumentList(Term),Subterm)));
	term_Free(Subterm);
      }
      else
	Scan = list_Cdr(Scan);
    }

  /* comp(..., comp( ..., ...)) -> comp(..., ..., ...) */ 
  } else if (symbol_Equal(Top,eml_Comp())) {
    Scan = term_ArgumentList(Term);
    while (!list_Empty(Scan)) {
      Subterm = (TERM)list_Car(Scan);
      eml_MakeOneAndOrCompSum(Subterm);
      if (symbol_Equal(term_TopSymbol(Subterm),eml_Comp())) {
	Scan = list_Cdr(Scan);
	term_RplacArgumentList(Term,
	  list_Nconc(term_ArgumentList(Subterm),list_PointerDeleteElement(term_ArgumentList(Term),Subterm)));
	term_Free(Subterm);
      }
      else
	Scan = list_Cdr(Scan);
    }

  /* sum(..., sum( ..., ...)) -> sum(..., ..., ...) */ 
  } else if (symbol_Equal(Top,eml_Sum())) {
    Scan = term_ArgumentList(Term);
    while (!list_Empty(Scan)) {
      Subterm = (TERM)list_Car(Scan);
      eml_MakeOneAndOrCompSum(Subterm);
      if (symbol_Equal(term_TopSymbol(Subterm),eml_Sum())) {
	Scan = list_Cdr(Scan);
	term_RplacArgumentList(Term,
	  list_Nconc(term_ArgumentList(Subterm),list_PointerDeleteElement(term_ArgumentList(Term),Subterm)));
	term_Free(Subterm);
      }
      else
	Scan = list_Cdr(Scan);
    }

  } else if (!symbol_IsPredicate(Top))
    for (Scan=term_ArgumentList(Term);!list_Empty(Scan);Scan=list_Cdr(Scan))
      eml_MakeOneAndOrCompSum(list_Car(Scan));

  return Term;
}

TERM  eml_SimplifyQuantors(TERM Term)
/**************************************************************
  INPUT:   A formula.
  RETURNS: The formula after
	   removal of bindings of variables that don't occur in the
	   respective subformula and possible mergings of quantors
  CAUTION: The term is destrucively changed.
  NOTE:    This procedure conincides with cnf_SimplifyQuantors()
***************************************************************/
{
   SYMBOL Top;
   LIST   Scan;

  Top = term_TopSymbol(Term);

  if (symbol_IsPredicate(Top) || symbol_Equal(Top,fol_Varlist()))
    return Term;

  if (fol_IsQuantifier(Top)) {
    LIST Vars;
    TERM Var,Subterm,Aux;
    Vars    = list_Nil();
    Subterm = term_SecondArgument(Term);

    while (symbol_Equal(term_TopSymbol(Subterm),Top)) {
      term_RplacArgumentList(term_FirstArgument(Term),
			     list_Nconc(fol_QuantifierVariables(Term),fol_QuantifierVariables(Subterm)));
      term_Free(term_FirstArgument(Subterm));
      Aux = term_SecondArgument(Subterm);
      list_Delete(term_ArgumentList(Subterm));
      term_Free(Subterm);
      list_Rplaca(list_Cdr(term_ArgumentList(Term)),Aux);
      Subterm = Aux;
    }
    
    for(Scan=fol_QuantifierVariables(Term);!list_Empty(Scan);Scan=list_Cdr(Scan)) {
      Var = (TERM)list_Car(Scan);
      if (!fol_VarOccursFreely(Var,Subterm))
	Vars = list_Cons(Var,Vars);
    }
    if (!list_Empty(Vars)) {
      Subterm = term_FirstArgument(Term);
      term_RplacArgumentList(Subterm,list_NPointerDifference(term_ArgumentList(Subterm),Vars));
      list_DeleteWithElement(Vars, (void (*)())term_Delete);
      if (list_Empty(term_ArgumentList(Subterm))) {
	Subterm = term_SecondArgument(Term);
	term_Delete(term_FirstArgument(Term));
	list_Delete(term_ArgumentList(Term));
	term_Free(Term);
	return eml_SimplifyQuantors(Subterm);
      }
    }
  }
  
  for (Scan=term_ArgumentList(Term);!list_Empty(Scan);Scan=list_Cdr(Scan))
    list_Rplaca(Scan,eml_SimplifyQuantors(list_Car(Scan)));
  
  return Term; 
}

TERM  eml_ObviousSimplifications(TERM Term, FLAGSTORE Flags)
/**************************************************************
  INPUT:   An eml formula.
  RETURNS: The formula after performing the following simplifications:
             - eliminate true, false, id, etc 
             - remove "or" and "and" with only one argument
             - merge quantors
  CAUTION: The term is destructively changed.
  NOTE:    This does not obliviate simplification of the first-order
	   formula.  E.g. dia(alpha,true) cannot be reduced in the modal
	   context.
	   Nested expression of n-ary associative operations (and, comp,
	   ...) are reduced later.
***************************************************************/
{
  Term = eml_RemoveTrivialAtomsAndOps(Term);
  Term = eml_SimplifyQuantors(Term);   /* strictly only needed for non-propositional formulae */

  /* Attempt to eliminate composition by applying */
  if (flag_GetFlagValue(Flags, flag_EMLELIMCOMP)) {
    Term = eml_MakeOneAndOrCompSum(Term);
    Term = eml_EliminateComp(Term);
  }

  return Term;
}

BOOL eml_IsPropositional(TERM Term)
/**************************************************************
  INPUT:   A formula.
  RETURNS: True, if formula does not contain an n-ary predicate symbol
           or a first order quantifier.
***************************************************************/
{
  LIST Scan;
  BOOL result;

  result = TRUE;
  if (term_IsComplex(Term)) {
    if (symbol_IsPredicate(term_TopSymbol(Term)) || 
	fol_IsQuantifier(term_TopSymbol(Term)))
      return FALSE;
    else 
      for(Scan=term_ArgumentList(Term); result && !list_Empty(Scan); Scan=list_Cdr(Scan))
        result = eml_IsPropositional(list_Car(Scan));
  }

  return result;
}

static TERM eml_RplacPropByFoAtom(TERM Atom, eml_SYMBOLTYPE SymbolType,
		int Arity, LIST Args, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   A propositional atom, a symbol type, a natural number, and a
           list of variables.
  RETURNS: A first-order atom with the specified arity formed with the
	   symbol of the specified type and the specified arguments.
	   The predicate name is built from the propositional name.
  EFFECT:  If the predicate symbol does not exist in the signature it is
           created and inherits its precedence setting.
  CAUTION: The atom is destructively changed.
***************************************************************/
{
  SYMBOL propSymbol, foSymbol;

#ifdef DEBUG
  if (list_Empty(term_ArgumentList(Atom)) {
	misc_StartErrorReport();
	misc_ErrorReport("\n In  eml_RplacPropByFoAtom: Propositional atom must not have argument list.");
	misc_FinishErrorReport();
      } 
#endif

  propSymbol = term_TopSymbol(Atom);

  if (symbol_Equal(propSymbol, fol_True()) || 
      symbol_Equal(propSymbol, fol_False())) {
    list_DeleteWithElement(Args, (void (*)())term_Delete);
    return Atom;  /* Attempt to simplify ?? */
  }

  if (symbol_Equal(propSymbol, eml_Id())) {  /* Arguments should be nil, propositional */
    symbol_SetOrdering(Precedence, fol_Equality(), symbol_Ordering(Precedence, eml_Id()));
    return eml_RplacWithOpAndArgs(Atom, fol_Equality(), Args);
  }
  else if (symbol_Equal(propSymbol, eml_Div())) {
    return eml_RplacWithOpAndArgs(Atom, fol_Not(),
		    list_List(term_Create(fol_Equality(), Args)));
  }

  foSymbol   = eml_GetFoSymbolAssocWithPropSymbol(propSymbol, Arity, SymbolType);

#ifdef DEBUG
  if (!eml_NaryType(SymbolType) && (foSymbol != symbol__NULL) &&
	    (symbol_Arity(foSymbol) != Arity)) {
    fprintf(stderr, "Symbol %s declared with arity %d, but arity %d required\n",
    symbol_Name(foSymbol), symbol_Arity(foSymbol),Arity);
    misc_Error();
    return NULL;
  } 
#endif

  if (foSymbol == symbol__NULL) {
    foSymbol = eml_CreateFoSymbol(propSymbol, SymbolType, Arity, symbol_STATLEX, Precedence);
    /* Precedence among the first-order symbols is inherited from that among
     * the propositional symbols */
    symbol_SetOrdering(Precedence, foSymbol,symbol_Ordering(Precedence, propSymbol));
  }

  return eml_RplacWithOpAndArgs(Atom, foSymbol, Args);
}

SYMBOL eml_CreateNarySymbol(SYMBOL PropSymbol, eml_SYMBOLTYPE SymbolType,
		char* NameSuffix, int Arity, int Status, PRECEDENCE Precedence)
/*******************************************************
  INPUT:   A symbol (which MUST be a propositonal symbol/nullary
	   predicate symbol), a symbol type (of the fo symbol to be
	   created), the predefined name suffix, the arity of the new
	   symbol, the status of the new symbol.
  RETURNS: A first-order symbol corresponding to PropSymbol (special for
	   the functial translation in terms of n-ary predicates with the sorts
	   encoded in the predicate names).
  REMARK:  Similar to dfg_SymbolDecl.  Prototypical.
********************************************************/
{
  char   newName[symbol__SYMBOLMAXLEN];
  SYMBOL symbol;
  
  sprintf(newName,"%s%s_%d%s", eml_PREDNAMEPREFIX[SymbolType],
		  symbol_Name(PropSymbol), Arity, NameSuffix);

  /* Check if this symbol was declared earlier */
  symbol = symbol_Lookup(newName);
  if (symbol != 0) {
    /* Symbol was declared before 
     * Check if the old and new symbol type are equal */
    /* Eventually we would want more checking to be done here, i.e.
     * we need new designated symbol types */
    if ( !symbol_IsPredicate(symbol)) {
      fprintf(stderr, "In eml_CreateNarySymbol: Symbol %s was already declared as ",
	      newName);
      switch (symbol_Type(symbol)) {
      case symbol_CONSTANT:
      case symbol_FUNCTION:
	fputs("function\n", stderr); break;
      case symbol_JUNCTOR:
	fputs("junctor", stderr); break;
      default:
	fputs("unknown non-predicate type\n", stderr);
      }
      misc_Error();
    }
    /* Now check the old and new arity if specified */
    if (Arity != -2 && Arity != symbol_Arity(symbol)) {
      fprintf(stderr, "In eml_CreateNarySymbol: Symbol %s was already declared with arity %d\n",
	      newName, symbol_Arity(symbol));
      misc_Error();
    }
  } else
    /* Symbol was not declared before */
    symbol = symbol_CreatePredicate(newName, Arity, Status, Precedence);

  return  symbol;
}

static TERM eml_RplacPropByNaryAtom(TERM Atom, eml_SYMBOLTYPE
		SymbolType, char* NameSuffix, int Arity, LIST Args, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   A propositional atom, a symbol type, a string, a natural
           number, and a list of variables.
  RETURNS: A first-order atom with the specified arity formed with the
	   symbol of the specified type and the specified arguments.
	   The predicate name is built from the propositional name and
	   (different from eml_RplacPropByFoAtom) the given name suffix.
  EFFECT:  A new predicate symbol is created and inherits its precedence
           setting.
  CAUTION: The atom is destructively changed.
***************************************************************/
{
  SYMBOL propSymbol, foSymbol;

  propSymbol = term_TopSymbol(Atom);

  if (symbol_Equal(propSymbol,fol_True()) || symbol_Equal(propSymbol,fol_False())) {
    list_DeleteWithElement(Args, (void (*)())term_Delete);
    return Atom;
  }

  if (flag_GetFlagValue(Flags, flag_EMLFFSORTS))  /* with explicit sorts */
    foSymbol = eml_CreateNarySymbol(propSymbol, SymbolType,
		    symbol_Name(propSymbol), Arity, symbol_STATLEX, Precedence);
  else                    /* sort info encoded in predicate names */
    foSymbol = eml_CreateNarySymbol(propSymbol, SymbolType, NameSuffix, Arity,
		    symbol_STATLEX, Precedence);
  symbol_SetOrdering(Precedence, foSymbol,symbol_Ordering(Precedence, propSymbol));  /* ?? */

  return eml_RplacWithOpAndArgs(Atom, foSymbol, Args);
}

static TERM eml_EmbedInRelCalculusProp(TERM Term)
/**************************************************************
  INPUT:   An Eml (propositional) formula.
  RETURNS: Its translation into a relational formula as a right
           injective formula.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);

  /* Term = p */
  if (symbol_IsPredicate(Top)) {
    list_Delete(term_ArgumentList(Term)); /* shouldn't be needed */
    return eml_RplacWithOpAndArgs(Term, eml_Comp(),
	     list_Cons(term_Copy(Term), 
		list_List(term_Create(fol_True(), list_Nil()))));
    /* comp(p,true) */
  }
  /* Term = not(phi), or(...), and(...), comp(...), sum(...), 
   *        test(phi), domrestr(...), ranrestr(...) */
  else  if (eml_IsRelationalJunctor(Top)) { /* Seems strange, but makes sense */
    LIST Scan;
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan))
      eml_EmbedInRelCalculusProp(list_Car(Scan));
    return Term;
  }
  /* Term = dia(alpha,phi) */
  else  if (symbol_Equal(Top, eml_Dia())) {
    LIST args;          
    args = list_Cons(eml_EmbedInRelCalculusRel(term_FirstArgument(Term)), 
	     list_List(eml_EmbedInRelCalculusProp(term_SecondArgument(Term))));
    list_Delete(term_ArgumentList(Term)); 
    return eml_RplacWithOpAndArgs(Term, eml_Comp(), args);
    /* comp(alpha,tr(phi)) */
  }
  /* Term = box(alpha,phi) */
  else  if (symbol_Equal(Top, eml_Box())) {
    TERM helpTerm;          
    helpTerm = term_Create(eml_Comp(), 
		 list_Cons(eml_EmbedInRelCalculusRel(term_FirstArgument(Term)),
		   list_List(term_Create(fol_Not(), 
		     list_List(eml_EmbedInRelCalculusProp(term_SecondArgument(Term)))))));
    list_Delete(term_ArgumentList(Term)); 
    return eml_RplacWithOpAndArgs(Term, fol_Not(), list_List(helpTerm));
    /* not(comp(alpha,not(tr(phi)))) */
  }
  /* Term = domain(alpha)  or  Term = range(alpha) */
  else if (symbol_Equal(Top,eml_Domain()) || symbol_Equal(Top,eml_Range())) {
    LIST args;          
    term_RplacTop(Term, eml_Comp());
    if (symbol_Equal(Top,eml_Domain())) 
      args = list_Cons(eml_EmbedInRelCalculusRel(term_FirstArgument(Term)), 
		   list_List(term_Create(fol_True(), list_Nil())));
    else
      args = list_Cons(term_Create(fol_True(), list_Nil()), 
		   list_List(eml_EmbedInRelCalculusRel(term_FirstArgument(Term))));
    list_Delete(term_ArgumentList(Term)); 
    term_RplacArgumentList(Term,args);

    return Term;
    /* comp(alpha,true)  or  comp(true,alpha) */
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_EmbedInRelCalculusProp()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }

}

static TERM eml_EmbedInRelCalculusRel(TERM Term)
/**************************************************************
  INPUT:   An Eml (propositional) formula.
  RETURNS: Its translation into a relational formula as a right
           injective formula.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;
  LIST args;          

  Top    = term_TopSymbol(Term);

  /* Term = p */
  if (symbol_IsPredicate(Top)) {
    return Term;
  }
  /* Term = test(phi) */
  else  if (symbol_Equal(Top, eml_Test())) {
    args = list_Cons(eml_EmbedInRelCalculusProp(term_FirstArgument(Term)),
	       list_List(term_Create(eml_Id(), list_Nil())));
    list_Delete(term_ArgumentList(Term));
    return eml_RplacWithOpAndArgs(Term, fol_And(), args);
    /* tr(phi) /\ id */
  }
  /* Term = domrestr(alpha,phi) */
  else  if (symbol_Equal(Top, eml_DomRestr())) {
    args = list_Cons(term_FirstArgument(Term),
	       list_List(eml_EmbedInRelCalculusProp(term_SecondArgument(Term))));
    list_Delete(term_ArgumentList(Term)); 
    return eml_RplacWithOpAndArgs(Term, fol_And(), args);
    /* alpha /\ tr(phi) */
  }
  /* Term = ranrestr(alpha,phi) */
  else  if (symbol_Equal(Top, eml_RanRestr())) {
    args = list_Cons(term_FirstArgument(Term),
	       list_List(term_Create(eml_Conv(),
		 list_List(eml_EmbedInRelCalculusProp(term_SecondArgument(Term))))));
    list_Delete(term_ArgumentList(Term)); 
    return eml_RplacWithOpAndArgs(Term, fol_And(), args);
    /* alpha /\ conv(tr(phi)) */
  }
  /* Term = not(phi), or(...), and(...), comp(...), sum(...) */
  /* It is important that this test is done last */
  else  if (eml_IsRelationalJunctor(Top)) {
    LIST Scan;
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan))
      eml_EmbedInRelCalculusRel(list_Car(Scan));
    return Term;
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_EmbedInRelCalculusRel()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }

}


static TERM eml_RelationalTranslationProp(TERM Term, SYMBOL Var, 
	FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (propositional) formula and a variable (the free variable).
  RETURNS: Its standard (relational) translation.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);

  /* Term = p */
  if (symbol_IsPredicate(Top)) {
    return eml_RplacPropByFoAtom(Term, eml_PROP, 1, list_List(term_Create(Var,list_Nil())), Flags, Precedence);
  }
  /* Term = not(phi), Term = or(...) or Term = and(...) */
  else  if (eml_IsPropJunctor(Top)) {
    LIST Scan;
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan))
      eml_RelationalTranslationProp(list_Car(Scan),Var, Flags, Precedence);
    return Term;
  }
  /* Term = dia(alpha,phi)  or  Term = box(alpha,phi) */
  else if (eml_IsModalOpSymbol(Top)) {
    SYMBOL newVar;
    TERM   helpTerm;          
    newVar   = symbol_CreateStandardVariable();
    helpTerm = term_Create(eml_FoJunctorAssocWithPropSymbol(Top), 
        list_Cons(eml_RelationalTranslationRel(term_FirstArgument(Term),Var,newVar, Flags, Precedence),
        list_List(eml_RelationalTranslationProp(term_SecondArgument(Term),newVar, Flags, Precedence))));
    list_Delete(term_ArgumentList(Term));
    return eml_RplacWithQuantifier(Term, eml_FoQuantAssocWithPropSymbol(Top), list_List(term_Create(newVar,list_Nil())),
		    list_List(helpTerm));
    /* exists y tr(alpha)(x,y) /\ tr(phi)(y)  or
     * forall y tr(alpha)(x,y) -> tr(phi)(y)  */
  }
  /* Term = domain(alpha)  or  Term = range(alpha) */
  else if (symbol_Equal(Top,eml_Domain()) || symbol_Equal(Top,eml_Range())) {
    SYMBOL newVar;
    TERM   helpTerm;          
    newVar   = symbol_CreateStandardVariable();
    if (symbol_Equal(Top,eml_Domain())) 
      helpTerm = eml_RelationalTranslationRel(term_FirstArgument(Term),Var,newVar, Flags, Precedence);
    else
      helpTerm = eml_RelationalTranslationRel(term_FirstArgument(Term),newVar,Var, Flags, Precedence);

    list_Delete(term_ArgumentList(Term));
    return eml_RplacWithQuantifier(Term, eml_FoQuantAssocWithPropSymbol(Top), list_List(term_Create(newVar,list_Nil())),
		    list_List(helpTerm));
    /* exists y tr(alpha)(x,y)  or  exists y tr(alpha)(y,x) */
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_RelationalTranslationProp()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }

}

static TERM eml_RelationalTranslationRel(TERM Term, SYMBOL VarX, SYMBOL VarY, 
	FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (relational) formula, two variables (the free
	   variables), a string encoding of the sorts of the arguments
	   and the modal depth.
  RETURNS: Its standard (relational) translation.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);

  /* Term = r */
  if (symbol_IsPredicate(Top)) {
    return eml_RplacPropByFoAtom(Term, eml_REL, 2, list_Cons(term_Create(VarX,list_Nil()),list_List(term_Create(VarY,list_Nil()))), Flags, Precedence);
  }
  /* Term = not(alpha), Term = or(...) or Term = and(...) */
  else  if (eml_IsPropJunctor(Top)) {
    LIST Scan;
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan))
      eml_RelationalTranslationRel(list_Car(Scan),VarX,VarY, Flags, Precedence);
    return Term;
  }
  /* Term = conv(alpha) */
  else  if (symbol_Equal(Top,eml_Conv())) {
    TERM helpTerm;          
    helpTerm = eml_RelationalTranslationRel(term_FirstArgument(Term),VarY,VarX, Flags, Precedence);
    list_Delete(term_ArgumentList(Term));
    Term     = eml_RplacWithOpAndArgs(Term, term_TopSymbol(helpTerm),
		    term_ArgumentList(helpTerm));
    term_Free(helpTerm);
    return Term;
    /* tr(alpha)(y,x) */
  }
  /* Term = comp(...)  or  sum(...)*/
  else if (symbol_Equal(Top,eml_Comp()) || symbol_Equal(Top,eml_Sum())) {
    SYMBOL var, newVar;
    TERM   helpTerm;          
    LIST   Scan, varList;
    var = VarX;
    varList = list_Nil();
    for (Scan=term_ArgumentList(Term); !list_Empty(list_Cdr(Scan)); Scan=list_Cdr(Scan)) {
      newVar   = symbol_CreateStandardVariable();
      varList  = list_Nconc(varList, list_List(term_Create(newVar,list_Nil())));
      eml_RelationalTranslationRel(list_Car(Scan),var,newVar, Flags, Precedence);
      var = newVar;
    }
    eml_RelationalTranslationRel(list_Car(Scan),var,VarY, Flags, Precedence);

    helpTerm = term_Create(eml_FoJunctorAssocWithPropSymbol(Top), term_ArgumentList(Term)); /* Sharing including argument list */
    return eml_RplacWithQuantifier(Term,
		eml_FoQuantAssocWithPropSymbol(Top), varList, list_List(helpTerm));
      /* exists z1,z2 tr(alpha1)(x,z1) /\ tr(alpha2)(z1,z2) /\ tr(alpha3)(z2,y) ...  or
       * forall z1,z2 tr(alpha1)(x,z1) \/ tr(alpha2)(z1,z2) \/ tr(alpha3)(z2,y) ... */
  }
  /* Term = test(phi) */
  else if (symbol_Equal(Top,eml_Test())) {
    TERM helpTerm;          
    helpTerm = eml_RelationalTranslationProp(term_FirstArgument(Term),VarY, Flags, Precedence);
    list_Delete(term_ArgumentList(Term));
    return eml_RplacWithOpAndArgs(Term, fol_And(),
	list_Cons(term_Create(fol_Equality(), 
			      list_Cons(term_Create(VarX,list_Nil()), list_List(term_Create(VarY,list_Nil())))),
	list_List(helpTerm)));
    /* equal(x,y) /\ tr(phi)(y) */
  }
  /* Term = domrestr(alpha,phi)  or  ranrestr(alpha,phi) */
  else if (symbol_Equal(Top,eml_DomRestr()) || symbol_Equal(Top,eml_RanRestr())) {
    TERM helpTerm, helpTermRel;          
    helpTermRel = eml_RelationalTranslationRel(term_FirstArgument(Term),VarX,VarY, Flags, Precedence);
    if (symbol_Equal(Top,eml_DomRestr()))
      helpTerm    = eml_RelationalTranslationProp(term_SecondArgument(Term),VarX, Flags, Precedence);
    else
      helpTerm    = eml_RelationalTranslationProp(term_SecondArgument(Term),VarY, Flags, Precedence);
    list_Delete(term_ArgumentList(Term));
    return eml_RplacWithOpAndArgs(Term, fol_And(),
	     list_Cons(helpTermRel, list_List(helpTerm)));
    /* tr(alpha)(x,y) /\ tr(phi)(x)  or  tr(alpha)(x,y) /\ tr(phi)(y) */
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_RelationalTranslationRel()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }

}

static TERM eml_RelationalTranslation(TERM Term, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  kjs entry point
  INPUT:   An eml (propositional) formula.
  RETURNS: Its standard (relational) translation.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  TERM newVarX, helpTerm;

  symbol_ResetStandardVarCounter();

  newVarX = term_Create(symbol_CreateStandardVariable(), list_Nil());

  /* kjs */
  /* if (flag_GetFlagValue(Flags, flag_EMLAXIOM)) {     */
  /*	 Term = eml_Axiomatic(Term, Flags, Precedence); */
  /*	 return Term;                                   */
  /* } */           
  /* kjs */
  
  /* Embedding into the relational calculus */
  if (flag_GetFlagValue(Flags, flag_EML2REL)) {
    TERM newVarY;

    Term = eml_EmbedInRelCalculusProp(Term);
    if (flag_GetFlagValue(Flags, flag_EMLPTRANS)) {
      printf("\n [Rel] \t");fol_PrintDFG(Term);
    }

    newVarY  = term_Create(symbol_CreateStandardVariable(), list_Nil());
    helpTerm = eml_RelationalTranslationRel(Term,term_TopSymbol(newVarX),term_TopSymbol(newVarY), Flags, Precedence);

    if (flag_GetFlagValue(Flags, flag_EMLPTRANS))
      printf("\n [RelTr] \t");
    return term_Create(fol_All(), list_Cons(term_Create(fol_Varlist(),list_Cons(newVarX,list_List(newVarY))), list_List(helpTerm)));
    /* forall x y tr(Term,x,y) */
  } 
  /* Relational functional/path-based translation */
  else if (flag_GetFlagValue(Flags, flag_EMLFNARY)) {
    char nameSuffix[symbol__SYMBOLMAXLEN] = "";

    flag_SetFlagValue(Flags, flag_EMLFFSORTS, flag_EMLFFSORTSOFF);  
		/* Don't use explicit sorts!  Important for creation of
		 * new atoms in eml_RplacPropByNaryAtom() */

    helpTerm = eml_RelFunctTranslProp(Term, term_TopSymbol(newVarX), nameSuffix, Flags, Precedence);

    if (flag_GetFlagValue(Flags, flag_EMLPTRANS))
      printf("\n [RelFuncTr] \t");
    return term_Create(fol_All(), list_Cons(term_Create(fol_Varlist(),list_List(newVarX)), list_List(helpTerm)));
  }
  /* Standard relational translation */
  else {
    helpTerm = eml_RelationalTranslationProp(Term,term_TopSymbol(newVarX), Flags, Precedence);

    if (flag_GetFlagValue(Flags, flag_EMLPTRANS))
      printf("\n [RelTr] \t");
    return term_Create(fol_All(), list_Cons(term_Create(fol_Varlist(),list_List(newVarX)), list_List(helpTerm)));
    /* forall x tr(Term,x) */
  }
}

static TERM eml_FunctTranslItoNaryPredProp(TERM Term, LIST VarList,
		char* SortEncoding, int VarListLength, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (propositional) formula, a variable list, a string
           encoding of the sorts of the arguments and the length of the
           list of variables.
  RETURNS: Its functional translation ito n-ary predicates.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);
  
#ifdef DEBUG
  if (VarListLength != list_Length(VarList)) {
    fprintf(stderr, "Arity VarListLength conflict\n");
    misc_Error();
    return NULL;
  }
#endif

  /* Term = p */
  if (symbol_IsPredicate(Top)) {
    VarList = list_CopyWithElement(VarList,(POINTER (*)())term_Copy);
    return eml_RplacPropByNaryAtom(Term, eml_NARYPROP, SortEncoding,
		    VarListLength, VarList, Flags, Precedence);
  }
  /* Term = not(phi), Term = or(...) or Term = and(...) */
  else  if (eml_IsPropJunctor(Top)) {
    LIST Scan;
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan))
      eml_FunctTranslItoNaryPredProp(list_Car(Scan), VarList,
		      SortEncoding, VarListLength, Flags, Precedence);
    return Term;
  }
  /* Term = dia(r,phi)  or  Term = box(r,phi) */
  else if (eml_IsModalOpSymbol(Top)) {
    TERM relSubTerm, newVar, helpTerm, anotherHelpTerm;          
    LIST newVarList;
    char newSortEncoding[symbol__SYMBOLMAXLEN];

    relSubTerm   = term_FirstArgument(Term);
    newVar     = term_Create(symbol_CreateStandardVariable(), list_Nil());
    newVarList = list_Nconc(list_CopyWithElement(VarList,(POINTER (*)())term_Copy), list_List(newVar));
    sprintf(newSortEncoding,"%s%s", SortEncoding, symbol_Name(term_TopSymbol(relSubTerm)));
    if (flag_GetFlagValue(Flags, flag_EMLFUNCNDEQ)) {
      helpTerm = eml_BuildSortQuantifierFor(Term, Top, term_TopSymbol(relSubTerm),
		term_TopSymbol(newVar), flag_GetFlagValue(Flags, flag_EMLFFSORTS), 
		list_List(eml_FunctTranslItoNaryPredProp(term_SecondArgument(Term),
			newVarList, newSortEncoding, VarListLength+1, Flags, Precedence)),
		(POINTER (*)())eml_CreateQuantifier, Precedence);
      list_Delete(term_ArgumentList(Term));
      anotherHelpTerm = eml_RplacWithOpAndArgs(Term, eml_FoJunctorAssocWithPropSymbol(Top), 
		list_Cons(eml_FunctTranslItoNaryPredRel(relSubTerm,
			VarList, SortEncoding, VarListLength, Flags, Precedence), 
		list_List(helpTerm)));
      list_DeleteWithElement(newVarList,(void (*)())term_Delete);
      return anotherHelpTerm;
      /* nde_r(vl) /\ exists y_r tr(phi)(vl,y)  or
       * nde_r(vl) -> forall y_r tr(phi)(vl,y)  */
    }
    else {
      TERM relSubTermCopy = term_Copy(relSubTerm);  /* make a copy; important */
      helpTerm = term_Create(eml_FoJunctorAssocWithPropSymbol(Top),
		list_Cons(eml_FunctTranslItoNaryPredRel(relSubTerm,
		    VarList, SortEncoding, VarListLength, Flags, Precedence), 
		  list_List(eml_FunctTranslItoNaryPredProp(term_SecondArgument(Term),
		    newVarList, newSortEncoding, VarListLength+1, Flags, Precedence))));
      list_Delete(term_ArgumentList(Term));
      anotherHelpTerm = eml_BuildSortQuantifierFor(Term, Top, 
	          term_TopSymbol(relSubTermCopy), term_TopSymbol(newVar),
		  flag_GetFlagValue(Flags, flag_EMLFFSORTS),
		  list_List(helpTerm), (POINTER (*)())eml_RplacWithQuantifier, Precedence);
      list_DeleteWithElement(newVarList,(void (*)())term_Delete);
      term_Delete(relSubTermCopy);
      return anotherHelpTerm;
      /* exists y_r nde_r(vl) /\ tr(phi)(vl,y)  or
       * forall y_r nde_r(vl) -> tr(phi)(vl,y)  */
    }
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_FunctTranslItoNaryPredProp()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }

}

static TERM eml_FunctTranslItoNaryPredRel(TERM Term, LIST VarList,
		char* SortEncoding, int VarListLength, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An EML relational formula, a variable list, a string (encoding
           the sorts of the accessibility relations in the scope), and
	   the length of the variable list (corresponds to the modal
	   depth).
  RETURNS: Its functional translation ito n-ary predicates.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);

  /* Term = r */
  if (symbol_IsPredicate(Top)) {
    switch (flag_GetFlagValue(Flags, flag_EMLTHEORY)) {
      case flag_EMLTHEORYKD:
        return eml_RplacWithDesignatedPropAtom(Term, fol_True());
        break;
      case flag_EMLTHEORYK:
        VarList = list_CopyWithElement(VarList,(POINTER (*)())term_Copy);
        return eml_RplacPropByNaryAtom(Term, eml_NARYNDE,
  		        SortEncoding, VarListLength, VarList, Flags, Precedence);
        break;
      default:
        fprintf(stderr, "\nThe option EMLTheory = %d is not implemented in eml_FunctTranslItoNaryPredRel()\n",
             flag_GetFlagValue(Flags, flag_EMLTHEORY));
        misc_Error();
        return NULL;
        break;
    }
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_FunctTranslItoNaryPredRel()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }
}

static TERM eml_FunctTranslProp(TERM Term, TERM WorldPath, 
	FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (propositional) formula, a variable list and its
           length.
  RETURNS: Its functional translation.
  CAUTION: The term is destructively changed.
  NOTE:    WorldPath needs to be copied before it is "used"
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);

  /* Term = p */
  if (symbol_IsPredicate(Top)) {
    return eml_RplacPropByFoAtom(Term, eml_PROP, 1, list_List(term_Copy(WorldPath)), Flags, Precedence);
  }
  /* Term = not(phi), Term = or(...) or Term = and(...) */
  else  if (eml_IsPropJunctor(Top)) {
    LIST Scan;
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan))
      eml_FunctTranslProp(list_Car(Scan), WorldPath, Flags, Precedence);
    return Term;
  }
  /* Term = dia(alpha,phi)  or  Term = box(alpha,phi) */
  else if (eml_IsModalOpSymbol(Top)) {
    TERM newVar, newWorldPath, relSubTerm, helpTerm, anotherHelpTerm;          
    relSubTerm   = term_FirstArgument(Term);
    newVar       = term_Create(symbol_CreateStandardVariable(), list_Nil());
    newWorldPath = term_Create(eml_ApplyFunct(), list_Cons(term_Copy(WorldPath),
			list_List(newVar)));
    if (flag_GetFlagValue(Flags, flag_EMLFUNCNDEQ)) {
      helpTerm = eml_BuildSortQuantifierFor(Term, Top, term_TopSymbol(relSubTerm), 
                term_TopSymbol(newVar), TRUE, 
		list_List(eml_FunctTranslProp(term_SecondArgument(Term),
			newWorldPath, Flags, Precedence)), (POINTER (*)())eml_CreateQuantifier, Precedence);
      /*printf("\n [*]\t"); fol_PrintDFG(helpTerm);*/
      list_Delete(term_ArgumentList(Term)); 
      anotherHelpTerm = eml_RplacWithOpAndArgs(Term, eml_FoJunctorAssocWithPropSymbol(Top), 
		list_Cons(eml_FunctTranslRel(relSubTerm, WorldPath, Flags, Precedence), 
		list_List(helpTerm)));
      /*printf("\n [**]\t"); fol_PrintDFG(anotherHelpTerm);*/
      term_Delete(newWorldPath);
      return anotherHelpTerm;
      /* nde_r(wp) /\ exists y_r tr(phi)(app(wp,y_r))  or
       * nde_r(wp) -> forall y_r tr(phi)(app(wp,y_r))  */
    }
    else {
      helpTerm = term_Create(eml_FoJunctorAssocWithPropSymbol(Top), 
	  list_Cons(eml_FunctTranslRel(relSubTerm, WorldPath, Flags, Precedence),
		    list_List(eml_FunctTranslProp(term_SecondArgument(Term), newWorldPath, Flags, Precedence))));
      list_Delete(term_ArgumentList(Term));
      anotherHelpTerm = eml_BuildSortQuantifierFor(Term, Top, term_TopSymbol(relSubTerm), 
                  term_TopSymbol(newVar), TRUE,
		  list_List(helpTerm), (POINTER (*)())eml_RplacWithQuantifier, Precedence);
      term_Delete(newWorldPath);
      return anotherHelpTerm;
      /* exists y_r nde_r(wp) /\ tr(phi)(app(wp,y_r))  or
       * forall y_r nde_r(wp) -> tr(phi)(app(wp,y_r))  */
    }
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_FunctTranslProp()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }

}

static TERM eml_FunctTranslRel(TERM Term, TERM WorldPath, 
	FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (propositional) formula, a variable list and its
           length.
  RETURNS: Its functional translation.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);

  /* Term = r */
  if (symbol_IsPredicate(Top)) {
    switch (flag_GetFlagValue(Flags, flag_EMLTHEORY)) {
      case flag_EMLTHEORYKD:
        return eml_RplacWithDesignatedPropAtom(Term, fol_True());
        break;
      case flag_EMLTHEORYK:
        return eml_RplacPropByFoAtom(Term, eml_NDE, 1, list_List(term_Copy(WorldPath)), Flags, Precedence);
        break;
      default:
        fprintf(stderr, "\nThe option EMLTheory = %d is not implemented in eml_FunctTranslRel()\n",
             flag_GetFlagValue(Flags, flag_EMLTHEORY));
        misc_Error();
        return NULL;
        break;
    }
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_FunctTranslRel()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }
}


static TERM eml_FunctionalTranslation(TERM Term, BOOL ItoNaryPreds, 
	FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (propositional) formula and a flag.
  RETURNS: Its functional translation.  If the flag is true the
           translation is into ordered first-order logic or the
           Bernays-Schoenfinkel class, meaning n-ary predicates
	   are generated.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  symbol_ResetStandardVarCounter();

  if (ItoNaryPreds) {
    char nameSuffix[symbol__SYMBOLMAXLEN] = "";
    
    if (flag_GetFlagValue(Flags, flag_EMLPTRANS))
      printf("\n [FuncFTr] \t");
    Term = eml_FunctTranslItoNaryPredProp(Term, list_Nil(), nameSuffix, 0, Flags, Precedence);
    /* Check whether sharing is possible on the name suffixes,
     * e.g. whether the iterative allocation of new memory in
     * eml_FunctTranslItoNaryPredProp is necessary. */
    /* memory_Free(nameSuffix, symbol__SYMBOLMAXLEN); */
    return  Term;
    /* note: without world quantifier */
  }
  else {
    TERM newVar, helpTerm;
    if (flag_GetFlagValue(Flags, flag_EMLPTRANS))
      printf("\n [FuncTr] \t");
    newVar   = term_Create(symbol_CreateStandardVariable(), list_Nil());
    helpTerm = eml_FunctTranslProp(Term,newVar, Flags, Precedence); 
    /*printf("\n [**]\t"); fol_PrintDFG(helpTerm);*/
    return term_Create(fol_All(), list_Cons(term_Create(fol_Varlist(),list_List(newVar)), list_List(helpTerm)));
    /* forall x tr(Term,x) */
  }

}

static TERM eml_SemiFunctTranslProp(TERM Term, TERM WorldTerm, int Polarity, 
	FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (propositional) formula, term of type world, and the
           polarity of the formula (Term) in the original formula
           length.
  RETURNS: Its functional translation.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);

  /* Term = p */
  if (symbol_IsPredicate(Top)) {
    return eml_RplacPropByFoAtom(Term, eml_PROP, 1, list_List(term_Copy(WorldTerm)), Flags, Precedence);
  }
  /* Term = not(phi) */
  else  if (eml_IsNotSymbol(Top)) {
      eml_SemiFunctTranslProp(term_FirstArgument(Term),
                      WorldTerm, Polarity * -1, Flags, Precedence);
    return Term;
  }
  /* Term = implies(...) */
  else  if (eml_IsImpliesSymbol(Top)) { 
    eml_SemiFunctTranslProp(term_FirstArgument(Term), WorldTerm, Polarity * -1, Flags, Precedence);
    eml_SemiFunctTranslProp(term_SecondArgument(Term), WorldTerm, Polarity, Flags, Precedence);
    return Term;
  }
  /* Term = implied(...) */
  else  if (eml_IsImpliedSymbol(Top)) { 
    eml_SemiFunctTranslProp(term_SecondArgument(Term), WorldTerm, Polarity * -1, Flags, Precedence);
    eml_SemiFunctTranslProp(term_FirstArgument(Term), WorldTerm, Polarity, Flags, Precedence);
    return Term;
  }
  /* Term = equiv(...) */
  else  if (eml_IsEquivSymbol(Top)) {
    TERM termL, termR, termLneg, termRneg;
    termL    = term_FirstArgument(Term);
    termR    = term_SecondArgument(Term);
    termLneg = term_Create(fol_Not(), list_List(term_Copy(termL)));
    termRneg = term_Create(fol_Not(), list_List(term_Copy(termR)));
    if ( Polarity == 1 ) {
      term_RplacTop(Term, fol_And());
      list_Rplaca(term_ArgumentList(Term), 
                  term_Create(fol_Or(), list_Cons(termLneg, list_List(termR))));
      list_RplacSecond(term_ArgumentList(Term),
                      term_Create(fol_Or(), list_Cons(termRneg, list_List(termL))));
    } 
    else if (Polarity == -1) {
      term_RplacTop(Term, fol_Or());
      list_Rplaca(term_ArgumentList(Term),
                  term_Create(fol_And(), list_Cons(termLneg, list_List(termRneg))));
      list_RplacSecond(term_ArgumentList(Term),
                  term_Create(fol_And(), list_Cons(termL, list_List(termR))));
    }
  eml_SemiFunctTranslProp(Term, WorldTerm, Polarity, Flags, Precedence);
  return Term;
  }
  /* Term = or(...), Term = and(...) */
  /* must be tested after eml_IsNotSymbol, eml_IsImpliesSymbol amd eml_IsEquivSymbol */
  else  if (eml_IsPropJunctor(Top)) {
    LIST Scan;
    for (Scan = term_ArgumentList(Term); 
         !list_Empty(Scan); 
         Scan = list_Cdr(Scan))
      eml_SemiFunctTranslProp(list_Car(Scan), WorldTerm, Polarity, Flags, Precedence);
    return Term;
  }
  else if (eml_IsModalOpSymbol(Top)) {
    /* Term = dia(alpha,phi), in the negation normal form (!) */
    if ( ( eml_IsDiaSymbol(Top) && (Polarity == 1) ) || 
         ( eml_IsBoxSymbol(Top) && (Polarity == -1) ) ) {
      TERM newVar, newWorldTerm, relSubTerm, helpTerm, anotherHelpTerm;
      relSubTerm   = term_FirstArgument(Term);
      newVar       = term_Create(symbol_CreateStandardVariable(), list_Nil());
      newWorldTerm = term_Create(eml_ApplyFunct(), 
                        list_Cons(term_Copy(WorldTerm), list_List(newVar)));
      if (flag_GetFlagValue(Flags, flag_EMLFUNCNDEQ)) {
        helpTerm = eml_BuildSortQuantifierFor(Term, Top, term_TopSymbol(relSubTerm), term_TopSymbol(newVar), TRUE, 
		list_List(eml_SemiFunctTranslProp(term_SecondArgument(Term),
			newWorldTerm, Polarity, Flags, Precedence)), 
                (POINTER (*)())eml_CreateQuantifier, Precedence);
        list_Delete(term_ArgumentList(Term)); 
        anotherHelpTerm = eml_RplacWithOpAndArgs(Term, eml_FoJunctorAssocWithPropSymbol(Top), 
		list_Cons(eml_SemiFunctTranslRelDia(relSubTerm, WorldTerm, Flags, Precedence), 
		list_List(helpTerm)));
        term_Delete(newWorldTerm);
        return anotherHelpTerm;
        /* nde_r(w) /\ exists y_r tr(phi)(app(w,y_r))  */
      }
      else {
        helpTerm = term_Create(eml_FoJunctorAssocWithPropSymbol(Top), 
	    list_Cons(eml_SemiFunctTranslRelDia(relSubTerm, WorldTerm, Flags, Precedence),
            list_List(eml_SemiFunctTranslProp(term_SecondArgument(Term), newWorldTerm, Polarity, Flags, Precedence))));
        list_Delete(term_ArgumentList(Term));
        anotherHelpTerm = eml_BuildSortQuantifierFor(Term, Top, term_TopSymbol(relSubTerm), 
		  term_TopSymbol(newVar), TRUE,
		  list_List(helpTerm), (POINTER (*)())eml_RplacWithQuantifier, Precedence);
        term_Delete(newWorldTerm);
        return anotherHelpTerm;
        /* exists y_r nde_r(w) /\ tr(phi)(app(w,y_r))  */
      }
    }
    /* Term = box(alpha,phi), in the negation normal form (!) */
    else {
      TERM newVar, helpTerm;          
      newVar   = term_Create(symbol_CreateStandardVariable(), list_Nil());
      helpTerm = term_Create(eml_FoJunctorAssocWithPropSymbol(Top), 
          list_Cons(eml_SemiFunctTranslRelBox(term_FirstArgument(Term), WorldTerm, newVar, Flags, Precedence),
          list_List(eml_SemiFunctTranslProp(term_SecondArgument(Term), newVar, Polarity, Flags, Precedence))));
      list_Delete(term_ArgumentList(Term));
      return eml_RplacWithQuantifier(Term, eml_FoQuantAssocWithPropSymbol(Top), list_List(newVar),
		    list_List(helpTerm));
      /* forall y tr(alpha)(w,y) -> tr(phi)(y)  */
    }
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_SemiFunctTranslProp()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }

}


static TERM eml_SemiFunctTranslRelDia(TERM Term, TERM WorldTerm, 
	FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (propositional) formula, argument term.
  RETURNS: Its semi functional translation.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);

  /* Term = r */
  if (symbol_IsPredicate(Top)) {
    switch (flag_GetFlagValue(Flags, flag_EMLTHEORY)) {
      case flag_EMLTHEORYKD:
        return eml_RplacWithDesignatedPropAtom(Term, fol_True());
        break;
      case flag_EMLTHEORYK:
        return eml_RplacPropByFoAtom(Term, eml_SEMIFNDE, 1, list_List(term_Copy(WorldTerm)), Flags, Precedence);
        break;
      default:
        fprintf(stderr, "\nThe option EMLTheory = %d is not implemented in eml_SemiFunctTranslRel()\n",
             flag_GetFlagValue(Flags, flag_EMLTHEORY));
        misc_Error();
        return NULL;
        break;
    }
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_SemiFunctTranslRel()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }
}

static TERM eml_SemiFunctTranslRelBox(TERM Term, TERM WorldTerm, TERM VarY, 
	FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (relational) formula, a term and a variable 
           (the free variable).
  RETURNS: Its standard (relational) translation.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);

  /* Term = r */
  if (symbol_IsPredicate(Top)) {
    return eml_RplacPropByFoAtom(Term, eml_REL, 2,
                    list_Cons(term_Copy(WorldTerm), list_List(term_Copy(VarY))), Flags, Precedence);
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_SemiFunctTranslRelBox()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }

}



static TERM eml_SemiFunctionalTranslation(TERM Term, int Polarity, 
	FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (propositional) formula.
  RETURNS: Its semi functional translation.  
  CAUTION: The term is destructively changed.
***************************************************************/
{
  TERM newVar, helpTerm;

  symbol_ResetStandardVarCounter();

  if (flag_GetFlagValue(Flags, flag_EMLPTRANS))
    printf("\n [SemiFuncTr] \t");
  newVar   = term_Create(symbol_CreateStandardVariable(), list_Nil());
  helpTerm = eml_SemiFunctTranslProp(Term, newVar, Polarity, Flags, Precedence);
    return term_Create(fol_All(), list_Cons(term_Create(fol_Varlist(),list_List(newVar)), list_List(helpTerm)));
    /* forall x tr(Term,x) */

}



static TERM eml_RelFunctTranslProp(TERM Term, SYMBOL Var, 
		char* SortEncoding, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml (propositional) formula, a variable, a string
           encoding of the sorts of the arguments and the modal depth.
  RETURNS: Its translation using the relational functional/path-based
           encoding of de Rijke et al.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);
  
  /* Term = p */
  if (symbol_IsPredicate(Top)) {
    return eml_RplacPropByNaryAtom(Term, eml_PROP, SortEncoding,
		    1, list_List(term_Create(Var,list_Nil())), Flags, Precedence);
  }
  /* Term = not(phi), Term = or(...) or Term = and(...) */
  else  if (eml_IsPropJunctor(Top)) {
    LIST Scan;
    for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan))
      eml_RelFunctTranslProp(list_Car(Scan), Var,
		      SortEncoding, Flags, Precedence);
    return Term;
  }
  /* Term = dia(r,phi)  or  Term = box(r,phi) */
  else if (eml_IsModalOpSymbol(Top)) {
    SYMBOL newVar;
    TERM   helpTerm;          
    SYMBOL relSubTop;
    char newSortEncoding[symbol__SYMBOLMAXLEN];
    newVar   = symbol_CreateStandardVariable();

    relSubTop = term_TopSymbol(term_FirstArgument(Term));
    sprintf(newSortEncoding,"%s%s", SortEncoding, symbol_Name(relSubTop));

    helpTerm = term_Create(eml_FoJunctorAssocWithPropSymbol(Top), 
        list_Cons(eml_RelFunctTranslRel(term_FirstArgument(Term),Var,newVar,newSortEncoding, Flags, Precedence),
        list_List(eml_RelFunctTranslProp(term_SecondArgument(Term),newVar,newSortEncoding, Flags, Precedence))));
    list_Delete(term_ArgumentList(Term));
    return eml_RplacWithQuantifier(Term, eml_FoQuantAssocWithPropSymbol(Top), list_List(term_Create(newVar,list_Nil())),
		    list_List(helpTerm));
    /* exists y R_r(x,y) /\ tr(phi)(y)  or
     * forall y R_r(x,y) -> tr(phi)(y)  */
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_RelFunctTranslProp()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }

}

static TERM eml_RelFunctTranslRel(TERM Term, SYMBOL VarX, SYMBOL VarY,
		char* SortEncoding, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An EML relational formula, a variable list, a string (encoding
           the sorts of the accessibility relations in the scope), and
	   the length of the variable list (corresponds to the modal
	   depth).
  RETURNS: Its functional translation ito n-ary predicates.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  SYMBOL Top;

  Top    = term_TopSymbol(Term);

  /* Term = r */
  if (symbol_IsPredicate(Top)) {
    switch (flag_GetFlagValue(Flags, flag_EMLTHEORY)) {
      case flag_EMLTHEORYK:
        return eml_RplacPropByNaryAtom(Term, eml_REL,
  		        SortEncoding, 2,  list_Cons(term_Create(VarX,list_Nil()),list_List(term_Create(VarY,list_Nil()))), Flags, Precedence);
        break;
      default:
        fprintf(stderr, "\nThe option EMLTheory = %d is not implemented in eml_RelFunctTranslRel()\n",
             flag_GetFlagValue(Flags, flag_EMLTHEORY));
        misc_Error();
        return NULL;
        break;
    }
  }
  else {
    fprintf(stderr, "\nNo case for %s in eml_RelFunctTranslRel()\n",
             symbol_Name(Top));
    misc_Error();
    return NULL;
  }
}




static TERM  eml_TranslateToFol(TERM Term, int Polarity, 
	FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   An eml formula.
  RETURNS: Its translation as specified by flag_EMLTR, provided
           the formula is provided, otherwise the simplification of the
           original formula.
  CAUTION: The term is destructively changed.
***************************************************************/
{
  if (!eml_IsPropositional(Term))
    fol_NormalizeVars(Term);

  Term = eml_ObviousSimplifications(Term, Flags);
  /* Term = eml_MakeOneAndOrCompSum(Term); */
  if (flag_GetFlagValue(Flags, flag_EMLPTRANS)) {
    printf("\n [Simpl]\t"); 
    if ( (Polarity == -1) ) {   /* Conjecture */
      symbol_Print(fol_Not());
      putchar('(');
      /* printf("(not "); */
      /* putchar(' ');*/
      fol_PrintDFG(Term);
      printf(")");
    }
    else                        /* Axiom */
      fol_PrintDFG(Term);
  }

  /* kjs */
  if (flag_GetFlagValue(Flags, flag_EMLAXIOM)) {
	  Term = eml_Axiomatic(Term, Flags, Precedence);
	  return Term;
  } else /* kjs */ if (eml_IsPropositional(Term)) {
	  switch (flag_GetFlagValue(Flags, flag_EMLTR)) {
	  case flag_EMLTRREL:
		  Term = eml_RelationalTranslation(Term, Flags, Precedence);
		  break;
	  case flag_EMLTRFUNC:
	  case flag_EMLTROPTFUNC:
		  Term = eml_FunctionalTranslation(Term, flag_GetFlagValue(Flags, flag_EMLFNARY), Flags, Precedence);
		  break;
	  case flag_EMLTRSEMIFUNC:
		  Term = eml_SemiFunctionalTranslation(Term, Polarity, Flags, Precedence);
		  break;
	  default:
		  fprintf(stderr, "\nFlag = %d is not implemented in eml_TranslateToFol()\n",
				  flag_GetFlagValue(Flags, flag_EMLTR));
		  misc_Error();
		  break;
	  }
  } else
	  if (flag_GetFlagValue(Flags, flag_EMLPTRANS))
		  printf("\n [FOL]\t");

  return Term;
}

static TERM eml_CreateTheoryTerm(int Flag, SYMBOL Symbol)
/**************************************************************
  INPUT:   A flag, must be of a logic determined by one axiom schema
  RETURNS: A single theory formula, e.g. for the flag flag_EMLTHEORYKD it
           returns  forall x exists y R(x,y)
  REMARK:  Prototypical.  Only implemented for the relational
           translation and a few axiom schemas (D, T, B, 4, 5)
***************************************************************/
{   
  TERM newVarX, newVarY, newVarZ, helpTerm;          
  TERM term;                   /* theory formula */
  
  switch (Flag) {

    case flag_EMLTHEORYKD:
      /*printf("\nD");*/
      newVarX  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      newVarY  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      term     = term_Create(Symbol,        /* R(x,y) */
                      list_Nconc(list_List(newVarX), list_List(newVarY)));
      /*printf("\n [*]\t"); fol_PrintDFG(term);*/
      helpTerm = term_Create(fol_Exist(),   /* exists y R(x,y) */
    		 list_Cons(term_Create(fol_Varlist(), list_List(term_Copy(newVarY))), 
                               list_List(term)));
      /*printf("\n [**]\t"); fol_PrintDFG(helpTerm);*/
      term     = term_Create(fol_All(),     /* forall x exists y R(x,y) */
    		     list_Cons(term_Create(fol_Varlist(), list_List(term_Copy(newVarX))), 
                           list_List(helpTerm) ));
      /*printf("\n [***]\t"); fol_PrintDFG(term);*/
      return term;
      break;

    case flag_EMLTHEORYKT:
      /*printf("\nT");*/
      newVarX  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      helpTerm = term_Create(Symbol,        /* R(x,x) */
                      list_Nconc(list_List(newVarX), list_List(term_Copy(newVarX))));
      /*printf("\n [*]\t"); fol_PrintDFG(helpTerm);*/
      term     = term_Create(fol_All(),     /* forall x R(x,x) */
    		     list_Cons(term_Create(fol_Varlist(), list_List(term_Copy(newVarX))), 
                           list_List(helpTerm) ));
      return term;
      break;

    case flag_EMLTHEORYKB:
      /*printf("\nB");*/
      newVarX  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      newVarY  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      term     = term_Create(Symbol,        /* R(x,y) */
                      list_Nconc(list_List(newVarX), list_List(newVarY)));
      /*printf("\n [*]\t"); fol_PrintDFG(term);*/
      helpTerm     = term_Create(Symbol,        /* R(y,x) */
                      list_Nconc(list_List(term_Copy(newVarY)), list_List(term_Copy(newVarX))));
      /*printf("\n [**]\t"); fol_PrintDFG(helpTerm);*/
      helpTerm = term_Create(fol_Implies(),   /* R(x,y) -> R(y,x) */
    		 list_Cons(term, list_List(helpTerm)));
      /*printf("\n [***]\t"); fol_PrintDFG(helpTerm);*/
      term     = term_Create(fol_All(),     /* forall x y R(x,y) -> R(y,x) */
    		     list_Cons(term_Create(fol_Varlist(), 
                             list_Cons(term_Copy(newVarX), list_List(term_Copy(newVarY)))), 
                       list_List(helpTerm) ));
      /*printf("\n [****]\t"); fol_PrintDFG(term);*/
      return term;
      break;

    case flag_EMLTHEORYK4:
      /*printf("\n4");*/
      newVarX  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      newVarY  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      newVarZ  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      term     = term_Create(Symbol,        /* R(x,y) */
                      list_Nconc(list_List(newVarX), list_List(newVarY)));
      /*printf("\n [*]\t"); fol_PrintDFG(term);*/
      helpTerm     = term_Create(Symbol,        /* R(y,z) */
                      list_Nconc(list_List(term_Copy(newVarY)), list_List(newVarZ)));
      /*printf("\n [**]\t"); fol_PrintDFG(helpTerm);*/
      helpTerm = term_Create(fol_And(),   /* R(x,y) /\ R(y,z) */
    		 list_Cons(term, list_List(helpTerm)));
      /*printf("\n [***]\t"); fol_PrintDFG(helpTerm);*/
      term     = term_Create(Symbol,        /* R(x,z) */
                      list_Nconc(list_List(term_Copy(newVarX)), list_List(term_Copy(newVarZ))));
      /*printf("\n [****]\t"); fol_PrintDFG(term);*/
      helpTerm = term_Create(fol_Implies(),   /* (R(x,y) /\ R(y,z)) -> R(x,z) */
    		 list_Cons(helpTerm, list_List(term)));
      /*printf("\n [*****]\t"); fol_PrintDFG(helpTerm);*/
      term     = term_Create(fol_All(),     /* forall x y z (R(x,y) /\ R(y,z)) -> R(x,z) */
    		     list_Cons(term_Create(fol_Varlist(), 
                             list_Cons(term_Copy(newVarX),
                                     list_Cons(term_Copy(newVarY),
                                             list_List(term_Copy(newVarZ))))), 
                       list_List(helpTerm) ));
      /*printf("\n [******]\t"); fol_PrintDFG(term);*/
      return term;
      break;

    case flag_EMLTHEORYK5:
      /*printf("\n5");*/
      newVarX  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      newVarY  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      newVarZ  = term_Create(symbol_CreateStandardVariable(), list_Nil());
      term     = term_Create(Symbol,        /* R(x,y) */
                      list_Nconc(list_List(newVarX), list_List(newVarY)));
      /*printf("\n [*]\t"); fol_PrintDFG(term);*/
      helpTerm     = term_Create(Symbol,        /* R(x,z) */
                      list_Nconc(list_List(term_Copy(newVarX)), list_List(newVarZ)));
      /*printf("\n [**]\t"); fol_PrintDFG(helpTerm);*/
      helpTerm = term_Create(fol_And(),   /* R(x,y) /\ R(x,z) */
    		 list_Cons(term, list_List(helpTerm)));
      /*printf("\n [***]\t"); fol_PrintDFG(helpTerm);*/
      term     = term_Create(Symbol,        /* R(y,z) */
                      list_Nconc(list_List(term_Copy(newVarY)), list_List(term_Copy(newVarZ))));
      /*printf("\n [****]\t"); fol_PrintDFG(term);*/
      helpTerm = term_Create(fol_Implies(),   /* (R(x,y) /\ R(x,z)) -> R(y,z) */
    		 list_Cons(helpTerm, list_List(term)));
      /*printf("\n [*****]\t"); fol_PrintDFG(helpTerm);*/
      term     = term_Create(fol_All(),     /* forall x y z (R(x,y) /\ R(x,z)) -> R(y,z) */
    		     list_Cons(term_Create(fol_Varlist(), 
                             list_Cons(term_Copy(newVarX),
                                     list_Cons(term_Copy(newVarY),
                                             list_List(term_Copy(newVarZ))))), 
                       list_List(helpTerm) ));
      /*printf("\n [******]\t"); fol_PrintDFG(term);*/
      return term;
      break;

    default:
      fprintf(stderr, "\nFlag = %d is not implemented in eml_CreateTheoryTerm()\n",
           Flag);
      misc_Error();
      return NULL;
  }
}

static void eml_AddBackgroundTheory(LIST* Axiomlist, FLAGSTORE Flags)
/**************************************************************
  INPUT:   The list of axioms
  RETURNS: Nothing
  EFFECT:  Additional axioms may be added to the list of axioms.
  REMARK:  Prototypical.  Only implemented for the relational
           translation and a few logics (K, KD, KT, KB, K4, K5, S4, S5 )
***************************************************************/
{   
  int i, flag;
  char L[100];
  char* label;
  SYMBOL symbol;
  LIST pair   = list_Nil();    /* theory formula plus label */
  LIST theory = list_Nil();    /* list of theory formulae */

          /*printf("\n Beginning of eml_AddBackgroundTheory()\t");*/

  if ( (flag_GetFlagValue(Flags, flag_EMLTHEORY) != flag_EMLTHEORYK) && 
       (flag_GetFlagValue(Flags, flag_EMLTR) == flag_EMLTRREL) ) {
    
    for (i = 1; i < symbol_ActIndex(); i++) {
      if (!symbol_IsFreed(i)) {
        symbol = symbol_Signature(i)->info;
        /* printf("\n []\t"); symbol_Print(symbol); */
        if ( symbol_IsPredicate(symbol) &&
             (symbol_Signature(i)->arity == 2) &&
             !symbol_Equal(symbol, fol_Equality())) {
          flag = flag_GetFlagValue(Flags, flag_EMLTHEORY);
          switch (flag) {

            case flag_EMLTHEORYKD:
            case flag_EMLTHEORYKT:
            case flag_EMLTHEORYKB:
            case flag_EMLTHEORYK4:
            case flag_EMLTHEORYK5:
              sprintf(L,"%s%s", eml_RELPROPERTYLABELS[flag], symbol_Name(symbol));
	      label = memory_Malloc(sizeof(char) * (strlen(L) + 1));
	      sprintf(label, "%s", L);
              pair     = list_PairCreate(label, eml_CreateTheoryTerm(flag, symbol));
    /*printf("\nLabel : %s", (char*) list_PairFirst(pair)); */
    /*printf("\nTheory formula : "); fol_PrintDFG(list_PairSecond(pair));*/
              theory   = list_Nconc(theory, list_List(pair));
              break;

            case flag_EMLTHEORYS4:
              /* T / reflexivity */
              sprintf(L,"%s%s", eml_RELPROPERTYLABELS[flag_EMLTHEORYKT], symbol_Name(symbol));
	      label = memory_Malloc(sizeof(char) * (strlen(L) + 1));
	      sprintf(label, "%s", L);
              pair     = list_PairCreate(label, eml_CreateTheoryTerm(flag_EMLTHEORYKT, symbol));
    /*printf("\nLabel : %s", (char*) list_PairFirst(pair)); */
    /*printf("\nTheory formula : "); fol_PrintDFG(list_PairSecond(pair));*/
              theory   = list_Nconc(theory, list_List(pair));
              /* 4 / transitivity */
              sprintf(L,"%s%s", eml_RELPROPERTYLABELS[flag_EMLTHEORYK4], symbol_Name(symbol));
	      label = memory_Malloc(sizeof(char) * (strlen(L) + 1));
	      sprintf(label, "%s", L);
              pair     = list_PairCreate(label, eml_CreateTheoryTerm(flag_EMLTHEORYK4, symbol));
    /*printf("\nLabel : %s", (char*) list_PairFirst(pair)); */
    /*printf("\nTheory formula : "); fol_PrintDFG(list_PairSecond(pair));*/
              theory   = list_Nconc(theory, list_List(pair));
              break;

            case flag_EMLTHEORYS5:
              /* T / reflexivity */
              sprintf(L,"%s%s", eml_RELPROPERTYLABELS[flag_EMLTHEORYKT], symbol_Name(symbol));
	      label = memory_Malloc(sizeof(char) * (strlen(L) + 1));
	      sprintf(label, "%s", L);
              pair     = list_PairCreate(label, eml_CreateTheoryTerm(flag_EMLTHEORYKT, symbol));
    /*printf("\nLabel : %s", (char*) list_PairFirst(pair)); */
    /*printf("\nTheory formula : "); fol_PrintDFG(list_PairSecond(pair));*/
              theory   = list_Nconc(theory, list_List(pair));
              /* B / symmetry */
              sprintf(L,"%s%s", eml_RELPROPERTYLABELS[flag_EMLTHEORYKB], symbol_Name(symbol));
	      label = memory_Malloc(sizeof(char) * (strlen(L) + 1));
	      sprintf(label, "%s", L);
              pair     = list_PairCreate(label, eml_CreateTheoryTerm(flag_EMLTHEORYKB, symbol));
    /*printf("\nLabel : %s", (char*) list_PairFirst(pair)); */
    /*printf("\nTheory formula : "); fol_PrintDFG(list_PairSecond(pair));*/
              theory   = list_Nconc(theory, list_List(pair));
              /* 4 / transitivity */
              sprintf(L,"%s%s", eml_RELPROPERTYLABELS[flag_EMLTHEORYK4], symbol_Name(symbol));
	      label = memory_Malloc(sizeof(char) * (strlen(L) + 1));
	      sprintf(label, "%s", L);
              pair     = list_PairCreate(label, eml_CreateTheoryTerm(flag_EMLTHEORYK4, symbol));
    /*printf("\nLabel : %s", (char*) list_PairFirst(pair)); */
    /*printf("\nTheory formula : "); fol_PrintDFG(list_PairSecond(pair));*/
              theory   = list_Nconc(theory, list_List(pair));
              break;
            default:
              fprintf(stderr, "\nThe option EMLTheory = %d is not implemented in eml_AddBackgroundTheory()\n",
                   flag_GetFlagValue(Flags, flag_EMLTHEORY));
              misc_Error();
              break;
          }
#ifdef DEBUG
            if (list_Empty(theory)) {
              fprintf(stderr, "In eml_AddBackgroundTheory(): theory is empty\n");
              misc_Error();
            } 
            if (list_Empty(*Axiomlist)) {
              fprintf(stderr, "In eml_AddBackgroundTheory(): *Axiomlist is empty\n");
              misc_Error();
            } 
#endif
        }
      } 
    }
    *Axiomlist = list_Nconc(theory, *Axiomlist);
  }
}


void eml_TranslateToFolMain(LIST* AxiomList, LIST* ConjectureList, 
                 BOOL  KeepProofSearch, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:   A list of axiom formulae,
           a list of conjecture formulae,
           a hasharray in which for every clause the list of labels 
           of the terms used for deriving the clause is stored (if DocProof 
           is set),
	   a flag store
  RETURNS: If KeepProofSearch is TRUE, then the ProofSearch object is not
           freed but returned.
           Else, NULL is returned.
***************************************************************/
{
  LIST  Scan, Pair;
  TERM  helpTerm;
  FLAG	flag_emltr;

  /* NOTE: EMLAUTO mode not as yet implemented */
  
  /* Print warnings for non-sensical flag combinations */
  flag_emltr = flag_GetFlagValue(Flags, flag_EMLTR);
  if (flag_GetFlagValue(Flags, flag_DOCPROOF) || flag_GetFlagValue(Flags, flag_EMLPTRANS)) {
	  flag_CheckEmlTranslationFlags(Flags, flag_emltr);
  }

  /* Set additional flags */
  if (flag_emltr == flag_EMLTROPTFUNC) {
    flag_SetFlagValue(Flags, flag_QUANTEXCH, flag_QUANTEXCHON);
  }
  /* This caused a memory leak because of the allocation done in
   * cnf_Init; fixed with warnings
   * if (flag_GetFlagValue(Flags, flag_QUANTEXCH)) {      
    flag_SetFlagValue(Flags, flag_CNFOPTSKOLEM, flag_CNFOPTSKOLEMOFF);
    flag_SetFlagValue(Flags, flag_CNFSTRSKOLEM, flag_CNFSTRSKOLEMOFF);
  } */
  /*
  if ((flag_emltr == flag_EMLTRFUNC || flag_emltr == flag_EMLTROPTFUNC) &&
      flag_GetFlagValue(Flags, flag_EMLFFSORTS)) {
    flag_SetFlagValue(Flags, flag_SORTS, flag_SORTSMONADICWITHVARIABLE); 
  } */
  /* RS: Check with Christoph?? */

  /* Limitations of current implementation */
  Scan = *AxiomList;
  if ( !list_Empty(Scan) && !list_Empty(list_Car(Scan)) ) {
    if ( flag_emltr == flag_EMLTROPTFUNC ) {
        fprintf(stderr, "ERROR: With the current implementation of the translation routines\n");
        fprintf(stderr, "       no axioms are allowed when the optimised functional translation\n");
        fprintf(stderr, "       is used (EMLTranslation=2)\n");
        misc_Error();
      }
    else {
      if ( flag_GetFlagValue(Flags, flag_EMLFNARY) ) {
        fprintf(stderr, "ERROR: With the current implementation of the translation routines\n");
        fprintf(stderr, "       no axioms are allowed when the encoding is in terms of\n");
        fprintf(stderr, "       n-ary predicates (EMLFuncNary=1)\n");
        misc_Error();
      }
    }
  }
  
  if (flag_GetFlagValue(Flags, flag_EMLPTRANS)) {
    printf("\n--------------------EML-TRANSLATION-START-------------------------");
    printf("\n Special   : "); 
    flag_PrintEmlTranslationMethod(flag_emltr);
    flag_PrintEmlTranslationFlags(Flags);
    printf("\n Precedence: "); symbol_PrintPrecedence(Precedence);
    printf("\nAxioms:");
  }

  /* Initialisation */
  switch (flag_GetFlagValue(Flags, flag_EMLTR)) {
    case flag_EMLTRFUNC:
    case flag_EMLTROPTFUNC:
    case flag_EMLTRSEMIFUNC:
      eml_InitFunctTransl(Flags, Precedence);
      break;
    default:
      /* Do nothing */
      break;
  }
   
  /* ------------------------entry point for axiomatic translation--------------- */
  if (flag_GetFlagValue(Flags, flag_EMLAXIOM)) { /* kjs */
	  if ( (list_Length(*AxiomList) == 1) && (list_Length(*ConjectureList) == 0) ) {  
		  /* This is the preferred mode!! */
		  for(Scan=*AxiomList; !list_Empty(Scan); Scan = list_Cdr(Scan)) {
			  Pair = list_Car(Scan);
			  helpTerm = (TERM) list_PairSecond(Pair);
			  eml_PrintT("\n[Axiom Input Term]:\t", helpTerm);
			  helpTerm = eml_TranslateToFol(helpTerm, 1, Flags, Precedence); /* positive polarity */
			  list_Rplacd(Pair, (LIST) helpTerm);
		  }
	  } else {
		  TERM CompositeTerm = NULL;
		  helpTerm = NULL;
		  eml_PrintD("\nEMLAxiomatic Translation Information:  %d axioms &", list_Length(*AxiomList));
		  eml_PrintD(" %d conjectures\n", list_Length(*ConjectureList)); 
		  
		  { /* Print input */
			  int count = 0;
			  for(Scan=*AxiomList; !list_Empty(Scan); Scan = list_Cdr(Scan)) {
				  Pair = list_Car(Scan);
				  helpTerm = (TERM) list_PairSecond(Pair);
				  eml_PrintDT("\nInput Axiom Term %d:\t",count,helpTerm); count++;
			  } /* This is the raw term at this stage */
			  count = 0;
			  for(Scan=*ConjectureList; !list_Empty(Scan); Scan = list_Cdr(Scan)) {
				  Pair = list_Car(Scan);
				  helpTerm = (TERM) list_PairSecond(Pair);
				  eml_PrintDT("\nInput Conjecture Term %d:\t",count,helpTerm); count++;
			  } /* This is automatically negated by this stage */
		  }

		  /* rollup all the axioms into one term A1 /\ A2 /\ A3 /\ ... */
			for (Scan=*AxiomList; !list_Empty(Scan); Scan = list_Cdr(Scan)) {
				Pair = list_Car(Scan);
				helpTerm = (TERM) list_PairSecond(Pair);

				if (CompositeTerm == NULL) {
					CompositeTerm = helpTerm;
				} else {
					CompositeTerm = term_Create(fol_And(), list_Cons(
							CompositeTerm, list_List(helpTerm)));
				}
			}
			/* rollup all the conjectures into one term C1 /\ C2 /\ C3 /\ ... */
			for (Scan=*ConjectureList; !list_Empty(Scan); Scan = list_Cdr(Scan)) {
				Pair = list_Car(Scan);
				helpTerm = (TERM) list_PairSecond(Pair);

				if (CompositeTerm == NULL) {
					CompositeTerm = helpTerm;
				} else {
					CompositeTerm = term_Create(fol_And(), list_Cons(
							CompositeTerm, list_List(helpTerm)));
				}
			}
			/* composite term is now A1 /\ A2 /\ A3 /\ ... /\ C1 /\ C2 /\ C3 /\ ... */
			for (Scan=*ConjectureList; !list_Empty(Scan); Scan = list_Cdr(Scan)) {
				Pair = list_Car(Scan);
				list_Rplacd(Pair, (LIST) term_Create(fol_True(), list_Nil()));
			}

			/* -------------- do the calculation */
			helpTerm = eml_TranslateToFol(CompositeTerm, 1, Flags, Precedence); /* positive polarity */
			Scan=*AxiomList;
			Pair = list_Car(Scan);
			list_Rplacd(Pair, (LIST) helpTerm);
			/* -------------- */

			/* set conjecture length = 0; axiom length = 1 */
			Scan=*AxiomList;
			list_Rplacd(Scan, list_Nil());
			*ConjectureList = list_Nil();

		  { /* Print input */
			  int count = 0;
			  eml_PrintD("\nLeaving EMLAxiomatic Translation with %d",list_Length(*AxiomList));
			  eml_PrintD(" axioms & %d conjectures (some re-organisation may have occurred).",list_Length(*ConjectureList));
			  for(Scan=*AxiomList; !list_Empty(Scan); Scan = list_Cdr(Scan)) {
				  Pair = list_Car(Scan);
				  helpTerm = (TERM) list_PairSecond(Pair);
				  eml_PrintDT("\nExiting Axiom Term %d:\t",count, helpTerm); count++;
			  } 
			  count = 0;
			  for(Scan=*ConjectureList; !list_Empty(Scan); Scan = list_Cdr(Scan)) {
				  Pair = list_Car(Scan);
				  helpTerm = (TERM) list_PairSecond(Pair);
				  eml_PrintDT("\nExiting Conjecture Term %d:\t",count,helpTerm); count++;
			  }
		  }
	  }
  } else { /* kjs end */  
	  for(Scan=*AxiomList; !list_Empty(Scan); Scan = list_Cdr(Scan)) {
		  Pair = list_Car(Scan);
		  helpTerm = (TERM) list_PairSecond(Pair);
		  if (flag_GetFlagValue(Flags, flag_EMLPTRANS)) {
			  if ( !list_Empty(list_PairFirst(Pair)) ) {
				  printf("\nLabel : %s", (char*) list_PairFirst(Pair)); 
			  }
			  if (eml_IsPropositional(helpTerm))
				  printf("\n [%s]\t", flag_Name(flag_EML));
			  else
				  printf("\n [FOL]\t");
			  fol_PrintDFG(helpTerm);
		  }
		  helpTerm = eml_TranslateToFol(helpTerm, 1, Flags, Precedence);         
		  /* positive polarity */
		  if (flag_GetFlagValue(Flags, flag_EMLPTRANS)) {
			  fol_PrintDFG(helpTerm);
			  printf("\n");
		  }
		  list_Rplacd(Pair, (LIST) helpTerm);
	  }

	  if (flag_GetFlagValue(Flags, flag_EMLPTRANS))
		  printf("\n\nConjecture:");

	  for(Scan=*ConjectureList; !list_Empty(Scan); Scan = list_Cdr(Scan)) {
		  Pair = list_Car(Scan);
		  helpTerm = (TERM) list_PairSecond(Pair);
		  if (flag_GetFlagValue(Flags, flag_EMLPTRANS)) {
			  if ( !list_Empty(list_PairFirst(Pair)) ) {
				  printf("\nLabel : %s", (char*) list_PairFirst(Pair)); 
			  }
			  if (eml_IsPropositional(helpTerm))
				  printf("\n [%s]\t", flag_Name(flag_EML));
			  else
				  printf("\n [FOL]\t");
			  fol_PrintDFG(helpTerm);
		  }
#ifdef DEBUG
		  if (!symbol_Equal(term_TopSymbol(helpTerm),fol_Not())) {
			  fprintf(stderr, "In eml_TranslateToFolMain(): The list of conjectures should have been negated\n");
			  misc_Error();
		  } 
#endif

		  term_RplacFirstArgument(helpTerm,
				  eml_TranslateToFol(term_FirstArgument(helpTerm), -1, Flags, Precedence));                
		  /* negative polarity */
		  if (flag_GetFlagValue(Flags, flag_EMLPTRANS)) {
			  fol_PrintDFG(helpTerm);
		  }
		  list_Rplacd(Pair, (LIST) helpTerm);
	  }
	  if (flag_GetFlagValue(Flags, flag_EMLPTRANS))
		  printf("\n");

	  eml_AddBackgroundTheory(AxiomList, Flags);

	  /* Check whether the following does the job (as it is supposed to).
	   * Deleting the symbol list causes a segmentation fault later on in cnf.c.
	   * Is this possbily due to a missing
	   *  if (!list_PointerMember(symbol_FREEDSYMBOLS,(POINTER)Index))
	   * ??
	   * */

  }
  
}

/* ------------------------------------kjs start-------------------------------------------- */

static TERM eml_AxiomaticTranslationRel (TERM DefFragment, SYMBOL VarX, SYMBOL VarY, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: DefFragment is term containing R (accessibility relation)
  Ref: Developed from eml_RelationalTranslationRel.
  SUMMARY: creates the R(x,y) Term in arbitary expression
  (Works for other letters than R)
 ***************************************************************/
{
	SYMBOL Top = term_TopSymbol(DefFragment);
	TERM OutTerm = NULL;
	
	if (symbol_IsPredicate(Top)) { /* Term = r */
		TERM TmpTerm = term_Copy(DefFragment);
		SYMBOL SymbolR = symbol__NULL;
		
		SymbolR = eml_FoQuantAssocWithPropSymbol(Top); /* use translpairs - if they are defined */
		if (symbol_Equal(SymbolR, symbol__NULL)) {
			SymbolR = eml_CreateAxiomSymbol(TmpTerm, eml_AXIOMREL, 2, symbol_STATLEX, Precedence); 
		}
		OutTerm = term_Create(SymbolR, list_Cons(term_Create(VarX,list_Nil()),
						list_List(term_Create(VarY,list_Nil())))	);		
	} else {
		eml_Error("No case for in eml_AxiomaticTranslationRel()");
	}
	return OutTerm;
}

static TERM eml_AxiomaticTranslation (TERM Def, SYMBOL VarX, SYMBOL VarY, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: TERM Term, SYMBOL Var, FLAGSTORE Flags, PRECEDENCE Precedence
  RETURNS: The one stage PI translation of the input formula (Def) 
  SUMMARY: 	a. PI(false, x)  = false
  			b. PI(p, x)      = T
  			c. PI(p, x)     = Qp(x)
  			d. PI(p/\q, x)    = Qp(x) /\ Qq(x)
  			e. PI((p/\q), x) = Qp(x) \/ Qq(x)
  			f. PI([]p, x)    = Ay( R(x, y) -> Qp(y) )
  			g. PI([]p, x)   = Ey( R(x, y) /\ Qp(y) )
 REF: developed from eml_RelationalTranslationProp.
 ***************************************************************/
{
	SYMBOL Top = term_TopSymbol(Def), Top2;
	TERM OutTerm;

	/* a. PI(false, x)  = false */
	if (eml_IsFalseSymbol(Top)) {
		OutTerm = term_Create(fol_False(), list_Nil());
		return OutTerm;
	}
	/* b. PI(p, x) = T */
	else if (symbol_IsPredicate(Top)) {
		OutTerm = term_Copy(Def);
		term_RplacTop(OutTerm, fol_True());
		term_RplacArgumentList(OutTerm, list_Nil());
		return OutTerm;
	}
	Top2 = term_TopSymbol(term_FirstArgument(Def));

	/* c. PI(p, x) = Qp(x) */
	if ( eml_IsNotSymbol(Top) && symbol_IsPredicate(Top2) ) {
		SYMBOL Symbol = symbol__NULL;

		{
			TERM FirstArgTerm = term_Copy(term_FirstArgument(Def)); /* p */
			Symbol = eml_CreateAxiomSymbol(FirstArgTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Qp */
		}
		OutTerm = eml_NegateElimNotNot( term_Create(Symbol, list_List(term_Create(VarX, list_Nil()))) ); /* Qp(x) */
		return OutTerm;
	}
	/* d. PI(p/\q, x) = Qp(x) /\ Qq(x) */
	else if (eml_IsAndSymbol(Top)) {
		LIST Scan, Result = list_Nil(); 
		TERM DefCopy = term_Copy(Def);

		/* works for non-binary case */
		for (Scan=term_ArgumentList(DefCopy); !list_Empty(Scan); Scan=list_Cdr(Scan)) { 
			SYMBOL Symbol = eml_CreateAxiomSymbol(list_Car(Scan), eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Qp, Qq, etc */
			TERM TmpTerm = term_Create(Symbol, list_List(term_Create(VarX, list_Nil()))); /* Qp(x), Qq(x), etc */ 
			Result = eml_ListAddTerm(TmpTerm, Result);
		}
		OutTerm = term_Create(fol_And(), Result);	/* Qp(x) /\ Qq(x) /\ etc */	
		return OutTerm;
	}
	/* e. PI((p/\q), x) = Qp(x) \/ Qq(x) */
	else if ( eml_IsNotSymbol(Top) && eml_IsAndSymbol(Top2) ) {
		LIST Scan, Result = list_Nil();
		TERM DefArgsCopy = term_Copy(term_FirstArgument(Def)); /* (p/\q) */

		/* works for non-binary case */
		for (Scan=term_ArgumentList(DefArgsCopy); !list_Empty(Scan); Scan=list_Cdr(Scan)) { 
			SYMBOL Symbol = symbol__NULL;
			TERM TmpTerm, SymbolTerm;
			SymbolTerm = eml_NegateElimNotNot(list_Car(Scan));
			Symbol = eml_CreateAxiomSymbol(SymbolTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q~p, Q~q, etc */
			TmpTerm = term_Create(Symbol, list_List(term_Create(VarX, list_Nil()))); /* Q~p(x), Q~q(x), etc */
			Result = eml_ListAddTerm(TmpTerm, Result);
		}
		OutTerm = term_Create(fol_Or(), Result); /* Qp(x) \/ Qq(x) \/ etc */
		return OutTerm;
	}
	/* f. PI([](r,p), x) = Ay( R(x, y) -> Qp(y) ) */
	else if (eml_IsBoxSymbol(Top)) {
		SYMBOL Qp = symbol__NULL;
		TERM DefCopy = term_Copy(Def), SubTerm;
		TERM TermP = term_SecondArgument(term_Copy(Def)); /* p */
		LIST list = list_Nil(); 
		if (eml_IsFalseSymbol(term_TopSymbol(TermP))) {  /* special case [](r, false) */  
			SubTerm = term_Create(fol_False(), list_Nil());
		} else {
			Qp = eml_CreateAxiomSymbol(term_SecondArgument(DefCopy), eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Qp */
			SubTerm = term_Create(Qp, list_List(term_Create(VarY, list_Nil()))); /* Qp(y) */
		}
		list = list_Cons(eml_AxiomaticTranslationRel(
				term_FirstArgument(DefCopy), VarX, VarY, Flags, Precedence), /* R(x, y) */
				list_List(SubTerm)		); /* R(x, y) , Qp(y) */
		OutTerm = term_Create(fol_Implies(), list); /* R(x, y) -> Qp(y) */
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm,	list_List(term_Create(VarY, list_Nil())) ); /* Ay( R(x, y) -> Qp(y) ) */
		return OutTerm;
	}
	/* g. PI([](r,p), x) = Ey( R(x, y) /\ Qp(y) ) */
	else if ( eml_IsNotSymbol(Top) && eml_IsBoxSymbol(Top2) ) {
		SYMBOL Qnp = symbol__NULL;
		TERM DefCopy = term_Copy(Def), SecondTerm, SecondSymbolTerm; 
		TERM TermP = term_SecondArgument(term_FirstArgument(term_Copy(Def))); /* p */

		if (eml_IsFalseSymbol(term_TopSymbol(TermP))) { /* special case ([](r,false)) */  
			SecondSymbolTerm = eml_Negate(term_Create(fol_False(), list_Nil()));
		} else {
			SecondSymbolTerm = eml_NegateElimNotNot(term_SecondArgument(term_FirstArgument(DefCopy))); /* ~p */ 
		}
		
		Qnp = eml_CreateAxiomSymbol(SecondSymbolTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q~p */
		SecondTerm = term_Create(Qnp, list_List(term_Create(VarY, list_Nil()))); /* Q~p(y) */
		OutTerm = term_Create(fol_And(), list_Cons(eml_AxiomaticTranslationRel(
						term_FirstArgument(term_FirstArgument(DefCopy)), /* r */
						VarX, VarY, Flags, Precedence), /* R(x, y) */ list_List(SecondTerm)	)	
		); /*  R(x, y) /\ Qp(y) */

		OutTerm = term_Create(fol_Exist(), 
				list_Cons( term_Create(fol_Varlist(), 
						list_List(term_Create(VarY, list_Nil()))), list_List(OutTerm) ) 
		); /* Ey( R(x, y) /\ Qp(y) ) */
		return OutTerm;
	}
	else {
		eml_Error("No case for in eml_AxiomTranslation"); return NULL;
	}
}

static LIST eml_ListAddTerm(TERM AddedTerm, LIST AddeeList) 
/**************************************************************
  SUMMARY: Adds Term to the list, and returns the now bigger list 
***************************************************************/
{
	if (list_Empty(AddeeList)) {
		AddeeList = list_List(AddedTerm);
	} else {
		AddeeList = list_Cons(AddedTerm, AddeeList);
	}	
	return AddeeList;
}
static LIST eml_ListAddList(LIST AddedList, LIST AddeeList) 
/************************************************************** 
  SUMMARY: Adds AddedList to AddeeList, and return AddeeList
***************************************************************/
{
	if (list_Empty(AddeeList)) {
		AddeeList = AddedList;
	} else {
		AddeeList = list_Nconc(AddeeList, AddedList);
	}
	return AddeeList;
}

static TERM eml_EliminateModals (TERM Term, BOOL *Changed)
/**************************************************************
  SUMMARY: 	eliminate some modal formulae in input TERM, returns modified TERM
  			[]true=true ... 	[]false=false
  			<>false=false ...	[]false=false (the same case in recursion)
  			Note this conversion has to be applied inside out
 **************************************************************/
{
	SYMBOL Top;

	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	} 
	Top = term_TopSymbol(Term);

	if (symbol_IsPredicate(Top)) { /* terminate recursion  */
		return Term;
	}
	
	if ( eml_IsBoxSymbol(Top) /* [](r,p) */
			&& eml_IsNotSymbol(term_TopSymbol(term_SecondArgument(Term))) /* [] */
	) { /* []false */
		if ( eml_IsFalseSymbol(term_TopSymbol(term_FirstArgument(term_SecondArgument(Term)))) ) { /* no lazy && */
			Term = term_SecondArgument(term_Copy(Term)); /* false */

			*Changed = TRUE;
			Term = eml_EliminateModals(Term, Changed); /* Recurse */
		} else {
			LIST Scan;
			for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
				list_Rplaca(Scan, (POINTER)eml_EliminateModals((TERM)list_Car(Scan), Changed));
			}	
		}
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan, (POINTER)eml_EliminateModals((TERM)list_Car(Scan), Changed));
		}
	}
	
	return Term;
}

static TERM eml_EliminateDiamond (TERM Term, BOOL *Changed)
/**************************************************************
  INPUT: TERM with or without Diamond Symbols
  RETURN: TERM without diamond symbols
  SUMMARY: <>p = []p.
 **************************************************************/
{
	SYMBOL Top;

	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}
	Top = term_TopSymbol(Term);

	if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return Term;
	} 

	if (eml_IsDiaSymbol(Top)) { 
		TERM TermtmpP = term_SecondArgument(Term); /* p */
		TERM TermtmpR = term_FirstArgument(Term); /* r */

		TermtmpP = eml_Negate(TermtmpP); /* p */
		TermtmpP = term_Create(eml_BOX, list_Cons(TermtmpR, list_List(TermtmpP))); /* [](r,p)) */ 
		Term = eml_Negate(TermtmpP); /* [](r,p)) */

		*Changed = TRUE;
		Term = eml_EliminateDiamond(Term, Changed); /* Recurse */
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan, (POINTER)eml_EliminateDiamond((TERM)list_Car(Scan), Changed)); 
		}
	}
	
	return Term;
}

static TERM eml_EliminateTrue (TERM Term, BOOL *Changed)
/**************************************************************
  INPUT: TERM with or without True Symbols. True has no arguments.
  RETURN: TERM without True symbols
  SUMMARY: true = not(false).
 **************************************************************/
{
	SYMBOL Top;

	Top = term_TopSymbol(Term); 
	if (eml_IsTrueSymbol(Top)) {
		Term = eml_Negate(term_Create(fol_False(), list_Nil()));
		*Changed = TRUE;
		return Term;
	}

	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	} else if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return Term;
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan, (POINTER)eml_EliminateTrue((TERM)list_Car(Scan), Changed));
		}
	}
	
	return Term;
}

static TERM eml_EliminateNotNot (TERM Term, BOOL *Changed) 
/**************************************************************
  INPUT: TERM, with or without repeated NOT NOT symbols
  RETURN: TERM without repeated NOT NOT symbols
  SUMMARY:   p = p.
 **************************************************************/
{
	SYMBOL Top, Top2;
	
	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}
	Top = term_TopSymbol(Term); /*  */
	
	if (symbol_IsPredicate(Top)) { /* terminate recursion  */
		return Term;
	}
	Top2 = term_TopSymbol(term_FirstArgument(Term)); /*  */
	
	if ( eml_IsNotSymbol(Top) && eml_IsNotSymbol(Top2) ) { /* notnot p*/
		Term = term_FirstArgument(Term); /* p */
		Term = term_FirstArgument(Term); /* p */
		
		*Changed = TRUE;
		Term = eml_EliminateNotNot(Term, Changed); /* Recurse */
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan, (POINTER)eml_EliminateNotNot((TERM)list_Car(Scan), Changed));
		}
	}
	
	return Term;
}

static TERM eml_EliminateNestedAnd (TERM Term, BOOL *Changed) 
/**************************************************************
  INPUT: TERM, with or without Nested And symbols
  RETURN: TERM without Nested And symbols
  SUMMARY:   /\(p,/\(a,b),q,p) = /\(p,a,b,q).
 **************************************************************/
{
	SYMBOL Top;
	
	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}
	Top = term_TopSymbol(Term); 
	
	if (symbol_IsPredicate(Top)) { /* terminate recursion  */
		return Term;
	}

	if ( eml_IsAndSymbol(Top) ) { 
		LIST Scan, List2 = list_Nil(), Scan2;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM AndTerm = (TERM)list_Car(Scan);
			if (eml_IsAndSymbol(term_TopSymbol(AndTerm))) {
				for (Scan2=term_ArgumentList(AndTerm); !list_Empty(Scan2); Scan2=list_Cdr(Scan2)) {
					TERM AndTerm2 = (TERM)list_Car(Scan2);
					if (!eml_ListContains(&List2, AndTerm2)) {
						List2 = eml_ListAddTerm(AndTerm2, List2);
					}
				}
				*Changed = TRUE;
			} else {
				if (!eml_ListContains(&List2, AndTerm)) {
					List2 = eml_ListAddTerm(AndTerm, List2);
				} else {
					*Changed = TRUE;
				}
			}
		}
		term_RplacArgumentList(Term, List2);
		List2 = list_NReverse(List2); /* could put a sorting function in here */
	}	
	
	{
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan, (POINTER)eml_EliminateNestedAnd((TERM)list_Car(Scan), Changed));
		}
	}
	
	return Term;
}

static TERM eml_EliminateBiImplication(TERM Term, BOOL *Changed) 
/**************************************************************
  INPUT: TERM, with or without BiImplication symbols
  RETURN: TERM without BiImplication symbols
  SUMMARY: (p<->q) = (p->q) /\ (p<-q) 
 **************************************************************/
{
	SYMBOL Top;

	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}
	Top = term_TopSymbol(Term);

	if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return Term;
	} 

	if (eml_IsEquivSymbol(Top)) { /* (p<->q) */
		TERM TermCopy = term_Copy(Term); /* (p<->q) */
		term_RplacTop(Term, fol_Implies()); /* (p->q) */
		term_RplacTop(TermCopy, fol_Implied()); /* (p<-q) */

		Term = term_Create(fol_And(),
				list_Cons(Term,	list_List(TermCopy))); /* (p->q) /\ (p<-q) */

		*Changed = TRUE;
		Term = eml_EliminateBiImplication(Term, Changed); /* Recurse */
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan,(POINTER)eml_EliminateBiImplication((TERM)list_Car(Scan), Changed));
		}
	}
	
	return Term;
}

static TERM eml_EliminateImplies(TERM Term, BOOL *Changed) 
/**************************************************************
  INPUT: TERM, with or without Implies symbols
  RETURN: TERM without Implies symbols
  SUMMARY: (p->q) = (p\/q)
 **************************************************************/
{
	SYMBOL Top;

	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}
	Top = term_TopSymbol(Term);

	if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return Term;
	} 

	if (eml_IsImpliesSymbol(Top)) { 
		TERM TermTmp1 = eml_Negate(term_FirstArgument(Term)); /* p */
		TERM TermTmp2 = term_SecondArgument(Term); /* q */
		Term = term_Create(fol_Or(), list_Cons(TermTmp1, list_List(TermTmp2))); /* (p\/q) */

		*Changed = TRUE;
		Term = eml_EliminateImplies(Term, Changed); /* Recurse */
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan, (POINTER)eml_EliminateImplies((TERM)list_Car(Scan), Changed));
		}
	}
	
	return Term;     
}

static TERM eml_EliminateImplied(TERM Term, BOOL *Changed) 
/**************************************************************
  INPUT: TERM, with or without Implied symbols
  RETURN: TERM without Implied symbols
  SUMMARY: (p<-q) = (q->p) 
 **************************************************************/
{
	SYMBOL Top;

	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}
	Top = term_TopSymbol(Term);

	if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return Term;
	} 

	if (eml_IsImpliedSymbol(Top)) { /* (p<-q) */ 
		term_RplacTop(Term, fol_Implies()); /* (p->q) */ 
		term_RplacArgumentList( Term, 
				list_Cons( term_SecondArgument(Term), list_List(term_FirstArgument(Term)) ) ); /* (q->p) */

		*Changed = TRUE;
		Term = eml_EliminateImplied(Term, Changed); /* Recurse */
	} else { /* TopSymbol wasn't Implied */
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan,(POINTER)eml_EliminateImplied((TERM)list_Car(Scan), Changed));
		}
	}
	
	return Term;
}

static TERM eml_EliminateOr(TERM Term, BOOL *Changed) 
/**************************************************************
  INPUT: TERM, with or without OR symbols
  RETURN: TERM without OR symbols; works with ternary, etc.
  SUMMARY:  (p\/q) = (p/\q)
  			(a \/ b)           = (a /\ b),
  			(a \/ b \/ c)      = (a /\ b /\ c),
  			(a \/ b \/ c \/ d) = (a /\ b /\ c /\ d), etc
 **************************************************************/ 
{
	SYMBOL Top;

	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}
	Top = term_TopSymbol(Term);

	if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return Term;
	} 

	if (eml_IsOrSymbol(Top)) { /* allows for more than 2 arguments */ 
		LIST Scan, NewList = list_Nil(); 

		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM newTerm = eml_Negate(term_Copy((TERM)list_Car(Scan))); /* avoid cyclic lists !!*/
			NewList = eml_ListAddList(list_List(newTerm), NewList);
		}
		term_RplacArgumentList(Term, NewList); 
		term_RplacTop(Term, fol_And());
		Term = eml_Negate(Term);

		*Changed = TRUE;
		Term = eml_EliminateOr(Term, Changed); /* Recurse */
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan,(POINTER)eml_EliminateOr((TERM)list_Car(Scan), Changed));
		}
	}
	
	return Term;
}		

static TERM eml_EliminateBoxAnd(TERM Term, BOOL *Changed) 
/**************************************************************
  INPUT: 
  RETURN: 
  SUMMARY: 	[](p/\q) <-> []p /\ []q		search for []/\()
  	 	This needs to be run until there is no futher Changed
  	And needs to be processed with eml_EliminateNotNot()
 **************************************************************/
{ /* recursion has been modified here - any change must prompt a restart */
	SYMBOL Top;
	if(!term_IsComplex(Term)) { /* terminate with no change */
		return Term;
	}
	Top = term_TopSymbol(Term);
	if (symbol_IsPredicate(Top)) { /* terminate with no change */
		return Term;
	} 

	if (eml_IsBoxSymbol(Top)) {  /* [](r,P) */
		SYMBOL Top2 = term_TopSymbol(term_SecondArgument(Term)); /* Top(P) */
		if (eml_IsAndSymbol(Top2)) { /* []/\(...,...) */
			TERM R = term_FirstArgument(Term); /* r */
			LIST Scan;
			Term = term_SecondArgument(Term); /* /\(...,...) */
			for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
				list_Rplaca(Scan,(POINTER)term_Create(eml_Box(), list_Cons(R, list_List((TERM)list_Car(Scan)))));
			}
			*Changed = TRUE; /* /\([](...),[](...)) */
		} else { /* descend for [] general case */
			LIST Scan;
			for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
				list_Rplaca(Scan,(POINTER)eml_EliminateBoxAnd((TERM)list_Car(Scan), Changed));
			}
		}
	} else { /* handle and & not */
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan,(POINTER)eml_EliminateBoxAnd((TERM)list_Car(Scan), Changed));
		}
	}
	
	return Term;
}

static TERM eml_NegateElimNotNot(TERM Term) 
/**************************************************************
  INPUT: TERM
  RETURN: negated TERM, with eml_EliminateNotNot() wrapper
 **************************************************************/ 
{
	BOOL Changed = FALSE;
	Term =  eml_Negate(Term);
	Term =  eml_EliminateNotNot(Term, &Changed);
	
	return Term;
}

static TERM eml_Negate(TERM Term) 
/**************************************************************
  INPUT: TERM
  RETURN: negated TERM
 **************************************************************/ 
{
	Term =  term_Create(fol_Not(), list_List(Term));
	return Term;
}		

static TERM eml_AxiomaticStd (TERM Term) 
/**************************************************************
  INPUT: A raw TERM
  Eliminates everthing except NOT & AND & BOX
  RETURN: A TERM formulated in a standard manner, with
          (1) bi-implication eliminated
          (2) implied eliminated
          (3) implies eliminated
          (4) OR eliminated
          (5) Diamond eliminated in favor of NotBoxNot
          (6) NotNot eliminated
          Note: the order in which these are preformed is critical to sucess.
  SUMMARY: May rebuild this as a recursive stack, if it proves to be a bottleneck.
 **************************************************************/
{
	BOOL Changed = FALSE;
	Term = eml_RemoveTrivialAtomsAndOps(Term); /* from Renate */
	Term = eml_SimplifyQuantors(Term); /* from Renate */
		
	Term = eml_EliminateDiamond(Term, &Changed); 
	Term = eml_EliminateTrue(Term, &Changed); 
	{
		do {  
			Changed = FALSE;
			Term = eml_EliminateModals(Term, &Changed);
			Term = eml_EliminateNotNot(Term, &Changed);
		} while (Changed == TRUE); 
	}

	Term = eml_EliminateBiImplication(Term, &Changed); 
	Term = eml_EliminateImplied(Term, &Changed);       
	Term = eml_EliminateImplies(Term, &Changed);       
	Term = eml_EliminateOr(Term, &Changed);            
	Term = eml_EliminateNotNot(Term, &Changed);
	
	{ /* standardize the format of the Term even further */
		do  { 
			Changed = FALSE;
			Term = eml_EliminateBoxAnd(Term, &Changed);
			Term = eml_EliminateNotNot(Term, &Changed);
		} while (Changed == TRUE);
	}
	
	{ /* standardize the format of the Term even further */
		do  { 
			Changed = FALSE;
			Term = eml_EliminateNestedAnd(Term, &Changed);
			Term = eml_EliminateNotNot(Term, &Changed);
		} while (Changed == TRUE);
	}
	
	return Term;
}

static void eml_Print(const char *Str)
/**************************************************************
  SUMMARY:   Wrapper for printf. If user defines DoNotUsePrintStatements ON
  then this is not printed.
 ***************************************************************/
{
	if (HiddenOpt.DoNotUsePrintStatements == eml_OFF) {
		printf(Str);
	}
}
static void eml_PrintD(const char *Str, const int d)
/**************************************************************
  SUMMARY: as above, but now with an int argument. 
  This could be done with a sort of function overloading 
  in which the Str is scanned for the presence of %d (or other markers)
  and then the appropriate helper function called to process a variable number of
  arguments in the arguemnt list. 
  However, this technique is considered unsafe unless essential.
  It is how printf(char*, ...) works in the first place.
  Function overloading in C++ appears to work in the way implememnted here - 
  a small variation of the function name is created according to the argument
  type(s) - only here it is is done manually and in C++ the complier does it for you. 
 ***************************************************************/
{
	if (HiddenOpt.DoNotUsePrintStatements == eml_OFF) {
		printf(Str, d);
	}
}
static void eml_PrintS(const char *Str, const SYMBOL symbol)
/**************************************************************  
  SUMMARY: As above, this time guarded wrapper for SYMBOL printing.
 ***************************************************************/
{
	if (HiddenOpt.DoNotUsePrintStatements == eml_OFF) {
		printf(Str);
		symbol_Print(symbol);
	}
}
static void eml_PrintDS(const char *Str, const int d, const SYMBOL symbol)
/**************************************************************  
  SUMMARY: As above, this time guarded wrapper for integer %d and SYMBOL printing.
 ***************************************************************/
{
	if (HiddenOpt.DoNotUsePrintStatements == eml_OFF) {
		printf(Str, d);
		symbol_Print(symbol);
	}
}
static void eml_PrintT(const char *Str, const TERM Term)
/**************************************************************  
  SUMMARY: As above, this time guarded wrapper for TERM printing.
 ***************************************************************/
{
	if (HiddenOpt.DoNotUsePrintStatements == eml_OFF) {
		printf(Str);
		fol_PrintDFG(Term);  /* prints in prefix notation */
		/* term_Print(Term);  prints in internal format */
	}
}
static void eml_PrintDT(const char *Str, const int d, const TERM Term)
/**************************************************************  
  SUMMARY: As above, this time guarded wrapper for integer %d & TERM printing.
 ***************************************************************/
{
	if (HiddenOpt.DoNotUsePrintStatements == eml_OFF) {
		printf(Str, d);
		fol_PrintDFG(Term);  /* prints in prefix notation */
		/* term_Print(Term);  prints in internal format */
	}
}
static void eml_Error(const char *Str)
/**************************************************************
  SUMMARY:wrapper for misc_Error(), adding print statements, to standard
         (not error) stream. 
 ***************************************************************/
{
	printf("\nError: "); printf(Str); printf("\n"); eml_Flush(); misc_Error();
}
static void eml_ErrorD(const char *Str, const int d)
/**************************************************************
  SUMMARY:wrapper for misc_Error(), adding print statements, to standard
         (not error) stream, with integer as %d in Str. 
 ***************************************************************/
{
	printf("\nError: "); printf(Str, d); printf("\n"); eml_Flush(); misc_Error();
}
static void eml_ErrorC(const char *Str, const char *Str2)
/**************************************************************
  SUMMARY:wrapper for misc_Error(), adding print statements, to standard
         (not error) stream, with seperate Str2
 ***************************************************************/
{
	printf("\nError: "); printf(Str); printf(Str2); printf("\n"); eml_Flush(); misc_Error();
}

static void eml_TermLengthHelper(const TERM Term, int *Length) 
/**************************************************************
  SUMMARY: Counts the number of Symbols in input Term, returning it through a pointer.
 ***************************************************************/
{
	LIST Scan;
	(*Length)++;

	if (!term_IsComplex(Term)) { /* terminate recursion */
		return;
	} 
	if (symbol_IsPredicate(term_TopSymbol(Term))) { /* terminate recursion */
		return;
	}

	for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
		eml_TermLengthHelper((TERM)list_Car(Scan), Length); /* Recurse */
	}

	return;
}
static int eml_TermLength(const TERM Term) 
/**************************************************************
  SUMMARY:  Counts the number of Symbols in input Term.
   			To be multiplied (in calling function) by symbol__SYMBOLMAXLEN.
            using ... Length = Length * symbol__SYMBOLMAXLEN;
  A facade for a recursive helper (eml_TermLengthHelper). 
 ***************************************************************/
{
	int Length = 0;
	eml_TermLengthHelper(Term, &Length);

	return Length;
}

static BOOL eml_SimpleTermEqual(const TERM Term1, const TERM Term2)
/**************************************************************
  INPUT:   Two Terms.
  RETURNS: TRUE if two terms are identical, else FALSE
  SUMMARY: This function creates a String representation of the 
          two terms and then compares them.
 ***************************************************************/
{
	int Length1 = (sizeof(char) * eml_TermLength(Term1) * symbol__SYMBOLMAXLEN) + 1;
	int Length2 = (sizeof(char) * eml_TermLength(Term2) * symbol__SYMBOLMAXLEN) + 1;
	char *Name1, *Name2;

	if ( (!symbol_Equal(term_TopSymbol(Term1), term_TopSymbol(Term2))) /* check Top Symbols */
		|| (Length1 != Length2)	) { /* check lengths */
		return FALSE;
	}
	
	Name1 = memory_Malloc(Length1);
	Name2 = memory_Malloc(Length2);
	if ( (Name1 == NULL) || (Name2 == NULL) ) {
		eml_Error("malloc error in eml_TermEqual. No space left.");
	}
	Name1[0] = '\0'; Name2[0] = '\0';

	/* no sorting */
		eml_TermName(Term1, Name1);
		eml_TermName(Term2, Name2);
	
	if (strcmp(Name1,Name2) != 0) {
		return FALSE;
	}
	
    string_StringFree(Name1);    string_StringFree(Name2);
    
	return TRUE; /* fall through */
}
static TERM eml_SortAnds (TERM Term) 
/**************************************************************
  INPUT: TERM, with or without Sorted And symbols
  RETURN: TERM with Sorted And Sysmbols symbols
 **************************************************************/
{
	BOOL Changed = FALSE;
	TERM Mod = term_Copy(Term);
	do {  
		TERM Before = term_Copy(Mod);
		TERM SortedTerm = eml_TermNameSort(term_Copy(Mod));
		Changed = FALSE;
		if (eml_SimpleTermEqual(Before, SortedTerm)==FALSE) {
			Mod = term_Copy(SortedTerm);
			Changed = TRUE;
		}		
	} while (Changed == TRUE);
	
	return Mod;
}

static LIST eml_SortTermList(LIST List)
/**************************************************************
  INPUT: A List of Terms to be sorted based on String comparison of the names
  SUMMARY: wrapper for list_MergeSort, producing sorted List
 ***************************************************************/
{
	LIST OutList = list_MergeSort(List, (BOOL (*) ())eml_TermNameTest);
	/* from ... LIST list_MergeSort (LIST L, BOOL (*Test) (POINTER, POINTER) */
	
	return OutList;
}

static BOOL eml_TermNameTest (POINTER Ptr1, POINTER Ptr2)
/**************************************************************
  INPUT: POINTERs are TERMs.
  RETURNS: TRUE if Str1 is less/equal than Str2 (Ptr1 <= Ptr2) 
  SUMMARY: compares two Terms according to their names
 ***************************************************************/
{
	/* int strcmp(const char *string1, const char *string2); 
	    Compares string1 and string2	   
	    Returns less than 0 if string1 is less than string2
	    Returns equal to 0 if string1 is equal to string2
	    Returns greater than 0 if string1 is greater than string2
	 */
	BOOL OutBool;
	TERM Term1 = (TERM) Ptr1;
	TERM Term2 = (TERM) Ptr2;
	int Lterm1 = (sizeof(char) * eml_TermLength(Term1) * symbol__SYMBOLMAXLEN ) + 1;
	int Lterm2 = (sizeof(char) * eml_TermLength(Term2) * symbol__SYMBOLMAXLEN ) + 1;
	char *Str1 = (char *) malloc(Lterm1);
	char *Str2 = (char *) malloc(Lterm2);
	if ( (Str1 == NULL) || (Str2 == NULL) ) {
		eml_Error("In routine eml_TermNameTest - malloc unrecoverable failure");
	}
	Str1[0] = '\0';	Str2[0] = '\0'; 
	eml_TermName(Term1, Str1);
	eml_TermName(Term2, Str2);

	if ( strcmp(Str1, Str2) < 0 ) { /* TODO < or <= */
		OutBool = TRUE;
	} else {
		OutBool = FALSE;
	}
	/* HouseKeeping */
	free(Str1); free(Str2);	/*string_StringFree(Str1); string_StringFree(Str2);*/
	return OutBool;
}

static void eml_OptTermName(TERM Term, char *str)
/**************************************************************
  INPUT: Term. The String should be pre-intialised according to eml_TermLength()
		char *str = (char *) malloc((eml_TermLength((TERM)list_Car(Scan)) * symbol__SYMBOLMAXLEN ) + 1);
		if (str == NULL) {
			fprintf(stderr, "\n malloc unrecoverable failure. \n"); misc_Error();
		} str[0] = '\0';
  This routine is optimized so that ANDed Terms are re-ordered in a standard fashion before Naming
  RETURNS:Name of Term. Modifies str, so usually the return string is ignored
 ***************************************************************/
{
	/* TERM SortedTerm = eml_TermNameSort(term_Copy(Term)); */
	TERM SortedTerm = eml_SortAnds(term_Copy(Term));
	
	if ( HiddenOpt.DoNotSortTermNames == eml_ON ) { /* no sorting */
		eml_Error("Internal error: Term sorting appears to have been called inappropriately.");
	}
	eml_TermName(SortedTerm, str);
}

static TERM eml_TermNameSort(TERM Term)
/**************************************************************
 SUMMARY: Sorts the Argument List of 'AND' Term/SubTerm of the input TERM
 ***************************************************************/
{
	SYMBOL Top;

	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}

	Top = term_TopSymbol(Term);

	if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return Term;
	} 

	if (eml_IsAndSymbol(Top)) { /* allows for more than 2 arguments */ 
		LIST SortingList = term_ArgumentList(Term), Scan; 
		SortingList = eml_SortTermList(SortingList);
		term_RplacArgumentList(Term, SortingList);
		
		/* Term = eml_TermNameSort(Term); */ /* Recurse */
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) { 
			list_Rplaca(Scan,(POINTER)eml_TermNameSort((TERM)list_Car(Scan)));
		}
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) { 
			list_Rplaca(Scan,(POINTER)eml_TermNameSort((TERM)list_Car(Scan)));
		}
	}
	
	return Term;
}

static void eml_TermName(TERM Term, char *str)
/**************************************************************
  INPUT: Term. The String should be pre-intialised according to eml_TermLength().
  For example: 
  		char *str = (char *) malloc((eml_TermLength((TERM)list_Car(Scan)) * symbol__SYMBOLMAXLEN ) + 1);
		if (str == NULL) {
			fprintf(stderr, "\n malloc unrecoverable failure. \n"); misc_Error();
		} str[0] = '\0';		
  RETURNS:Name of Term. Modifies str, so usually the return string is ignored
 ***************************************************************/
{
	if (term_IsComplex(Term)) {
		LIST Scan;
		eml_SymbolNameHelper(term_TopSymbol(Term), str); /* helper */
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			eml_TermName(list_Car(Scan), str); /* recurse */
		}
	} else if (term_IsVariable(Term)) {
		eml_SymbolNameHelper(term_TopSymbol(Term), str); /* helper */
	} else if(term_IsConstant(Term)) {
		eml_SymbolNameHelper(term_TopSymbol(Term), str); /* helper */
	} else { /* catch all = error */
		eml_Error("In routine eml_TermName no case for term.");
	}
}
static void eml_SymbolNameHelper (SYMBOL Symbol, char* str) 
/**************************************************************
  RETURNS: Modifies str, so usually the return string is ignored
  SUMMARY: Helper for eml_TermName(). Provides a name for the Symbol
  REF:  Modified from symbol_Print.
 ***************************************************************/
{
	if (str[0] != '\0')  { /* if string already has contents */
		strcat(str, "_");
	}

	if (eml_IsNullSymbol(Symbol)) {
		strcat(str, "NULL");
	} else if (symbol_IsVariable(Symbol)) {
		SYMBOL NormSymbol = symbol_NormVar(Symbol);

		if (symbol_IsStandardVariable(Symbol)) {
			/*char *str2 = symbol_GetSymbolSTDVARIABLENAMES(NormSymbol-1); strcat(str, str2);*/
			strcat(str, symbol_GetSymbolSTDVARIABLENAMES(NormSymbol-1));
		} else if (symbol_IsIndexVariable(Symbol)) { /* I1, I2, I3, ... */
			char str1[symbol__SYMBOLMAXLEN+1]; /* used for index, so symbol__SYMBOLMAXLEN characters plenty */ 
			sprintf(str1, "%d", NormSymbol);
			strcat(str, str1);
		}
	} else if (symbol_SignatureExists()) {
		/*char *str2 = symbol_Name(Symbol); strcat(str, str2);*/
		strcat(str, symbol_Name(Symbol));
	} else {
		char str1[symbol__SYMBOLMAXLEN+1]; /* used for index, so symbol__SYMBOLMAXLEN characters plenty */ 
		sprintf(str1, "%d", Symbol);
		strcat(str, str1);
	}
	
}

static int eml_TermCompare(const TERM Term1, const TERM Term2)
/**************************************************************
  INPUT:   Two Terms.
  RETURNS: compares terms by string comparison
  SUMMARY: This function creates a String representation of the 
          two terms and then compares them.
 ***************************************************************/
{
	int Length1 = (sizeof(char) * eml_TermLength(Term1) * symbol__SYMBOLMAXLEN) + 1;
	int Length2 = (sizeof(char) * eml_TermLength(Term2) * symbol__SYMBOLMAXLEN) + 1;
	char *Name1, *Name2;
	int returnValue = 0;
	
	Name1 = memory_Malloc(Length1);
	Name2 = memory_Malloc(Length2);
	if ( (Name1 == NULL) || (Name2 == NULL) ) {
		eml_Error("malloc error in eml_TermEqual. No space left.");
	}
	Name1[0] = '\0'; Name2[0] = '\0';

	if ( HiddenOpt.DoNotSortTermNames == eml_OFF ) { /* sorting on */
		eml_OptTermName(Term1, Name1);  /* eml_OptTermName or eml_TermName */
		eml_OptTermName(Term2, Name2);  /* eml_OptTermName or eml_TermName */
	} else { /* no sorting */
		eml_TermName(Term1, Name1);
		eml_TermName(Term2, Name2);
	}

	returnValue = strcmp(Name1,Name2);
	string_StringFree(Name1);    string_StringFree(Name2);
	return returnValue;
}

static BOOL eml_TermEqual(const TERM Term1, const TERM Term2)
/**************************************************************
  INPUT:   Two Terms.
  RETURNS: TRUE if two terms are identical, else FALSE
  SUMMARY: This function creates a String representation of the 
          two terms and then compares them.
 ***************************************************************/
{
	int Length1 = (sizeof(char) * eml_TermLength(Term1) * symbol__SYMBOLMAXLEN) + 1;
	int Length2 = (sizeof(char) * eml_TermLength(Term2) * symbol__SYMBOLMAXLEN) + 1;
	char *Name1, *Name2;

	if ( (!symbol_Equal(term_TopSymbol(Term1), term_TopSymbol(Term2))) /* check Top Symbols */
		|| (Length1 != Length2)	) { /* check lengths */
		return FALSE;
	}
	
	Name1 = memory_Malloc(Length1);
	Name2 = memory_Malloc(Length2);
	if ( (Name1 == NULL) || (Name2 == NULL) ) {
		eml_Error("malloc error in eml_TermEqual. No space left.");
	}
	Name1[0] = '\0'; Name2[0] = '\0';

	if ( HiddenOpt.DoNotSortTermNames == eml_OFF ) { /* sorting on */
		eml_OptTermName(Term1, Name1);  /* eml_OptTermName or eml_TermName */
		eml_OptTermName(Term2, Name2);  /* eml_OptTermName or eml_TermName */
	} else { /* no sorting */
		eml_TermName(Term1, Name1);
		eml_TermName(Term2, Name2);
	}

	if (strcmp(Name1,Name2) != 0) {
		return FALSE;
	}
	/* HouseKeeping */
    string_StringFree(Name1);    string_StringFree(Name2);
    
	return TRUE; /* fall through */
}

static BOOL eml_ListContains (const LIST *List, TERM Term) 
/**************************************************************
  INPUT: List of Terms, Term to be searched for.
  RETURNS: Loops through List of Terms, 
  		  and returns TRUE if Term already in List, else FALSE.
  		  In addition it does a check for the R modality index
 ***************************************************************/
{
	BOOL Contains = FALSE;
	LIST Scan;
	for (Scan=*List; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
		if ( eml_TermEqual(Term, (TERM)list_Car(Scan) ) == TRUE ) {
			Contains = TRUE;
		}
	}
	
	return Contains;
}

static void eml_GetDEFUnits(AXIOMDEFLIST *DEFs) 
/**************************************************************
  INPUT: Standardized Term *within* the AXIOMDEFLIST. 
  RETURNS: List of Def Units, and LISTs populated *within* the AXIOMDEFLIST.
  SUMMARY: 
 ***************************************************************/
{
	/* Just be sure that these are empty */
	(*DEFs).BoxDef = list_Nil();
	(*DEFs).SubDef = list_Nil();
	(*DEFs).SuperDef = list_Nil();
	(*DEFs).XtraBoxDef = list_Nil();
	(*DEFs).CompositionList = list_Nil();

	eml_GetDEFUnitsHelper((*DEFs).Term, DEFs); /* populate DEFs units */

	{ /* print routines */
		int i = 0;
		LIST Scan; /* a concatenated LIST of all Def Terms */

		eml_Print("\n[Axiomatic Translation Def Units]");
		for (Scan=eml_AxiomDEFListConc(DEFs, eml_ALL); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			i++;
			eml_PrintDT("\nDEFUNITS %d :",i,(TERM)list_Car(Scan));
		}
	}
	
	return;
}
static void eml_GetDEFUnitsHelper(TERM Term, AXIOMDEFLIST *DEFs) 
/**************************************************************
  INPUT: Standardized Term *within* AXIOMDEFLIST from eml_GetDEFUnits().
  RETURNS: List of Def Units
  SUMMARY: 	the structure of the list returned is ... e.g. with BoxDefs
	   		shortest box term,	next to shortest box term, etc ...
	   		then, longesttest box term
	DEFs.BoxDef ... is a list of Box pointers.
	DEFs.SubDef ...  is a list of pointers to predicates. 
	DEFs.SuperDef ... is a list of the rest.
	The possible standardized inputs are 
		box(r,'p') ... r is a dummy
		and('p','q')
		'p'		... and ...
		not (box(r,'p') 
		not (and('p','q')
		'not p' 
 ***************************************************************/
{
	SYMBOL Top = term_TopSymbol(Term);

	if (eml_IsBoxSymbol(Top)) { /* [] */
		LIST *BoxDef = &((*DEFs).BoxDef);
		if (!eml_ListContains(BoxDef, Term)) {
			if (*BoxDef == NULL) {
				*BoxDef = list_List(term_Copy(Term));
			} else {
				*BoxDef = list_Cons(term_Copy(Term), *BoxDef);
			}
		}
	} else if (symbol_IsPredicate(Top)) { /* p */
		LIST *SubDef = &((*DEFs).SubDef); 
		if (!eml_ListContains(SubDef, Term)) {
			if (*SubDef == NULL) {
				*SubDef = list_List(term_Copy(Term));
			} else {
				*SubDef = list_Cons(term_Copy(Term), *SubDef);
			}
		}
	} else if (eml_IsAndSymbol(Top)) { /* /\ */
		LIST *SuperDef = &((*DEFs).SuperDef);
		if(!eml_ListContains(SuperDef, Term)) {
			if (*SuperDef == NULL) {
				*SuperDef = list_List(term_Copy(Term));
			} else {
				*SuperDef = list_Cons(term_Copy(Term), *SuperDef);
			}
		}
	} else if ( eml_IsNotSymbol(Top) ) { /* Not series */
		if (HiddenOpt.IncludeNegativeDefs == eml_ON) {
			LIST *SuperDef = &((*DEFs).SuperDef);
			if(!eml_ListContains(SuperDef, Term)) {
				if (*SuperDef == NULL) {
					*SuperDef = list_List(term_Copy(Term));
				} else {
					*SuperDef = list_Cons(term_Copy(Term), *SuperDef);
				}
			}
		}
	} else {
		eml_Error("No case in eml_GetDEFUnitsHelper");
	}

	if (eml_IsBoxSymbol(Top)) { /* recurse */
		/* There will be two arguments, the first of which is the dummy, and should be ignored */
		eml_GetDEFUnitsHelper(term_SecondArgument(Term), DEFs);
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			eml_GetDEFUnitsHelper((TERM)list_Car(Scan), DEFs);
		}
	}
	
    return;
}

static LIST eml_DEF (TERM Def, SYMBOL VarX, SYMBOL VarY, 
	    BOOL WithShortCut, FLAGSTORE Flags, PRECEDENCE Precedence) 
/**************************************************************
  SUMMARY: Creates a function of the form below (for each individual DEF term)
  Ax(Qp(x) -> PI(p, x))	/\	Ax(Qp(x) -> Qp(x))	/\	Ax(Qp(x)-> PI(p, x)) 
  Note:	PredSymbol = Qp		NegPredSymbol = Qp 
 ***************************************************************/
{
	TERM FirstTerm, ThirdTerm = NULL; 
	LIST OutList = list_Nil();
	SYMBOL PredSymbol = eml_CreateAxiomSymbol(Def, eml_AXIOM, 1, symbol_STATLEX, Precedence);  
	SYMBOL NegPredSymbol = eml_CreateAxiomSymbol(eml_NegateElimNotNot(Def), eml_AXIOM, 1, symbol_STATLEX, Precedence); 

	if (eml_ListContains(&AlreadyDEFinedList,Def)==TRUE) { /* avoid any duplicates */
		return list_Nil();
	}
	
	/* Build Second DEF Term and Second Reversed DEF Term - positive shortcut */
	OutList =  eml_SimpleDEF(Def, VarX, VarY, WithShortCut, Flags, Precedence);
		
	/* Build First DEF Term */
	FirstTerm = term_Create(fol_Implies(), 
			list_Cons(term_Create(PredSymbol, list_List(term_Create(VarX, list_Nil()))),
					list_List(eml_AxiomaticTranslation(term_Copy(Def), VarX, VarY, Flags, Precedence)
	)));
	FirstTerm = eml_QuantifyTerm(fol_All(), FirstTerm,
		list_List(term_Create(VarX, list_Nil())));
		
	OutList = list_Cons(FirstTerm, OutList);
	eml_PrintT("\n1stTERM = ", FirstTerm); 
	
	/* Build Third DEF Term */
	ThirdTerm = term_Create(fol_Implies(), 
			list_Cons(term_Create(NegPredSymbol, list_List(term_Create(VarX, list_Nil()))),
					list_List(eml_AxiomaticTranslation(
							eml_NegateElimNotNot(term_Copy(Def)), VarX, VarY, Flags, Precedence)
	)));
	ThirdTerm = eml_QuantifyTerm(fol_All(), ThirdTerm,
			list_List(term_Create(VarX, list_Nil())));
	OutList = list_Cons(ThirdTerm, OutList);
	eml_PrintT("\n3rdTERM = ", ThirdTerm); 
	
	return OutList;
}

static LIST eml_SimpleDEF (TERM Def, SYMBOL VarX, SYMBOL VarY, 
	    BOOL WithShortCut, FLAGSTORE Flags, PRECEDENCE Precedence) 
/**************************************************************
  SUMMARY: Creates a function of the form below (for each individual DEF term)
         Ax(Qp(x) -> Qp(x))
  (This is identical for either true or false)
 ***************************************************************/
{
	LIST OutList = list_Nil();
	TERM SecondTerm, SecondTermRev = NULL; 
	
	if (eml_ListContains(&AlreadyDEFinedList,Def)==TRUE) { /* avoid any duplicates */
			return list_Nil();
	}
	eml_PrintT("\nTranslation of DEF = ", Def);

	if (eml_TestFalse(Def) == TRUE) { /* special case */
		SYMBOL NegPredSymbol = eml_CreateAxiomSymbol(eml_NegateElimNotNot(Def),	eml_AXIOM, 1, symbol_STATLEX, Precedence);

		/* Build Second DEF Term */
		SecondTerm = term_Create(fol_Implies(), list_Cons(term_Create(fol_False(), list_Nil()),
				list_List(eml_NegateElimNotNot(term_Create(NegPredSymbol,
						list_List(term_Create(VarX, list_Nil()))))) 
		));
		if (WithShortCut == TRUE) {	/* Build Second Reversed DEF Term - Positive Shortcut */
			SecondTermRev = term_Create(fol_Implied(), list_Cons(term_Create(fol_False(), list_Nil()),
					list_List(eml_NegateElimNotNot(term_Create(NegPredSymbol,
							list_List(term_Create(VarX, list_Nil()))))) 
		));
		}
	} else {
		SYMBOL PredSymbol = eml_CreateAxiomSymbol(Def, eml_AXIOM, 1, symbol_STATLEX, Precedence);  
		SYMBOL NegPredSymbol = eml_CreateAxiomSymbol(eml_NegateElimNotNot(Def), eml_AXIOM, 1, symbol_STATLEX, Precedence); 

		/* Build Second DEF Term */
		SecondTerm = term_Create(fol_Implies(), 
				list_Cons(term_Create(PredSymbol, list_List(term_Create(VarX, list_Nil()))),
						list_List(eml_NegateElimNotNot(term_Create(NegPredSymbol, 
								list_List(term_Create(VarX, list_Nil())))))
		));
		if (WithShortCut == TRUE) {
			/* Build Second Reversed DEF Term - Positive Shortcut */
			SecondTermRev = term_Create(fol_Implied(), 
					list_Cons(term_Create(PredSymbol, list_List(term_Create(VarX, list_Nil()))),
							list_List(eml_NegateElimNotNot(term_Create(NegPredSymbol, 
									list_List(term_Create(VarX, list_Nil())))))
		));
		}
	}	
	SecondTerm = eml_QuantifyTerm(fol_All(), SecondTerm,
		list_List(term_Create(VarX, list_Nil()))	);
	eml_PrintT("\n2ndTERM = ", SecondTerm); 

	if (WithShortCut == TRUE) {
		SecondTermRev = eml_QuantifyTerm(fol_All(), SecondTermRev,
					list_List(term_Create(VarX, list_Nil()))		);
		eml_PrintT("\n2ndTERMSC = ", SecondTermRev); 
	}

	OutList = list_List(SecondTerm);
	if (WithShortCut == TRUE) {
		OutList = list_Cons(SecondTermRev, OutList);
	}
	AlreadyDEFinedList = eml_ListAddTerm(term_Copy(Def), AlreadyDEFinedList); /* avoid any duplicates */
	return OutList;
}

static void eml_SetAxiomSymbol(char *Name, SYMBOL *Symbol, TERM Term, eml_SYMBOLTYPE Type)
/******************************************************* 
  SUMMARY: Records new Symbols in the eml_AxiomSymbolList[]
 ********************************************************/
{
	AXIOMSYMBOL AxiomSymbol;

	if (eml_INDEXAXIOMSYMBOL >= eml__MAXNOAXIOMSYMBOL) {
		eml_Error("Exceeded Max. No Created Axiom Symbols.");
	}

	AxiomSymbol.Name = (char *) memory_Malloc(strlen(Name) + 1); 
	if (AxiomSymbol.Name == NULL) {
		eml_Error("In routine eml_SetAxiomSymbol() - malloc unrecoverable failure.");
	}
	AxiomSymbol.Name[0] = '\0';

	strcpy(AxiomSymbol.Name, Name);
	AxiomSymbol.Symbol = *Symbol;
	AxiomSymbol.Term = term_Copy(Term);
	AxiomSymbol.Type = Type;
	AxiomSymbol.NegBox = list_Nil();
	AxiomSymbol.AccessCount = 0;
	eml_AxiomSymbolList[eml_INDEXAXIOMSYMBOL] = AxiomSymbol;
	eml_INDEXAXIOMSYMBOL++;
	
}

static SYMBOL eml_GetAxiomSymbol(const char *Name)
/******************************************************* 
  SUMMARY: Gets SYMBOL corresponding to Name, or SYMBOL__NULL if Symbol does not already exist
 ********************************************************/
{
	SYMBOL Symbol = symbol__NULL;
	BOOL Found = FALSE;

	{
		int i = 0;
		while ( (i < eml_INDEXAXIOMSYMBOL) && (Found == FALSE) ) {
			if ( strcmp(eml_AxiomSymbolList[i].Name, Name) == 0 ) {
				Symbol = eml_AxiomSymbolList[i].Symbol;
				Found = TRUE;
			}
			i++;
		}
	}
	return Symbol;
}

static SYMBOL eml_CreateAxiomSymbol(TERM Term, eml_SYMBOLTYPE SymbolType,
		int Arity, int Status, PRECEDENCE Precedence)
/*******************************************************
  INPUT: Modifies the SYMBOL pointer, and returns it as well
  SUMMARY: Create Axiom Symbol, Tied to a lookup to prevent symbol duplication.
 ********************************************************/
{
	SYMBOL Symbol = symbol__NULL;
	char NewName[symbol__SYMBOLMAXLEN], *TermName, *TmpStr; 
	BOOL LongSymbol = FALSE;
	BOOL Changed = FALSE;
	int MaxTermLength = 0, length;
	
	/* this is handled case-by-case elsewhere - returning false breaks the contract of this function */
	/* if (symbol_Equal(fol_False(), term_TopSymbol(Term))) {
		return fol_False();  / * Qfalse(x) = false; but Qtrue(x) = Qnot_false(x) * /
	} */
	
	NewName[0] = '\0';
	Term = eml_EliminateNotNot(Term, &Changed);

	/* get the Term Name */
	MaxTermLength = (sizeof(char) * eml_TermLength(Term) * symbol__SYMBOLMAXLEN) + strlen(eml_PREDNAMEPREFIX[SymbolType]) + 1;
	TermName = (char *) memory_Malloc(MaxTermLength); 
	length = (sizeof(char) * eml_TermLength(Term) * symbol__SYMBOLMAXLEN) + 1;
	TmpStr = (char *) memory_Malloc(length);
	if ( (TermName == NULL) || (TmpStr == NULL) ) {
		eml_Error("In routine eml_GetDEFUnits - malloc unrecoverable failure.");
	}
	TermName[0] = '\0'; TmpStr[0] = '\0';

	if ( HiddenOpt.DoNotSortTermNames == eml_OFF ) { /* sorting on */
		eml_OptTermName(Term, TmpStr); /* TODO this has been changed from eml_TermName */
	} else { /* no sorting */
		eml_TermName(Term, TmpStr);	
	}

	strcpy(TermName, eml_PREDNAMEPREFIX[SymbolType]); 
	strcat(TermName, TmpStr);
	
	if (strlen(TermName) > (symbol__SYMBOLMAXLEN - 1)) {
		LongSymbol = TRUE;
	}
	/* for Renate */
	if (HiddenOpt.AlwaysUseSubstitutedSymbolNames == eml_ON) {
		LongSymbol = TRUE;
	}
	
	/* lookup to prevent symbol duplication ... does the symbol already exist ? - if so get it */
	if (LongSymbol == FALSE) {
		Symbol = symbol_Lookup(TermName);	
	} else { /* LongSymbol == TRUE */
		Symbol = eml_GetAxiomSymbol(TermName);
	}

	/* symbol needs to be created */
	if (eml_IsNullSymbol(Symbol)) {
		if (LongSymbol == FALSE) {
			Symbol = symbol_CreatePredicate(TermName, Arity, Status, Precedence);
		} else { /* LongSymbol == TRUE */
			char Integer[31];
			Integer[0] = '\0';
			sprintf(Integer, "%d", eml_INDEXAXIOMSYMBOL); 
			strcpy(NewName, eml_PREDNAMEPREFIX[SymbolType]); 
			strcat(NewName, Integer);
			Symbol = symbol_CreatePredicate(NewName, Arity, Status, Precedence);
		}
		eml_SetAxiomSymbol(TermName, &Symbol, Term, SymbolType);
	}
	/* HouseKeeping */
	string_StringFree(TmpStr); /*memory_Free(TmpStr, length);*/
    
	return Symbol;
}

static SYMBOL eml_GetVar(int Index) 
/******************************************************
SUMMARY: population of and access to eml_AxiomVarStore[] 
		... [0]=VarX, [1]=VarY, [2]=VarZ, ... 
 ********************************************************/
{	
	if (Index > eml_SIZEAXIOMVARSTORE) {
		eml_Error("Index too large in eml_GetVar");
	}
	if (eml_IsNullSymbol(eml_AxiomVarStore[Index])) { /* populate if empty */
		eml_AxiomVarStore[Index] = symbol_CreateStandardVariable();
	}
	return eml_AxiomVarStore[Index];
}
                                                          
                                                          
static BOOL eml_SetPositiveShortcutHelper(AXIOM Axiom)
/******************************************************
  SUMMARY: determines whether shortcuts are optional for completeness
   at the current axiom, in context of the axiom stack 
   - Helper for eml_SetPositiveShortcut()
 ********************************************************/
{
	if (HiddenOpt.ExcludeOptionalPositiveShortcuts == eml_OFF) {
    	return TRUE; /* usually return TRUE; user can override to use only optional shortcuts */
    }
	if (HiddenOpt.NeverUsePositiveShortcuts) {
			return FALSE;
	}
	
    if ( (Axiom.AxiomType == FIVE)  /* +ve shortcut needed for K5 ans K5K */
    		|| (Axiom.AxiomType == FIVEK) ) {
    	return FALSE;
    } 
    else if (Axiom.AxiomType == T) { 
    	AXIOM Axiom2 = eml_GetAxiom(Axiom.Index + 1); 
    	if (Axiom2.AxiomType == FIVE) { /* +ve shortcut needed for KT5 */
    		return TRUE;
    	} else if (Axiom2.AxiomType == FOUR ) { /* +ve shortcut needed for KT4B */
    		AXIOM Axiom3 = eml_GetAxiom(Axiom.Index + 2);
    		if (Axiom3.AxiomType == B) {
    			return TRUE;
    		}
    	}
    }
    else if (Axiom.AxiomType == D) { /* +ve shortcut needed for KD4B */
    	AXIOM Axiom2 = eml_GetAxiom(Axiom.Index + 1);	
    	if (Axiom2.AxiomType == FOUR ) { /* +ve shortcut needed for KD4B */
    	 	AXIOM Axiom3 = eml_GetAxiom(Axiom.Index + 2);
			if (Axiom3.AxiomType == B) {
				return TRUE;
			}
    	}
       	return TRUE;
    }
    else if (Axiom.AxiomType == FOUR) { /* +ve shortcut needed for KT4B KD4B */
    	AXIOM Axiom2 = eml_GetAxiom(Axiom.Index - 1);
    	if ( (Axiom2.AxiomType == T) || (Axiom2.AxiomType == D)	){
    		AXIOM Axiom3 = eml_GetAxiom(Axiom.Index + 1);
    		if (Axiom3.AxiomType == B) {
    			return TRUE;
    		}
    	}
    }
    else if (Axiom.AxiomType == B) { /* +ve shortcut needed for KT4B KD4B */
    	AXIOM Axiom2 = eml_GetAxiom(Axiom.Index - 2);
    	   if ( (Axiom2.AxiomType == T) || (Axiom2.AxiomType == D)	){
    		   AXIOM Axiom3 = eml_GetAxiom(Axiom.Index - 1);
    		   if (Axiom3.AxiomType == 4) {
    	    		return TRUE;
    	    	}
    	   }
    }
    
	return TRUE; /* fall through */
}
static BOOL eml_SetPositiveShortcut()
/******************************************************
  SUMMARY: determines whether shortcuts are optional for completeness
   at the current axiom, in context of the axiom stack
 ********************************************************/
{
	BOOL SetPositiveShortcut = TRUE;
	int i;
	if (HiddenOpt.ExcludeOptionalPositiveShortcuts == eml_OFF) {
	   	return TRUE; /* usually return TRUE; user can override to use only optional shortcuts */
	} 
	if (HiddenOpt.NeverUsePositiveShortcuts) {
		return FALSE;
	}
	
	for (i = 1; i < AxiomCompositionIndex; i++) {
		if (eml_SetPositiveShortcutHelper(eml_GetAxiom(i)) == FALSE) {
			return FALSE;
		}
	}
	
	return SetPositiveShortcut;
}

static TERM eml_BubbleAnd(TERM Term, BOOL *Changed) 
/**************************************************************
  INPUT: 
  RETURN: 
  SUMMARY: 	[](p/\q) <-> []p /\ []q			search for []/\()
  			<>(p/\q)  -> <>p /\ <>q
  	This is used to create a basis for comparison
  	- and is not a generally valid trnalsformation
  	This need to be run until there is no futher Changed
  	And needs to be processed with eml_EliminateNotNot()
 **************************************************************/
{ /* recursion has been modified here - any change prompts a restart at the higher level */
	SYMBOL Top;
	if(!term_IsComplex(Term)) { /* terminate with no change */
		return Term;
	}
	Top = term_TopSymbol(Term);
	if (symbol_IsPredicate(Top)) { /* terminate with no change */
		return Term;
	} 

	if (eml_IsBoxSymbol(Top)) {  /* [](r,P) */
		SYMBOL Top2 = term_TopSymbol(term_SecondArgument(Term)); /* Top(P) */
		TERM R = term_FirstArgument(Term); /* r */
		if (eml_IsAndSymbol(Top2)) { /* []/\(...,...) */
			LIST Scan;
			Term = term_SecondArgument(Term); /* /\(...,...) */
			for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
				list_Rplaca(Scan,(POINTER)term_Create(eml_Box(), list_Cons(R, list_List((TERM)list_Car(Scan)))));
			}
			*Changed = TRUE; /* /\([](...),[](...)) */
		} else if (eml_IsNotSymbol(Top2)) {
			SYMBOL Top3 = term_TopSymbol(term_FirstArgument(term_SecondArgument(Term)));
			if (eml_IsAndSymbol(Top3)) { /* []/\(P,...) */
				LIST Scan;
				Term = term_SecondArgument(Term); /* /\(P,...) */
				Term = term_FirstArgument(Term); /* /\(P,...) */
				for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
					list_Rplaca(Scan,(POINTER)(eml_NegateElimNotNot(
						term_Create(eml_Box(), list_Cons(R, 
							list_List(eml_NegateElimNotNot((TERM)list_Car(Scan))))))));
				}
				Term = eml_NegateElimNotNot(Term);
				*Changed = TRUE;
			} else {
				LIST Scan;
				for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
					list_Rplaca(Scan,(POINTER)eml_BubbleAnd((TERM)list_Car(Scan), Changed));
				}
			}
		} else { /* descend for [] general case */
			LIST Scan;
			for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
				list_Rplaca(Scan,(POINTER)eml_BubbleAnd((TERM)list_Car(Scan), Changed));
			}
		}
	} else if (eml_IsNotSymbol(Top)) { 
		SYMBOL Top2 = term_TopSymbol(term_FirstArgument(Term));
		if (eml_IsAndSymbol(Top2)) { /* /\ = /\(, ) */
			LIST Scan;
			Term = term_FirstArgument(Term);
			for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
				list_Rplaca(Scan,(POINTER)(eml_NegateElimNotNot((TERM)list_Car(Scan))));
			}
			*Changed = TRUE;
		} else { /* general not */
			LIST Scan;
			for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
				list_Rplaca(Scan,(POINTER)eml_BubbleAnd((TERM)list_Car(Scan), Changed));
			}
		}
	} else { /* handle and  */
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan,(POINTER)eml_BubbleAnd((TERM)list_Car(Scan), Changed));
		}
	}
	
	return Term;
}
static LIST eml_BuildNegBoxHelper(const TERM Term) 
/**************************************************************
 SUMMARY: 	Helper for eml_BuildNegBox().
 			Populates the NegBox Field of an AXIOMSYMBOL entry.
 **************************************************************/
{
	SYMBOL Top;
	LIST List = list_Nil();
	if(!term_IsComplex(Term)) {
		if (!eml_ListContains(&List, Term)) {
			List = eml_ListAddTerm(Term, List);
		}
		return List;
	}
	Top = term_TopSymbol(Term);
	if (symbol_IsPredicate(Top)) {
		if (!eml_ListContains(&List, Term)) {
			List = eml_ListAddTerm(Term, List);
		}
		return List;
	}
		
	if (eml_IsBoxSymbol(Top) ) {
		if (!eml_ListContains(&List, Term)) {
			List = eml_ListAddTerm(Term, List);
		}
	} else if (eml_IsNotSymbol(Top)) {
		if (!eml_ListContains(&List, Term)) {
			List = eml_ListAddTerm(Term, List);
		}
	} else if (eml_IsAndSymbol(Top)) { /* Recurse */
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			LIST SubList = eml_BuildNegBoxHelper((TERM)list_Car(Scan));
			for (; !list_Empty(SubList); SubList=list_Cdr(SubList)) {
				TERM SubTerm = (TERM)list_Car(SubList);
				if (!eml_ListContains(&List, SubTerm)) {
					List = eml_ListAddTerm(SubTerm, List);
				}
			}
		}	
	} else {
		eml_Error("eml_BuildNegBoxHelper"); return list_Nil();
	}
	return List;
}

static void eml_NoOfBoxes(TERM Term, int *Count)
/**************************************************************
  SUMMARY: Counts the Number of boxes in a term with no and's
***************************************************************/
{
	SYMBOL Top;
	if(!term_IsComplex(Term)) {
		return;
	}
	Top = term_TopSymbol(Term);
	if (symbol_IsPredicate(Top)) {
		return;
	}
		
	if (eml_IsBoxSymbol(Top)) {
		(*Count)++;
		eml_NoOfBoxes(term_SecondArgument(Term), Count);
	} else if (eml_IsNotSymbol(Top)) {
		eml_NoOfBoxes(term_FirstArgument(Term), Count);
	} else {
		printf("\n=============="); term_Print(Term);
		eml_Error("No case in eml_NoOfBoxes().");
	}
	return;
}

static int eml_NoOfQs(const TERM Term, SYMBOL *Symbol)
/**************************************************************
  SUMMARY: Counts the Number of occurences of Symbol in a term
***************************************************************/
{
	SYMBOL Top = term_TopSymbol(Term);
	int Count = 0;
	if (symbol_Equal(Top, *Symbol)) {
		Count++;
	}
	if(!term_IsComplex(Term)) {
		return Count;
	}
	if (symbol_IsPredicate(Top)) {
		return Count;
	}
		
	{
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM SubTerm = (TERM)list_Car(Scan);
			if (symbol_Equal(term_TopSymbol(SubTerm), *Symbol)) {
				Count++;
			}
			Count = Count + eml_NoOfQs(SubTerm, Symbol); 
		}
	}
	
	return Count;
}

static TERM eml_TerminalPredicate(TERM Term)
/**************************************************************
  SUMMARY: Finds the terminal predicate in a term with no and's
***************************************************************/
{
	SYMBOL Top;
	if(!term_IsComplex(Term)) {
		return Term;
	}
	Top = term_TopSymbol(Term);
	if (symbol_IsPredicate(Top)) {
		return Term;
	}
		
	if (eml_IsBoxSymbol(Top)) {
		return eml_TerminalPredicate(term_SecondArgument(Term));
	} else if (eml_IsNotSymbol(Top)) {
		return eml_TerminalPredicate(term_FirstArgument(Term));
	} else {
		eml_Error("No case in eml_TerminalPredicate()."); return NULL;
	}
}
static int eml_NotIndex(TERM Term, int Index, int *BoxDepth, int *NotCount)
/**************************************************************
  SUMMARY: Returns the box depth of the Index'th Not symbol in a term with no and's,
  			or -1 if the Index'th Not symbol does not exist.
***************************************************************/
{
	SYMBOL Top;
	if(!term_IsComplex(Term)) {
		return -1;
	}
	Top = term_TopSymbol(Term);
	if (symbol_IsPredicate(Top)) {
		return -1;
	}
	
	if (eml_IsNotSymbol(Top)){
		(*NotCount)++;
		if ( (*NotCount)==Index ) {
			return (*BoxDepth);
		} else {	
			return eml_NotIndex(term_FirstArgument(Term), Index, BoxDepth, NotCount);
		}
	} else if (eml_IsBoxSymbol(Top)) {
		(*BoxDepth)++;
		return eml_NotIndex(term_SecondArgument(Term), Index, BoxDepth, NotCount);
	} else {
		eml_Error("No case in eml_NotIndex()."); return -2;
	}
}
static void eml_ContainsAnd(TERM Term, BOOL *Contains)
/**************************************************************
  SUMMARY: 
***************************************************************/
{
	SYMBOL Top;
	if(!term_IsComplex(Term)) {
		return;
	}
	Top = term_TopSymbol(Term);
	if (symbol_IsPredicate(Top)) {
		return;
	}
	
	if (eml_IsAndSymbol(Top)){
		*Contains = TRUE;
		return;
	} else {	
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			eml_ContainsAnd((TERM)list_Car(Scan), Contains);
			return;
		}
	}
}
static int eml_CompareTermListHelper(TERM Left, TERM Right)
/**************************************************************
  INPUT:   Two terms.
  RETURNS:  1 if left term < right term
            0 if left term = right term
	   		-1 if left term > right term
  SUMMARY:  Terms are compared top down, left to right with 
           respect to the arity of their signature symbols,
	   where variables in addition are defined to be smaller than constants.
  REF: copied entirely from term_CompareByArity()
***************************************************************/
{
	TERM TerminalPredicateLeft, TerminalPredicateRight; 
	int Index, LeftNotCount, RightNotCount, NotLeft, NotRight;
	BOOL End = FALSE;
		
	int LeftBoxDepth = 0, RightBoxDepth = 0; /* these are non-branching terms */
	eml_NoOfBoxes(Left, &LeftBoxDepth);
	eml_NoOfBoxes(Right, &RightBoxDepth);
	
	if (LeftBoxDepth > RightBoxDepth) {
		return -1;
	} else if (LeftBoxDepth < RightBoxDepth) {
		return 1;
	} /* else terms have same depth */
	
	/* compare precedence of terminal predicates */
	TerminalPredicateLeft = eml_TerminalPredicate(Left);
	TerminalPredicateRight = eml_TerminalPredicate(Right);
	
	if (!eml_TermEqual(TerminalPredicateLeft, TerminalPredicateRight)) {
		if ( eml_TermCompare(TerminalPredicateLeft,TerminalPredicateRight) < 0 ) {
			return -1;
		} else {
			return 1;
		}
	}
	/* if they are the same */
	Index = 0; LeftNotCount = -1; RightNotCount = -1; LeftBoxDepth = 0; RightBoxDepth = 0;
	
	while (End == FALSE) {
		NotLeft = eml_NotIndex(Left, Index, &LeftBoxDepth, &LeftNotCount);
		NotRight = eml_NotIndex(Right, Index, &RightBoxDepth, &RightNotCount);
		/*printf("\n-----%d:%d",Index,NotLeft); term_Print(Left); 
		printf(" %d:%d",Index,NotRight); term_Print(Right);*/
		if ((NotLeft == -1 ) && (NotRight != -1)) {
			return 1;
		} else if ((NotLeft != -1 ) && (NotRight == -1)) {
			return -1;
		}
		if (NotLeft < NotRight) {
			return -1;
		} else if (NotLeft > NotRight) {
			return 1;
		}
		if ((NotLeft==-1) && (NotRight==-1)) {
			End = TRUE;
		}
		LeftNotCount = -1; RightNotCount = -1; LeftBoxDepth = 0; RightBoxDepth = 0;
		Index++;
	}
	return 0;
}

static BOOL eml_CompareTermList (POINTER Ptr1, POINTER Ptr2) 
/**************************************************************
  INPUT: POINTERs are AXIOMSYMBOLs.
  RETURNS: TRUE if Ptr1 is less/equal than Ptr2 (Ptr1 <= Ptr2) TODO 
  SUMMARY: wrapper for eml_CompareTermListHelper()
 ***************************************************************/
{
	TERM Term1 = term_Copy((TERM)Ptr1), Term2 = term_Copy((TERM)Ptr2);
	BOOL Out;
	if ( eml_CompareTermListHelper(Term1, Term2) <= 0 ) { /* TODO < or <= */
		Out = FALSE;
	} else {
		Out = TRUE;
	}
	return Out;
}
static void eml_BuildNegBox(AXIOMSYMBOL *AxiomSymbol, PRECEDENCE Precedence) 
/**************************************************************
 SUMMARY: Populates the NegBox Field of an AXIOMSYMBOL entry.
 **************************************************************/
{
	LIST List = list_Nil();
	TERM Term = term_Copy((*AxiomSymbol).Term);
	{ /* standardize the format of the Term even further */
		BOOL Changed = TRUE;
		while (Changed == TRUE) { /* run at least once */
			Changed = FALSE; /* don't re-run if there isn't any change */
			Term = eml_BubbleAnd(Term, &Changed);
			Term = eml_EliminateNotNot(Term, &Changed);
		}
	}
	
	/*printf("\n"); term_Print((*AxiomSymbol).Term); 
	printf(" : In eml_BuildNegBox becomes : "); term_Print(Term);
	printf("\n"); eml_Flush();*/
	
	/* Populate the NegBox Field */
	List = eml_BuildNegBoxHelper(Term);
	List = list_MergeSort(List, (BOOL (*) ())eml_CompareTermList);
	
	(*AxiomSymbol).NegBox = List;
	return;
}

static BOOL eml_CompareByBoxNot (POINTER Ptr1, POINTER Ptr2) 
/**************************************************************
  INPUT: POINTERs are AXIOMSYMBOLs.
  RETURNS: TRUE if Ptr1 is less/equal than Ptr2 (Ptr1 <= Ptr2) TODO 
  SUMMARY: 
 ***************************************************************/
{
	LIST List1 = (*(AXIOMSYMBOL *)Ptr1).NegBox;
	LIST List2 = (*(AXIOMSYMBOL *)Ptr2).NegBox;
	int Length1 = list_Length(List1), Length2 = list_Length(List2);
	BOOL ContainsAnd1 = FALSE;
	BOOL ContainsAnd2 = FALSE;
	eml_ContainsAnd((*(AXIOMSYMBOL *)Ptr1).Term, &ContainsAnd1);
	eml_ContainsAnd((*(AXIOMSYMBOL *)Ptr2).Term, &ContainsAnd2);
	
	/* FALSE TRUE */
	if ( (ContainsAnd1 == FALSE) && (ContainsAnd2 == TRUE) ) {
		return FALSE;
	} else if ( (ContainsAnd1 == TRUE) && (ContainsAnd2 == FALSE) ) {
		return TRUE;
	}
	
	{ /* FALSE TRUE TRUE FALSE FALSE */
		int i, Length = Length1;
		if (Length2 > Length1) {
			Length = Length2;
		}
		for (i = 0; i < Length; i++) {
			TERM Term1, Term2;
			if (list_Empty(List1) == TRUE) {
				return FALSE;
			}
			if (list_Empty(List2) == TRUE) {
				return TRUE;
			}
			Term1 = (TERM)list_Car(List1);
			Term2 = (TERM)list_Car(List2);
			if ( eml_CompareTermListHelper(Term1, Term2) < 0 ) {
				return TRUE;
			} else if ( eml_CompareTermListHelper(Term1, Term2) > 0 ) {
				return FALSE;
			}
			List1=list_Cdr(List1); List2=list_Cdr(List2);
		}
	}
	return FALSE;
}

static BOOL eml_CompareByCountPlus (POINTER Ptr1, POINTER Ptr2) 
/**************************************************************
  INPUT: POINTERs are AXIOMSYMBOLs.
  RETURNS: TRUE if Ptr1 is less/equal than Ptr2 (Ptr1 <= Ptr2) TODO 
  SUMMARY: 
 ***************************************************************/
{
	int Count1 = (*(AXIOMSYMBOL *)Ptr1).AccessCount;
	int Count2 = (*(AXIOMSYMBOL *)Ptr2).AccessCount;
	
	/*if ( Count1 <= Count2 ) {
		return FALSE;
	} else {
		return TRUE;
	}*/
	if ( Count1 < Count2 ) {
		return TRUE;
	} else if ( Count1 > Count2 ) {
		return FALSE;
	} else {
		return eml_CompareByBoxNot (Ptr1, Ptr2);
	}
}

static void eml_SetPrecedence(PRECEDENCE Precedence, const TERM FinalTerm)
/**************************************************************
  SUMMARY: Re-order the precedence of the new symbols introduced
 **************************************************************/
{
	LIST QList=list_Nil(), RList=list_Nil(), SortedQList=list_Nil(), SortedRList=list_Nil(), CombinedList=list_Nil();
	int i = 0, MinimumPrec = -1;

	if (HiddenOpt.DoNotUseSetPrecedence == eml_ON) {
		return;
	}
	
	{
		/* Populate the NegBox Field */
		for (i = 0; i < eml_INDEXAXIOMSYMBOL; i++) {
			eml_BuildNegBox(&eml_AxiomSymbolList[i], Precedence);
			/*{
			  LIST Scan; int j = 0; printf("\n------- "); term_Print(eml_AxiomSymbolList[i].Term);
			  for (Scan=eml_AxiomSymbolList[i].NegBox; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
				TERM Term = (TERM)list_Car(Scan); printf("\n%d:%d ",i,j); term_Print(Term); j++;
			  }
			}*/
		}
		/* populate access counts */
		for (i = 0; i < eml_INDEXAXIOMSYMBOL; i++) {
			int Count = eml_NoOfQs(FinalTerm, &(eml_AxiomSymbolList[i].Symbol));
			eml_AxiomSymbolList[i].AccessCount = Count;
			/*printf("\n--- %d for symbol ",Count); symbol_Print(eml_AxiomSymbolList[i].Symbol);*/
		}
	}
	
	i = 0;
	/* Build the lists */
	while (i < eml_INDEXAXIOMSYMBOL) {	
		if (eml_AxiomSymbolList[i].Type == eml_AXIOM) {
			QList = eml_ListAddList(list_List(&eml_AxiomSymbolList[i]), QList);
		} else if (eml_AxiomSymbolList[i].Type == eml_AXIOMREL) {
			RList = eml_ListAddList(list_List(&eml_AxiomSymbolList[i]), RList);
		} else {
			eml_Error("No case in eml_SetPrecedence");
		}
		i++;
	}
	
	/* Sort the lists */
	if (HiddenOpt.DoNotUseSetPrecedence == eml_OFF) {
		SortedQList = list_MergeSort(QList, (BOOL (*) ())eml_CompareByBoxNot);
		SortedRList = list_MergeSort(RList, (BOOL (*) ())eml_CompareByBoxNot);
		eml_Print("\nUsing Subformulae Ordering.");
	} else { /* == eml_FULL */
		SortedQList = list_MergeSort(QList, (BOOL (*) ())eml_CompareByCountPlus);
		SortedRList = list_MergeSort(RList, (BOOL (*) ())eml_CompareByCountPlus);
		eml_Print("\nUsing Inverse Popularity + Subformulae Ordering.");
	}
	
	/* recombine the lists */
	CombinedList = list_Nconc(SortedRList, SortedQList);
	
	{ /* process the CombinedList */
		LIST Scan;
		for (Scan=CombinedList; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			SYMBOL Symbol = (*(AXIOMSYMBOL *)list_Car(Scan)).Symbol;
			if (MinimumPrec == -1) {
				MinimumPrec = symbol_Ordering(Precedence, Symbol);
			} else {
				int Test = symbol_Ordering(Precedence, Symbol);
				if (Test < MinimumPrec) {
					MinimumPrec = Test;
				}
			}
		}
	}
	
    { /* set new symbol ordering  */
		int Prec;
		LIST Scan = CombinedList;
		SYMBOL Symbol;
		
		for (Prec = 0; Prec < list_Length(CombinedList); Prec++) {
			Symbol = (*(AXIOMSYMBOL *)list_Car(Scan)).Symbol;
			symbol_SetOrdering(Precedence, Symbol, (MinimumPrec + Prec) );
			Scan=list_Cdr(Scan);
		}  
    }

    /*{	/ * print current symbol ordering  * /
    		LIST Scan;
    		int Prec;
    		SYMBOL Symbol;
    		Scan = CombinedList;
    		for (Prec = 0; Prec < list_Length(CombinedList); Prec++) {
    			Symbol = (*(AXIOMSYMBOL *)list_Car(Scan)).Symbol;
    			printf("\n %d ", symbol_Ordering(Precedence, Symbol)); symbol_Print(Symbol);
    			Scan=list_Cdr(Scan);
    		}
    		printf("\nPrecedence = "); symbol_PrintPrecedence(Precedence);
    }*/  
    if(HiddenOpt.DoNotUsePrintStatements == eml_OFF) {
    	eml_Print("\nRe-Organized Precedence = "); symbol_PrintPrecedence(Precedence); 
    }
    
	return;
}

static void eml_PrintSymbolTable()
/**************************************************************
  SUMMARY: print out the current symbol cache
 **************************************************************/
{
	if (HiddenOpt.DoNotUsePrintStatements == eml_OFF) {
		int i = 0;
		while (i < eml_INDEXAXIOMSYMBOL) {
			printf("\n %d: ", i);
			if ( (strlen(eml_AxiomSymbolList[i].Name) > (symbol__SYMBOLMAXLEN - 1))
					|| (HiddenOpt.AlwaysUseSubstitutedSymbolNames == eml_ON) ) {
				symbol_Print(eml_AxiomSymbolList[i].Symbol);
				printf(" ... renamed from ... %s", eml_AxiomSymbolList[i].Name);
			} else {
				symbol_Print(eml_AxiomSymbolList[i].Symbol);
			}
			i++;
		}
	}
}

static void eml_AxiomInit(FLAGSTORE Flags, PRECEDENCE Precedence) 
/**************************************************************
  SUMMARY: Initialisation of eml module for axiomatic translation 
 **************************************************************/
{
	{ /* initialize Varible Store Array */
		int i;
		for (i = 0; i < eml_SIZEAXIOMVARSTORE; i++) {
			eml_AxiomVarStore[i] = symbol__NULL;
		}
	}
	
	/* make K the first 'axiom' */
	(void) eml_BuildAxiomAt(0, K, AXIOMATIC_TR_COMP, -1, -1);
		
	/* initialize by processing the two options flags */
	eml_AxiomOptionsInit(Flags);
	
	if (eml_INDEX_FLAG > 0) {
		int Count;
		for (Count = 0; Count < eml_INDEX_FLAG; Count++) {
			printf("\nDefined AxiomFlag: %s  %s ", eml_AXIOMFLAG[Count].R, eml_AXIOMFLAG[Count].Axiom);
		}
	}	
	AlreadyDEFinedList = list_Nil();
	return;
}

static void eml_AxiomCleanUp() 
/**************************************************************
  SUMMARY: cleanup eml_module for the axiomatic translation
 **************************************************************/
{
	int i;
		
	for (i = 0; i < eml_INDEXAXIOMSYMBOL; i++) { /* struct {}AXIOMSYMBOL;*/
		string_StringFree(eml_AxiomSymbolList[i].Name);
	}
}

static TERM eml_ComposeAxioms(TERM Term)
/**************************************************************
  SUMMARY: (1)scan through term (2)remove AXM% terms (3)compose axiom series
   		   (4)set flag to ignore Axiom user flags. Recursive.
 **************************************************************/
{
	SYMBOL Top;
	
	if(!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}
	Top = term_TopSymbol(Term);

	if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return Term;
	} 

	if (eml_IsAxiomTypeSymbol(Top)) { /* input is Term = axmL(r,p) */
		/* for D,B,T,4,5,Alt1       ... eml_Axiom_X(R, Term) */
		/* for Dc,Bc,Tc,4c,5c,Alt1c ... eml_Axiom_Xc(R, Term) */
		/* for Do,Bo,To,4o,5o,Alt1o ... eml_Axiom_Xo(R, Term) */
		SYMBOL RSymbol = term_TopSymbol(term_FirstArgument(Term)); /* r */
		Term = term_SecondArgument(Term); /* p */

		if (eml_IsAxiom_D_Symbol(Top)) { 
			(void) eml_BuildAxiomR(D, AXIOMATIC_TR, -1, -1, RSymbol);
		} else if (eml_IsAxiom_B_Symbol(Top)) {	
			(void) eml_BuildAxiomR(B, AXIOMATIC_TR, -1, -1, RSymbol);
		} else if (eml_IsAxiom_T_Symbol(Top)) {	
			(void) eml_BuildAxiomR(T, AXIOMATIC_TR, -1, -1, RSymbol);
		} else if (eml_IsAxiom_4_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FOUR, AXIOMATIC_TR, -1, -1, RSymbol);
		} else if (eml_IsAxiom_5_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FIVE, AXIOMATIC_TR, -1, -1, RSymbol);
		} else if (eml_IsAxiom_ALT1_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1, AXIOMATIC_TR, -1, -1, RSymbol);
			
		} else if (eml_IsAxiom_Dc_Symbol(Top)) { 
			(void) eml_BuildAxiomR(D, CLASSICAL_TR, -1, -1, RSymbol);
		} else if (eml_IsAxiom_Bc_Symbol(Top)) {	
			(void) eml_BuildAxiomR(B, CLASSICAL_TR, -1, -1, RSymbol);
		} else if (eml_IsAxiom_Tc_Symbol(Top)) {	
			(void) eml_BuildAxiomR(T, CLASSICAL_TR, -1, -1, RSymbol);
		} else if (eml_IsAxiom_4c_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FOUR, CLASSICAL_TR, -1, -1, RSymbol);
		} else if (eml_IsAxiom_5c_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FIVE, CLASSICAL_TR, -1, -1, RSymbol);
		} else if (eml_IsAxiom_ALT1c_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1, CLASSICAL_TR, -1, -1, RSymbol);

		} else if (eml_IsAxiom_Do_Symbol(Top)) { 
			(void) eml_BuildAxiomR(D, AXIOMATIC_TR_COMP, -1, -1, RSymbol);
		} else if (eml_IsAxiom_Bo_Symbol(Top)) {	
			(void) eml_BuildAxiomR(B, AXIOMATIC_TR_COMP, -1, -1, RSymbol);
		} else if (eml_IsAxiom_To_Symbol(Top)) {	
			(void) eml_BuildAxiomR(T, AXIOMATIC_TR_COMP, -1, -1, RSymbol);
		} else if (eml_IsAxiom_4o_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FOUR, AXIOMATIC_TR_COMP, -1, -1, RSymbol);
		} else if (eml_IsAxiom_5o_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FIVE, AXIOMATIC_TR_COMP, -1, -1, RSymbol);
		} else if (eml_IsAxiom_ALT1o_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1, AXIOMATIC_TR_COMP, -1, -1, RSymbol);

		} else if (eml_IsAxiom_4K2_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FOURK, AXIOMATIC_TR, 2, -1, RSymbol);
		} else if (eml_IsAxiom_4K3_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FOURK, AXIOMATIC_TR, 3, -1, RSymbol);
		} else if (eml_IsAxiom_5K2_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FIVEK, AXIOMATIC_TR, 2, -1, RSymbol);
		} else if (eml_IsAxiom_5K3_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FIVEK, AXIOMATIC_TR, 3, -1, RSymbol);
		} else if (eml_IsAxiom_ALT1KK11_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR, 1, 1, RSymbol);
		} else if (eml_IsAxiom_ALT1KK12_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR, 1, -2, RSymbol);
		} else if (eml_IsAxiom_ALT1KK21_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR, 2, 1, RSymbol);
		} else if (eml_IsAxiom_ALT1KK22_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR, 2, 2, RSymbol);

		} else if (eml_IsAxiom_4K2o_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FOURK, AXIOMATIC_TR_COMP, 2, -1, RSymbol);
		} else if (eml_IsAxiom_4K3o_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FOURK, AXIOMATIC_TR_COMP, 3, -1, RSymbol);
		} else if (eml_IsAxiom_5K2o_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FIVEK, AXIOMATIC_TR_COMP, 2, -1, RSymbol);
		} else if (eml_IsAxiom_5K3o_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FIVEK, AXIOMATIC_TR_COMP, 3, -1, RSymbol);
		} else if (eml_IsAxiom_ALT1KK11o_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR_COMP, 1, 1, RSymbol);
		} else if (eml_IsAxiom_ALT1KK12o_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR_COMP, 1, -2, RSymbol);
		} else if (eml_IsAxiom_ALT1KK21o_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR_COMP, 2, 1, RSymbol);
		} else if (eml_IsAxiom_ALT1KK22o_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR_COMP, 2, 2, RSymbol);
			
		} else if (eml_IsAxiom_4K2c_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FOURK, CLASSICAL_TR, 2, -1, RSymbol);
		} else if (eml_IsAxiom_4K3c_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FOURK, CLASSICAL_TR, 3, -1, RSymbol);
		} else if (eml_IsAxiom_5K2c_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FIVEK, CLASSICAL_TR, 2, -1, RSymbol);
		} else if (eml_IsAxiom_5K3c_Symbol(Top)) {	
			(void) eml_BuildAxiomR(FIVEK, CLASSICAL_TR, 3, -1, RSymbol);
		} else if (eml_IsAxiom_ALT1KK11c_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, CLASSICAL_TR, 1, 1, RSymbol);
		} else if (eml_IsAxiom_ALT1KK12c_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, CLASSICAL_TR, 1, -2, RSymbol);
		} else if (eml_IsAxiom_ALT1KK21c_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, CLASSICAL_TR, 2, 1, RSymbol);
		} else if (eml_IsAxiom_ALT1KK22c_Symbol(Top)) { 
			(void) eml_BuildAxiomR(ALT1KK, CLASSICAL_TR, 2, 2, RSymbol);
			
		} else {
			eml_Error("No case in eml_ComposeAxioms.");
		}

		Term = eml_ComposeAxioms(Term); /* Recurse */
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan, (POINTER)eml_ComposeAxioms((TERM)list_Car(Scan)));
		}
	}
	
	return Term;
}

static TERM eml_BuildExistentialTerm(AXIOMDEFLIST *DEFs, SYMBOL VarX,
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  SUMMARY: Builds the E quantified term ... in ...	BigPI (p) = ExQp(x) ^ { /\ Def(p) } 
 **************************************************************/
{
	TERM OutTerm;
	LIST Arguments; 
	SYMBOL PredSymbol = symbol__NULL;

	if (eml_IsFalseSymbol(term_TopSymbol((*DEFs).Term))) {
		return term_Create(fol_False(), list_Nil());
	}
	/* Process Term to create a new Predicate */
	PredSymbol = eml_CreateAxiomSymbol((*DEFs).Term, eml_AXIOM, 1, symbol_STATLEX, Precedence);

	/* Build Arguments List for Pred Symbol */
	Arguments = list_List(term_Create(PredSymbol, 
					list_List(term_Create(VarX, list_Nil())))
	);
	OutTerm = term_Create(fol_Exist(), 
			list_Cons(term_Create(fol_Varlist(), list_List(term_Create(VarX, list_Nil()))), Arguments));
	
	return OutTerm;
}

static LIST eml_ProcessAxiomaticDefList (AXIOMDEFLIST *DEFs, FLAGSTORE Flags, PRECEDENCE Precedence) 
/**************************************************************
  RETURNS: The Translated Terms
  SUMMARY:  Scans through the contents of the DEFUnits list, and acts a a control in processing
 **************************************************************/
{
	TERM TopTerm;
	LIST OutList = list_Nil(), ConjList = list_Nil(), DEFList = list_Nil(), SimpleDEFList = list_Nil(); 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);

	/* Build Quantifed Term  */
	TopTerm = eml_BuildExistentialTerm(DEFs, VarX, Flags, Precedence);

	DEFList = eml_AxiomDEFListConc(DEFs, eml_COMPLEX);
	SimpleDEFList = (*DEFs).SubDef;

	{ /* Introduce DEF definition -- for complex DefUnits */ 
		LIST Scan, ResultList = list_Nil(); 

		for (Scan=DEFList; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM TmpTerm = (TERM)list_Car(Scan); 
			BOOL WithShortCut = eml_SetPositiveShortcut(); /* usually true */
			ResultList = eml_DEF(TmpTerm, VarX, VarY, WithShortCut, Flags, Precedence); 
			ConjList = eml_ListAddList(ResultList, ConjList);
		}
	}

	{ /* Introduce DEF definition -- for simple DefUnits */
		LIST Scan, ResultList = list_Nil(); 

		for (Scan=SimpleDEFList; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM TmpTerm = (TERM)list_Car(Scan);  
			BOOL WithShortCut = eml_SetPositiveShortcut(); /* usually true */
			ResultList = eml_SimpleDEF(TmpTerm, VarX, VarY, WithShortCut, Flags, Precedence);
			if (!list_Empty(ResultList)) {
				ConjList = eml_ListAddList(ResultList, ConjList);
			}
		}
	} 
	/* Build Output Term ... Note: Quantified at a lower level */
	if (!list_Empty(ConjList)) {
		OutList = list_Cons(TopTerm, ConjList);
	}
	
	return OutList;
}

static void eml_AxiomDEFListInit (TERM Term, AXIOMDEFLIST *DEFs)
/**************************************************************
  SUMMARY: Initialises the AXIOMDEFLIST structure
 ***************************************************************/
{	
	(*DEFs).Term = term_Copy(Term);
	(*DEFs).BoxDef = list_Nil(); 
	(*DEFs).SubDef = list_Nil(); 
	(*DEFs).SuperDef = list_Nil(); 
	(*DEFs).XtraBoxDef = list_Nil();
	(*DEFs).CompositionList = list_Nil();
}

static LIST eml_AxiomDEFListConc (AXIOMDEFLIST *DEFs, EML_CONTROL Mode)
/**************************************************************
  SUMMARY: Concatenates AXIOMDEFLIST Lists.
 ***************************************************************/
{
	LIST List = list_Nil();
	
	if (Mode == eml_ALL) { /* concatenate all of BoxDef + SubDef + SuperDef */
		if (!list_Empty((*DEFs).BoxDef)) { /* []p */
			if (list_Empty(List)) {
				List = list_Copy((*DEFs).BoxDef);
			} else {
				List = list_Nconc(List, list_Copy((*DEFs).BoxDef));
			}
		}
		if (!list_Empty((*DEFs).SubDef)) { /* predicates */
			if (list_Empty(List)) {
				List = list_Copy((*DEFs).SubDef);
			} else {
				List = list_Nconc(List, list_Copy((*DEFs).SubDef));
			}
		}
		if (!list_Empty((*DEFs).SuperDef)) { /*/\ and possibly  */
			if (list_Empty(List)) {
				List = list_Copy((*DEFs).SuperDef);
			} else {
				List = list_Nconc(List, list_Copy((*DEFs).SuperDef));
			}
		}
	} else if (Mode == eml_COMPLEX) { /* complex elements only = BoxDef + SuperDef */
		if (!list_Empty((*DEFs).BoxDef)) {
			if (list_Empty(List)) {
				List = list_Copy((*DEFs).BoxDef);
			} else {
				List = list_Nconc(List, list_Copy((*DEFs).BoxDef));
			}
		}
		if (!list_Empty((*DEFs).SuperDef)) {
			if (list_Empty(List)) {
				List = list_Copy((*DEFs).SuperDef);
			} else {
				List = list_Nconc(List, list_Copy((*DEFs).SuperDef));
			}
		}
	} else {
		eml_Error("No case in eml_AxiomDEFListConc");
	}

	return List;
}

static TERM eml_SLFtoCorrespondence(SYMBOL SymbolR, 
		int h, int i, int j, int k, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  	<>h.[]i.p -> []j.<>k.p
	Rh(w,v) /\ Rj(w,u) -> Ex( Ri(v,x) /\ Rk(u,x) )
  	SUMMARY: Process a Scott-Lemmon formula to produce a correspondence relation
 ***************************************************************/
{
	LIST ExistList = list_Nil(), AllList =  list_Nil();
	TERM OutTerm=NULL, LHS1=NULL, LHS2=NULL, RHS1=NULL, RHS2=NULL, LHS=NULL, RHS=NULL;
	SYMBOL SymbolW = eml_GetVar(0), SymbolV = eml_GetVar(1), 
		SymbolU = eml_GetVar(2), SymbolX = eml_GetVar(3); 
	TERM R = term_Create(SymbolR, list_Nil());
	int Index = 4;
	if ((h==0)&&(i==0)&&(j==0)&&(k==0)) {
		eml_Print("\nScott-Lemmon formula: TRUE\n");
		return term_Create(fol_TRUE, list_Nil());
	}
	if ((h==0)&&(j==0)) { /* u=v */
		TERM Tmp;
		LHS1 = term_Create(fol_EQUALITY, list_Cons(term_Create(SymbolU, list_Nil()),
				list_List(term_Create(SymbolV, list_Nil()))));
		Tmp = term_Create(SymbolV, list_Nil());
		if (!eml_ListContains(&AllList, Tmp)) {
			AllList = list_Cons(Tmp, AllList);
		}
		Tmp = term_Create(SymbolU, list_Nil());
		if (!eml_ListContains(&AllList, Tmp)) {
			AllList = list_Cons(Tmp, AllList);
		}
	} else if (h==0) { /* R^j(v,u) ----------------------- */
		if (j==1) {
			TERM Tmp;
			if (LHS2==NULL) {
				LHS2 = eml_AxiomaticTranslationRel(R, SymbolV, SymbolU, Flags, Precedence);
			} else {
				LHS2 = term_Create(fol_And(), list_Cons(
						eml_AxiomaticTranslationRel(R, SymbolV, SymbolU, Flags,
								Precedence), list_List(LHS2)));
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		} else { /* j>1 */
			TERM Tmp;
			int q;
			SYMBOL SymbolA, SymbolB;
			for (q = 0; q < j; q++) {
				if (q==0) {
					SymbolA = SymbolV;
					SymbolB = eml_GetVar(Index);
				} else if (q==(j-1)) {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = SymbolU;
				} else {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = eml_GetVar(Index);
				}
				if (LHS2==NULL) {
					LHS2 = eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
							Flags, Precedence);
				} else {
					LHS2 = term_Create(fol_And(), list_Cons(
							eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
									Flags, Precedence), list_List(LHS2)));
				}
				Tmp = term_Create(SymbolB, list_Nil());
				if (!eml_ListContains(&AllList, Tmp)) {
					AllList = list_Cons(Tmp, AllList);
				}
				Index++;
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		}
	} else if (j==0) { /* R^h(u,v) -------------------- */
		if (h==1) {
			TERM Tmp;
			if (LHS2==NULL) {
				LHS2 = eml_AxiomaticTranslationRel(R, SymbolV, SymbolU, Flags,	Precedence);
			} else {
				LHS2 = term_Create(fol_And(), list_Cons(
						eml_AxiomaticTranslationRel(R, SymbolV, SymbolU, Flags,
								Precedence), list_List(LHS2)));
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		} else { /* h>1 */
			TERM Tmp;
			int q;
			SYMBOL SymbolA, SymbolB;
			for (q = 0; q < h; q++) {
				if (q==0) {
					SymbolA = SymbolU;
					SymbolB = eml_GetVar(Index);
				} else if (q==(h-1)) {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = SymbolV;
				} else {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = eml_GetVar(Index);
				}
				if (LHS1==NULL) {
					LHS1 = eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
							Flags, Precedence);
				} else {
					LHS1 = term_Create(fol_And(), list_Cons(
							eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
									Flags, Precedence), list_List(LHS1)));
				}
				Tmp = term_Create(SymbolB, list_Nil());
				if (!eml_ListContains(&AllList, Tmp)) {
					AllList = list_Cons(Tmp, AllList);
				}
				Index++;
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		} /*------------------------------*/
	} else { /* R^h(w,v) /\ R^j(w,u) */
		if (j==1) {
			TERM Tmp;
			if (LHS2==NULL) {
				LHS2 = eml_AxiomaticTranslationRel(R, SymbolW, SymbolU, Flags, Precedence);
			} else {
				LHS2 = term_Create(fol_And(), list_Cons(
					eml_AxiomaticTranslationRel(R, SymbolW, SymbolU,
					Flags, Precedence), list_List(LHS2)));
			}
			Tmp = term_Create(SymbolW, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		} else { /* j>1 */			
			TERM Tmp;
			int q;
			SYMBOL SymbolA, SymbolB;
			for (q = 0; q < j; q++) {
				if (q==0) {
					SymbolA = SymbolW;
					SymbolB = eml_GetVar(Index);
				} else if (q==(j-1)) {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = SymbolU;
				} else {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = eml_GetVar(Index);
				}
				if (LHS2==NULL) {
					LHS2 = eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
							Flags, Precedence);
				} else {
					LHS2 = term_Create(fol_And(), list_Cons(
							eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
									Flags, Precedence), list_List(LHS2)));
				}
				Tmp = term_Create(SymbolB, list_Nil());
				if (!eml_ListContains(&AllList, Tmp)) {
					AllList = list_Cons(Tmp, AllList);
				}
				Index++;
			}
			Tmp = term_Create(SymbolW, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		} /* -------------------------- */
		if (h==1) {
			TERM Tmp;
			if (LHS1==NULL) {
				LHS1 = eml_AxiomaticTranslationRel(R, SymbolW, SymbolV, Flags, Precedence);
			} else {
				LHS1 = term_Create(fol_And(), list_Cons(
					eml_AxiomaticTranslationRel(R, SymbolW, SymbolV,
					Flags, Precedence), list_List(LHS1)));
			}
			Tmp = term_Create(SymbolW, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		} else { /* h>1 */
			TERM Tmp;
			int q;
			SYMBOL SymbolA, SymbolB;
			for (q = 0; q < h; q++) {
				if (q==0) {
					SymbolA = SymbolW;
					SymbolB = eml_GetVar(Index);
				} else if (q==(h-1)) {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = SymbolV;
				} else {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = eml_GetVar(Index);
				}
				if (LHS1==NULL) {
					LHS1 = eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
							Flags, Precedence);
				} else {
					LHS1 = term_Create(fol_And(), list_Cons(
							eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
									Flags, Precedence), list_List(LHS1)));
				}
				Index++;
				Tmp = term_Create(SymbolB, list_Nil());
				if (!eml_ListContains(&AllList, Tmp)) {
					AllList = list_Cons(Tmp, AllList);
				}
			}
			Tmp = term_Create(SymbolW, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		}
	}
	/* ===================== */
	
	if ((i==0)&&(k==0)) { /* u=v */
		TERM Tmp;
		RHS1 = term_Create(fol_EQUALITY, list_Cons(term_Create(SymbolU, list_Nil()),
					list_List(term_Create(SymbolV, list_Nil()))));
		Tmp = term_Create(SymbolU, list_Nil());
		if (!eml_ListContains(&AllList, Tmp)) {
			AllList = list_Cons(Tmp, AllList);
		}
		Tmp = term_Create(SymbolV, list_Nil());
		if (!eml_ListContains(&AllList, Tmp)) {
			AllList = list_Cons(Tmp, AllList);
		}
	} else if (i==0) { /* R^k(u,v) */
		if (k==1) {
			TERM Tmp;
			if (RHS2==NULL) {
				RHS2 = eml_AxiomaticTranslationRel(R, SymbolU, SymbolV, Flags,
						Precedence);
			} else {
				RHS2 = term_Create(fol_And(), list_Cons(
						eml_AxiomaticTranslationRel(R, SymbolU, SymbolV, Flags,
								Precedence), list_List(RHS2)));
			}
			Index++;
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		} else { /* k>1 */
			TERM Tmp;
			int q;
			SYMBOL SymbolA, SymbolB;
			for (q = 0; q < k; q++) {
				if (q==0) {
					SymbolA = SymbolU;
					SymbolB = eml_GetVar(Index);
				} else if (q==(k-1)) {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = SymbolV;
				} else {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = eml_GetVar(Index);
				}
				if (RHS2==NULL) {
					RHS2 = eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
							Flags, Precedence);
				} else {
					RHS2 = term_Create(fol_And(), list_Cons(
							eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
									Flags, Precedence), list_List(RHS2)));
				}
				Index++;
				Tmp = term_Create(SymbolB, list_Nil());
				if (!eml_ListContains(&AllList, Tmp)) {
					AllList = list_Cons(Tmp, AllList);
				}
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		}
	} else if (k==0) { /* R^i(u,v) */
		if (i==1) {
			TERM Tmp;
			if (RHS1==NULL) {
				RHS1 = eml_AxiomaticTranslationRel(R, SymbolU, SymbolV,
						Flags, Precedence);
			} else {
				RHS1 = term_Create(fol_And(), list_Cons(
						eml_AxiomaticTranslationRel(R, SymbolU, SymbolV,
						Flags, Precedence), list_List(RHS1)));
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		} else { /* i>1 */
			TERM Tmp;
			int q;
			SYMBOL SymbolA, SymbolB;
			for (q = 0; q < i; q++) {
				if (q==0) {
					SymbolA = SymbolU;
					SymbolB = eml_GetVar(Index);
				} else if (q==(i-1)) {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = SymbolV;
				} else {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = eml_GetVar(Index);
				}
				if (RHS1==NULL) {
					RHS1 = eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
							Flags, Precedence);
				} else {
					RHS1 = term_Create(fol_And(), list_Cons(
							eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
									Flags, Precedence), list_List(RHS1)));
				}
				Tmp = term_Create(SymbolB, list_Nil());
				if (!eml_ListContains(&AllList, Tmp)) {
					AllList = list_Cons(Tmp, AllList);
				}
				Index++;
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
		}
	} else { /* Ex(Ri(v,x) /\ Rk(u,x)) ---------------- */
		if (k==1) {
			TERM Tmp;
			if (RHS2==NULL) {
				RHS2 = eml_AxiomaticTranslationRel(R, SymbolU, SymbolX,
					Flags, Precedence);
			} else {
				RHS2 = term_Create(fol_And(), list_Cons(
					eml_AxiomaticTranslationRel(R, SymbolU, SymbolX,
					Flags, Precedence), list_List(RHS2)));
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolX, list_Nil());
			if (!eml_ListContains(&ExistList, Tmp)) {
				ExistList = list_Cons(Tmp, ExistList);
			}
		} else { /* k>1 */
			TERM Tmp;
			int q;
			SYMBOL SymbolA, SymbolB;
			for (q = 0; q < k; q++) {
				if (q==0) {
					SymbolA = SymbolU;
					SymbolB = eml_GetVar(Index);
				} else if (q==(k-1)) {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = SymbolX;
				} else {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = eml_GetVar(Index);
				}
				if (RHS2==NULL) {
					RHS2 = eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
							Flags, Precedence);
				} else {
					RHS2 = term_Create(fol_And(), list_Cons(
							eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
									Flags, Precedence), list_List(RHS2)));
				}
				Index++;
				if(!symbol_Equal(SymbolB,SymbolX)) {
					Tmp = term_Create(SymbolB, list_Nil());
					if (!eml_ListContains(&AllList, Tmp)) {
						AllList = list_Cons(Tmp, AllList);
					}
				}
			}
			Tmp = term_Create(SymbolU, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolX, list_Nil()); 
			if (!eml_ListContains(&ExistList, Tmp)) {
				ExistList = list_Cons(Tmp, ExistList);
			}
		}
		
		if (i==1) {
			TERM Tmp;
			if (RHS1==NULL) {
				RHS1 = eml_AxiomaticTranslationRel(R, SymbolV, SymbolX,
					Flags, Precedence);
			} else {
				RHS1 = term_Create(fol_And(), list_Cons(
					eml_AxiomaticTranslationRel(R, SymbolV, SymbolX,
						Flags, Precedence), list_List(RHS1)));
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolX, list_Nil());
			if (!eml_ListContains(&ExistList, Tmp)) {
				ExistList = list_Cons(Tmp, ExistList);
			}
		} else { /* i>1 */
			TERM Tmp;
			int q;
			SYMBOL SymbolA, SymbolB;
			for (q = 0; q < i; q++) {
				if (q==0) {
					SymbolA = SymbolV;
					SymbolB = eml_GetVar(Index);
				} else if (q==(i-1)) {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = SymbolX;
				} else {
					SymbolA = eml_GetVar(Index-1);
					SymbolB = eml_GetVar(Index);
				}
				if (RHS1==NULL) {
					RHS1 = eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
							Flags, Precedence);
				} else {
					RHS1 = term_Create(fol_And(), list_Cons(
							eml_AxiomaticTranslationRel(R, SymbolA, SymbolB,
									Flags, Precedence), list_List(RHS1)));
				}
				Index++;
				if(!symbol_Equal(SymbolB,SymbolX)) {
					Tmp = term_Create(SymbolB, list_Nil());
					if (!eml_ListContains(&AllList, Tmp)) {
						AllList = list_Cons(Tmp, AllList);
					}
				}
			}
			Tmp = term_Create(SymbolV, list_Nil());
			if (!eml_ListContains(&AllList, Tmp)) {
				AllList = list_Cons(Tmp, AllList);
			}
			Tmp = term_Create(SymbolX, list_Nil());
			if (!eml_ListContains(&ExistList, Tmp)) {
				ExistList = list_Cons(Tmp, ExistList);		}
			}
	}
	/* -------------------- */
	if ( (LHS1 != NULL) && (LHS2 != NULL) ){
		LHS = term_Create(fol_And(), list_Cons(LHS1, list_List(LHS2)));
	} else if (LHS1 != NULL) { 
		LHS = LHS1;
	} else if (LHS2 != NULL) {
		LHS = LHS2;
	} else {
		LHS = NULL;
	}
	
	if ( (RHS1 != NULL) && (RHS2 != NULL) ){
		RHS = term_Create(fol_And(), list_Cons(RHS1, list_List(RHS2)));
		RHS = eml_QuantifyTerm(fol_Exist(), RHS, ExistList);
	} else if (RHS1 != NULL) { 
		RHS = RHS1;
	} else if (RHS2 != NULL) {
		RHS = RHS2;
	} else {
		RHS = NULL;
	}
	
	if ( (LHS != NULL) && (RHS != NULL) ){
		OutTerm = term_Create(fol_Implies(), list_Cons(LHS, list_List(RHS)));
	} else if (LHS != NULL) { 
		OutTerm = LHS;
	} else if (RHS != NULL) {
		OutTerm = RHS;
	} else {
		eml_Error("No Case in eml_SLFtoCorrespondence().");
	}
	if (!list_Empty(AllList)) {
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, AllList);
	}
	
	eml_PrintT("\nScott-Lemmon formula:", OutTerm);
	return OutTerm;
}
static TERM eml_ProcessSLFHelper(TERM Term, TERM *SLFformula, BOOL *FoundSLF, 
		int *h, int *i, int *j, int *k, FLAGSTORE Flags, PRECEDENCE Precedence)
/************************************************************** 
  SUMMARY: Analyse the input term to extract h, i, j, k, 
  		Process a Scott-Lemmon formula to produce a correspondence relation
 ***************************************************************/
{
	SYMBOL Top;
	if (!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}
	Top = term_TopSymbol(Term);
	if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return Term;
	}

	if (eml_IsSLF_Symbol(Top)) { /* input is Term = slf(r,<>^h[]^i(p)->[]^j<>^k(p)) */
		SYMBOL RSymbol = term_TopSymbol(term_FirstArgument(Term)); /* r */
		TERM NewTerm = term_SecondArgument(Term); /* slf */
		TERM Left, Right;
		*FoundSLF = TRUE;
		if (!eml_IsImpliesSymbol(term_TopSymbol(NewTerm))) {
			eml_Error("Syntax Error in Scott_Lemmon formula.");
		}
		Left = term_FirstArgument(NewTerm);
		Right = term_SecondArgument(NewTerm);
		
		if ((!eml_IsBoxSymbol(term_TopSymbol(Left)))
				&& (!eml_IsDiaSymbol(term_TopSymbol(Left)))
				&& (!term_IsComplex(Left))
				&& (!symbol_IsPredicate(term_TopSymbol(Left)))) {
			eml_Error("Syntax Error in Scott_Lemmon formula - Left.");
		}
		if (eml_IsDiaSymbol(term_TopSymbol(Left))) {
			do {  
				(*h)++;
				Left = term_SecondArgument(Left);
			} while (eml_IsDiaSymbol(term_TopSymbol(Left))); 
		}
		if (eml_IsBoxSymbol(term_TopSymbol(Left))) {
			do {  
				(*i)++;
				Left = term_SecondArgument(Left);
			} while (eml_IsBoxSymbol(term_TopSymbol(Left))); 
		}
		if (symbol_IsPredicate(term_TopSymbol(Left))) {
			; /* end */
		} else {
			eml_Error("Syntax Error in Scott_Lemmon formula - Left.");
		}
		
		if ((!eml_IsBoxSymbol(term_TopSymbol(Right)))
				&& (!eml_IsDiaSymbol(term_TopSymbol(Right)))
				&& (!term_IsComplex(Right))
				&& (!symbol_IsPredicate(term_TopSymbol(Right)))) {
			eml_Error("Syntax Error in Scott_Lemmon formula - Right.");
		}
		if (eml_IsBoxSymbol(term_TopSymbol(Right))) {
			do {
				(*j)++;
				Right = term_SecondArgument(Right);
			} while (eml_IsBoxSymbol(term_TopSymbol(Right)));
		}
		if (eml_IsDiaSymbol(term_TopSymbol(Right))) {
			do {
				(*k)++;
				Right = term_SecondArgument(Right);
			} while (eml_IsDiaSymbol(term_TopSymbol(Right)));
		}
		if (symbol_IsPredicate(term_TopSymbol(Right))) {
			; /* end */
		} else {
			eml_Error("Syntax Error in Scott_Lemmon formula - Right.");
		}
		
		if (*SLFformula==NULL) {
			*SLFformula = eml_SLFtoCorrespondence(RSymbol, *h, *i, *j, *k, Flags, Precedence);
		} else {
			*SLFformula = term_Create(fol_And(),
					list_Cons(eml_SLFtoCorrespondence(RSymbol, *h, *i, *j, *k, Flags, Precedence),
					list_List(*SLFformula)));
		}
		Term = term_Create(fol_True(), list_Nil());
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan, (POINTER)eml_ProcessSLF((TERM)list_Car(Scan), SLFformula, Flags, Precedence));
		}
	}
	
	return Term;
}
static TERM eml_ProcessSLF(TERM Term, TERM *SLFformula, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  SUMMARY: Control to Process a Scott-Lemmon formula to produce a correspondence relation
 ***************************************************************/
{
	BOOL FoundSLF = FALSE;
	int h = 0, i = 0, j = 0, k = 0;
	Term = eml_ProcessSLFHelper(Term, SLFformula, &FoundSLF, &h, &i, &j , &k, Flags, Precedence);
	if (FoundSLF == TRUE) {
		printf("\n<>^%d[]^%d(p)->[]^%d<>^%d(p)",h,i,j,k);
	}
	return Term;
}
static TERM eml_ProcessAXSLF(TERM Term, TERM *AXSLFformula, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  SUMMARY: Control to Process a Scott-Lemmon formula to produce an axiomatic translation
 ***************************************************************/
{
	return Term;
}
static TERM eml_ProcessExemptHelper(TERM Term, TERM *ExemptFormula)
/**************************************************************
  SUMMARY: Process a formula which by-passes the translation
 ***************************************************************/
{
	SYMBOL Top;
	if (!term_IsComplex(Term)) { /* terminate recursion */
		return Term;
	}
	Top = term_TopSymbol(Term);
	if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return Term;
	}

	if (eml_IsNOAXIOM_Symbol(Top)) { /* input is Term = slf(r,<>^h[]^i(p)->[]^j<>^k(p)) */
		Term = term_FirstArgument(Term); /* exempt formula */
		
		if (*ExemptFormula==NULL) {
			*ExemptFormula = Term;
		} else {
			*ExemptFormula = term_Create(fol_And(), list_Cons(Term, list_List(*ExemptFormula)));
		}
		Term = term_Create(fol_True(), list_Nil());
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			list_Rplaca(Scan, (POINTER)eml_ProcessExemptHelper((TERM)list_Car(Scan),ExemptFormula));
		}
	}
		
	return Term;
}
static TERM eml_ProcessExempt(TERM Term, TERM *ExemptFormula)
/**************************************************************
  SUMMARY: Process a formula which by-passes the translation
 ***************************************************************/
{
	Term = eml_ProcessExemptHelper(Term, ExemptFormula);
	if (*ExemptFormula != NULL) {
			eml_PrintT("\nFormula Exempt from Translation: ",*ExemptFormula);
	}
	return Term;
}
static BOOL eml_AxiomsAreClassical() 
/**************************************************************
  SUMMARY: 
 ***************************************************************/
{
	BOOL Output = FALSE;
	int loop;
	for (loop=1; loop < AxiomCompositionIndex; loop++) { /* 1 avoids the default K */
		AXIOM Axiom = AxiomComposition[loop];
		if (Axiom.Mode==CLASSICAL_TR) {
			Output = TRUE;
		}
	}
		
	return Output;
}

static TERM eml_Axiomatic (TERM Term, FLAGSTORE Flags, PRECEDENCE Precedence) 
/**************************************************************
  INPUT: All input data for the main control routine of axiomatic translation. 
	     Term: Pre-Translation Term, and Flags/Precedence to pass down.
  RETURNS: Translated Term.
  SUMMARY: Top level for control.
 ***************************************************************/
{
	TERM FinalTerm, DeaxiomizedTerm, StdTerm, SLFformula=NULL, ExemptFormula=NULL, AXSLFformula=NULL; 
	AXIOMDEFLIST DEFs;  
	LIST OutList = list_Nil();
	
	/* HouseKeeping - all the initializations that must come before anything else is done */
	eml_AxiomInit(Flags, Precedence);
	
	/* Copyright Notice.
	 * Modifications of SPASS for Axiomatic Translation.  
	 * @K.J.Smith 2007-2008
	 * john@KJSmith.net  
	 * Permission is granted (under a modified GNU LGPL) to use and modify this code (for Axiomatic Translation) 
	 * for any purpose (commercial or non-commercial use) provided 
	 *  1. The following line of information is printed to the user interface (each time the code is executed),
	 *     in all software using this code, or derived from this code (in any way)  */ 
	printf("\nAxiomatic Translation, version 1.1.0, @K.J.Smith 2007-2008, http://project.kjsmith.net/");
	 /* 2. This message is included in any software using this code or derived from this code (in any way). 
	  * 3. This program is free software. This program is distributed in the hope that it will be useful,
           but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
           A PARTICULAR PURPOSE. See the GNU General Public License for more details.
	  */
	
	eml_PrintT("\n[Axiomatic Translation Input] ", Term); 
	
	{ /* stripping out the inline axiom features - so this must come first */
		TERM DeAXSLFTerm = eml_ProcessAXSLF(Term, &AXSLFformula, Flags, Precedence); /* Not implemented */
		TERM DeExemptTerm = eml_ProcessExempt(DeAXSLFTerm, &ExemptFormula);
		TERM DeSLFTerm = eml_ProcessSLF(DeExemptTerm, &SLFformula, Flags, Precedence);
		DeaxiomizedTerm = eml_ComposeAxioms(DeSLFTerm);
		if (eml_AreAxiomsDefined() == TRUE) {
			HiddenOpt.UsingInlineAxiomfeatures = eml_ON; /*this will now ignore axiom based flags */
		} else if (eml_INDEX_FLAG > 0) {
			eml_AnalyzeSetAxiom(Flags);
			HiddenOpt.UsingSetFlagAxiomfeatures = eml_ON;
		} else {
			/* setup the flags for axioms - need to do this inorder to do eml_SetPositiveShortcut() */
			eml_AnalyzeEmlAxiomTranslationFlags(Flags);
		}
		eml_PrintAxiomComposition(); /* the least that will be reported is K */
		if (eml_AxiomsAreClassical()==TRUE) {
			HiddenOpt.DoNotUseSetPrecedence = eml_ON;
			eml_Print("\nPrecedence reverting to SPASS control.");
		}
	}
	
	/* start building some variables from baseline */
	symbol_ResetStandardVarCounter();
	
	/* 2 ... Standardize the format to { & \/ & []} */
	StdTerm = eml_AxiomaticStd(DeaxiomizedTerm);
	eml_PrintT("\n[Axiomatic Translation Standardized] ", StdTerm);

	eml_AxiomDEFListInit (StdTerm, &DEFs); /* HouseKeeping */
	eml_GetDEFUnits(&DEFs); /* 3 ... GET THE DEFS LIST */
	
	/* 4 ... PROCESS THE DEFS LIST TO FORM CONJUNCTION OF DEF TRANSLATED TERMS */
	/* 5 ... PROCESS THE DEF TRANSLATED TERMS TO REDUCE PI-FUNCTION TO FOL */
	OutList = eml_ProcessAxiomaticDefList(&DEFs, Flags, Precedence);
	
	{	
		TERM PrintTerm = term_Create(fol_And(), OutList);
		eml_PrintT("\n[Axiomatic Translation: Logic K]\n", PrintTerm);
	}
	/* Note ... terms are quantified Indvidually ... not above a big /\ */

	/* Process the Logic Flags for this problem - if necessary */
	if ( (eml_AreAxiomsDefined() == TRUE /*Axioms are Active*/) 
			&& ((!list_Empty(DEFs.BoxDef)) || (!list_Empty(DEFs.XtraBoxDef))) ) {
		LIST LogicList = eml_AxiomLogicControl(&DEFs, Flags, Precedence);
		if (!list_Empty(LogicList)) {
			OutList = list_Nconc(OutList, LogicList);
		}
	} /* else Logic Terms were NOT enabled or there are no box terms */

	
	if (SLFformula!=NULL) {
		OutList = list_Cons(SLFformula, OutList);
	}
	if (ExemptFormula!=NULL) {
		OutList = list_Cons(ExemptFormula, OutList);
	}
	
	FinalTerm = term_Create(fol_And(), OutList);
	
	eml_PrintSymbolTable(); /* print the symbols table */
	if (HiddenOpt.DoNotUseSetPrecedence != eml_ON) {
			eml_SetPrecedence(Precedence, FinalTerm); /* last set precedence of symbols in symbol table */
			/*printf("\nFOL Precedence\n"); fol_PrintPrecedence(Precedence);*/
	}
		
	eml_PrintT("\nFINAL TERM:\t", FinalTerm); eml_Print("\n"); eml_Flush();
	return FinalTerm;
}

static LIST eml_AxiomLogicControl(AXIOMDEFLIST *DEFs, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  RETURNS: Combined Axiom Terms.
  DESCRIPTION: Entry point for analysis of axioms.
 ***************************************************************/
{
	LIST OutList = list_Nil();
	eml_Count_Modalitys((*DEFs).Term);
	
	{ /* updating AxiomComposition array for modality - has not been nedded until now */
		int Counter;
		printf("\nThis Problem has %d Modalities [ ", eml_INDEX_R);
		for (Counter = 0; Counter < eml_INDEX_R; Counter++) {
			symbol_Print(eml_R[Counter]); printf(" ");
		} printf("]");

		if ( (HiddenOpt.UsingInlineAxiomfeatures == eml_OFF)
				&& (HiddenOpt.UsingSetFlagAxiomfeatures == eml_OFF)) {
			if (eml_INDEX_R > 1) {
				eml_Error("If Axioms are defined in Flag Mode, then only a single modality is supported.");
			} else if (eml_INDEX_R == 1) {
				int loop;
				for (loop=1; loop < AxiomCompositionIndex; loop++) { /* 1 avoids the default K */
					AxiomComposition[loop].Modality = eml_R[0];
				}
			}
		}
	}
	
	{ /* for each axiom gather the result into OutList */
		int loop;
		for (loop=1; loop < AxiomCompositionIndex; loop++) { /* 1 avoids the default K */
			LIST ResultList = eml_ProcessAxiomLogic(AxiomComposition[loop], DEFs, Flags, Precedence);
			if (!list_Empty(ResultList)) {
				OutList = eml_ListAddList(ResultList, OutList);
			}
		}
	}
	return OutList;
}

static void eml_Count_Modalitys(TERM Term)
/**************************************************************
  DESCRIPTION:  helper function for eml_AxiomLogicControl(). Counts the
  number of distict modality indexes and updates the eml_R structure
 ***************************************************************/
{
	SYMBOL Top;
	
	if(!term_IsComplex(Term)) { /* terminate recursion */
		return;
	}
	Top = term_TopSymbol(Term);
	if (symbol_IsPredicate(Top)) { /* terminate recursion */
		return;
	} 

	if (eml_IsDiaSymbol(Top) || eml_IsBoxSymbol(Top)) { 
		TERM TermtmpP = term_SecondArgument(Term); /* p */
		SYMBOL TmpR = term_TopSymbol(term_FirstArgument(Term)); /* r */
		BOOL Found = FALSE;
		int Counter;
		for (Counter = 0; Counter < eml_INDEX_R; Counter++) {
			if ( symbol_Equal(TmpR, eml_R[Counter]) ) {
				Found = TRUE;
			}
		}
		if (Found == FALSE) {
            if ( (eml_INDEX_R+1) >= MAXDEFINEDAXIOMS) {
            	eml_Error("Max. No. Modalities Exceeded.");
            }
			eml_R[eml_INDEX_R] = TmpR;
			eml_INDEX_R++;
		}
		eml_Count_Modalitys(TermtmpP); /* Recurse */
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			eml_Count_Modalitys((TERM)list_Car(Scan));
		}
	}
	
	return;
} 

static TERM eml_QuantifyTerm(SYMBOL Quantifier, TERM Term, LIST VarListContents)
/**************************************************************
INPUT: Quantifier is fol_All() or fol_Exist(), LIST contains VarX, VarY, etc
DESCRIPTION: Adds a quantifier, and varlist to given Term. Just a helper function.
 ***************************************************************/
{
	TERM OutTerm = term_Create(Quantifier,
			list_Cons(term_Create(fol_Varlist(), VarListContents), list_List(Term))
	);
	return OutTerm;
}

static TERM eml_ProcessClassicalLogic (AXIOM Axiom, FLAGSTORE Flags, PRECEDENCE Precedence) 
/**************************************************************
SUMMARY: define classical translation of axiom. Need Axiom for axiom-type & modality index
 ***************************************************************/
{
	TERM OutTerm = NULL, FirstTerm;
	SYMBOL VarX = eml_GetVar(VARX);
	TERM R = term_Create(Axiom.Modality, list_Nil());
	
	if (Axiom.Mode != CLASSICAL_TR) { /* guard statement */
		eml_Error("Internal Error in eml_ProcessClassicalLogic.");
	}
	
	switch(Axiom.AxiomType) {
	/**************************************************************
  	T:   Reflexive ... 	[]p -> p	Ax(R(x,x))
	 ***************************************************************/
	case T: {
		FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarX, Flags, Precedence);
		OutTerm = eml_QuantifyTerm(fol_All(), FirstTerm,
				list_List(term_Create(VarX, list_Nil()))
		);
		
		eml_PrintT("\n[Class.Rel.Translation T].[",R); eml_PrintT("].",OutTerm); 
		return OutTerm;
	}
	break;
	/**************************************************************
  	D:    Serial ...  []p -> []p	AxEy(R(x,y))
	 ***************************************************************/
	case D:	{
		SYMBOL VarY = eml_GetVar(VARY);
		FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarY, Flags, Precedence);
		OutTerm = eml_QuantifyTerm(fol_Exist(), FirstTerm,
				list_List(term_Create(VarY, list_Nil()))
		);
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
				list_List(term_Create(VarX, list_Nil()))
		);
		
		eml_PrintT("\n[Class.Rel.Translation D].[",R);	eml_PrintT("].",OutTerm); 
		return OutTerm;
	}
	break;
	/**************************************************************
   	4:  OK. Transitive  []p -> [][]p	Axyz((R(x,y) /\ R(y,z)) -> R(x,z))
	 ***************************************************************/
	case FOUR:	{
		TERM SecondTerm, ThirdTerm;
		SYMBOL VarY = eml_GetVar(VARY);
		SYMBOL VarZ = eml_GetVar(VARZ);
		FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarY, Flags, Precedence);
		SecondTerm = eml_AxiomaticTranslationRel(R, VarY, VarZ, Flags, Precedence);
		ThirdTerm = eml_AxiomaticTranslationRel(R, VarX, VarZ, Flags, Precedence);
		OutTerm = term_Create(fol_And(), list_Cons(FirstTerm, list_List(SecondTerm)));
		OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(ThirdTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
				list_Cons(term_Create(VarX, list_Nil()),
						list_Cons(term_Create(VarY, list_Nil()),
								list_List(term_Create(VarZ, list_Nil())))
		));
		
		eml_PrintT("\n[Class.Rel.Translation 4].[",R);	eml_PrintT("].",OutTerm); 	
		return OutTerm;
	}
	break;
	/**************************************************************
   	5:   Euclidean  [][]p -> []p	Axyz(R(x,y) /\ R(x,z) -> R(y,z))
	 ***************************************************************/
	case FIVE:	{
		TERM SecondTerm, ThirdTerm;
		SYMBOL VarY = eml_GetVar(VARY);
		SYMBOL VarZ = eml_GetVar(VARZ);
		FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarY, Flags, Precedence);
		SecondTerm = eml_AxiomaticTranslationRel(R, VarX, VarZ, Flags, Precedence);
		ThirdTerm = eml_AxiomaticTranslationRel(R, VarY, VarZ, Flags, Precedence);
		OutTerm = term_Create(fol_And(), list_Cons(FirstTerm, list_List(SecondTerm)));
		OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(ThirdTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
				list_Cons(term_Create(VarX, list_Nil()),
						list_Cons(term_Create(VarY, list_Nil()),
								list_List(term_Create(VarZ, list_Nil())))
		));
		
		eml_PrintT("\n[Class.Rel.Translation 5].[",R);	eml_PrintT("].",OutTerm); 	
		return OutTerm;
	}
	break;
	/**************************************************************
   	B:   Symmetry ...  [][]p -> p  Axy(R(x,y) -> R(y,x))
	 ***************************************************************/
	case B:	{
		TERM SecondTerm;
		SYMBOL VarY = eml_GetVar(VARY);
		FirstTerm = eml_AxiomaticTranslationRel(R,	VarX, VarY, Flags, Precedence);
		SecondTerm = eml_AxiomaticTranslationRel(R,	VarY, VarX, Flags, Precedence);
		OutTerm = term_Create(fol_Implies(), list_Cons(FirstTerm, list_List(SecondTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
				list_Cons(term_Create(VarX, list_Nil()),
								list_List(term_Create(VarY, list_Nil()))
		));
		
		eml_PrintT("\n[Class.Rel.Translation B].[",R);	eml_PrintT("].",OutTerm);	
		return OutTerm;
	}
	break; 
	/**************************************************************
   	ALT1:   []p -> []p  functionality   Axyz(R(x,y) /\ R(x,z) -> y=z )
	 ***************************************************************/
	case ALT1:	{
		TERM SecondTerm, ThirdTerm;
		SYMBOL VarY = eml_GetVar(VARY);
		SYMBOL VarZ = eml_GetVar(VARZ);
		FirstTerm = eml_AxiomaticTranslationRel(R,	VarX, VarY, Flags, Precedence);
		SecondTerm = eml_AxiomaticTranslationRel(R,	VarX, VarZ, Flags, Precedence);
		ThirdTerm = term_Create(fol_Equality(), 
				list_Cons(term_Create(VarY, list_Nil()), list_List(term_Create(VarZ, list_Nil())))
		);
		OutTerm = term_Create(fol_And(), list_Cons(FirstTerm, list_List(SecondTerm)));
		OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(ThirdTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
				list_Cons(term_Create(VarX, list_Nil()),
						list_Cons(term_Create(VarY, list_Nil()),
								list_List(term_Create(VarZ, list_Nil())))
		));
		
		eml_PrintT("\n[Class.Rel.Translation Alt1].[",R); eml_PrintT("].",OutTerm); 
		return OutTerm;
	}
	break;
	/**************************************************************
   	5K:  []k[]p -> []p	Axyz(Rk(x,y) /\ R(x,z) -> R(y,z))
	 ***************************************************************/
	case FIVEK:	{
		SYMBOL VarY = eml_GetVar(VARY);
		SYMBOL VarZ = eml_GetVar(VARZ);
		SYMBOL VarU = eml_GetVar(VARU);
		SYMBOL VarV = eml_GetVar(VARV);
		int FactorK5 = Axiom.Parameter1;
		
		if (FactorK5 == 2) { /* Axuyz((Rxu /\ Ruy /\ Rxz ) -> Ryz) */
			TERM SecondTerm, ThirdTerm, FourthTerm;
			FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarU, Flags, Precedence);
			SecondTerm = eml_AxiomaticTranslationRel(R,	 VarU, VarY, Flags, Precedence);
			ThirdTerm = eml_AxiomaticTranslationRel(R, VarX, VarZ, Flags, Precedence);
			FourthTerm = eml_AxiomaticTranslationRel(R, VarY, VarZ, Flags, Precedence);
			
			OutTerm = term_Create(fol_And(), 
					list_Cons(FirstTerm, list_Cons(SecondTerm, list_List(ThirdTerm))));
			OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(FourthTerm)));
			OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
					list_Cons(term_Create(VarX, list_Nil()),
							list_Cons(term_Create(VarU, list_Nil()),
									list_Cons(term_Create(VarY, list_Nil()),
											list_List(term_Create(VarZ, list_Nil()))))
			));
		} else if (FactorK5 == 3) { /* Axuvyz((Rxu /\ Ruv /\ Rvy /\ Rxz ) -> Ryz) */
			TERM SecondTerm, ThirdTerm, FourthTerm, FifthTerm;
			FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarU, Flags, Precedence);
			SecondTerm = eml_AxiomaticTranslationRel(R,	 VarU, VarV, Flags, Precedence);
			ThirdTerm = eml_AxiomaticTranslationRel(R, VarV, VarY, Flags, Precedence);
			FourthTerm = eml_AxiomaticTranslationRel(R, VarX, VarZ, Flags, Precedence);
			FifthTerm = eml_AxiomaticTranslationRel(R, VarY, VarZ, Flags, Precedence);
			OutTerm = term_Create(fol_And(), 
					list_Cons(FirstTerm, list_Cons(SecondTerm, 
							list_Cons(ThirdTerm, list_List(FourthTerm)))));
			OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(FifthTerm)));
			OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
					list_Cons(term_Create(VarX, list_Nil()),
							list_Cons(term_Create(VarU, list_Nil()),
									list_Cons(term_Create(VarV, list_Nil()),
											list_Cons(term_Create(VarY, list_Nil()),
													list_List(term_Create(VarZ, list_Nil())))))
			));
		} else {
			eml_Error("No case for classical 5K.");
		}
		
		eml_PrintDT("\n[Class.Rel.Translation 5K^%d].[",FactorK5,R); eml_PrintT("].",OutTerm); 
		return OutTerm;
	}
	break;
	/**************************************************************
  	4K:  []p -> []k[]p		Axy(Rk+1(x,y) -> R(x,y))
	 ***************************************************************/
	case FOURK:	{
		SYMBOL VarY = eml_GetVar(VARY);
		SYMBOL VarZ = eml_GetVar(VARZ);
		SYMBOL VarU = eml_GetVar(VARU);
		SYMBOL VarV = eml_GetVar(VARV);
		int FactorK4 = Axiom.Parameter1;
		
		if (FactorK4 == 2) { /* Axuyz((Rxu /\ Ruy /\ Ryz) -> Rxz) */
			TERM SecondTerm, ThirdTerm, FourthTerm;
			FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarU, Flags, Precedence);
			SecondTerm = eml_AxiomaticTranslationRel(R, VarU, VarY, Flags, Precedence);
			ThirdTerm = eml_AxiomaticTranslationRel(R, VarY, VarZ, Flags, Precedence);
			FourthTerm = eml_AxiomaticTranslationRel(R, VarX, VarZ, Flags, Precedence);
			OutTerm = term_Create(fol_And(), 
					list_Cons(FirstTerm, list_Cons(SecondTerm, list_List(ThirdTerm))));
			OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(FourthTerm)));
			OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
					list_Cons(term_Create(VarX, list_Nil()),
							list_Cons(term_Create(VarU, list_Nil()),
									list_Cons(term_Create(VarY, list_Nil()),
											list_List(term_Create(VarZ, list_Nil()))))
			));
		} else if (FactorK4 == 3) { /* Axuvyz((Rxu /\ Ruv /\ Rvy /\ Ryz) -> Rxz) */
			TERM SecondTerm, ThirdTerm, FourthTerm, FifthTerm;
			FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarU, Flags, Precedence);
			SecondTerm = eml_AxiomaticTranslationRel(R, VarU, VarV, Flags, Precedence);
			ThirdTerm = eml_AxiomaticTranslationRel(R, VarV, VarY, Flags, Precedence);
			FourthTerm = eml_AxiomaticTranslationRel(R, VarY, VarZ, Flags, Precedence);
			FifthTerm = eml_AxiomaticTranslationRel(R, VarX, VarZ, Flags, Precedence);
			OutTerm = term_Create(fol_And(), 
					list_Cons(FirstTerm, list_Cons(SecondTerm, 
							list_Cons(ThirdTerm, list_List(FourthTerm)))));
			OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(FifthTerm)));
			OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
					list_Cons(term_Create(VarX, list_Nil()),
							list_Cons(term_Create(VarU, list_Nil()),
									list_Cons(term_Create(VarV, list_Nil()),
											list_Cons(term_Create(VarY, list_Nil()),
													list_List(term_Create(VarZ, list_Nil())))))
			));
		} else {
			eml_Error("No case for classical 4K.");
		}
		
		eml_PrintDT("\n[Class.Rel.Translation 4K^%d].[",FactorK4, R); eml_PrintT("].",OutTerm); 
		return OutTerm;
	}
	break;
	/**************************************************************
  	ALT1KK: []k1[]p -> []k2[]p 	Axyz(Rk1+1(x,y) /\ Rk2+1(x,z) -> y=z)
	 ***************************************************************/
	case ALT1KK: {
		SYMBOL VarY = eml_GetVar(VARY);
		SYMBOL VarZ = eml_GetVar(VARZ);
		SYMBOL VarU = eml_GetVar(VARU);
		SYMBOL VarV = eml_GetVar(VARV);
		SYMBOL VarW = eml_GetVar(VARW);
		SYMBOL VarG = eml_GetVar(VARG);
		int FactorK1 = Axiom.Parameter1;
		int FactorK2 = Axiom.Parameter2;
		
		if ((FactorK1 == 1) && (FactorK2 == 1)) { /* Axyz((Eu(Rxu /\ Ruy) /\ Ev(Rxv /\ Rvz)) -> y=z) */
			TERM SecondTerm, ThirdTerm, FourthTerm, FifthTerm, ATerm, BTerm;
			FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarU, Flags, Precedence);
			SecondTerm = eml_AxiomaticTranslationRel(R, VarU, VarY, Flags, Precedence);
			ThirdTerm = eml_AxiomaticTranslationRel(R, VarX, VarV, Flags, Precedence);
			FourthTerm = eml_AxiomaticTranslationRel(R, VarV, VarZ, Flags, Precedence);
			FifthTerm = term_Create(fol_Equality(), list_Cons(term_Create(VarY, list_Nil()), 
					list_List(term_Create(VarZ, list_Nil()))));
			ATerm = eml_QuantifyTerm(fol_Exist(), term_Create(fol_And(), 
					list_Cons(FirstTerm, list_List(SecondTerm))), 
					list_List(term_Create(VarU, list_Nil()))
			);
			BTerm = eml_QuantifyTerm(fol_Exist(), term_Create(fol_And(), 
					list_Cons(ThirdTerm, list_List(FourthTerm))), 
					list_List(term_Create(VarV, list_Nil()))
			);
			OutTerm = term_Create(fol_And(), list_Cons(ATerm, list_List(BTerm)));
			OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(FifthTerm)));
			OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
					list_Cons(term_Create(VarX, list_Nil()),
							list_Cons(term_Create(VarY, list_Nil()),
									list_List(term_Create(VarZ, list_Nil())))
			));
		} else if ((FactorK1 == 1) && (FactorK2 == 2)) { /* Axyz((Eu(Rxu /\ Ruy) /\ Evw(Rxv /\ Rvw /\ Rwz)) -> y=z) */
			TERM SecondTerm, ThirdTerm, FourthTerm, FifthTerm, SixthTerm, ATerm, BTerm;
			FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarU, Flags, Precedence);
			SecondTerm = eml_AxiomaticTranslationRel(R, VarU, VarY, Flags, Precedence);
			ThirdTerm = eml_AxiomaticTranslationRel(R, VarX, VarV, Flags, Precedence);
			FourthTerm = eml_AxiomaticTranslationRel(R, VarV, VarW, Flags, Precedence);
			FifthTerm = eml_AxiomaticTranslationRel(R, VarW, VarZ, Flags, Precedence);
			SixthTerm = term_Create(fol_Equality(), list_Cons(term_Create(VarY, list_Nil()), 
					list_List(term_Create(VarZ, list_Nil()))));
			ATerm = eml_QuantifyTerm(fol_Exist(), term_Create(fol_And(), 
					list_Cons(FirstTerm, list_List(SecondTerm))), 
					list_List(term_Create(VarU, list_Nil()))
			);
			BTerm = eml_QuantifyTerm(fol_Exist(), term_Create(fol_And(), 
					list_Cons(ThirdTerm, list_Cons(FourthTerm, list_List(FifthTerm)))), 
					list_Cons(term_Create(VarV, list_Nil()),
							list_List(term_Create(VarW, list_Nil()))
			));
			OutTerm = term_Create(fol_And(), list_Cons(ATerm, list_List(BTerm)));
			OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(SixthTerm)));
			OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
					list_Cons(term_Create(VarX, list_Nil()),
							list_Cons(term_Create(VarY, list_Nil()),
									list_List(term_Create(VarZ, list_Nil())))
			));
		} else if ((FactorK1 == 2) && (FactorK2 == 1)) { /* Axyz((Euw(Rxu /\ Ruw /\ Rwy) /\ Ev(Rxv /\ Rvz)) -> y=z) */
			TERM SecondTerm, ThirdTerm, FourthTerm, FifthTerm, SixthTerm, ATerm, BTerm;
			FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarU, Flags, Precedence);
			SecondTerm = eml_AxiomaticTranslationRel(R, VarU, VarW, Flags, Precedence);
			ThirdTerm = eml_AxiomaticTranslationRel(R, VarW, VarY, Flags, Precedence);
			FourthTerm = eml_AxiomaticTranslationRel(R, VarX, VarV, Flags, Precedence);
			FifthTerm = eml_AxiomaticTranslationRel(R, VarV, VarZ, Flags, Precedence);
			SixthTerm = term_Create(fol_Equality(), list_Cons(term_Create(VarY, list_Nil()), 
					list_List(term_Create(VarZ, list_Nil()))));
			ATerm = eml_QuantifyTerm(fol_Exist(), term_Create(fol_And(), 
					list_Cons(FirstTerm, list_Cons(SecondTerm, list_List(ThirdTerm)))), 
					list_Cons(term_Create(VarU, list_Nil()),
							list_List(term_Create(VarW, list_Nil()))
					)
			);
			BTerm = eml_QuantifyTerm(fol_Exist(), term_Create(fol_And(), 
					list_Cons(FourthTerm, list_List(FifthTerm))), 
					list_List(term_Create(VarV, list_Nil()))
			);
			OutTerm = term_Create(fol_And(), list_Cons(ATerm, list_List(BTerm)));
			OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(SixthTerm)));
			OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
					list_Cons(term_Create(VarX, list_Nil()),
							list_Cons(term_Create(VarY, list_Nil()),
									list_List(term_Create(VarZ, list_Nil())))
			));
		} else if ((FactorK1 == 2) && (FactorK2 == 2)) { /* Axyz((Euw(Rxu/\Ruw/\Rwy)/\Evg(Rxv/\Rvg/\Rgz)) -> y=z) */
			TERM SecondTerm, ThirdTerm, FourthTerm, FifthTerm, SixthTerm, SeventhTerm, ATerm, BTerm;
			FirstTerm = eml_AxiomaticTranslationRel(R, VarX, VarU, Flags, Precedence);
			SecondTerm = eml_AxiomaticTranslationRel(R, VarU, VarW, Flags, Precedence);
			ThirdTerm = eml_AxiomaticTranslationRel(R, VarW, VarY, Flags, Precedence);
			FourthTerm = eml_AxiomaticTranslationRel(R, VarX, VarV, Flags, Precedence);
			FifthTerm = eml_AxiomaticTranslationRel(R, VarV, VarG, Flags, Precedence);
			SixthTerm = eml_AxiomaticTranslationRel(R, VarG, VarZ, Flags, Precedence);
			SeventhTerm = term_Create(fol_Equality(), list_Cons(term_Create(VarY, list_Nil()), 
					list_List(term_Create(VarZ, list_Nil()))));
			ATerm = eml_QuantifyTerm(fol_Exist(), term_Create(fol_And(), 
					list_Cons(FirstTerm, list_Cons(SecondTerm, list_List(ThirdTerm)))), 
					list_Cons(term_Create(VarU, list_Nil()),
							list_List(term_Create(VarW, list_Nil()))
			));
			BTerm = eml_QuantifyTerm(fol_Exist(), term_Create(fol_And(), 
					list_Cons(FourthTerm, list_Cons(FifthTerm, list_List(SixthTerm)))), 
					list_Cons(term_Create(VarV, list_Nil()),
							list_List(term_Create(VarG, list_Nil()))
			));
			OutTerm = term_Create(fol_And(), list_Cons(ATerm, list_List(BTerm)));
			OutTerm = term_Create(fol_Implies(), list_Cons(OutTerm, list_List(SeventhTerm)));
			OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, 
					list_Cons(term_Create(VarX, list_Nil()),
							list_Cons(term_Create(VarY, list_Nil()),
									list_List(term_Create(VarZ, list_Nil())))
			));
		} else {
			eml_Error("No case for classical Alt1KK.");
		}
		 
		eml_PrintD("\n[Class.Rel.Translation Alt1KK^%d",FactorK1);	eml_PrintDT("%d].[",FactorK2, R);
		eml_PrintT("].", OutTerm);		
		return OutTerm;
	}
	break;
	default:
		eml_Error("No case in eml_ProcessClassicalLogic()."); break;
	}
	return OutTerm;
}

static void eml_DefineNewDefs(TERM Term, AXIOMDEFLIST *DEFs, LIST *OutTerms,
		FLAGSTORE Flags, PRECEDENCE Precedence, BOOL Recursive) 
/**************************************************************
  SUMMARY: Define new DEF terms, recursive, and with a test for duplication
 ***************************************************************/
{
	SYMBOL Top = term_TopSymbol(Term);
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);

	if (eml_IsBoxSymbol(Top)) { /* [] */
		if ( (!eml_ListContains(&(*DEFs).BoxDef, Term)) 
				&& (!eml_ListContains(&(*DEFs).XtraBoxDef, Term)) ) { /* build Def for the new Unit */
			LIST ResultList = list_Nil();
			BOOL WithShortCut = eml_SetPositiveShortcut(); /* usually TRUE */
			ResultList = eml_DEF(term_Copy(Term), VarX, VarY, WithShortCut,	Flags, Precedence);
			if(!list_Empty(ResultList)) {
				*OutTerms = eml_ListAddList(ResultList, *OutTerms);
			}
		}
	}

	if (Recursive==TRUE) {
		if (eml_IsBoxSymbol(Top)) {	/* two arguments, the first is the dummy, and ignored */
			eml_DefineNewDefs(term_SecondArgument(Term), DEFs,OutTerms, Flags, Precedence, Recursive);
		} else {
			LIST Scan;
			for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
				eml_DefineNewDefs((TERM)list_Car(Scan), DEFs, OutTerms, Flags, Precedence, Recursive);
			}
		}
	}
	
    return;
}

/*static TERM eml_ProcessLogicNONE (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/ **************************************************************
  INPUT: Infomation to Process Logic None for this problem.
  SUMMARY: Does Nothing.
 *************************************************************** /
{
	TERM OutTerm=NULL;
	return OutTerm;
}*/

static TERM eml_ProcessLogicSR (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic SR for this problem.
  RETURNS: Terms representing Logic SR additions for this problem.
  SUMMARY: 	AxAy(R(x,y)vQ[]p(y)vQp(y)) 			[]([]p->p)
  			No New Symbols are created to be defined
 ***************************************************************/
{
	TERM OutTerm=NULL, FirstTerm, SecondTerm, ThirdTerm; 
	SYMBOL Symbolmore = eml_CreateAxiomSymbol(Def, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	
	if ( eml_IsFalseTerm(term_SecondArgument(Def)) == TRUE ) {
		ThirdTerm = term_Create(fol_False(), list_Nil()); /* QF(y) = false */
	} else {
		TERM TmpTerm = term_SecondArgument(term_Copy(Def)); 
		SYMBOL Symbolless = eml_CreateAxiomSymbol(TmpTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Qp */
		ThirdTerm = term_Create(Symbolless, list_List(term_Create(VarY, list_Nil()))); /* Qp(y) */
	}
	
	FirstTerm = eml_Negate(eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
						VarX, VarY, Flags, Precedence)); /* R(x,y) */
	SecondTerm = eml_Negate(term_Create(Symbolmore, list_List(term_Create(VarY, list_Nil())))); /* Q[]p(y) */
	
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_Cons(SecondTerm, list_List(ThirdTerm))));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_Cons(term_Create(VarX, list_Nil()), 
			list_List(term_Create(VarY, list_Nil()))) ); /* AxAy */
	
	eml_PrintS("\n[Axiom SR]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicG (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic G for this problem.
  RETURNS: Terms representing Logic G additions for this problem.
  SUMMARY: 	Ax(Ay(Rxy\/Q[]p(y))\/Ay(Rxy\/Q[]p(y))     <>[]p->[]<>p
  			[]p New Symbols are created to be defined
 ***************************************************************/
{
	TERM OutTerm=NULL, FirstTerm, SecondTerm; 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL Symbolless, Symbolmore;
	
	/* No special handling for false is required */
	Symbolless = eml_CreateAxiomSymbol(term_Copy(Def), eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	
	{
		TERM CopyTerm = term_Copy(Def); /* []p */
		TERM TmpTermP = eml_Negate(term_SecondArgument(CopyTerm)); /* p */
		TERM TmpTermR = term_FirstArgument(CopyTerm); /* r */
		TERM SymbolTerm = term_Create(eml_BOX, list_Cons(TmpTermR, list_List(TmpTermP))); /* []p */
		Symbolmore = eml_CreateAxiomSymbol(SymbolTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	}

	FirstTerm = term_Create(fol_Or(), list_Cons(eml_Negate(
			eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
			VarX, VarY, Flags, Precedence)), /* R(x,y) */
			list_List(eml_Negate(term_Create(Symbolless, list_List(term_Create(VarY, list_Nil()))))))); /* Q[]p(y) */ 
	FirstTerm = eml_QuantifyTerm(fol_All(), FirstTerm, list_List(term_Create(VarY, list_Nil())) ); /* Ay */
	
	SecondTerm = term_Create(fol_Or(), list_Cons(eml_Negate(
			eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
			VarX, VarY, Flags, Precedence)), /* R(x,y) */
			list_List(eml_Negate(term_Create(Symbolmore, list_List(term_Create(VarY, list_Nil()))))))); /* Q[]p(y) */
	SecondTerm = eml_QuantifyTerm(fol_All(), SecondTerm, list_List(term_Create(VarY, list_Nil())) ); /* Ay */
		
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) ); /* Ax */
	
	{ /* ---------------------------------- define new symbol []p */
		TERM NewTerm = NULL, TmpTermP, TmpTermR, NewDef;
		LIST OutTerms = list_Nil();
		TERM CopyTerm = term_Copy(Def); /* []p */
		TmpTermP = eml_Negate(term_SecondArgument(CopyTerm)); 
		TmpTermR = term_FirstArgument(CopyTerm); /* r */
		NewDef = term_Create(eml_BOX, list_Cons(TmpTermR, list_List(TmpTermP))); /* []p */
	    eml_Print("\nFor Axiom G:");
	    eml_DefineNewDefs(NewDef, DEFs, &OutTerms, Flags, Precedence,TRUE);
	    if (list_Length(OutTerms) > 0) {
	    	NewTerm = term_Create(fol_And(), OutTerms);
	    }
	    if (NewTerm != NULL) {
	    	OutTerm = term_Create(fol_And(), list_Cons(NewTerm, list_List(OutTerm)));
	    }
	}
	
	eml_PrintS("\n[Axiom G]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicDEN (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic DEN for this problem.
  RETURNS: Terms representing Logic DEN additions for this problem.
  SUMMARY: 	Ax(Ey(R(x,y)/\Q[]p(y))\/Q[]p(x))  [][]p->[]p
  			No new ew Symbols are created to be defined
 ***************************************************************/
{
	TERM OutTerm=NULL, FirstTerm, SecondTerm; 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL Symbolless = eml_CreateAxiomSymbol(term_Copy(Def), eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	
	/* No special handling for false is required */
	FirstTerm = term_Create(fol_And(), list_Cons(
		eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarY, Flags, Precedence), /* R(x,y) */
		list_List(eml_Negate(term_Create(Symbolless, list_List(term_Create(VarY, list_Nil()))))))); /* Q[]p(y) */
	FirstTerm = eml_QuantifyTerm(fol_Exist(), FirstTerm, list_List(term_Create(VarY, list_Nil())) ); /* Ey */
	
	SecondTerm = term_Create(Symbolless, list_List(term_Create(VarX, list_Nil()))); /* Q[]p(x) */
			
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm))); 
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) ); /* Ax */
	
	eml_PrintS("\n[Axiom DEN]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicTR (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic TR for this problem.
  RETURNS: Terms representing Logic TR additions for this problem.
  SUMMARY: 	Ax((Q[]p(x)\/Qp(x))/\(Qp(x)\/Q[]p(x))) []p<->p
  			No New Symbols are created to be defined
 ***************************************************************/
{
	TERM OutTerm=NULL, FirstTerm, SecondTerm, ThirdTerm, FourthTerm; 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL Symbolmore = eml_CreateAxiomSymbol(term_Copy(Def), eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	
	if ( eml_IsFalseTerm(term_SecondArgument(Def)) == TRUE ) {
		ThirdTerm = term_Create(fol_False(), list_Nil()); /* QF(y) = false */
		FourthTerm = eml_Negate(term_Create(fol_False(), list_Nil())); /* QF(y) = false */	
	} else {
		TERM TmpTerm = term_SecondArgument(term_Copy(Def)); 
		SYMBOL Symbolless = eml_CreateAxiomSymbol(TmpTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Qp */
		ThirdTerm = term_Create(Symbolless, list_List(term_Create(VarX, list_Nil()))); /* Qp(x) */
		FourthTerm = eml_Negate(term_Create(Symbolless, list_List(term_Create(VarX, list_Nil())))); /* Qp(x) */
	}
	
	FirstTerm = term_Create(fol_Or(), list_Cons(
		eml_Negate(term_Create(Symbolmore, list_List(term_Create(VarX, list_Nil())))), /* Q[]p(x) */ 
		list_List(ThirdTerm))); /* Qp(x) */ 
	
	SecondTerm = term_Create(fol_Or(), list_Cons(
		term_Create(Symbolmore, list_List(term_Create(VarX, list_Nil()))), /* Q[]p(x) */
		list_List(FourthTerm))); /* Qp(x) */
	
	OutTerm = term_Create(fol_And(), list_Cons(FirstTerm, list_List(SecondTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) ); /* Ax */
	
	eml_PrintS("\n[Axiom TR]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicM (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic M for this problem.
  RETURNS: Terms representing Logic M additions for this problem.
  SUMMARY: 	Ax(Ey(R(x,y)/\Q[]p(y))\/Ey(R(x,y)/\Q[]p(y)))		[]<>p-><>[]p
  			New []p Symbols are created to be defined
 ***************************************************************/
{
	TERM OutTerm=NULL, FirstTerm, SecondTerm; 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL Symbolless, Symbolmore;
	Symbolless = eml_CreateAxiomSymbol(term_Copy(Def), eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	
	{ /* No special handling for false is required */
		TERM CopyTerm = term_Copy(Def); /* []p */
		TERM TmpTermP = eml_Negate(term_SecondArgument(CopyTerm)); /* p */
		TERM TmpTermR = term_FirstArgument(CopyTerm); /* r */
		TERM SymbolTerm = term_Create(eml_BOX, list_Cons(TmpTermR, list_List(TmpTermP))); /* []p */
		Symbolmore = eml_CreateAxiomSymbol(SymbolTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	}

	FirstTerm = term_Create(fol_And(), list_Cons(
		eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
		VarX, VarY, Flags, Precedence), /* R(x,y) */
		list_List(term_Create(Symbolmore, list_List(term_Create(VarY, list_Nil())))))); /* Q[]p(y) */
	FirstTerm = eml_QuantifyTerm(fol_Exist(), FirstTerm, list_List(term_Create(VarY, list_Nil())) ); /* Ay */
	
	SecondTerm = term_Create(fol_And(), list_Cons(
		eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
		VarX, VarY, Flags, Precedence), /* R(x,y) */
		list_List(term_Create(Symbolless, list_List(term_Create(VarY, list_Nil())))))); /* Q[]p(y) */
	SecondTerm = eml_QuantifyTerm(fol_Exist(), SecondTerm, list_List(term_Create(VarY, list_Nil())) ); /* Ay */
		
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) ); /* Ax */
	
	{ /* ---------------------------------- define new symbol []p */
		TERM NewTerm = NULL, TmpTermP, TmpTermR, NewDef;
		LIST OutTerms = list_Nil();
		TERM CopyTerm = term_Copy(Def); /* []p */
		TmpTermP = eml_Negate(term_SecondArgument(CopyTerm)); 
		TmpTermR = term_FirstArgument(CopyTerm); /* r */
		NewDef = term_Create(eml_BOX, list_Cons(TmpTermR, list_List(TmpTermP))); /* []p */
	    eml_Print("\nFor Axiom M:");
	    eml_DefineNewDefs(NewDef, DEFs, &OutTerms, Flags, Precedence,TRUE);
	    if (list_Length(OutTerms) > 0) {
	    	NewTerm = term_Create(fol_And(), OutTerms);
	    }
	    if (NewTerm != NULL) {
	    	OutTerm = term_Create(fol_And(), list_Cons(NewTerm, list_List(OutTerm)));
	    }
	}
	
	eml_PrintS("\n[Axiom M]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicW (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic W for this problem.
  RETURNS: Terms representing Logic W additions for this problem.
  SUMMARY: 	Ax(Ey(R(x,y)  /\  Q[]p(y)  /\  Qp(y))  \/  Q[]p(x))		[]([]p->p)->[]p
  			No New Symbols are created to be defined
 ***************************************************************/
{
	TERM OutTerm=NULL, FirstTerm, SecondTerm, ThirdTerm; 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL Symbolmore = eml_CreateAxiomSymbol(term_Copy(Def), eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	
	if ( eml_IsFalseTerm(term_SecondArgument(Def)) == TRUE ) {
		ThirdTerm = eml_Negate(term_Create(fol_False(), list_Nil())); /* QF(y) = false */		
	} else {
		TERM TmpTerm = term_SecondArgument(term_Copy(Def)); 
		SYMBOL Symbolless = eml_CreateAxiomSymbol(TmpTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Qp */
		ThirdTerm = eml_Negate(term_Create(Symbolless, list_List(term_Create(VarY, list_Nil())))); /* Qp(y) */
	}
	
	FirstTerm = term_Create(fol_And(), list_Cons(
		eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarY, Flags, Precedence), /* R(x,y) */
		list_Cons(term_Create(Symbolmore, list_List(term_Create(VarY, list_Nil()))), /* Q[]p(y) */
		list_List(ThirdTerm)))); /* Qp(y) */ 
	FirstTerm = eml_QuantifyTerm(fol_Exist(), FirstTerm, list_List(term_Create(VarY, list_Nil())) ); /* Ey */
	
	SecondTerm = term_Create(Symbolmore, list_List(term_Create(VarX, list_Nil()))); /* Q[]p(x) */
	
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) ); /* Ax */ 
	
	eml_PrintS("\n[Axiom W]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicBK (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic BK for this problem.
  RETURNS: Terms representing Logic BK additions for this problem.
  SUMMARY: 	Axiom B^2:  <><>[]p -> p		[][][]p -> p
  			Ax(Ay(R(x,y) v  Az(R(y,z) v  Q[]p(z))) v Qp(x))
  			Axiom B^3: <><><>[]p -> p		[][][][]p -> p
  			Ax(Ay(R(x,y)  v Az(R(y,z) v Au(R(z,u) v  Q[]p(u)))) v Qp(x))
  			No New Symbols are created to be defined
 ***************************************************************/
{
	TERM OutTerm, FirstTerm; 
	int FactorK = Axiom.Parameter1;
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL VarZ = eml_GetVar(VARZ);
	SYMBOL VarU = eml_GetVar(VARU);
	SYMBOL Symbolmore = eml_CreateAxiomSymbol(term_Copy(Def), eml_AXIOM, 1,symbol_STATLEX, Precedence); /* Q[]p */
	
	if ( eml_IsFalseTerm(term_SecondArgument(Def)) == TRUE ) {
		FirstTerm = term_Create(fol_False(), list_Nil()); /* QF(y) = false */
	} else {
		TERM TmpTerm = term_SecondArgument(term_Copy(Def)); 
		SYMBOL Symbolless = eml_CreateAxiomSymbol(TmpTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Qp */
		FirstTerm = term_Create(Symbolless, list_List(term_Create(VarX, list_Nil()))); /* Qp(x) */			
	}
	
	if (FactorK == 2) { /* Ax(Ay(R(x,y) v  Az(R(y,z) v  Q[]p(z))) v Qp(x)) */
		TERM SecondTerm, ThirdTerm, FourthTerm;

		SecondTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarY, Flags, Precedence);
		SecondTerm = eml_Negate(SecondTerm); /* Rxy */
		ThirdTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarY, VarZ, Flags, Precedence);
		ThirdTerm = eml_Negate(ThirdTerm); /* Ryz */
		FourthTerm = eml_Negate(term_Create(Symbolmore, list_List(term_Create(VarZ,	list_Nil())))); /* Q[]p(z) */
		OutTerm = term_Create(fol_Or(), list_Cons(ThirdTerm, list_List(FourthTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarZ, list_Nil()))); /* Az */
		OutTerm = term_Create(fol_Or(),	list_Cons(SecondTerm, list_List(OutTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarY, list_Nil())) ); /* Ay */
		OutTerm = term_Create(fol_Or(),	list_Cons(FirstTerm, list_List(OutTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) ); /* Ax */
		
	} else if (FactorK == 3) { /* Ax(Ay(R(x,y)  v Az(R(y,z) v Au(R(z,u) v  Q[]p(u)))) v Qp(x)) */
		TERM SecondTerm, ThirdTerm, FourthTerm, FifthTerm;

		SecondTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarY, Flags, Precedence);
		SecondTerm = eml_Negate(SecondTerm); /* Rxy */
		ThirdTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarY, VarZ, Flags, Precedence);
		ThirdTerm = eml_Negate(ThirdTerm); /* Ryz */
		FourthTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarZ, VarU, Flags, Precedence);
		FourthTerm = eml_Negate(FourthTerm); /* Rzu */
		FifthTerm = eml_Negate(term_Create(Symbolmore, list_List(term_Create(VarU, list_Nil())))); /* Q[]rp(u) */
		OutTerm = term_Create(fol_Or(), list_Cons(FourthTerm, list_List(FifthTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarU, list_Nil()))); /* Au */
		OutTerm = term_Create(fol_Or(),	list_Cons(ThirdTerm, list_List(OutTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarZ, list_Nil()))); /* Az */
		OutTerm = term_Create(fol_Or(),	list_Cons(SecondTerm, list_List(OutTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarY, list_Nil()))); /* Ay */
		OutTerm = term_Create(fol_Or(),	list_Cons(FirstTerm, list_List(OutTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil()))); /* Ax */
	} else {
		eml_Error("Undefined Axiom in K-B.");
		return NULL;
	}
			
	eml_PrintDS("\n[Axiom B^%d]:[",FactorK, Axiom.Modality); eml_PrintT(" in term:", Def); 
	eml_PrintT("].\n", OutTerm);
	return OutTerm;
}

static TERM eml_ProcessLogicCR (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic CR for this problem.
  RETURNS: Terms representing Logic CR additions for this problem.
  SUMMARY: 	[R]p -> [S]p
  			Ax(Q[R]p(x) v Q[S]p(x))
  			No New Symbols are created to be defined
 ***************************************************************/
{ /* only R's will get through to here */
	TERM OutTerm, FirstTerm, SecondTerm; 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL Symbol1, Symbol2;
	SYMBOL R = term_TopSymbol(term_FirstArgument(Def));
	
	{ /* No special handling for false is required */
		TERM TermP = term_SecondArgument(term_Copy(Def));
		TERM TermBoxRP = term_Create(eml_BOX, list_Cons(term_Create(Axiom.Modality, list_Nil()), list_List(TermP)));
		TERM TermBoxSP;
		TermP = term_SecondArgument(term_Copy(Def));
		TermBoxSP = term_Create(eml_BOX, list_Cons(term_Create(Axiom.Modality2, list_Nil()), list_List(TermP)));
		Symbol1 = eml_CreateAxiomSymbol(TermBoxRP, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[R]p */
		Symbol2 = eml_CreateAxiomSymbol(TermBoxSP, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[S]p */
	}
	
	if (symbol_Equal(R,Symbol1)) {
		eml_Error("Incorrect R modality in eml_ProcessLogicCR.");
	}
	
	FirstTerm =	eml_Negate(term_Create(Symbol1, list_List(term_Create(VarX, list_Nil())))); /* Q[R]p(x) */ 
	SecondTerm = term_Create(Symbol2, list_List(term_Create(VarX, list_Nil()))); /* Q[S]p(x) */
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) ); /* Ax */
	
	eml_PrintS("\n[Axiom CR]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicCR2 (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic CR2 for this problem.
  RETURNS: Terms representing Logic CR2 additions for this problem.
  SUMMARY: 	[R]p -> [S][R]p
  			Ax(Q[R]p(x) v Ay(S(x,y) v Q[R]p(y)))
  			[S][R]p
  			No New Symbols are created to be defined
 ***************************************************************/
{   /* only R's will get through to here */
	TERM OutTerm, FirstTerm, SecondTerm, ThirdTerm; 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL Symbol1;
	SYMBOL R = term_TopSymbol(term_FirstArgument(Def));
	
	{ /* No special handling for false is required */
		TERM TermP = term_SecondArgument(term_Copy(Def));
		TERM TermBoxRP = term_Create(eml_BOX, list_Cons(term_Create(Axiom.Modality, list_Nil()), list_List(TermP)));
		Symbol1 = eml_CreateAxiomSymbol(TermBoxRP, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[R]p */
	}
	
	if (symbol_Equal(R,Symbol1)) {
		eml_Error("Incorrect R modality in eml_ProcessLogicCR.");
	}
	
	FirstTerm =	eml_Negate(term_Create(Symbol1, list_List(term_Create(VarX, list_Nil())))); /* Q[R]p(x) */ 
	SecondTerm = eml_Negate(eml_AxiomaticTranslationRel(term_Create(Axiom.Modality2, list_Nil()),
			VarX, VarY, Flags, Precedence)), /* S(x,y) */
	ThirdTerm = term_Create(Symbol1, list_List(term_Create(VarY, list_Nil()))); /* Q[R]p(y) */
	OutTerm = term_Create(fol_Or(), list_Cons(SecondTerm, list_List(ThirdTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarY, list_Nil())) ); /* Ay */
	
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(OutTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) ); /* Ax */
		
	eml_PrintS("\n[Axiom CR2]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicCR3 (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic CR3 for this problem.
  RETURNS: Terms representing Logic CR3 additions for this problem.
  SUMMARY: 	[R]p -> [R][S]p
  			Ax(Q[R]p(x) v Ay(R(x,y) v  Q[S]p(y)))
  			[R][S]p
  			No New Symbols are created to be defined
 ***************************************************************/
{   /* only R's will get through to here */
	TERM OutTerm, FirstTerm, SecondTerm, ThirdTerm; 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL Symbol1, Symbol2;
	SYMBOL R = term_TopSymbol(term_FirstArgument(Def));
	
	{ /* No special handling for false is required */
		TERM TermP = term_SecondArgument(term_Copy(Def));
		TERM TermBoxRP = term_Create(eml_BOX, list_Cons(term_Create(Axiom.Modality, list_Nil()), list_List(TermP)));
		TERM TermBoxSP;
		TermP = term_SecondArgument(term_Copy(Def));
		TermBoxSP = term_Create(eml_BOX, list_Cons(term_Create(Axiom.Modality2, list_Nil()), list_List(TermP)));
		Symbol1 = eml_CreateAxiomSymbol(TermBoxRP, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[R]p */
		Symbol2 = eml_CreateAxiomSymbol(TermBoxSP, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[S]p */
	}
	
	if (symbol_Equal(R,Symbol1)) {
		eml_Error("Incorrect R modality in eml_ProcessLogicCR.");
	}
	
	FirstTerm =	eml_Negate(term_Create(Symbol1, list_List(term_Create(VarX, list_Nil())))); /* Q[R]p(x) */ 
	SecondTerm = eml_Negate(eml_AxiomaticTranslationRel(term_Create(Axiom.Modality, list_Nil()),
			VarX, VarY, Flags, Precedence)), /* S(x,y) */
	ThirdTerm = term_Create(Symbol2, list_List(term_Create(VarY, list_Nil()))); /* Q[R]p(y) */
	OutTerm = term_Create(fol_Or(), list_Cons(SecondTerm, list_List(ThirdTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarY, list_Nil())) ); /* Ay */
	
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(OutTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) ); /* Ax */
		
	eml_PrintS("\n[Axiom CR3]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicDBBB (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic DBBB for this problem.
  RETURNS: Terms representing Logic DBBB additions for this problem.
  SUMMARY: 	<>[]p -> [][]p       [][]p -> [][]p    
  			Ax(Ay(R(x,y) v Q[]p(y)) v Ay(R(x,y) v Q[]p(y)))
  			No New Symbols are created to be defined
 ***************************************************************/
{
	TERM OutTerm=NULL, FirstTerm, SecondTerm; 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL Symbolmore = eml_CreateAxiomSymbol(term_Copy(Def), eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	/* No special handling for false is required */
	FirstTerm = term_Create(fol_Or(), list_Cons(
		eml_Negate(eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
	    VarX, VarY, Flags, Precedence)), /* R(x,y) */
		list_List(eml_Negate(term_Create(Symbolmore, list_List(term_Create(VarY, list_Nil()))))))); 
	FirstTerm = eml_QuantifyTerm(fol_All(), FirstTerm, list_List(term_Create(VarY, list_Nil())) );
	
	SecondTerm = term_Create(fol_Or(), list_Cons(
		eml_Negate(eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
		VarX, VarY, Flags, Precedence)), /* R(x,y) */
		list_List(term_Create(Symbolmore, list_List(term_Create(VarY, list_Nil())))))); 
	SecondTerm = eml_QuantifyTerm(fol_All(), SecondTerm, list_List(term_Create(VarY, list_Nil())) ); /* Ay */
	
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) );  /* Ax */
	
	eml_PrintS("\n[Axiom DBBB]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicH (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic H for this problem.
  RETURNS: Terms representing Logic H additions for this problem.
  SUMMARY: 	
  			No New Symbols are created to be defined
 ***************************************************************/
{
	TERM OutTerm=NULL;
	
	eml_Error("Sorry Not Implemented Yet");
	
	eml_PrintS("\n[Axiom H]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicT (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic T for this problem.
  RETURNS: Terms representing Logic T additions for this problem.
  SUMMARY: 	Reflexive ... 	[]p -> p	Ax( Q[]p(x) \/ Qp(x) )
  			No New Symbols are created to be defined
  			Input is []p i.e. [](r,p)
 ***************************************************************/
{
	TERM OutTerm, FirstTerm, SecondTerm; 
	SYMBOL SymbolT, SymbolTless;
	SYMBOL VarX = eml_GetVar(VARX);
	SymbolT = eml_CreateAxiomSymbol(Def, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */

	if (eml_IsFalseTerm(term_SecondArgument(Def)) == TRUE) { /* eml_TestFalse */
		FirstTerm = eml_Negate(term_Create(SymbolT, list_List(term_Create(VarX, list_Nil())))); 
		SecondTerm = term_Create(fol_False(), list_Nil());
	} else {
		{
			TERM TmpTerm = term_SecondArgument(term_Copy(Def)); 
			SymbolTless = eml_CreateAxiomSymbol(TmpTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Qp */
		}
		FirstTerm = eml_Negate(term_Create(SymbolT, list_List(term_Create(VarX, list_Nil())))); 
		SecondTerm = term_Create(SymbolTless, list_List(term_Create(VarX, list_Nil())));
	}
	
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));	
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())));
	
	eml_PrintS("\n[Axiom T]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
    return OutTerm;
}

static TERM eml_ProcessLogicD (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic D for this problem.  
  RETURNS: Terms representing Logic D additions for this problem.
  SUMMARY:	Serial   []p -> []p	Ax( Q[]p(x) \/ Q[]p(x) )
			A new symbol needs to be defined []p
 ***************************************************************/
{
	TERM OutTerm, FirstTerm, SecondTerm; 
	SYMBOL SymbolD, SymbolDNot;
	SYMBOL VarX = eml_GetVar(VARX);

	/* No special handling for false is required */
	
	SymbolD = eml_CreateAxiomSymbol(Def, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */

	{
		TERM CopyTerm = term_Copy(Def); /* []p */
		TERM TmpTermP = eml_Negate(term_SecondArgument(CopyTerm)); 
		TERM TmpTermR = term_FirstArgument(CopyTerm); /* r */
		TERM SymbolTerm = term_Create(eml_BOX, list_Cons(TmpTermR, list_List(TmpTermP))); /* []p */
		SymbolTerm = eml_Negate(SymbolTerm); /* []p */
		SymbolDNot = eml_CreateAxiomSymbol(SymbolTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
		/*term_Delete(TmpTermP); term_Delete(TmpTermR);*/
	}
	
	FirstTerm = eml_Negate(term_Create(SymbolD, list_List(term_Create(VarX, list_Nil())))); 
	SecondTerm = term_Create(SymbolDNot, list_List(term_Create(VarX, list_Nil()))); /* Q[]p(x) */
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm))); /* Q[]p(x) \/ Q~[]p(x) */
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())));
	
	{ /* ---------------------------------- define new symbol []p */
		TERM NewTerm = NULL, TmpTermP, TmpTermR, NewDef;
		LIST OutTerms = list_Nil();
		TERM CopyTerm = term_Copy(Def); /* []p */
		TmpTermP = eml_Negate(term_SecondArgument(CopyTerm)); 
		TmpTermR = term_FirstArgument(CopyTerm); /* r */
		NewDef = term_Create(eml_BOX, list_Cons(TmpTermR, list_List(TmpTermP))); /* []p */
	    eml_Print("\nFor Axiom D:");
	    eml_DefineNewDefs(NewDef, DEFs, &OutTerms, Flags, Precedence,TRUE);
	    if (list_Length(OutTerms) > 0) {
	    	NewTerm = term_Create(fol_And(), OutTerms);
	    }
	    if (NewTerm != NULL) {
	    	OutTerm = term_Create(fol_And(), list_Cons(NewTerm, list_List(OutTerm)));
	    }
	}
	
	eml_PrintS("\n[Axiom D]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
	return OutTerm;
}

static TERM eml_ProcessLogic4 (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic 4 for this problem.
  RETURNS: Terms representing Logic 4 additions for this problem.
  SUMMARY: Transitive  []p -> [][]p	Ax( Q[]p(x) \/ Ay(R(x,y) \/ Q[]p(y)) )
  		   No new symbols are created
 ***************************************************************/
{
	TERM OutTerm, FirstTerm, SecondTerm; 
	SYMBOL Symbol4;
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	/* No special handling for false is required */
	
	Symbol4 = eml_CreateAxiomSymbol(Def, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	FirstTerm = eml_Negate(term_Create(Symbol4, list_List(term_Create(VarX, list_Nil())))); /* Q[]p(x) */
	SecondTerm = term_Create(fol_Or(), list_Cons(
			eml_Negate(eml_AxiomaticTranslationRel(
					term_Copy(term_FirstArgument(Def)), /* r */
					VarX, VarY, Flags, Precedence)), /* R(x,y) */
					list_List(term_Create(Symbol4, list_List(term_Create(VarY, list_Nil())))) /* Q[]p(y) */
	)); /* R(x,y) \/ Q[]p(y)) */
	SecondTerm = eml_QuantifyTerm(fol_All(), SecondTerm, list_List(term_Create(VarY, list_Nil())));

	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) );
	
	eml_PrintS("\n[Axiom 4]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
	return OutTerm;
}

static TERM eml_ProcessLogic5 (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Axiom 5 for this problem.
  RETURNS: Terms representing Axiom 5 additions for this problem.
  SUMMARY: 	Euclidean  [][]p -> []p	Ax( Ay(R(x,y) \/ Q[]p(y)) \/ Q[]p(x) )
			Need to define & process via the axiom a term of the form [][]p
 ***************************************************************/
{
	TERM OutTerm = NULL, FirstTerm, SecondTerm; 
	SYMBOL Symbol5;
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	/* No special handling for false is required */
	
	Symbol5 = eml_CreateAxiomSymbol(Def/*Term*/, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	FirstTerm = term_Create(Symbol5, list_List(term_Create(VarX, list_Nil()))); /* Q[]p(x) */
	SecondTerm = term_Create(fol_Or(), list_Cons(
			eml_Negate(eml_AxiomaticTranslationRel(
					term_Copy(term_FirstArgument(Def/*Term*/)), /* r */
					VarX, VarY, Flags, Precedence)), /* R(x,y) */
					list_List(eml_Negate(term_Create(Symbol5, 
							list_List(term_Create(VarY, list_Nil()))))) /* Q[]p(y) */
	) ); /* R(x,y) \/ Q[]p(y) */
	SecondTerm = eml_QuantifyTerm(fol_All(), SecondTerm, list_List(term_Create(VarY, list_Nil())));
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())));
		
	eml_PrintS("\n[Axiom 5]:[", Axiom.Modality); eml_PrintT(" in term:", Def); 
	eml_PrintT("].\n", OutTerm);

	return OutTerm;
}

static TERM eml_ProcessLogicB (AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Infomation to Process Logic B for this problem.
  RETURNS: Terms representing Logic B additions for this problem.
  SUMMARY: 	Symmetry  [][]p -> p 
  			Ax( Ay(R(x,y) \/ Q[]p(y)) \/ Qp(x) )
  			No new symbols have been defined
 ***************************************************************/
{
	TERM OutTerm, FirstTerm, SecondTerm; 
	SYMBOL SymbolB, SymbolBless;
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY); 
	SymbolB = eml_CreateAxiomSymbol(Def, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */

	if (eml_IsFalseTerm(term_SecondArgument(Def)) == TRUE) { /* eml_TestFalse */
		SecondTerm = term_Create(fol_False(), list_Nil());
	} else {
		{
			TERM TmpTerm = term_SecondArgument(term_Copy(Def)); /* p */
			SymbolBless = eml_CreateAxiomSymbol(TmpTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Qp */
			/*term_Delete(TmpTerm);*/
		}
		SecondTerm = term_Create(SymbolBless, list_List(term_Create(VarX, list_Nil()))); /* Qp(x) */
	}

	FirstTerm = term_Create(fol_Or(), list_Cons(
			eml_Negate(eml_AxiomaticTranslationRel(
					term_Copy(term_FirstArgument(Def)), /* r */
					VarX, VarY, Flags, Precedence)), /* R(x,y) */
					list_List(eml_Negate(term_Create(SymbolB,
							list_List(term_Create(VarY, list_Nil()))))) /* Q[]p(y) */
	));
	FirstTerm = eml_QuantifyTerm(fol_All(), FirstTerm, list_List(term_Create(VarY, list_Nil()))	);
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil()))	);
	
	eml_PrintS("\n[Axiom B]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
	return OutTerm;
}

static TERM eml_ProcessLogicAlt1(AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:
  RETURNS:
  SUMMARY: []p -> []p or ... functionality
  		  Ax( Q[]p(x) \/ Q[]p(x) ) from []p
  		  A new symbol of the form []p has been defined.
 ***************************************************************/
{
	TERM OutTerm, FirstTerm, SecondTerm; 
	SYMBOL SymbolNN, SymbolN;
	SYMBOL VarX = eml_GetVar(VARX);

	SymbolNN = eml_CreateAxiomSymbol(eml_Negate(
			term_Copy(Def)), eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */

	{ /* No special handling for false is required */
		TERM TmpCopy = term_Copy(Def);
		TERM TmpTerm = eml_Negate(term_SecondArgument(TmpCopy)); /* p */
		TmpTerm = term_Create(eml_BOX, list_Cons(term_FirstArgument(TmpCopy), list_List(TmpTerm))); /* []r,p */
		SymbolN = eml_CreateAxiomSymbol(TmpTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	}

	FirstTerm = eml_Negate(term_Create(SymbolNN, list_List(term_Create(VarX, list_Nil())))); 
	SecondTerm = term_Create(SymbolN, list_List(term_Create(VarX, list_Nil())));
	OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
	OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil()))	);
	{ /* ---------------------------------- define new symbol []p */
		TERM NewTerm = NULL, TmpTermP, TmpTermR, NewDef;
		LIST OutTerms = list_Nil();
		TERM CopyTerm = term_Copy(Def); /* []p */
		TmpTermP = eml_Negate(term_SecondArgument(CopyTerm)); /* p */
		TmpTermR = term_FirstArgument(CopyTerm); /* r */
		NewDef = term_Create(eml_BOX, list_Cons(TmpTermR, list_List(TmpTermP))); /* []p */
		eml_Print("\nFor Axiom ALt1:");
		eml_DefineNewDefs(NewDef, DEFs, &OutTerms, Flags, Precedence,TRUE);
		if (list_Length(OutTerms) > 0) {
			NewTerm = term_Create(fol_And(), OutTerms);
		}
		if (NewTerm != NULL) {
			OutTerm = term_Create(fol_And(), list_Cons(NewTerm, list_List(OutTerm)));
		}
	}
	
	eml_PrintS("\n[Axiom Alt1]:[", Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
	return OutTerm;
}

static TERM eml_ProcessLogic5K(AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:
  RETURNS:
  SUMMARY: 		define & process via the axiom a term of the form [][]p
  	    []k[]p -> []p 	 Ax( Q[]p(x) \/ Ay(~Rk(x,y) \/ Q[]p(y))  ) from []p
   5^2  [][][]p -> []p     Ax( Q[]rp(x) \/ Azy(Rxz \/ Rzy \/ Q[]rp(y)) )
   5^3	[][][][]p -> []p   Ax( Q[]rp(x) \/ Azuy(Rxz \/ Rzu \/ Ruy \/ Q[]rp(y)) )
 ***************************************************************/
{
	TERM OutTerm;/*, BoxNotBoxDefTerm=NULL;*/ 
	SYMBOL Symbol;
	int FactorK5 = Axiom.Parameter1;
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL VarZ = eml_GetVar(VARZ);
	SYMBOL VarU = eml_GetVar(VARU);
	/* No special handling for false is required */
	
	Symbol = eml_CreateAxiomSymbol(term_Copy(Def/*Term*/), eml_AXIOM, 1,symbol_STATLEX, Precedence); /* Q[]p */
	if (FactorK5 == 2) { /* Ax( Q[]rp(x) \/ Azy(Rxz \/ Rzy \/ Q[]rp(y)) ) */
		TERM FirstTerm, SecondTerm, ThirdTerm, FourthTerm;

		FirstTerm = term_Create(Symbol,	list_List(term_Create(VarX, list_Nil()))); /* Q[]p(x) */
		SecondTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def/*Term*/)), /* r */
				VarX, VarZ, Flags, Precedence);
		SecondTerm = eml_Negate(SecondTerm); /* Rxz */
		ThirdTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def/*Term*/)), /* r */
				VarZ, VarY, Flags, Precedence);
		ThirdTerm = eml_Negate(ThirdTerm); /* Rzy */
		FourthTerm = eml_Negate(term_Create(Symbol, list_List(term_Create(VarY,	list_Nil())))); /* Q[]rp(y) */
		OutTerm = term_Create(fol_Or(), list_Cons(SecondTerm, list_Cons(
				ThirdTerm, list_List(FourthTerm))));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_Cons(term_Create(
				VarZ, list_Nil()), list_List(term_Create(VarY, list_Nil())))); /* Azy */
		OutTerm = term_Create(fol_Or(),	list_Cons(FirstTerm, list_List(OutTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) );

	} else if (FactorK5 == 3) { /* Ax( Q[]rp(x) \/ Azuy(Rxz \/ Rzu \/ Ruy \/ Q[]rp(y)) ) */
		TERM FirstTerm, SecondTerm, ThirdTerm, FourthTerm, FifthTerm;

		FirstTerm = term_Create(Symbol,	list_List(term_Create(VarX, list_Nil()))); /* Q[]rp(x) */
		SecondTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def/*Term*/)), /* r */
				VarX, VarZ, Flags, Precedence);
		SecondTerm = eml_Negate(SecondTerm); /* Rxz */
		ThirdTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def/*Term*/)), /* r */
				VarZ, VarU, Flags, Precedence);
		ThirdTerm = eml_Negate(ThirdTerm); /* Rzu */
		FourthTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def/*Term*/)), /* r */
				VarU, VarY, Flags, Precedence);
		FourthTerm = eml_Negate(FourthTerm); /* Ruy */
		FifthTerm = eml_Negate(term_Create(Symbol, list_List(term_Create(VarY, list_Nil())))); /* Q[]rp(y) */
		OutTerm = term_Create(fol_Or(), list_Cons(SecondTerm, list_Cons(
				ThirdTerm, list_Cons(FourthTerm, list_List(FifthTerm)))));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_Cons(term_Create(
				VarZ, list_Nil()), list_Cons(term_Create(VarU, list_Nil()),
				list_List(term_Create(VarY, list_Nil()))))); /* Azuy */
		OutTerm = term_Create(fol_Or(),
				list_Cons(FirstTerm, list_List(OutTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())));
	} else {
		eml_Error("Undefined Axiom in K5K.");
		return NULL;
	}

	eml_PrintDS("\n[Axiom 5K^%d]:[",FactorK5, Axiom.Modality); eml_PrintT(" in term:", Def); 
	eml_PrintT("].\n", OutTerm);
	return OutTerm;
}

static TERM eml_ProcessLogic4K(AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:
  RETURNS:
  SUMMARY: 	[]p -> []k[]p	Ax( Q[]p(x) \/ Ay(Rk(x,y) \/ Q[]p(y)) ) from []p
  	4^2	[]p -> [][][]p	Ax(Q[]rp(x) \/ Ayz(R(xy) \/ R(yz) \/ Q[]rp(z))) )
  	4^3	[]p -> [][][][]p Ax(Q[]rp(x) \/ Ayzu(R(xy) \/ R(yz) \/ R(zu) \/ Q[]rp(u)))
  			No new symbols have been defined
 ***************************************************************/
{
	TERM OutTerm; 
	SYMBOL Symbol;
	int FactorK4 = Axiom.Parameter1; /* flag_GetFlagValue(Flags, flag_EMLAXIOMLOGICFACTOR4); */
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL VarZ = eml_GetVar(VARZ);
	SYMBOL VarU = eml_GetVar(VARU);
	Symbol = eml_CreateAxiomSymbol(term_Copy(Def), eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	/* No special handling for false is required */
	
	if (FactorK4 == 2) { /* Ax(Q[]rp(x) \/ Ayz(R(xy) \/ R(yz) \/ Q[]rp(z))) ) */
		TERM FirstTerm, SecondTerm, ThirdTerm, FourthTerm; 
			
		FirstTerm = eml_Negate(term_Create(Symbol, list_List(term_Create(VarX, list_Nil())))); /* Q[]rp(x) */
		SecondTerm = eml_AxiomaticTranslationRel(
				term_Copy(term_FirstArgument(Def)), /*r*/
				VarX, VarY, Flags, Precedence); /* R(xy) */
		SecondTerm = eml_Negate(SecondTerm); /* R(xy) */
		ThirdTerm = eml_AxiomaticTranslationRel(
				term_Copy(term_FirstArgument(Def)), /*r*/
				VarY, VarZ, Flags, Precedence); /* R(yz) */
		ThirdTerm = eml_Negate(ThirdTerm); /* R(yz) */
		FourthTerm = term_Create(Symbol, list_List(term_Create(VarZ, list_Nil()))); /* Q[]rp(z) */
		OutTerm = term_Create(fol_Or(), list_Cons(SecondTerm, list_Cons(ThirdTerm, list_List(FourthTerm))));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm,
				list_Cons(term_Create(VarY, list_Nil()), list_List(term_Create(VarZ, list_Nil())))  
		); /* Ayz */
		OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(OutTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) );
	} else if (FactorK4 == 3) { /* Ax(Q[]rp(x) \/ Ayzu(R(xy) \/ R(yz) \/ R(zu) \/ Q[]rp(u))) */
		TERM FirstTerm, SecondTerm, ThirdTerm, FourthTerm, FifthTerm; 

		FirstTerm = eml_Negate(term_Create(Symbol, list_List(term_Create(VarX, list_Nil())))); /* Q[]rp(x) */
		SecondTerm = eml_AxiomaticTranslationRel(
				term_Copy(term_FirstArgument(Def)), /*r*/
				VarX, VarY, Flags, Precedence); /* R(xy) */
		SecondTerm = eml_Negate(SecondTerm); /* R(xy) */
		ThirdTerm = eml_AxiomaticTranslationRel(
				term_Copy(term_FirstArgument(Def)), /*r*/
				VarY, VarZ, Flags, Precedence); /* R(yz) */
		ThirdTerm = eml_Negate(ThirdTerm); /* R(yz) */
		FourthTerm = eml_AxiomaticTranslationRel(
				term_Copy(term_FirstArgument(Def)), /*r*/
				VarZ, VarU, Flags, Precedence); /* R(zu) */
		FourthTerm = eml_Negate(FourthTerm); /* R(zu) */
		FifthTerm = term_Create(Symbol, list_List(term_Create(VarU, list_Nil()))); /* Q[]rp(u) */
		OutTerm = term_Create(fol_Or(), 
				list_Cons(SecondTerm, list_Cons(ThirdTerm, list_Cons(FourthTerm, list_List(FifthTerm)))));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm,
				list_Cons(term_Create(VarY, list_Nil()), list_Cons(term_Create(VarZ, list_Nil()),
								list_List(term_Create(VarU, list_Nil()))))
		); /* Ayzu */
		OutTerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(OutTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil())) );
	} else {
		eml_Error("Undefined Axiom factor K called in K4K."); return NULL;
	}
	
	eml_PrintDS("\n[Axiom 4K^%d]:[",FactorK4, Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
	return OutTerm;
}

static TERM eml_ProcessLogicAlt1KK(AXIOM Axiom, TERM Def, AXIOMDEFLIST *DEFs, FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT:
  RETURNS:
  SUMMARY: 	New symbols have been defined of the form: []p
  Axiom   []k1[]p -> []k2[]p Axyz( Rk1(x,y) \/ Rk2(x,z) \/ Q[]p(y) \/ Q[]p(z) ) from []p
  Alt1^11   [][]p -> [][]p   Ax(Ay[Rxy \/ Q[]rp(y)] \/ Az[Rxz \/ Q[]rp(z)])
  Alt1^12   [][]p -> [][][]p Ax(Ay[Rxy \/ Q[]rp(y)] \/ Auz[Rxu \/ Ruz \/ Q[]rp(z)])
  Alt1^21 [][][]p -> [][]p   Ax(Auy[Rxu \/ Ruy \/ Q[]rp(y)] \/ Az[Rxz \/ Q[]rp(z)])
  Alt1^22 [][][]p -> [][][]p Ax(Auy[Rxu \/ Ruy \/ Q[]rp(y)] \/ Avz[Rxv \/ Rvz \/ Q[]rp(z)])
 ***************************************************************/
{
	TERM OutTerm = NULL; 
	SYMBOL Symbol1, Symbol2;
	int FactorK1 = Axiom.Parameter1; 
	int FactorK2 = Axiom.Parameter2; 
	SYMBOL VarX = eml_GetVar(VARX);
	SYMBOL VarY = eml_GetVar(VARY);
	SYMBOL VarZ = eml_GetVar(VARZ);
	SYMBOL VarU = eml_GetVar(VARU);
	SYMBOL VarV = eml_GetVar(VARV);

	{ /* No special handling for false is required */
		TERM TmpTerm2 = eml_Negate(term_SecondArgument(term_Copy(Def))); /* p */
		TERM TmpTerm1 = term_FirstArgument(term_Copy(Def)); /* R */
		TERM TmpTerm = term_Create(eml_BOX, list_Cons(TmpTerm1, list_List(TmpTerm2))); /* []p */
		TERM TmpTerm3 = eml_Negate(term_Copy(Def)); /* []p */
		Symbol1 = eml_CreateAxiomSymbol(TmpTerm3, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
		Symbol2 = eml_CreateAxiomSymbol(TmpTerm, eml_AXIOM, 1, symbol_STATLEX, Precedence); /* Q[]p */
	}
	
	if ( (FactorK1 == 1) && (FactorK2 == 1) ) { /* Ax (Ay[Rxy \/ Q[]rp(y)] \/ Az[Rxz \/ Q[]rp(z)]) */
		TERM FirstTerm, SecondTerm, ThirdTerm, FourthTerm, ATerm, BTerm;

		FirstTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarY, Flags, Precedence); /* Rxy */
		FirstTerm = eml_Negate(FirstTerm); /* Rxy  */
		SecondTerm = eml_Negate(term_Create(Symbol1, list_List(term_Create(VarY, list_Nil())))); /* Q[]p(y) */
		ATerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
		ATerm = eml_QuantifyTerm(fol_All(), ATerm, list_List(term_Create(VarY, list_Nil()) ));
		
		ThirdTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarZ, Flags, Precedence); /* Rxz */
		ThirdTerm = eml_Negate(ThirdTerm); /* Rxz  */
		FourthTerm = term_Create(Symbol2, list_List(term_Create(VarZ, list_Nil()))); /* Q[]p(z) */
		BTerm = term_Create(fol_Or(), list_Cons(ThirdTerm, list_List(FourthTerm)));
		BTerm = eml_QuantifyTerm(fol_All(), BTerm, list_List(term_Create(VarZ, list_Nil()) ));
		
		OutTerm = term_Create(fol_Or(), list_Cons(ATerm, list_List(BTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil()) ));
		
	} else if ( (FactorK1 == 1) && (FactorK2 == 2) ) { /* Ax (Ay[Rxy \/ Q[]rp(y)] \/ Auz[Rxu \/ Ruz \/ Q[]rp(z)]) */
		TERM FirstTerm, SecondTerm, ThirdTerm, FourthTerm, FifthTerm, ATerm, BTerm;

		FirstTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarY, Flags, Precedence); /* Rxy */
		FirstTerm = eml_Negate(FirstTerm); /* Rxy */
		SecondTerm = eml_Negate(term_Create(Symbol1, list_List(term_Create(VarY, list_Nil())))); /* Q[]p(y) */
		ATerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_List(SecondTerm)));
		ATerm = eml_QuantifyTerm(fol_All(), ATerm, list_List(term_Create(VarY, list_Nil()) ));

		ThirdTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarU, Flags, Precedence); /* Rxu */
		ThirdTerm = eml_Negate(ThirdTerm); /* Rxu */
		FourthTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarU, VarZ, Flags, Precedence); /* Ruz */
		FourthTerm = eml_Negate(FourthTerm); /* Ruz */
		FifthTerm = term_Create(Symbol2, list_List(term_Create(VarZ, list_Nil()))); /* Q[]p(z) */
		BTerm = term_Create(fol_Or(), list_Cons(ThirdTerm, list_Cons(FourthTerm, list_List(FifthTerm))));
		BTerm = eml_QuantifyTerm(fol_All(), BTerm, list_Cons(term_Create(VarU, list_Nil()),
				list_List(term_Create(VarZ, list_Nil()) )));

		OutTerm = term_Create(fol_Or(), list_Cons(ATerm, list_List(BTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil()) ));
				
	} else if ( (FactorK1 == 2) && (FactorK2 == 1) ) { /* Ax (Auy[Rxu \/ Ruy \/ Q[]rp(y)] \/ Az[Rxz \/ Q[]rp(z)]) */
		TERM FirstTerm, SecondTerm, ThirdTerm, FourthTerm, FifthTerm, ATerm, BTerm;

		FirstTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarU, Flags, Precedence); /* Rxu */
		FirstTerm = eml_Negate(FirstTerm); /* Rxu */
		SecondTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarU, VarY, Flags, Precedence); /* Ruy */
		SecondTerm = eml_Negate(SecondTerm); /* Ruy */
		ThirdTerm = eml_Negate(term_Create(Symbol1, list_List(term_Create(VarY, list_Nil())))); /* Q[]p(y) */
		ATerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_Cons(SecondTerm, list_List(ThirdTerm))));
		ATerm = eml_QuantifyTerm(fol_All(), ATerm,
				list_Cons(term_Create(VarU, list_Nil()), list_List(term_Create(VarY, list_Nil()))));

		FourthTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarZ, Flags, Precedence); /* Rxz */
		FourthTerm = eml_Negate(FourthTerm); /* Rxz */
		FifthTerm = term_Create(Symbol2, list_List(term_Create(VarZ, list_Nil()))); /* Q[]p(z) */
		BTerm = term_Create(fol_Or(), list_Cons(FourthTerm, list_List(FifthTerm)));
		BTerm = eml_QuantifyTerm(fol_All(), BTerm, list_List(term_Create(VarZ, list_Nil()) ));

		OutTerm = term_Create(fol_Or(), list_Cons(ATerm, list_List(BTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil()) ));
		
	} else if ( (FactorK1 == 2) && (FactorK2 == 2) ) { /* Ax(Auy[Rxu \/ Ruy \/ Q[]rp(y)] \/ Avz[Rxv \/ Rvz \/ Q[]rp(z)]) */
		TERM FirstTerm, SecondTerm, ThirdTerm, FourthTerm, FifthTerm, SixthTerm, ATerm, BTerm;
		
		FirstTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarU, Flags, Precedence); /* Rxu */
		FirstTerm = eml_Negate(FirstTerm); /* Rxu */
		SecondTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarU, VarY, Flags, Precedence); /* Ruy */
		SecondTerm = eml_Negate(SecondTerm); /* Ruy */
		ThirdTerm = eml_Negate(term_Create(Symbol1, list_List(term_Create(VarY, list_Nil())))); /* Q[]p(y) */
		ATerm = term_Create(fol_Or(), list_Cons(FirstTerm, list_Cons(SecondTerm, list_List(ThirdTerm))));
		ATerm = eml_QuantifyTerm(fol_All(), ATerm,
				list_Cons(term_Create(VarU, list_Nil()), list_List(term_Create(VarY, list_Nil()))));

		FourthTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarX, VarV, Flags, Precedence); /* Rxv */
		FourthTerm = eml_Negate(FourthTerm); /* Rxv */
		FifthTerm = eml_AxiomaticTranslationRel(term_Copy(term_FirstArgument(Def)), /* r */
				VarV, VarZ, Flags, Precedence); /* Rvz */
		FifthTerm = eml_Negate(FifthTerm); /* Rvz */
		SixthTerm = term_Create(Symbol2, list_List(term_Create(VarZ, list_Nil()))); /* Q[]p(z) */
		BTerm = term_Create(fol_Or(), list_Cons(FourthTerm, list_Cons(FifthTerm, list_List(SixthTerm))));
		BTerm = eml_QuantifyTerm(fol_All(), BTerm, list_Cons(term_Create(VarV, list_Nil()),
				list_List(term_Create(VarZ, list_Nil()) )));

		OutTerm = term_Create(fol_Or(), list_Cons(ATerm, list_List(BTerm)));
		OutTerm = eml_QuantifyTerm(fol_All(), OutTerm, list_List(term_Create(VarX, list_Nil()) ));

	} else {
		eml_Error("Undefined factor K1 or k2 called Axiom in KAlt1KK."); return NULL;
	}
	
	{ /* ---------------------------------- define new symbol []p */
		TERM NewTerm = NULL, TmpTermP, TmpTermR, NewDef;
		LIST OutTerms = list_Nil();
		TERM CopyTerm = term_Copy(Def); /* []p */
		TmpTermP = eml_Negate(term_SecondArgument(CopyTerm)); /* p */
		TmpTermR = term_FirstArgument(CopyTerm); /* r */
		NewDef = term_Create(eml_BOX, list_Cons(TmpTermR, list_List(TmpTermP))); /* []p */
		eml_Print("\nFor Axiom ALt1KK:");
		eml_DefineNewDefs(NewDef, DEFs, &OutTerms, Flags, Precedence,TRUE);
		if (list_Length(OutTerms) > 0) {
			NewTerm = term_Create(fol_And(), OutTerms);
		}
		if (NewTerm != NULL) {
			OutTerm = term_Create(fol_And(), list_Cons(NewTerm, list_List(OutTerm)));
		}
	}
	eml_PrintD("\n[Axiom Alt1KK^%d^",FactorK1);
	eml_PrintDS("%d]:[",FactorK2, Axiom.Modality); eml_PrintT(" in term:", Def); eml_PrintT("].\n", OutTerm);
	return OutTerm;
}

static LIST eml_ProcessLogic (AXIOM Axiom, AXIOMDEFLIST *DEFs, FLAGSTORE Flags, PRECEDENCE Precedence,
		TERM (*ProcessLogic)(AXIOM, TERM, AXIOMDEFLIST *, FLAGSTORE, PRECEDENCE)) 
/**************************************************************
  SUMMARY: Control Logic Analysis, Creates and Processes the Term List. Loop through DEFs.
 ***************************************************************/
{
	LIST ConjList = list_Nil(); 
	LIST DEFUnits = list_Copy((*DEFs).BoxDef); 
	SYMBOL ModalSymbol = Axiom.Modality;
	if (list_Length((*DEFs).BoxDef) > 0) { /* This is set BEFORE any analysis */
		DEFUnits = list_Nconc(DEFUnits, list_Copy((*DEFs).XtraBoxDef));
	}

	{ /* process []DEFUnits */
		LIST Scan;
		for (Scan=DEFUnits; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM TmpTerm, Def = (TERM)list_Car(Scan); 

			if (symbol_Equal(term_TopSymbol(term_FirstArgument(Def)), ModalSymbol)) {
				TmpTerm = (*ProcessLogic)(Axiom, Def, DEFs, Flags, Precedence);
				ConjList = eml_ListAddTerm(TmpTerm, ConjList);
			}
		}
	}
	
	return ConjList;
}

static BOOL eml_IsNewAxiom (AXIOMTYPE atype) 
/**************************************************************
	SUMMARY: SR, G, DEN, TR, M, W
 ***************************************************************/	
{
	if ((atype==SR) || (atype==G) || (atype==DEN) || (atype==TR) 
			|| (atype==M) || (atype==W) || (atype==H) || (atype==BK) 
			|| (atype==CR) || (atype==CR2) || (atype==CR3) || (atype==DBBB) )  {
		return TRUE;
	} else {
		return FALSE;
	}
}
static LIST eml_ProcessAxiomLogic (AXIOM Axiom, AXIOMDEFLIST *DEFs,
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  INPUT: Information and Flags required to define Logics for the particular problem.
  RETURNS: The combined Term representing the following Logics 
  			... K4, K5, KB, KT, KD, KAlt1, K5K, K4K, KAlt1KK
  SUMMARY: Initiate and Gather Logic Analysis.
 ***************************************************************/	
{
	LIST OutList = list_Nil();
	TERM CompTerm = NULL, CompTerm2 = NULL; 
	
	if ((Axiom.Mode==AXIOMATIC_TR) /* ------ NON CLASSICAL_TR --------*/
			||(Axiom.Mode==AXIOMATIC_TR_COMP)) {
		CompTerm2 = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, ExternalMode); /* Tests inside function */
		switch (Axiom.AxiomType) {
		case NONE:
			/*eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); */
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			/*OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicNONE);*/			
		case FOUR:  
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogic4);
			break;
		case FIVE:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogic5);
			break;
		case B: 
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicB);
			break;
		case T: 
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicT);
			break;
		case D:
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicD);
			break;
		case ALT1: 
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicAlt1);
			break;
		case FOURK: 
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogic4K);
			break;
		case FIVEK: 
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogic5K);
			break;
		case ALT1KK: 
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicAlt1KK);
			break;
		case SR:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicSR);
			break;
		case G:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicG);
			break;
		case DEN:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicDEN);
			break;
		case TR:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicTR);
			break;
		case M:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicM);
			break;
		case W:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicW);
			break;
		case BK:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicBK);
			break;
		case CR:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicCR);
			break;
		case CR2:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicCR2);
			break;
		case CR3:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicCR3);
			break;
		case DBBB:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicDBBB);
			break;
		case H:
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); 
			CompTerm = eml_ProcessPreviousComposition(Axiom, DEFs, Flags, Precedence, InternalMode);
			OutList = eml_ProcessLogic (Axiom, DEFs, Flags, Precedence, (TERM (*) ())eml_ProcessLogicH);
			break;		
		default:
			eml_Error("No case in eml_ProcessAxiomLogic()."); 
			break;
		}
		if ((Axiom.AxiomType!=FIVE)&&(Axiom.AxiomType!=FIVEK)&&(!eml_IsNewAxiom(Axiom.AxiomType))) { /*v1.0.2*/
			eml_UpdateCompositionAxiomLogic(Axiom, DEFs, Flags, Precedence); /* tests inside function */
		}
		if (CompTerm2 != NULL) {
			OutList = list_Cons(CompTerm2, OutList);
		}
		if (CompTerm != NULL) {
			OutList = list_Cons(CompTerm, OutList);
	    }
	} else if ( Axiom.Mode==CLASSICAL_TR ) { /* ---- CLASSICAL_TR -----*/
		OutList = list_List(eml_ProcessClassicalLogic(Axiom, Flags, Precedence));
	} else {
		eml_Error("No case in eml_ProcessAxiomLogic()."); return NULL;
	}
		
	return OutList;
}

static TERM eml_ProcessPreviousComposition(AXIOM Axiom, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence, int Mode)
/**************************************************************
  SUMMARY: Process Composition [] terms from the previous axiom
 ***************************************************************/
{
	TERM OutTerm = NULL;
	if ((HiddenOpt.DoNotUseComposition == eml_ON) 
			|| (list_Empty((*DEFs).CompositionList))) { /* Guard - for T, K, classical */
		return OutTerm;
	}
	
	{ /* build Def for the new Units */
		LIST Scan, ConjList = list_Nil();
		
		for (Scan=(*DEFs).CompositionList; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM TmpTerm = (TERM)list_Car(Scan); 
			LIST ResultList = list_Nil();
			eml_DefineNewDefs(TmpTerm, DEFs, &ResultList, Flags, Precedence,FALSE); 
			if(!list_Empty(ResultList)) {
				ConjList = eml_ListAddList(ResultList, ConjList);
			}
		}
		if (!list_Empty(ConjList)) {
			OutTerm = term_Create(fol_And(), ConjList);
		}
	}

	if(HiddenOpt.DoNotUsePrintStatements == eml_OFF) { /* print for the new units routines */
		int i = 0, j = 1;
		LIST Scan;
		AXIOM PreviousAxiom;
		
		/*if ( (Axiom.AxiomType==FIVE) || (Axiom.AxiomType==FIVEK) 
				|| (eml_IsNewAxiom(Axiom.AxiomType)==TRUE) ) {
			PreviousAxiom = Axiom;
		} else {
			PreviousAxiom = AxiomComposition[Axiom.Index-j];
		}*/
		if ( Mode ==  InternalMode ) { /* v1.0.3 */
			PreviousAxiom = Axiom;
		} else {
			PreviousAxiom = AxiomComposition[Axiom.Index-j];
		}
		
		while (PreviousAxiom.Mode!=AXIOMATIC_TR_COMP) {
			j++;
			if (Axiom.Index==j) {
				eml_Error("Internal Error in eml_ProcessPreviousComposition()");
			}
			PreviousAxiom = AxiomComposition[Axiom.Index-j];
		} 
		
		printf("\n[Summary Axiomatic DEFUNITS for");
		switch (PreviousAxiom.AxiomType) {
		case FOUR:
			printf(" FOUR ");		break;
		case FIVE:
			printf(" FIVE ");		break;
		case D:
			printf(" D ");			break;
		case T:
			printf(" T ");			break;
		case B:
			printf(" B ");			break;
		case ALT1:
			printf(" ALT1 ");		break;
		case FOURK:
			printf(" FOURK ");		break;
		case FIVEK:
			printf(" FIVEK ");		break;
		case ALT1KK:
			printf(" ALT1KK ");		break;
		case SR:
			printf(" SR ");		break;
		case G:
			printf(" G ");		break;
		case DEN:
			printf(" DEN ");	break;
		case TR:
			printf(" TR ");		break;
		case M:
			printf(" M ");		break;
		case W:
			printf(" W ");		break;
		case CR:
			printf(" CR ");		break;
		case CR2:
			printf(" CR2 ");	break;
		case CR3:
			printf(" CR3 ");	break;
		case DBBB:
			printf(" DBBB ");	break;
		case BK:
			printf(" BK ");		break;
		case H:
			printf(" H ");		break;
		case NONE:
			printf(" None ");	break;
		default:
			eml_ErrorD("No case in eml_ProcessPreviousComposition. %d", PreviousAxiom.AxiomType);	break;
		}
		printf("Composition were] :");
		
		/* actually print the list */
		for (Scan = (*DEFs).CompositionList; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			i++; eml_PrintDT("\n%d ",i,(TERM)list_Car(Scan)); 
		} 
	}
	
	{ /* append the compositional list to the current BoxList - so they join automatically processing */
		if (list_Empty((*DEFs).BoxDef)) { /* check this TODO */
			(*DEFs).XtraBoxDef = (*DEFs).CompositionList;
		} else {
			(*DEFs).XtraBoxDef = list_Nconc((*DEFs).XtraBoxDef, (*DEFs).CompositionList);
		}
	}
	(*DEFs).CompositionList = list_Nil();
	
	return OutTerm;
}

static void eml_UpdateCompositionList(TERM Term, AXIOMDEFLIST *DEFs) 
/**************************************************************
  SUMMARY: Control loop that builds a list of [] terms for composition 
  - that will be processed before applying the next axiom 
 ***************************************************************/
{
	SYMBOL Top = term_TopSymbol(Term);
	
	if (eml_IsNotSymbol(Top)) { /* TODO strip the first not symbol */
		Term = term_FirstArgument(Term);
		Top = term_TopSymbol(Term);
	}
		
	if (eml_IsBoxSymbol(Top)) { /* only [] terms are added to composition list */
		if ( (!eml_ListContains(&(*DEFs).BoxDef, Term)) /* test also includes check for R */
				&& (!eml_ListContains(&(*DEFs).XtraBoxDef, Term))
				&& (!eml_ListContains(&(*DEFs).CompositionList, Term)) ) {
			
			(*DEFs).CompositionList = eml_ListAddTerm(term_Copy(Term), (*DEFs).CompositionList);
		}
	}
	
	if (eml_IsBoxSymbol(Top)) { /* two arguments, the first is dummy, needs stripping */
		eml_UpdateCompositionList(term_SecondArgument(Term), DEFs);
	} else {
		LIST Scan;
		for (Scan=term_ArgumentList(Term); !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			eml_UpdateCompositionList((TERM)list_Car(Scan), DEFs);
		}
	}
	
    return;
}

static void eml_UpdateCompositionAxiomLogic(AXIOM Axiom, AXIOMDEFLIST *DEFs, 
		FLAGSTORE Flags, PRECEDENCE Precedence)
/**************************************************************
  SUMMARY: Update the composition list for each axiom type
***************************************************************/
{	
	LIST BoxDefs, *CompositionList;
	
	if ( (Axiom.Mode != AXIOMATIC_TR_COMP) /* Guard statements */
		|| (HiddenOpt.DoNotUseComposition == eml_ON) ) {
		return;
	}
	CompositionList = &((*DEFs).CompositionList);
	if (!list_Empty(*CompositionList)) {
		eml_Error("Internal Error in eml_UpdateCompositionAxiomLogic().");
	}
	
	BoxDefs = list_Copy(((*DEFs).BoxDef));
	if (!list_Empty((*DEFs).XtraBoxDef)) {
		BoxDefs = list_Nconc(BoxDefs, list_Copy((*DEFs).XtraBoxDef));
	}
	
	switch(Axiom.AxiomType) 
	{
	/**************************************************************
	  	None: 	 NOTHING
	 ***************************************************************/
	case NONE:	{ 
		; /* nothing */
	}
	break;
	/**************************************************************
  	T: 	 Reflexive ...      []p -> p   for composition: NOTHING
	 ***************************************************************/
	case T:	{ 
		; /* nothing */
	}
	break;
	/**************************************************************
  	B:  Symmetry ...  [][]p -> p   for composition: [][]p
	 ***************************************************************/
	case B:	{ /* ADD TERMS of the form: [][]p from original []p */
		LIST Scan;
		if (HiddenOpt.DoNotUseAxiomBComposition == eml_ON) {
			return;
		}
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = eml_Negate(Term); /* []p */
				Term = term_Create(eml_BOX, 
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term))); /* [][]p  */
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;	
	/**************************************************************
  	D:  Serial ...  []p -> []p   for composition: []p
	 ***************************************************************/
	case D:	{ /* ADD TERMS of the form: []p from original []p */
		LIST Scan;
		if (HiddenOpt.DoNotUseAxiomDComposition == eml_ON) {
			return;
		}
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term =	term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = term_SecondArgument((TERM)list_Car(Scan)); /* p */
				Term = eml_Negate(Term); /* p  */
				Term = term_Create(eml_BOX, 
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term))); /* []p  */
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}	
	}
	break;
	/**************************************************************
  	FOUR:   Transitive  ...  []p -> [][]p for composition:  [][]p
	 ***************************************************************/
	case FOUR:	{ /* ADD TERMS of the form: [][]p from original */
		LIST Scan;
		if (HiddenOpt.DoNotUseAxiom4Composition == eml_ON) {
			return;
		}
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term =	term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = term_Create(eml_BOX, 
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term))); /* [][]p  */
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
  	FIVE:  Euclidean ...  [][]p -> []p  for composition: [][]p
	 ***************************************************************/
	case FIVE:	{ /* ADD TERMS of the form: [][]p from original []p */
		LIST Scan;
		if (HiddenOpt.DoNotUseAxiom5Composition == eml_ON) {
			return;
		}
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term =	term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {	
				Term = eml_Negate(Term); /* [](r,p) */
				Term = term_Create(eml_BOX, /* [](r,[](r,p)) == [][]p  */
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term))); 
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
  	ALT1:  []p -> []p ... functionality    for composition: []p
	 ***************************************************************/
	case ALT1: { /* ADD TERMS of the form: []p from original []p */
		LIST Scan;
		if (HiddenOpt.DoNotUseAxiomAlt1Composition == eml_ON) {
			return;
		}
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term =	term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = term_SecondArgument((TERM)list_Car(Scan)); /* p */
				Term = eml_Negate(Term); /* p */
				Term = term_Create(eml_BOX, 
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term))); /* []p  */
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
  	FOURK: 		Axiom []p -> []k[]p		4^k   composition: []k([]p)
  	Example:    4^2   []p -> [][][]p      for composition: [][]([]p) 
                4^3   []p -> [][][][]p    for composition: [][][]([]p)
	 ***************************************************************/
	case FOURK:	{
		int FactorK = Axiom.Parameter1;
		LIST Scan;
		int count;
		if (HiddenOpt.DoNotUseAxiom4KComposition == eml_ON) {
			return;
		}
		if (!((FactorK == 2) || (FactorK == 3))) {
			eml_Error("No case in eml_UpdateCompositionAxiomLogic for 4K.");
		}
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term =	term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) { 
				for (count = 0; count < FactorK; count++) { /* add [][] or [][][] looping k */
					Term = term_Create(eml_BOX, /* [][] or [][][] */
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term))); 
				}
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
  	FIVEK: 	Axiom []k[]p -> []p				5^k  for composition     []k[]p
  	Example:  5^2    axiom ... [][][]p -> []p ...  for composition ... [][][]p
              5^3    axiom ... [][][][]p -> []p ...for composition ... [][][][]p
	 ***************************************************************/
	case FIVEK:	{
		int FactorK = Axiom.Parameter1;
		LIST Scan;
		int count;
		if (HiddenOpt.DoNotUseAxiom5KComposition == eml_ON) {
			return;
		}
		if (!((FactorK == 2) || (FactorK == 3))) {
			eml_Error("No case in eml_UpdateCompositionAxiomLogic for 5K.");
		}
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term =	term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) { 
				Term = eml_Negate(Term); /* []p */
				for (count = 0; count < FactorK; count++) { /* loop 2 or 3 times */
					Term = term_Create(eml_BOX, 
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				}
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
  	ALT1KK:		Axiom []k1[]p -> []k2[]p 					[]k2[]p & []k1[]p
  	Example:    Alt1^11 :  [][]p -> [][]p   	for composition... [][]p & [][]p
                Alt1^12 : [][]p -> [][][]p   	for composition... [][]p & [][][]p
                Alt1^21 : [][][]p -> [][]p   	for composition... [][][]p & [][]p
                Alt1^22 :  [][][]p -> [][][]p	for composition... [][][]p & [][][]p
	 ***************************************************************/
	case ALT1KK: {
		int FactorK1 = Axiom.Parameter1;
		int FactorK2 = Axiom.Parameter2;
		LIST Scan;
		if (HiddenOpt.DoNotUseAxiomAlt1KKComposition == eml_ON) {
			return;
		}
		if (!( ((FactorK1==1)||(FactorK1==2)) && ((FactorK2==1)||(FactorK2==2)) )) {
			eml_Error("No case in eml_UpdateCompositionAxiomLogic for Alt1KK.");
		}
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */			
			int count;
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
			{ /* []k2[]p */
				TERM Term =	term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
				Term = term_SecondArgument((TERM)list_Car(Scan)); /* p */
				Term = eml_Negate(Term); /* p */
				Term = term_Create(eml_BOX, 
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term))); /* []p  */
				for (count = 0; count < FactorK2; count++) { /* loop k times */
					Term = term_Create(eml_BOX, 
							list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				}
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
			{ /* []k1[]p */
				TERM Term =	term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
				for (count = 0; count < FactorK1; count++) { /* loop k times */
					Term = term_Create(eml_BOX, 
							list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				}
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
			}
		}
	}
	break;
	/**************************************************************
	  	SR: 	 []([]p->p)
	  	compositional term is []([]p->p) = []([]p/\p)
	 ***************************************************************/
	case SR:	{ 
		LIST Scan;
		/* ADD TERMS of the form: []([]p/\p) from original []p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM TermBoxP = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				TERM TermP = term_SecondArgument(term_Copy((TERM)list_Car(Scan))); /* p */
				TERM Term = term_Create(fol_And(), list_Cons(TermBoxP, list_List(eml_Negate(TermP)))); /* []p/\p */
				Term = eml_Negate(Term); /* ([]p/\p) */
				Term = term_Create(eml_BOX, /* []([]p/\p)  */
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
	  	G: 	 <>[]p->[]<>p
	  	[][]p, [][]p
	***************************************************************/
	case G:	{ 
		LIST Scan;
		/* ADD TERMS of the form: [][]p from original []p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = eml_Negate(Term); /* [](r,p) */
				Term = term_Create(eml_BOX, /* [](r,[](r,p)) == [][]p  */
				list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
		/* [][]p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			Term = eml_Negate(term_SecondArgument(Term)); /* p */;
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = eml_Negate(term_Create(eml_BOX, list_Cons(
						term_Create(Symbol_R, list_Nil()), list_List(Term)))); /* [](r,p) */
				Term = term_Create(eml_BOX, /* [](r,[](r,p)) == [][]p  */
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
	  	DEN: 	 [][]p->[]p
	  	[][]p
	 ***************************************************************/
	case DEN:	{ 
		LIST Scan;
		/* ADD TERMS of the form: [][]p from original []p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = term_Create(eml_BOX, /* [](r,[](r,p)) == [][]p  */
				list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
	  	TR: 	 []p<->p
	 ***************************************************************/
	case TR:	{ 
			; /* nothing */
	}
	break;
	/**************************************************************
	  	M: 	 []<>p-><>[]p
	  	[][]p, [][]p
	 ***************************************************************/
	case M:	{ 
		LIST Scan;
		/* ADD TERMS of the form: [][]p from original []p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = eml_Negate(Term); /* [](r,p) */
				Term = term_Create(eml_BOX, /* [](r,[](r,p)) == [][]p  */
				list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
		/* [][]p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			Term = eml_Negate(term_SecondArgument(Term)); /* p */;
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = eml_Negate(term_Create(eml_BOX, list_Cons(
						term_Create(Symbol_R, list_Nil()), list_List(Term)))); /* [](r,p) */
				Term = term_Create(eml_BOX, /* [](r,[](r,p)) == [][]p  */
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
	  	W: 	 []([]p->p)->[]p
	  	[]([]p\/p) = []([]p/\p)
	 ***************************************************************/
	case W:	{ 
		LIST Scan;
		/* ADD TERMS of the form: []([]p\/p) from original []p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM TermBoxP = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				TERM TermP = term_SecondArgument(term_Copy((TERM)list_Car(Scan))); /* p */
				TERM Term = term_Create(fol_And(), list_Cons(TermBoxP, list_List(eml_Negate(TermP)))); /* []p/\p */
				Term = eml_Negate(Term); /* ([]p/\p) */
				Term = term_Create(eml_BOX, /* []([]p/\p)  */
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
	  	CR: 	 [r]p -> [s]p
	 ***************************************************************/
	case CR:	{ 
			; /* none */
	}
	break;
	/**************************************************************
	  	CR2: 	 [r]p -> [s][r]p
	  	[s][r]p
	 ***************************************************************/
	case CR2:	{ 
		LIST Scan;
		/* ADD TERMS of the form: [s][r]p from original []p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				TERM TermP = term_SecondArgument(Term); /* p */
				TERM TermR = term_Create(Axiom.Modality, list_Nil()); /* R */
				TERM TermS = term_Create(Axiom.Modality2, list_Nil()); /* S */
				Term = term_Create(eml_BOX, list_Cons(TermR, list_List(TermP))); /* [r]p */
				Term = term_Create(eml_BOX, list_Cons(TermS, list_List(Term))); /* [s][r]p */
				
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
		CR3: 	 [r]p -> [r][s]p
		[r][s]p
	 ***************************************************************/
	case CR3:	{ 
		LIST Scan;
		/* ADD TERMS of the form: [s][r]p from original []p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				TERM TermP = term_SecondArgument(Term); /* p */
				TERM TermR = term_Create(Axiom.Modality, list_Nil()); /* R */
				TERM TermS = term_Create(Axiom.Modality2, list_Nil()); /* S */
				Term = term_Create(eml_BOX, list_Cons(TermS, list_List(TermP))); /* [s]p */
				Term = term_Create(eml_BOX, list_Cons(TermR, list_List(Term))); /* [r][s]p */
				
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
	}
	break;
	/**************************************************************
		DBBB: 	 <>[]p -> [][]p       [][]p -> [][]p
		[][]p, [][]p
	 ***************************************************************/
	case DBBB:	{ 
		LIST Scan;
		/* ADD TERMS of the form: [][]p from original []p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = term_Create(eml_BOX, /* [](r,[](r,p)) == [][]p  */
				list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}
		/* ADD TERMS of the form: [][]p from original []p */
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term = term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) {
				Term = eml_Negate(Term); /* [](r,p) */
				Term = term_Create(eml_BOX, /* [](r,[](r,p)) == [][]p  */
				list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		}		
	}
	break;
	/**************************************************************
	BK: B^2: <><>[]p -> p			[][][]p -> p
	  	[][][]p (, [][]p)
	  	B^3: <><><>[]p -> p			[][][][]p -> p
	  	[][][][]p (, [][][]p, [][]p) 	 
	 ***************************************************************/
	case BK:	{ 
		int FactorK = Axiom.Parameter1;
		LIST Scan;
		int count;
		if (!((FactorK == 2) || (FactorK == 3))) {
			eml_Error("No case in eml_UpdateCompositionAxiomLogic for B^K.");
		}
		for (Scan = BoxDefs; !list_Empty(Scan); Scan=list_Cdr(Scan)) {
			TERM Term =	term_Copy((TERM)list_Car(Scan)); /* [](r,p) */
			SYMBOL Symbol_R = term_TopSymbol(term_FirstArgument((TERM)list_Car(Scan))); /* r */
			if (symbol_Equal(Symbol_R, Axiom.Modality)) { 
				Term = eml_Negate(Term); /* []p */
				for (count = 0; count < FactorK; count++) { /* loop 2 or 3 times */
					Term = term_Create(eml_BOX, 
						list_Cons(term_Create(Symbol_R, list_Nil()), list_List(Term)));
				}
				eml_UpdateCompositionList(Term, DEFs); /* Term & subterms not already in BoxDefs */
			}
		} 
	}
	break;
	/**************************************************************
	  	H: 	 []([]p->q)->[]([]q->p)
	 ***************************************************************/
	case H:	{ 
		eml_Error("Sorry not implemented yet.");; 
	}
	break;
	default:
		eml_Error("No case in eml_UpdateCompositionAxiomLogic().");	break;
	}
	return;
}
	
static void eml_AnalyzeEmlAxiomTranslationFlags(FLAGSTORE Flags)
/**************************************************************
  INPUT:   A FlagStore.
  EFFECT:  Print warnings for non-sensical flag combinations. 
  		   Populate ordered list of axioms to be applied.
  		   Deals with cases:
  		   1: Case where axioms are restricted to contents of paper
  		   2: General case where any axiom combination can be applied
 ***************************************************************/
{	
	int KT = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGICT);
	int KD = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGICD);
	int K5 = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGIC5);
	int K4 = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGIC4);
	int KB = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGICB);
	int KALT1 = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGICALT1);
	int K5K = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGIC5K);
	int K4K = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGIC4K);
	int KALT1KK = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGICALT1KK);
	int FactorK1 = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGICFACTOR1);
	int FactorK2 = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGICFACTOR2);
	int FactorK4 = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGICFACTOR4); 
	int FactorK5 = flag_GetFlagValue(Flags, flag_EMLAXIOMLOGICFACTOR5);
	int FactorK1c = flag_GetFlagValue(Flags, flag_EMLCLASSLOGICFACTOR1);
	int FactorK2c = flag_GetFlagValue(Flags, flag_EMLCLASSLOGICFACTOR2);
	int FactorK4c = flag_GetFlagValue(Flags, flag_EMLCLASSLOGICFACTOR4); 
	int FactorK5c = flag_GetFlagValue(Flags, flag_EMLCLASSLOGICFACTOR5);
	int KcT = flag_GetFlagValue(Flags, flag_EMLCLASSLOGICT);
	int KcD = flag_GetFlagValue(Flags, flag_EMLCLASSLOGICD);
	int Kc5 = flag_GetFlagValue(Flags, flag_EMLCLASSLOGIC5);
	int Kc4 = flag_GetFlagValue(Flags, flag_EMLCLASSLOGIC4);
	int KcB = flag_GetFlagValue(Flags, flag_EMLCLASSLOGICB);
	int KcALT1 = flag_GetFlagValue(Flags, flag_EMLCLASSLOGICALT1);
	int Kc4K = flag_GetFlagValue(Flags, flag_EMLCLASSLOGIC4K);
	int Kc5K = flag_GetFlagValue(Flags, flag_EMLCLASSLOGIC5K);
	int KcALT1KK = flag_GetFlagValue(Flags, flag_EMLCLASSLOGICALT1KK);
		
	/* check for defined logic compositions */
	if (HiddenOpt.IgnoreLogicFlagWarnings == eml_OFF) { /* This restricts to examples in the paper */
		BOOL HasBeenDefined = FALSE;
		/* Always begin with K */
		(void) eml_BuildAxiomAt(0, K, AXIOMATIC_TR, -1, -1);
		/* chooses == Not Classical */
		if ((KcT<=0)&&(KcD<=0)&&(Kc5<=0)&&(Kc4<=0)&&(KcB<=0)&&(KcALT1<=0)
				&&(Kc5K<=0)&&(Kc4K<=0)&&(KcALT1KK<=0)) {
			if ( (KT<=0)&&(KD<=0)&&(K5<=0)&&(K4<=0)&&(KB<=0)&&(KALT1<=0) &&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)) {
				/* K - nothing to add */HasBeenDefined = TRUE;
			} else if ( (KT<=0)&&(KD<=0)&&(K5<=0)&&(K4>0)&&(KB<=0)&&(KALT1<=0)
					&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)) { /* K4 */	HasBeenDefined = TRUE;
				(void) eml_BuildAxiomAt(1, FOUR, AXIOMATIC_TR, -1, -1);
			} else if ( (KT>0)&&(KD<=0)&&(K5<=0)&&(K4<=0)&&(KB<=0)&&(KALT1<=0)
					&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)) { /* KT */	HasBeenDefined = TRUE;
				(void) eml_BuildAxiomAt(1, T, AXIOMATIC_TR, -1, -1);
			} else if ( (KT<=0)&&(KD>0)&&(K5<=0)&&(K4<=0)&&(KB<=0)&&(KALT1<=0)
					&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)) { /* KD */	HasBeenDefined = TRUE;
				(void) eml_BuildAxiomAt(1, D, AXIOMATIC_TR, -1, -1);
			} else if ( (KT<=0)&&(KD<=0)&&(K5<=0)&&(K4<=0)&&(KB>0)&&(KALT1<=0)
					&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)) { /* KB */ HasBeenDefined = TRUE;
				(void) eml_BuildAxiomAt(1, B, AXIOMATIC_TR, -1, -1);
			} else if ( (KT<=0)&&(KD<=0)&&(K5<=0)&&(K4<=0)&&(KB<=0)&&(KALT1>0)
					&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)) { /* KALT1 */	HasBeenDefined = TRUE;
				(void) eml_BuildAxiomAt(1, ALT1, AXIOMATIC_TR, -1, -1);
			} else if ( (KT<=0)&&(KD<=0)&&(K5>0)&&(K4<=0)&&(KB<=0)&&(KALT1<=0)
					&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)) { /* K5 */	HasBeenDefined = TRUE;
				(void) eml_BuildAxiomAt(1, FIVE, AXIOMATIC_TR_COMP, -1, -1);
			} else if ( (KT<=0)&&(KD<=0)&&(K5<=0)&&(K4<=0)&&(KB<=0)&&(KALT1<=0)
					&&(K5K<=0)&&(K4K>0)&&(KALT1KK<=0)) { /* K4K */	HasBeenDefined = TRUE;
				if ( (FactorK4 < 2) || (FactorK4 > 3)) { /* currently allow K=2 or 3 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR4 (2-3).");
				}
				(void) eml_BuildAxiomAt(1, FOURK, AXIOMATIC_TR, FactorK4, -1);
			} else if ( (KT<=0)&&(KD<=0)&&(K5<=0)&&(K4<=0)&&(KB<=0)&&(KALT1<=0)
					&&(K5K<=0)&&(K4K<=0)&&(KALT1KK>0)) { /* KALT1KK */	HasBeenDefined = TRUE;
				if ( (FactorK1 < 1) || (FactorK1 > 2)) { /* currently allow K1 = 1 or 2 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR1 (1-2).");
				} else if ( (FactorK2 < 1) || (FactorK2 > 2)) { /* currently allow K2=1 or 2 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR2 (1-2).");
				}
				(void) eml_BuildAxiomAt(1, ALT1KK, AXIOMATIC_TR, FactorK1, FactorK2);
			} else if ( (KT<=0)&&(KD<=0)&&(K5<=0)&&(K4<=0)&&(KB<=0)&&(KALT1<=0)
					&&(K5K>0)&&(K4K<=0)&&(KALT1KK<=0)) { /* K5K */	HasBeenDefined = TRUE;
				if ( (FactorK5 < 2) || (FactorK5 > 3)) { /* currently allow K=2 or 3 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR5 (2-3).");
				}
				(void) eml_BuildAxiomAt(1, FIVEK, AXIOMATIC_TR_COMP, FactorK5, -1);
			} /* pure axiomatics in combination  ---- KT4--- */
			else if ( (KD<=0)&&(K5<=0)&&(KB<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)
					&&(KT>0)&&(K4>0)) { /* KT4 */ HasBeenDefined = TRUE;
					(void) eml_BuildAxiomAt(1, T, AXIOMATIC_TR, -1, -1);
					(void) eml_BuildAxiomAt(2, FOUR, AXIOMATIC_TR, -1, -1);
			} /* --------------------------------------- KTB */
			else if ((KD<=0)&&(K5<=0)&&(K4<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)
					&&(KT>0)&&(KB>0)) {	 /* KTB */ HasBeenDefined = TRUE;
					(void) eml_BuildAxiomAt(1, T, AXIOMATIC_TR, -1, -1);
					(void) eml_BuildAxiomAt(2, B, AXIOMATIC_TR, -1, -1);
			} /* --------------------------------------- KDB */
			else if ((KT<=0)&&(K5<=0)&&(K4<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)
					&&(KD>0)&&(KB>0)) { /* KDB */ HasBeenDefined = TRUE;
					(void) eml_BuildAxiomAt(1, D, AXIOMATIC_TR, -1, -1);
					(void) eml_BuildAxiomAt(2, B, AXIOMATIC_TR, -1, -1); 
			} /* --------------------------------------- KD4 */
			else if ((KT<=0)&&(K5<=0)&&(KB<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)
					&&(KD>0)&&(K4>0)) { /* KD4 */ HasBeenDefined = TRUE;
					(void) eml_BuildAxiomAt(1, D, AXIOMATIC_TR, -1, -1);
					(void) eml_BuildAxiomAt(2, FOUR, AXIOMATIC_TR, -1, -1);
			}/* --------------------------------------- K4B */
			else if ((KT<=0)&&(KD<=0)&&(K5<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0) 
					&&(K4>0)&&(KB>0)) {	 /* K4B */ HasBeenDefined = TRUE; 
					(void) eml_BuildAxiomAt(1, FOUR, AXIOMATIC_TR_COMP, -1, -1);
					(void) eml_BuildAxiomAt(2, B, AXIOMATIC_TR, -1, -1); 
			}/* --------------------------------------- K5oB */
			else if ((KT<=0)&&(KD<=0)&&(K4<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0) 
					&&(K5>0)&&(KB>0)) { /* K5B */ HasBeenDefined = TRUE;
					(void) eml_BuildAxiomAt(1, FIVE, AXIOMATIC_TR_COMP, -1, -1);
					(void) eml_BuildAxiomAt(2, B, AXIOMATIC_TR, -1, -1);
			}/* --------------------------------------- KT5o must be 5oT */
			else if ((KD<=0)&&(K4<=0)&&(KB<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0) 
					&&(KT>0)&&(K5>0)) {	 /* KT5 */ HasBeenDefined = TRUE;
					(void) eml_BuildAxiomAt(1, FIVE, AXIOMATIC_TR_COMP, -1, -1);
					(void) eml_BuildAxiomAt(2, T, AXIOMATIC_TR, -1, -1);
			}/* --------------------------------------- KT4B */
			else if ( (KD<=0)&&(K5<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0) 
					&&(KT>0)&&(K4>0)&&(KB>0)) {	/* KT4oB*/ HasBeenDefined = TRUE;
					(void) eml_BuildAxiomAt(1, T, AXIOMATIC_TR, -1, -1);
					(void) eml_BuildAxiomAt(2, FOUR, AXIOMATIC_TR_COMP, -1, -1);
					(void) eml_BuildAxiomAt(3, B, AXIOMATIC_TR, -1, -1);
			} /* --------------------------------------- KD4B */
			else if ((KT<=0)&&(K5<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0) 
					&&(KD>0)&&(K4>0)&&(KB>0)) {	/* KD4B */ HasBeenDefined = TRUE;
					(void) eml_BuildAxiomAt(1, D, AXIOMATIC_TR, -1, -1);
					(void) eml_BuildAxiomAt(2, FOUR, AXIOMATIC_TR_COMP, -1, -1);
					(void) eml_BuildAxiomAt(3, B, AXIOMATIC_TR, -1, -1);
			} /* --------------------------------------- */
			/* ---------------- chooses == Is Classical -------------------------  */
		} else if ((KT<=0)&&(KD<=0)&&(K5<=0)&&(K4<=0)&&(KB<=0)&&(KALT1<=0)
				&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0)) {
			/* this is ... purely classical - allow all combinations of classical axioms */
			int i;
			eml_Print("\nBuilding a General Classical Composition Structure");

			/* Always begin with K */
			(void) eml_BuildAxiomAt(0, K, AXIOMATIC_TR_COMP, -1, -1);

			for (i=1; i <= 9; i++) { /* Note: greater than 0 */
				if (KcT==i) {					HasBeenDefined = TRUE;
					(void) eml_BuildAxiom(T, CLASSICAL_TR, -1, -1);
				}
				if (KcD==i) {					HasBeenDefined = TRUE;
					(void) eml_BuildAxiom(D, CLASSICAL_TR, -1, -1);
				}
				if (Kc5==i) {					HasBeenDefined = TRUE;
					(void) eml_BuildAxiom(FIVE, CLASSICAL_TR, -1, -1);
				}
				if (Kc4==i) {					HasBeenDefined = TRUE;
					(void) eml_BuildAxiom(FOUR, CLASSICAL_TR, -1, -1);
				}
				if (KcB==i) {					HasBeenDefined = TRUE;
					(void) eml_BuildAxiom(B, CLASSICAL_TR, -1, -1);
				}
				if (KcALT1==i) {				HasBeenDefined = TRUE;
					(void) eml_BuildAxiom(ALT1, CLASSICAL_TR, -1, -1);
				}
				if (Kc5K==i) {					HasBeenDefined = TRUE;
					if ( (FactorK5c < 2) || (FactorK5c > 3)) { /* currently K=2 or 3 */
						eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR5 (2-3).");
					}
					(void) eml_BuildAxiom(FIVEK, CLASSICAL_TR, FactorK5c, -1);
				}
				if (Kc4K==i) {					HasBeenDefined = TRUE;
					if ( (FactorK4c < 2) || (FactorK4c > 3)) { /* currently K=2 or 3 */
						eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR4 (2-3).");
					}
					(void) eml_BuildAxiom(FOURK, CLASSICAL_TR, FactorK4c, -1);
				}
				if (KcALT1KK==i) {				HasBeenDefined = TRUE;
					if ( (FactorK1c < 1) || (FactorK1c > 2)) { /* currently K=1 or 2 */
						eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR1 (1-2).");
					} else if ( (FactorK2c < 1) || (FactorK2c > 2)) { /* currently K=1 or 2 */
						eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR2 (1-2).");
					}
					(void) eml_BuildAxiom(ALT1KK, CLASSICAL_TR, FactorK1c, FactorK2c);
				}
			} /* -------- choose == Mixed Combinations of Axioms -------------------- */
		} /* --------------------------------------- KDB */
		else if ((KT<=0)&&(K5<=0)&&(K4<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0) 
				&&(KcT<=0)&&(Kc5<=0)&&(Kc4<=0)&&(KcALT1<=0)&&(Kc5K<=0)&&(Kc4K<=0)&&(KcALT1KK<=0)) {
			if ((KD<=0)&&(KB>0)&&(KcD>0)&&(KcB<=0)) { /* KDcB */ HasBeenDefined = TRUE;
				(void) eml_BuildAxiomAt(1, D, CLASSICAL_TR, -1, -1);
				(void) eml_BuildAxiomAt(2, B, AXIOMATIC_TR, -1, -1);
			}
		} /* --------------------------------------- KD4 */
		else if ((KT<=0)&&(K5<=0)&&(KB<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0) 
				&&(KcT<=0)&&(Kc5<=0)&&(KcB<=0)&&(KcALT1<=0)&&(Kc5K<=0)&&(Kc4K<=0)&&(KcALT1KK<=0)) {
			if ((KD<=0)&&(K4>0)&&(KcD>0)&&(Kc4<=0)) { /* KDc4 */ HasBeenDefined = TRUE;
				(void) eml_BuildAxiomAt(1, D, CLASSICAL_TR, -1, -1);
				(void) eml_BuildAxiomAt(2, FOUR, AXIOMATIC_TR, -1, -1);
			}
		}/* --------------------------------------- KT4B */ 
		else if ( (KD<=0)&&(K5<=0)&&(KALT1<=0)&&(K5K<=0)&&(K4K<=0)&&(KALT1KK<=0) 
				&&(KcD<=0)&&(Kc5<=0)&&(KcALT1<=0)&&(Kc5K<=0)&&(Kc4K<=0)&&(KcALT1KK<=0)) {
			if ((KT<=0)&&(K4>0)&&(KB<=0)&&(KcT>0)&&(Kc4<=0)&&(KcB>0)) {	/* KTc4Bc */ HasBeenDefined = TRUE;
				(void) eml_BuildAxiomAt(1, T, CLASSICAL_TR, -1, -1);
				(void) eml_BuildAxiomAt(2, FOUR, AXIOMATIC_TR, -1, -1);
				(void) eml_BuildAxiomAt(3, B, CLASSICAL_TR, -1, -1);
			}
		} /* --------------------------------------- */
		if (HasBeenDefined == FALSE) {
			printf("\nNo case in eml_AnalyzeEmlAxiomTranslationFlags(). Please modify your flags."); 
			eml_Error("Allowed None,4,5,T,B,D,Alt1,4K,5K,Alt1KK,T4,TB,DB,D4,4B,5oB,T5,T4B,D4B (with classical/relational options.)");
		} 
	} else { /* build a general composition structure */
		int i;
		eml_Print("\nBuilding a General Composition Structure");

		/* Always begin with K */
		(void) eml_BuildAxiomAt(0, K, AXIOMATIC_TR_COMP, -1, -1);

		for (i=1; i <= 9 ; i++) { /* Note: greater than 0 */
			if (KT==i){	
				(void) eml_BuildAxiom(T, AXIOMATIC_TR_COMP, -1, -1);
			}
			if (KD==i){	
				(void) eml_BuildAxiom(D, AXIOMATIC_TR_COMP, -1, -1);
			}
			if (K5==i){	
				(void) eml_BuildAxiom(FIVE, AXIOMATIC_TR_COMP, -1, -1);
			}
			if (K4==i){	
				(void) eml_BuildAxiom(FOUR, AXIOMATIC_TR_COMP, -1, -1);
			}
			if (KB==i){	
				(void) eml_BuildAxiom(B, AXIOMATIC_TR_COMP, -1, -1);
			}
			if (KALT1==i){ 
				(void) eml_BuildAxiom(ALT1, AXIOMATIC_TR_COMP, -1, -1);
			}
			if (K5K==i){ 
				if ( (FactorK5 < 2) || (FactorK5 > 3) ) { /* currently K = 2 or 3 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR5 (2-3).");
				}
				(void) eml_BuildAxiom(FIVEK, AXIOMATIC_TR_COMP, FactorK5, -1);			  
			}
			if (K4K==i){ 
				if ( (FactorK4 < 2) || (FactorK4 > 3) ) { /* currently K = 2 or 3 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR4 (2-3).");
				}
				(void) eml_BuildAxiom(FOURK, AXIOMATIC_TR_COMP, FactorK4, -1);
			}
			if (KALT1KK==i){ 
				if ( (FactorK1 < 1) || (FactorK1 > 2) ) { /* currently K = 1 or 2 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR1 (1-2).");
				} else	if ( (FactorK2 < 1) || (FactorK2 > 2) ) { /* currently K = 1 or 2 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR2 (1-2).");
				}
				(void) eml_BuildAxiom(ALT1KK, AXIOMATIC_TR_COMP, FactorK1, FactorK2);
			}
			/* --------------------------------------- */
			if (KcT==i){ 
				(void) eml_BuildAxiom(T, CLASSICAL_TR, -1, -1);
			}
			if (KcD==i){ 
				(void) eml_BuildAxiom(D, CLASSICAL_TR, -1, -1);
			}
			if (Kc5==i){ 
				(void) eml_BuildAxiom(FIVE, CLASSICAL_TR, -1, -1);
			}
			if (Kc4==i){ 
				(void) eml_BuildAxiom(FOUR, CLASSICAL_TR, -1, -1);
			}
			if (KcB==i){ 
				(void) eml_BuildAxiom(B, CLASSICAL_TR, -1, -1);
			}
			if (KcALT1==i){ 
				(void) eml_BuildAxiom(ALT1, CLASSICAL_TR, -1, -1);
			}
			if (Kc5K==i){ 
				if ( (FactorK5c < 2) || (FactorK5c > 3) ) { /* currently K =2 or 3 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR5 (2-3).");
				}
				(void) eml_BuildAxiom(FIVEK, CLASSICAL_TR, FactorK5c, -1);			  
			}
			if (Kc4K==i){ 
				if ( (FactorK4c < 2) || (FactorK4c > 3) ) { /* currently K =2 or 3 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR4 (2-3).");
				}
				(void) eml_BuildAxiom(FOURK, CLASSICAL_TR, FactorK4c, -1);
			}
			if (KcALT1KK==i){ 
				if ( (FactorK1c < 1) || (FactorK1c > 2) ) { /* currently K =1 or 2 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR1 (1-2).");
				} else	if ( (FactorK2c < 1) || (FactorK2c > 2) ) { /* currently K =1 or 2 */
					eml_Error("Incorrect value in flag_EMLAXIOMLOGICFACTOR2 (1-2).");
				}
				(void) eml_BuildAxiom(ALT1KK, CLASSICAL_TR, FactorK1c, FactorK2c);
			}
		}
	}
	
	{ /* Update for HiddenOpt.DoNotUseAxiomTComposition, etc, and HiddenOpt.DoNotUseComposition */
		int loop;
		AXIOM *AxiomInstance;
		for (loop=1; loop < AxiomCompositionIndex; loop++) { /* ignore K */
			AxiomInstance = &AxiomComposition[loop];
			
			if (HiddenOpt.DoNotUseComposition == eml_ON) {
				if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
					(*AxiomInstance).Mode = AXIOMATIC_TR;
				}
  			} else if ((*AxiomInstance).AxiomType == T) { /* To makes No sense */
				if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
					(*AxiomInstance).Mode = AXIOMATIC_TR;
				}
			} else if (((*AxiomInstance).AxiomType == B) && (HiddenOpt.DoNotUseAxiomBComposition == eml_ON)) {
				if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
					(*AxiomInstance).Mode = AXIOMATIC_TR;
				}
			} else if (((*AxiomInstance).AxiomType == D) && (HiddenOpt.DoNotUseAxiomDComposition == eml_ON)) {
				if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
					(*AxiomInstance).Mode = AXIOMATIC_TR;
				}
			} else if (((*AxiomInstance).AxiomType == ALT1) && (HiddenOpt.DoNotUseAxiomAlt1Composition == eml_ON)) {
				if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
					(*AxiomInstance).Mode = AXIOMATIC_TR;
				}
			} else if (((*AxiomInstance).AxiomType == FOUR) && (HiddenOpt.DoNotUseAxiom4Composition == eml_ON)) {
				if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
					(*AxiomInstance).Mode = AXIOMATIC_TR;
				}
			} else if (((*AxiomInstance).AxiomType == FIVE) && (HiddenOpt.DoNotUseAxiom5Composition == eml_ON)) {
				if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
					(*AxiomInstance).Mode = AXIOMATIC_TR;
				}
			} else if (((*AxiomInstance).AxiomType == ALT1KK) && (HiddenOpt.DoNotUseAxiomAlt1KKComposition == eml_ON)) {
				if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
					(*AxiomInstance).Mode = AXIOMATIC_TR;
				}
			} else if (((*AxiomInstance).AxiomType == FOURK) && (HiddenOpt.DoNotUseAxiom4KComposition == eml_ON)) {
				if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
					(*AxiomInstance).Mode = AXIOMATIC_TR;
				}
			} else if (((*AxiomInstance).AxiomType == FIVEK) && (HiddenOpt.DoNotUseAxiom5KComposition == eml_ON)) {
				if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
					(*AxiomInstance).Mode = AXIOMATIC_TR;
				}
			}
		}
	}
	
	/* { / * the last axiom can't be composition - although it wouldn't be processed anyway * /
		AXIOM *AxiomInstance = &AxiomComposition[AxiomCompositionIndex-1];
		if (((*AxiomInstance).AxiomType==FIVE) || ((*AxiomInstance).AxiomType==FIVEK)) {
			; / * nothing * /
		} else {
			if ((*AxiomInstance).Mode == AXIOMATIC_TR_COMP) {
				(*AxiomInstance).Mode = AXIOMATIC_TR;
			}
		}
	}*/		
	
	return;
}

static void eml_PrintAxiomComposition()
/**************************************************************
  INPUT:   Looks at ordered list of axioms to be applied
  EFFECT:  prints a string representation of the ordered axiom list for user information
 ***************************************************************/
{
	char CompStr[1001]; /* 1001 is way over */
	CompStr[0] = '\0';
	
	{ /* Build a print String */
		int j = 1, i;
		CompStr[0] = 'K'; 
		if (AxiomCompositionIndex > 1) {CompStr[1] = ','; j++;}

		for (i=1; i<AxiomCompositionIndex; i++){ /* only look at 2nd axiom onwards */
			int TypeAxiom = AxiomComposition[i].AxiomType;

			switch (TypeAxiom) {
			case FOUR:
			case T:
			case D:
			case B:
			case ALT1:
			case FIVE:
			case SR:
			case G:
			case DEN:
			case TR:
			case M:
			case W:
			case H:
			case CR:
			case CR2:
			case CR3:
			case DBBB:
			case NONE:
				if (TypeAxiom == FOUR) {
					CompStr[j] = '4'; j++;
				} else if (TypeAxiom == T) {
					CompStr[j] = 'T'; j++;
				} else if (TypeAxiom == D) {
					CompStr[j] = 'D'; j++;
				} else if (TypeAxiom == B) {
					CompStr[j] = 'B'; j++;
				} else if (TypeAxiom == ALT1) {
					CompStr[j] = 'A';j++; CompStr[j] = 'L';j++; CompStr[j] = 'T';j++; CompStr[j] = '1'; j++;
				} else if (TypeAxiom == FIVE) {
					CompStr[j] = '5'; j++;
				} else if (TypeAxiom == SR) {
					CompStr[j] = 'S'; j++; CompStr[j] = 'R'; j++;
				} else if (TypeAxiom == G) {
					CompStr[j] = 'G'; j++;
				} else if (TypeAxiom == DEN) {
					CompStr[j] = 'D'; j++; CompStr[j] = 'E'; j++; CompStr[j] = 'N'; j++;
				} else if (TypeAxiom == TR) {
					CompStr[j] = 'T'; j++; CompStr[j] = 'R'; j++;
				} else if (TypeAxiom == M) {
					CompStr[j] = 'M'; j++;
				} else if (TypeAxiom == W) {
					CompStr[j] = 'W'; j++;
				} else if (TypeAxiom == H) {
					CompStr[j] = 'H'; j++;
				} else if (TypeAxiom == CR) {
					CompStr[j] = 'C'; j++; CompStr[j] = 'R'; j++;
				} else if (TypeAxiom == CR2) {
					CompStr[j] = 'C'; j++; CompStr[j] = 'R'; j++; CompStr[j] = '2'; j++;
				} else if (TypeAxiom == CR3) {
					CompStr[j] = 'C'; j++; CompStr[j] = 'R'; j++; CompStr[j] = '3'; j++;
				} else if (TypeAxiom == DBBB) {
					CompStr[j] = 'D'; j++; CompStr[j] = 'B'; j++; CompStr[j] = 'B'; j++; CompStr[j] = 'B'; j++;
				}
			    else if (TypeAxiom == NONE) {
			    	CompStr[j] = 'N'; j++; CompStr[j] = 'o'; j++; CompStr[j] = 'n'; j++; CompStr[j] = 'e'; j++;
				}
			
				if (AxiomComposition[i].Mode == CLASSICAL_TR) {
					CompStr[j] = 'c'; j++;
				} else if (AxiomComposition[i].Mode == AXIOMATIC_TR_COMP) {
					CompStr[j] = 'o'; j++;
				}
				break;
			case FOURK:
			{
				char INT[100]; INT[0]='\0'; sprintf(INT, "%d", AxiomComposition[i].Parameter1);
				CompStr[j] = '4'; j++; CompStr[j] = 'K'; j++;
				if (AxiomComposition[i].Mode == CLASSICAL_TR) {
					CompStr[j] = 'c'; j++;
				} else if (AxiomComposition[i].Mode == AXIOMATIC_TR_COMP) {
					CompStr[j] = 'o'; j++;
				}
				CompStr[j] = '['; j++;
				CompStr[j] = INT[0]; j++;
				if (INT[1]!='\0') { CompStr[j] = INT[1]; j++; }
				CompStr[j] = ']'; j++;
			}
				break;
			case ALT1KK:
			{
				char INT1[100], INT2[200]; INT1[0]='\0'; INT2[0]='\0'; 
				sprintf(INT1, "%d", AxiomComposition[i].Parameter1); 
				sprintf(INT2, "%d", AxiomComposition[i].Parameter2);
				CompStr[j] = 'A';j++; CompStr[j] = 'L';j++; CompStr[j] = 'T';j++;
				CompStr[j] = '1';j++; CompStr[j] = 'K';j++;	CompStr[j] = 'K';j++;
				if (AxiomComposition[i].Mode == CLASSICAL_TR) {
					CompStr[j] = 'c'; j++;
				} else if (AxiomComposition[i].Mode == AXIOMATIC_TR_COMP) {
					CompStr[j] = 'o'; j++;
				}
				CompStr[j] = '['; j++;
				CompStr[j] = INT1[0]; j++;
				if (INT1[1]!='\0') { CompStr[j] = INT1[1]; j++;	}
				CompStr[j] = ']'; j++;
				CompStr[j] = '['; j++;
				CompStr[j] = INT2[0]; j++;
				if (INT2[1]!='\0') { CompStr[j] = INT2[1]; j++;	}
				CompStr[j] = ']'; j++;
			}
				break;
			case FIVEK:
			{
				char INT[100]; INT[0]='\0'; sprintf(INT, "%d", AxiomComposition[i].Parameter1);
				CompStr[j] = '5'; j++; CompStr[j] = 'K'; j++;
				if (AxiomComposition[i].Mode == CLASSICAL_TR) {
					CompStr[j] = 'c'; j++;
				} else if (AxiomComposition[i].Mode == AXIOMATIC_TR_COMP) {
					CompStr[j] = 'o'; j++;
				}
				CompStr[j] = '['; j++;
				CompStr[j] = INT[0]; j++;
				if (INT[1]!='\0') { CompStr[j] = INT[1]; j++; }
				CompStr[j] = ']'; j++;
			}
				break;
			case BK:
			{
				char INT[100]; INT[0]='\0'; sprintf(INT, "%d", AxiomComposition[i].Parameter1);
				CompStr[j] = 'B'; j++; CompStr[j] = 'K'; j++;
				if (AxiomComposition[i].Mode == AXIOMATIC_TR_COMP) {
					CompStr[j] = 'o'; j++;
				}
				CompStr[j] = '['; j++;
				CompStr[j] = INT[0]; j++;
				if (INT[1]!='\0') { CompStr[j] = INT[1]; j++; }
				CompStr[j] = ']'; j++;
			}
				break;	
			default:
				eml_Error("No case in eml_PrintAxiomComposition.");
				break;
			}
			if (i != AxiomCompositionIndex-1){CompStr[j] = ','; j++;}
		}
		CompStr[j] = '\0';
	}
	printf("\nRequested Composition ..... %s", CompStr); /* always print */
			
}

static void eml_AxiomOptionsInit(FLAGSTORE Flags)
/**************************************************************
  INPUT:   Flags
  EFFECT:  Puts the default values into the HiddenOpt structure
           Populates these structures with values read from the flags 
           flag_EMLAXIOMOPTIONS and flag_EMLAXIOMHIDDENOPTIONS 
 ***************************************************************/
{
	char Options[31], HiddenOptions[31]; /* 11 is enough */
	int OptInt = flag_GetFlagValue(Flags, flag_EMLAXIOMOPTIONS); 
	int HiddenOptInt = flag_GetFlagValue(Flags, flag_EMLAXIOMHIDDENOPTIONS);
	Options[0] = '\0'; 
	HiddenOptions[0] = '\0';
		
	/* Set to default values  */
	HiddenOpt.IgnoreLogicFlagWarnings = eml_OFF;
	HiddenOpt.IncludeNegativeDefs = eml_OFF;
	HiddenOpt.ExcludeOptionalPositiveShortcuts = eml_OFF;
	HiddenOpt.NeverUsePositiveShortcuts = eml_OFF;
	HiddenOpt.DoNotSortTermNames = eml_OFF;	/* refers to eml_OptTermName vs. eml_TermName */
	HiddenOpt.DoNotUseComposition = eml_OFF;
	HiddenOpt.UsingInlineAxiomfeatures = eml_OFF; /* NOT set by flags - set by software */
	HiddenOpt.UsingSetFlagAxiomfeatures = eml_OFF; /* NOT set by flags - set by software */
	HiddenOpt.AlwaysUseSubstitutedSymbolNames = eml_OFF;
	HiddenOpt.DoNotUsePrintStatements = eml_OFF;
	HiddenOpt.DoNotUseAxiomBComposition = eml_OFF;
	HiddenOpt.DoNotUseAxiomDComposition = eml_OFF;
	HiddenOpt.DoNotUseAxiomAlt1Composition = eml_OFF;
	HiddenOpt.DoNotUseAxiom4Composition = eml_OFF;
	HiddenOpt.DoNotUseAxiom5Composition = eml_OFF;
	HiddenOpt.DoNotUseAxiom4KComposition = eml_OFF;
	HiddenOpt.DoNotUseAxiom5KComposition = eml_OFF;
	HiddenOpt.DoNotUseAxiomAlt1KKComposition = eml_OFF;
	HiddenOpt.DoNotUseSetPrecedence = eml_FULL; /* NB */
	/* Override default values according to flags */
	if (OptInt > 0) {
		eml_Int2String(OptInt, Options); /* check value & populate string */
		
		if (Options[0] == '1') {
			HiddenOpt.DoNotUseAxiomBComposition = eml_ON;
			eml_Print("\nDoNotUseAxiomBComposition = ON"); 
		}
		if (Options[0] == '2') {
			HiddenOpt.DoNotUseAxiomBComposition = eml_OFF;
			eml_Print("\nDoNotUseAxiomBComposition = Scheme2"); 
		}
		if (Options[1] == '1') {
			HiddenOpt.DoNotUseAxiomDComposition = eml_ON;
			eml_Print("\nDoNotUseAxiomDComposition = ON"); 
		}
		if (Options[2] == '1') {
			HiddenOpt.DoNotUseAxiomAlt1Composition = eml_ON;
			eml_Print("\nDoNotUseAxiomAlt1Composition = ON"); 
		}
		if (Options[3] == '1') {
			HiddenOpt.DoNotUseAxiom4Composition = eml_ON;
			eml_Print("\nDoNotUseAxiom4Composition = ON"); 
		}
		if (Options[4] == '1') {
			HiddenOpt.DoNotUseAxiom5Composition = eml_ON;
			eml_Print("\nDoNotUseAxiom5Composition = ON"); 
		}
		if (Options[5] == '1') {
			HiddenOpt.DoNotUseAxiom4KComposition = eml_ON;
			eml_Print("\nDoNotUseAxiom4KComposition = ON"); 
		}
		if (Options[6] == '1') {
			HiddenOpt.DoNotUseAxiom5KComposition = eml_ON;
			eml_Print("\nDoNotUseAxiom5KComposition = ON"); 
		}
		if (Options[7] == '1') {
			HiddenOpt.DoNotUseAxiomAlt1KKComposition = eml_ON;
			eml_Print("\nDoNotUseAxiomAlt1KKComposition = ON"); 
		}
	}

	if (HiddenOptInt > 0) {
		eml_Int2String(HiddenOptInt, HiddenOptions); /* check value and polulate string */
		
		if (HiddenOptions[0] == '1') {
			HiddenOpt.DoNotUseSetPrecedence = eml_ON; 
			eml_Print("\nDoNotUseSetPrecedence = ON");
		}
		if (HiddenOptions[1] == '1') {
			HiddenOpt.IgnoreLogicFlagWarnings = eml_ON;
			eml_Print("\nIgnoreLogicFlagWarnings = ON"); 
		}
		if (HiddenOptions[2] == '1') {
			HiddenOpt.ExcludeOptionalPositiveShortcuts = eml_ON;
			eml_Print("\nExcludeOptionalPositiveShortcuts = ON = NONE"); 
		}
		if (HiddenOptions[3] == '1') {
			HiddenOpt.DoNotSortTermNames = eml_ON;
			eml_Print("\nDoNotSortTermNames = ON"); 
		}
		if (HiddenOptions[4] == '1') {
			HiddenOpt.DoNotUseComposition = eml_ON;
			eml_Print("\nDoNotUseComposition = ON");
		}
		if (HiddenOptions[5] == '1') { 
			HiddenOpt.AlwaysUseSubstitutedSymbolNames = eml_ON;
			eml_Print("\nAlwaysUseSubstitutedSymbolNames = ON");
		}
		if (HiddenOptions[6] == '1') {
			HiddenOpt.DoNotUsePrintStatements = eml_ON;
			eml_Print("\nDoNotUsePrintStatements = ON");
		} 
		if (HiddenOptions[7] == '1') { 
			HiddenOpt.NeverUsePositiveShortcuts  = eml_ON;
			eml_Print("\nNeverUsePositiveShortcuts = ON");
		}
	}
		
	return;
}

static void eml_Int2String(int Value, char *Integer)
/**************************************************************
  INPUT: An Integer beginning with dummy 9, typically of the form 900001001 (1+8 digits) 
         Str must be char[9]  or more
  RETURNS: Indirectly returns the String described below.
  EFFECT:  Builds a string from the integer used as input for the flags 
           	flag_EMLAXIOMOPTIONS and flag_EMLAXIOMHIDDENOPTIONS
 ***************************************************************/
{
	if (Value > 999999999) { 
		eml_Error("Error in Binary Flag caught in eml_Int2String.");
	}
	Integer[0] = '\0';
	sprintf(Integer, "%d", Value); /* convert int to String */
	
	if ((Integer[0] != '9') || (strlen(Integer) != 9)) { /* check format */
		eml_Error("Format Error in Binary Flag caught in eml_Int2String.");
	}
	
	/* process string - shift along one to loose the leading 9 */
	Integer[0] = Integer[1]; 
	Integer[1] = Integer[2];
	Integer[2] = Integer[3];
	Integer[3] = Integer[4];
	Integer[4] = Integer[5];
	Integer[5] = Integer[6];
	Integer[6] = Integer[7];
	Integer[7] = Integer[8];
	Integer[8] = '\0';
		
	return;
}

static BOOL eml_AreAxiomsDefined ()
/**************************************************************
  EFFECT:  Tests whether any axioms (other than the default K) as defined
 ***************************************************************/
{
	if (AxiomCompositionIndex > 1) {
		return TRUE;
	} else {
		return FALSE;
	}
}
static AXIOM eml_GetAxiom (int Index) 
/************************************************************** 
  EFFECT:  Get an axiom structure from the array at position index 
 ***************************************************************/
{
	if (Index >= AxiomCompositionIndex) {
		eml_Error("Attempt to Access AxiomComposition Past Defined Axioms.");
	}
	return AxiomComposition[Index];
}
static BOOL eml_BuildAxiom(AXIOMTYPE AxiomType, AXIOMMODE Mode, int Parameter1, int Parameter2)
/**************************************************************
  EFFECT: Build an axiom with the defined input at the next avaialbe slot in the store array
 ***************************************************************/
{
	return eml_BuildAxiomRS(AxiomType, Mode, Parameter1, Parameter2, symbol__NULL, symbol__NULL);
}
static BOOL eml_BuildAxiomR(AXIOMTYPE AxiomType, AXIOMMODE Mode, int Parameter1, int Parameter2, 
		SYMBOL Symbol)
/**************************************************************
  EFFECT:  Build an axiom with the defined input at the next avaialbe slot in the store array
 ***************************************************************/
{
	return eml_BuildAxiomRS(AxiomType, Mode, Parameter1, Parameter2, Symbol, symbol__NULL);
}
static BOOL eml_BuildAxiomRS(AXIOMTYPE AxiomType, AXIOMMODE Mode, int Parameter1, int Parameter2,
		SYMBOL Symbol, SYMBOL Symbol2)
/**************************************************************
  EFFECT:  Build an axiom with the defined input at the next avaialbe slot in the store array
 ***************************************************************/
{
	AXIOM Axiom;	
	Axiom.AxiomType = AxiomType;
	Axiom.Mode = Mode;
	Axiom.Parameter1 = Parameter1;
	Axiom.Parameter2 = Parameter2;
	Axiom.Index = AxiomCompositionIndex;
	Axiom.Modality = Symbol;
	Axiom.Modality2 = Symbol2;
	
	if (AxiomCompositionIndex >= (MAXDEFINEDAXIOMS-1) ) {
		eml_Error("Exceeded No. of Axioms. Recompile."); return FALSE;
	} else {
		AxiomComposition[AxiomCompositionIndex] = Axiom;
		AxiomCompositionIndex++;		
		return TRUE;
	}
}
static BOOL eml_BuildAxiomAt(int Index, AXIOMTYPE AxiomType, AXIOMMODE Mode, int Parameter1, int Parameter2)
/**************************************************************
  EFFECT:  Build an axiom with the defined input at the slot Index in the store array
 ***************************************************************/
{
	AXIOM Axiom;
    Axiom.AxiomType = AxiomType;
	Axiom.Mode = Mode;
	Axiom.Parameter1 = Parameter1;
	Axiom.Parameter2 = Parameter2;
	Axiom.Index = Index;
	Axiom.Modality = symbol__NULL;
	Axiom.Modality2 = symbol__NULL;
	
	if (AxiomCompositionIndex >= (MAXDEFINEDAXIOMS-1) ) {
		eml_Error("Exceeded No. of Axioms. Recompile."); return FALSE;
	} else {
		AxiomComposition[Index] = Axiom;
		AxiomCompositionIndex = Index+1;		
		return TRUE;
	}
}

void eml_SetAxiomFlagValueBi(char *Value1, char *Value3, char *Value2) 
/**************************************************************
  EFFECT:  Called from the .dfg parsing routines, to setup bi-modal axioms in set_axiom()
 ***************************************************************/
{
	AXIOMFLAG AxiomFlag;
    int Count, LengthOfArray;
	BOOL Found = FALSE;
	
    if ( (eml_INDEX_FLAG - 1) > MAXDEFINEDAXIOMS) {
    	eml_Error("Too Many Axioms defined in set_axiom");
	}
	AxiomFlag.R = Value1;
	AxiomFlag.S = Value3;
	AxiomFlag.Axiom = Value2;
	eml_AXIOMFLAG[eml_INDEX_FLAG] = AxiomFlag;
	LengthOfArray = sizeof eml_AllowedSetFlags/sizeof eml_AllowedSetFlags[0];
	
	for (Count = 0; Count < LengthOfArray; Count++) {
		if (strcmp(eml_AllowedSetFlags[Count], Value2) == 0) {
			Found = TRUE;
			/* break; */
		}
	}
	
	if (Found == FALSE) {
		eml_ErrorC("Unknown Axiom requested in set_Axiom = ",Value2);
	}
	eml_INDEX_FLAG++;
}

void eml_SetAxiomFlagValue(char *Value1, char *Value2) 
/**************************************************************
  EFFECT:  Called from the .dfg parsing routines, to setup all
  axioms except 4 and 5 in set_axiom()
 ***************************************************************/
{
	AXIOMFLAG AxiomFlag;
    int Count, LengthOfArray;
	BOOL Found = FALSE;
	
    if ( (eml_INDEX_FLAG - 1) > MAXDEFINEDAXIOMS) {
    	eml_Error("Too Many Axioms defined in set_axiom");
	}
	AxiomFlag.R = Value1;
	AxiomFlag.Axiom = Value2;
	AxiomFlag.S = Value1;
	eml_AXIOMFLAG[eml_INDEX_FLAG] = AxiomFlag;
	LengthOfArray = sizeof eml_AllowedSetFlags/sizeof eml_AllowedSetFlags[0];
	
	for (Count = 0; Count < LengthOfArray; Count++) {
		if (strcmp(eml_AllowedSetFlags[Count], Value2) == 0) {
			Found = TRUE;
			/* break; */
		}
	}
	
	if (Found == FALSE) {
		eml_ErrorC("Unknown Axiom requested in set_Axiom = ",Value2);
	}
	eml_INDEX_FLAG++;
}

void eml_SetAxiomFlagValue2(char *Value1, int Value2) 
/**************************************************************
  EFFECT:  Called from the .dfg parsing routines, to setup axioms 4 and 5 in set_axiom()
 ***************************************************************/
{
	static char Value2Str4[2], Value2Str5[2];
	Value2Str4[0] = '4'; Value2Str5[0] = '5';
	Value2Str4[1] = '\0'; Value2Str5[1] = '\0';
	
	switch (Value2) {
	case 4: /*sprintf(Value2Str4, "%d", Value2);*/
		eml_SetAxiomFlagValue(Value1, Value2Str4);
		break;
	case 5:
		eml_SetAxiomFlagValue(Value1, Value2Str5);
		break;
	default:
		eml_ErrorD("Unknown Axiom requested in set_Axiom [%d]", Value2);	break;
	}
}

static void eml_AnalyzeSetAxiom(FLAGSTORE Store) 
/**************************************************************
  EFFECT:  Called in eml module to support set_axiom() mechanism
 ***************************************************************/
{
	int Count;
	for (Count = 0; Count < eml_INDEX_FLAG; Count++) {
		SYMBOL SymbolR = symbol_Lookup(eml_AXIOMFLAG[Count].R);
		SYMBOL SymbolS = symbol_Lookup(eml_AXIOMFLAG[Count].S);
		if ( eml_IsNullSymbol(SymbolR) ) { /* TODO think about moving these to the parser */
			eml_ErrorC("Symbol was undefined  ", eml_AXIOMFLAG[Count].R);
		}
		if ( eml_IsNullSymbol(SymbolS) ) {
			eml_ErrorC("Symbol was undefined  ", eml_AXIOMFLAG[Count].S);
		}
		
		if (strcmp(eml_AXIOMFLAG[Count].Axiom, "T") == 0) {
			eml_BuildAxiomR(T, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "B") == 0) {
			eml_BuildAxiomR(B, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "D") == 0) {
			eml_BuildAxiomR(D, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "4") == 0) {
			eml_BuildAxiomR(FOUR, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "5") == 0) {
			eml_BuildAxiomR(FIVE, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1") == 0) {
			eml_BuildAxiomR(ALT1, AXIOMATIC_TR, -1, -1, SymbolR);
		} 
		else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "None") == 0) {
			eml_BuildAxiomR(NONE, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} 
		else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "Tc") == 0) {
			eml_BuildAxiomR(T, CLASSICAL_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "Bc") == 0) {
			eml_BuildAxiomR(B, CLASSICAL_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "Dc") == 0) {
			eml_BuildAxiomR(D, CLASSICAL_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "4c") == 0) {
			eml_BuildAxiomR(FOUR, CLASSICAL_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "5c") == 0) {
			eml_BuildAxiomR(FIVE, CLASSICAL_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1c") == 0) {
			eml_BuildAxiomR(ALT1, CLASSICAL_TR, -1, -1, SymbolR);
		} 		
		  else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "To") == 0) {
			eml_BuildAxiomR(T, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "Bo") == 0) {
			eml_BuildAxiomR(B, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "Do") == 0) {
			eml_BuildAxiomR(D, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "4o") == 0) {
			eml_BuildAxiomR(FOUR, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "5o") == 0) {
			eml_BuildAxiomR(FIVE, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1o") == 0) {
			eml_BuildAxiomR(ALT1, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} 
		  else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "4K2") == 0) {
			eml_BuildAxiomR(FOURK, AXIOMATIC_TR, 2, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "4K3") == 0) {
			eml_BuildAxiomR(FOURK, AXIOMATIC_TR, 3, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "5K2") == 0) {
			eml_BuildAxiomR(FIVEK, AXIOMATIC_TR, 2, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "5K3") == 0) {
			eml_BuildAxiomR(FIVEK, AXIOMATIC_TR, 3, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK11") == 0) {
			eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR, 1, 1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK12") == 0) {
			eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR, 1, 2, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK21") == 0) {
			eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR, 2, 1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK22") == 0) {
			eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR, 2, 2, SymbolR);
		} 
		else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "4K2o") == 0) {
			eml_BuildAxiomR(FOURK, AXIOMATIC_TR_COMP, 2, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "4K3o") == 0) {
			eml_BuildAxiomR(FOURK, AXIOMATIC_TR_COMP, 3, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "5K2o") == 0) {
			eml_BuildAxiomR(FIVEK, AXIOMATIC_TR_COMP, 2, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "5K3o") == 0) {
			eml_BuildAxiomR(FIVEK, AXIOMATIC_TR_COMP, 3, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK11o") == 0) {
			eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR_COMP, 1, 1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK12o") == 0) {
			eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR_COMP, 1, 2, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK21o") == 0) {
			eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR_COMP, 2, 1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK22o") == 0) {
			eml_BuildAxiomR(ALT1KK, AXIOMATIC_TR_COMP, 2, 2, SymbolR);
		}
		else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "4K2c") == 0) {
			eml_BuildAxiomR(FOURK, CLASSICAL_TR, 2, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "4K3c") == 0) {
			eml_BuildAxiomR(FOURK, CLASSICAL_TR, 3, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "5K2c") == 0) {
			eml_BuildAxiomR(FIVEK, CLASSICAL_TR, 2, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "5K3c") == 0) {
			eml_BuildAxiomR(FIVEK, CLASSICAL_TR, 3, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK11c") == 0) {
			eml_BuildAxiomR(ALT1KK, CLASSICAL_TR, 1, 1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK12c") == 0) {
			eml_BuildAxiomR(ALT1KK, CLASSICAL_TR, 1, 2, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK21c") == 0) {
			eml_BuildAxiomR(ALT1KK, CLASSICAL_TR, 2, 1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "ALT1KK22c") == 0) {
			eml_BuildAxiomR(ALT1KK, CLASSICAL_TR, 2, 2, SymbolR);
		}
		/* new axioms "SRo", "Go", "DENo", "TRo", "Mo", "Wo" */
		else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "SRo") == 0) {
			eml_BuildAxiomR(SR, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "Go") == 0) {
			eml_BuildAxiomR(G, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "DENo") == 0) {
			eml_BuildAxiomR(DEN, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "TRo") == 0) {
			eml_BuildAxiomR(TR, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "Mo") == 0) {
			eml_BuildAxiomR(M, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "Wo") == 0) {
			eml_BuildAxiomR(W, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		}
		else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "SR") == 0) {
			eml_BuildAxiomR(SR, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "G") == 0) {
			eml_BuildAxiomR(G, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "DEN") == 0) {
			eml_BuildAxiomR(DEN, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "TR") == 0) {
			eml_BuildAxiomR(TR, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "M") == 0) {
			eml_BuildAxiomR(M, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "W") == 0) {
			eml_BuildAxiomR(W, AXIOMATIC_TR, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "Ho") == 0) {
			eml_BuildAxiomR(H, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "H") == 0) {
			eml_BuildAxiomR(H, AXIOMATIC_TR, -1, -1, SymbolR);
		} 
		else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "CRo") == 0) {
			eml_BuildAxiomRS(CR, AXIOMATIC_TR_COMP, -1, -1, SymbolR, SymbolS);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "CR") == 0) {
			eml_BuildAxiomRS(CR, AXIOMATIC_TR, -1, -1, SymbolR, SymbolS);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "CR2o") == 0) {
			eml_BuildAxiomRS(CR2, AXIOMATIC_TR_COMP, -1, -1, SymbolR, SymbolS);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "CR2") == 0) {
			eml_BuildAxiomRS(CR2, AXIOMATIC_TR, -1, -1, SymbolR, SymbolS);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "CR3o") == 0) {
			eml_BuildAxiomRS(CR3, AXIOMATIC_TR_COMP, -1, -1, SymbolR, SymbolS);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "CR3") == 0) {
			eml_BuildAxiomRS(CR3, AXIOMATIC_TR, -1, -1, SymbolR, SymbolS);
		} 
		else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "B2o") == 0) {
			eml_BuildAxiomR(BK, AXIOMATIC_TR_COMP, 2, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "B2") == 0) {
			eml_BuildAxiomR(BK, AXIOMATIC_TR, 2, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "B3o") == 0) {
			eml_BuildAxiomR(BK, AXIOMATIC_TR_COMP, 3, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "B3") == 0) {
			eml_BuildAxiomR(BK, AXIOMATIC_TR, 3, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "DBBBo") == 0) {
			eml_BuildAxiomR(DBBB, AXIOMATIC_TR_COMP, -1, -1, SymbolR);
		} else if (strcmp(eml_AXIOMFLAG[Count].Axiom, "DBBB") == 0) {
			eml_BuildAxiomR(DBBB, AXIOMATIC_TR, -1, -1, SymbolR);
		}
		else {
			eml_Error("Unknown Axiom requested in setAxiomFlag.");
		}
	}
}


int eml_GetPrecedenceMode()
/**************************************************************
  EFFECT:  
 ***************************************************************/
{
	if (HiddenOpt.DoNotUseSetPrecedence == eml_OFF) {
		return 1;
	} else if (HiddenOpt.DoNotUseSetPrecedence == eml_FULL) {
		return 1;
	} else { 
		return 0;
	}	
		
}

/* ---- END ---- */
